
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Formal geometry
+--{: .hide}
[[!include formal geometry -- contents]]
=--
=--
=--



#Contents#
* table of contents
{:toc}

## Idea

### General

An _asymptotic expansion_ of a [[function]] is a [[formal power series]] that may not [[convergence|converge]], but whose terms decrease fast enough such that the truncation of the series at any finite order still provides a controled approximation to a given [[function]].  

A key class of examples of asymptotic expansions are the [[Taylor series]] of [[smooth functions]] (example \ref{TaylorSeriesOfSmoothFunctionIsAsymptoticSeries} below) around any point. Beware that by [[Borel's theorem]] this means that _every_ [[formal power series]] is the asymptotic expansion of _some_ smooth function and of more than one smooth function (remark \ref{TheoremBorel} below).

In [[resurgence theory]] one tries to re-identify from an asymptotic expansion the corresponding [[analytic function|non-analytic]] contributions.


### In perturbative quantum field theory

The concept of asymptotic expansions plays a key role in the interpretation of [[perturbative quantum field theory]] (pQFT): This computes [[quantum observables]] as [[formal power series]] (in the [[coupling constant]] and in [[Planck's constant]]) whose [[radius of convergence]] necessarily vanishes in cases of interest ([Dyson 52](#Dyson52)). 

Nevertheless, for examples such as [[quantum electrodynamics]] and [[quantum chromodynamics]] as in the [[standard model of particle physics]], the truncation of these series to the first handful of [[loop orders]]  happens to agree with [[experiment]] (such as at the [[LHC]] collider) to high precision (for [[QED]]) or at least good precision (for [[QCD]]). Therefore one interprets the [[scattering matrix]] in [[perturbative quantum field theory]] as an asymptotic expansion of what should be the true [[non-perturbative field theory|non-perturbative]] result. 

With [[resurgence theory]] one may try to deduce from the [[Feynman perturbation series]] regarded as an asymptotic expansion the hidden [[non-perturbative effects]].

## Definition

+-- {: .num_defn}
###### Definition

Given a [[function]] $f \colon \mathbb{R} \to \mathbb{R}$, a [[formal power series]] $\sum_{n = 0}^\infty a_n x^n$ is an 
**asymptotic expansion** of $f$ at $x = 0$ if for each $n \in \mathbb{N}$ the [[limit of a sequence|limit]] of the difference between $f$ and the [[sum]] of the first $n$ terms of the series divided by $x^n$ is zero as $x$ tends to 0:

$$
  \underset{x \to 0}{\lim} 
  \left( 
    \frac{1}{x^n}
    \left(
      f(x)  - \sum_{k = 0}^n a_k x^k
    \right)
  \right)
  \;=\; 
  0
  \,.
$$

=--

+-- {: .num_remark}
###### Remark

This definition makes no statement about the behaviour as $n \to \infty$. In particular an asymptotic expansion may have vanishing [[radius of convergence]] (and nevertheless provide useful approximate information).

=--


## Examples
 {#Examples}

+-- {: .num_example #TaylorSeriesOfSmoothFunctionIsAsymptoticSeries}
###### Example
**([[Taylor series]] of [[smooth function]] is asymptotic series)**

The [[Taylor series]] of a [[smooth function]] $f \colon \mathbb{R} \to \mathbb{R}$ at any point is always an asymptotic expansion of $f$ around that point, regardless of whether its [[radius of convergence]] vanishes or not.

=--

+-- {: .proof}
###### Proof

This follows from the [[Hadamard lemma]], which says that for each $n \in \mathbb{N}$ and each expansion point $x_0 \in \mathbb{R}$ (which we may without restrict of generality assume to be $x_0 = 0$) there exists a smooth function $h_n \colon \mathbb{R} \to \mathbb{R}$ such that 

$$
  f(x) = f(0) + x f^{(0)}(0) + \frac{1}{2} x^2 f^{(2)}(0) 
  + \cdots +
  \frac{1}{n!} x^n f^{n}(0)
  + 
 \frac{1}{(n+1)!} x^{n+1} h_n(x)
  \,,
$$

where $f^{(k)} \colon \mathbb{R} \to \mathbb{R}$ denotes the $k$th [[derivative]] of $f$.

Therefore with 

$$
  (a_k)_{k \in \mathbb{N}}
  \coloneqq
  \left(
    \frac{1}{k!} f^{(k)}(0)
  \right)_{k \in \mathbb{N}}
$$

the [[coefficients]] of the [[Taylor series]] of $f$ at $x_0 = 0$, we have

$$
  \begin{aligned}
    \underset{x \to 0}{\lim}
    \left(  
      \frac{1}{x^n}
      \left(
        f(x)  - \sum_{k = 0}^n  a_k x^k
      \right)
    \right)
    & =
    \underset{x \to 0}{\lim} 
    \left( 
      \frac{1}{x^n}
      \left(
        \frac{1}{(n+1)!} x^{n+1} h_n(x)
      \right)   
    \right)
    \\
    & = 
    \underset{x \to 0}{\lim} 
    \left(
      x \frac{1}{(n+1)!} h_n(x)
    \right)   
    \\
    & = 
    0 \cdot \frac{1}{(n+1)!} h_n(0)
    \\
    & = 0
  \end{aligned}
  \,.
$$

Here in taking the [[limit of a sequence|limit]] we used from [[Hadamard's lemma]] that $h_n(x)$ and hence also $x h_n(x)$ is a [[smooth function]], hence in particular a [[continuous function]], on all of $\mathbb{R}$, hence that its limit as $x \to 0$ is just the value of the function at $x = 0$.

=--


+-- {: .num_remark #TheoremBorel}
###### Remark
**([[Borel's theorem]])**

Beware that by [[Borel's theorem]], _every_ [[formal power series]] is the [[Taylor series]] of _some_ [[smooth function]], and of more than one smooth function; hence by example \ref{TaylorSeriesOfSmoothFunctionIsAsymptoticSeries} every formal power series is the asymptotic expansion of _some_ smooth function, and of more than one smooth function. 

=--

## History

From [Suslov 05](#Suslov05):

> Classical books on diagrammatic techniques $[$in [[perturbative quantum field theory]]$]$ describe the construction of [[Feynman diagram|diagram]] series as if they were well defined. However, almost all important [[Feynman perturbation series|perturbation series]] are hopelessly [[divergent series|divergent]] since they have zero [[radii of convergence]]. The first argument to this effect was [given by Dyson](#Dyson52) with regard to [[quantum electrodynamics]].

> $[$...$]$

> Even though Dyson's argument is unquestionable, it was hushed up or decried for many years: the scientific community was not ready to face the problem of the hopeless divergency of perturbation series.

> $[$...$]$

> The modern status of divergent series suggests that techniques for manipulating them should be included in a minimum syllabus for graduate students in theoretical physics. However, the theory of divergent series is almost unknown to physicists, because the corresponding parts of standard university courses in calculus date back to the mid-nineteenth century, when divergent series were virtually banished from mathematics.

## Related concepts

* [[series]], [[divergent series]]

* [[Taylor series]], [[Puiseux series]]

* [[asymptotic series]], [[transseries]]

* [[resummation]], [[regular summation method]], [[Borel summability]]

* [[perturbation series]], [[Stokes phenomenon]]

* [[Feynman perturbation series]]

## References

An original article is

* G. Watson, _A theory of asymptotic series_, Philosophical Transactions of the Royal Society of London. Series A, Containing Papers of a Mathematical or Physical Character
Vol. 211, (1912), pp. 279-313 ([JSTOR](http://www.jstor.org/stable/91005))

Basic introductions include

* Joel Feldman, _Taylor series and asymptotic expansions_ lecture notes [pdf](http://www.math.ubc.ca/~feldman/m321/asymptotic.pdf)

* R. Shankar Subramanian, _An Introduction to Asymptotic Expansions_ ([pdf](http://web2.clarkson.edu/projects/subramanian/ch527/supplem/asympt.pdf))

The argument that the [[S-matrix]] formal power series in all [[perturbative quantum field theories]] of interest is necessarily divergent (and hence at best an asymptotic series) is due to


* {#Dyson52} [[Freeman Dyson]], _Divergence of perturbation theory in quantum electrodynamics_, Phys. Rev. 85, 631, 1952 ([spire](http://inspirehep.net/record/29799?ln=en))

made more precise in

* {#Lipatov77} [[Lev Lipatov]], _Divergence of the Perturbation Theory Series and the Quasiclassical Theory_, Sov.Phys.JETP 45 (1977) 216&#8211;223 ([pdf](http://jetp.ac.ru/cgi-bin/dn/e_045_02_0216.pdf))

recalled for instance in

* {#Suslov05} [[Igor Suslov]], section 1 of _Divergent perturbation series_, Zh.Eksp.Teor.Fiz. 127 (2005) 1350; J.Exp.Theor.Phys. 100 (2005) 1188 ([arXiv:hep-ph/0510142](https://arxiv.org/abs/hep-ph/0510142))

* Justin Bond, last section of _Perturbative QFT is Asymptotic; is Divergent; is Problematic in Principle_ ([pdf](https://mcgreevy.physics.ucsd.edu/s13/final-papers/2013S-215C-Bond-Justin.pdf))

* {#HollandsWald14} [[Stefan Hollands]], [[Robert Wald]], section 4.1 of _Quantum fields in curved spacetime_, Physics Reports Volume 574, 16 April 2015, Pages 1-35 ([arXiv:1401.2026](https://arxiv.org/abs/1401.2026))

In the example of [[phi^4 theory]] this non-convergence of the perturbation series is discussed in

* {#Helling} Robert Helling, p. 4 of _Solving classical field equations_ ([pdf](http://homepages.physik.uni-muenchen.de/~helling/classical_fields.pdf))


[[!redirects asymptotic expansions]]

[[!redirects asymptotic series]]

