+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Philosophy
+-- {: .hide}
[[!include philosophy - contents]]
=--
#### Physics
+-- {: .hide}
[[!include physicscontents]]
=--
=--
=--


# Contents
* table of contents
{: toc}



##General Idea


In [[philosophy of science]] and specifically in the [[philosophy of physics]],  **coordination** concerns the relationship between [[theory (physics)|scientific theory]] and [[experiment|empirical data]]. A [[physical theory]], written, say, as a set of [[equations]] or similar data, does not by itself allow the formation of predictions. In addition we need some way of mediating between this theory and what instruments can detect about the [[observable universe]]. 

For example an abstract [[differential equation]] on the [[sections]] of some abstract [[fiber bundle]] does not constitute a theory of physics unless one specifies which kind of [[field (physics)|physical field]] these sections are meant to represent. 

The nature of the field however determines a rule for how to measure it: If we are told that the theory is meant to be about the [[electromagnetic field]], say [[electromagnetic waves]], we test it by measuring, say, [[Lorentz forces]] on [[electrons]]; while if we are told that the theory is meant to be about [[gravity]], say [[gravitational waves]], we test it by entirely different measurements (e.g. via the [[LIGO]] experiment). 

But this distinction may not be reflected in the plain [[mathematics]] that constitutes the physical, theory: In the previous example both [[electromagnetic waves]] and [[gravitational waves]] may be described,  after appropriate [[gauge fixing]], by the same kind of [[wave equation]]. Hence _coordination_ is involved in specifying what aspect of observable reality this equation is meant to be referring to.

Further aspects of coordination concern the workings of instruments such as detectors. To be able to say that a physical field has a certain strength at a point requires us to give an account of how the field affects some component of the detection process. Typically then we need to rely on an understanding that other parts of the apparatus will not be significantly affected by the physical field.


##History

The term *coordination* is a translation of the German *Zuordnung*. The latter has a long history of use with [[mathematics]] as something like _assignment_, hence _[[function]]_. Its use in [[philosophy]] stretches back to [[Hermann von Helmholtz]]'s *Zeichentheorie*, and was taken up later by a number of philosophers, especially by those, such as [[Ernst Cassirer]], trying to understand the implications for epistemology of the profound transformations which took place in mathematics and physics at the turn of the nineteenth century ([[special relativity]], [[general relativity]], [[quantum mechanics]]).

In the early twentieth century, discussions about coordination often took [[Henri Poincaré's]] _conventionalism_ as a starting point. Poincaré had illustrated his ideas with a thought experiment about the geometric investigations of inhabitants of a spherical world in which the temperature distribution is non-uniform, cooling off to the boundary away from the center in a prescribed way, and where all materials thermally expand with the same coefficient. An inhabitant of this world measuring with a ruler the ratio of circumference to diameter of a circle about the center of the world will find an answer greater than $\pi$. 

Two interpretations then present themselves: either the geometry of the space can be taken to be [[Euclidean geometry|Euclidean]], by factoring in the changing length of a ruler through the space, or the ruler may be considered to provide a stable unit of distance and the geometry is now taken to be hyperbolic (the heat distribution having been arranged to allow this). Poincaré proposed that it is only a matter of convenience which of these accounts we choose, suggesting that we will typically retain the interpretation in terms of Euclidean geometry.

A relevant real-life experiment is Michelson and Morley's attempt in 1887 to detect the presence of the aether. Measurements of the [[speed of light]] along two perpendicular directions via interference patterns indicated it to be a constant, when one might have expected a difference according to the orientation of the direction with respect to the supposed passage of the apparatus through the aether. However another interpretation given by FitzGerald and Lorentz proposed that physical objects contract according to their motion relative to the aether in such a way that the apparatus would not be able to detect a direction-dependent speed of light.

In his *Allgemeine Erkenntnislehre* ([Schlick18](#Schlick18})), Moritz Schlick  relies heavily on the notion of coordination, proposing that it should be understood as a simple [[set theory|set-theoretic]] [[mapping]] between the system of implicitly defined terms of a [[physical theory]] and some system of given objects or elements of sensation. A few years later, Hans Reichenbach, by contrast, argued ([Reichenbach 24](#Reichenbach24)) that the act of coordination was no mere mapping between existing systems, but itself played a constitutive role in defining the objects of knowledge themselves:

>The difficulty concerning coordinative definitions is similar to that concerning elementary facts: the physical thing that is coordinated is not an immediate perceptual experience but must be constructed from such experience by means of an interpretation. If I establish the coordinative definition "a light ray is a straight line", then the coordinated physical thing, the light ray, is a construction going beyond perception. ([1924](#Reichenbach24), p. 8)

A central issue between these accounts is that the more you press on the constitutive function of coordinating principles, the more it seems that the entities referred to by physics owe their characteristics to our conceptual framing rather than to how things are in themselves. 

One might hope, however, that away from toy cases such as Poincaré's heated sphere world, detailed physical investigation can determine between competing accounts. Einstein explained the superiority of his account of the Michelson-Morley experiment relative to FitzGerald-Lorentz contraction:

>Although the estimated difference between these two times is exceedingly small, Michelson and Morley performed an experiment involving interference in which this difference should have been clearly detectable. But the experiment gave a negative result — a fact very perplexing to physicists. Lorentz and FitzGerald rescued the theory from this difficulty by assuming that the motion of the body relative to the æther produces a contraction of the body in the direction of motion, the amount of contraction being just sufficient to compensate for the difference in time mentioned above. Comparison with the discussion in Section 11 shows that also from the standpoint of the theory of relativity this solution of the difficulty was the right one. But on the basis of the theory of relativity the method of interpretation is incomparably more satisfactory. According to this theory there is no such thing as a "specially favoured" (unique) co-ordinate system to occasion the introduction of the æther-idea, and hence there can be no æther-drift, nor any experiment with which to demonstrate it. Here the contraction of moving bodies follows from the two fundamental principles of the theory, without the introduction of particular hypotheses; and as the prime factor involved in this contraction we find, not the motion in itself, to which we cannot attach any meaning, but the motion with respect to the body of reference chosen in the particular case in point. Thus for a co-ordinate system moving with the earth the mirror system of Michelson and Morley is not shortened, but it is shortened for a co-ordinate system which is at rest relatively to the sun. ([Einstein 1916](#Einstein16))




## In quantum mechanics
 

### Bohrification

The idea of _[[Bohr toposes]]_ might be regarded as an attempt to formalize coordination for [[observables]] in [[quantum mechanics]]. There the idea is roughly that to a [[quantum mechanical system]] one assigns a [[topos]] (the "[[Bohr topos]]") such that the (or some of the) [[propositions]] in the [[internal logic]] of this topos match propositions about [[observables]] of the [[physical system]].


### Relation to interpretation of QM
 {#RelationToInterpretationOfQM}

Coordination is different from -- in fact somewhat orthogonal to -- [[interpretation of quantum mechanics]]. For instance a coordination in [[quantum mechanics]] involves relating [[self-adjoint operators]] to certain [[experiments]]. Given this coordination, the theory assigns [[expectation values]] for the outcomes of the experiment, but it does not necessarily offer an "interpretation why" these propbabilities are predicted.

On the other hand, it might be that a good formulation of the coordination process makes the need/desire for interpretations diminish. This was argued by ([Tanona 10](#Tanona10)):

>...the characterization of collapse as a separate physical process is misguided because the phenomenon which collapse is supposed to address concerns not an actual process within quantum mechanical theory but rather the coordination between empirical measurements and representations of quantum systems. Until we first get clear on this relationship, it is premature to propose new processes to account for features of that relationship.

## Related concepts

* [[experiment]]

* [[theory (physics)]]

* [[interpretation of quantum mechanics]]

* [[computable physics]]

##References

* {#Schlick18} Moritz Schlick, _Allgemeine Erkenntnislehre_ (1918)
  

* {#Reichenbach24} Hans Reichenbach, _Axiomatization of the Theory of Relativity_. Berkeley: University of California Press. (1969). Original German edition published in 1924.
  

* {#Ryckman91} Thomas Ryckman (1991), _Conditio sine qua non? Zuordnung in the Early Epistemologies of Cassirer and Schlick_, Synthese 88(1), pp. 57-95.
 

* {#Tanona10}[[Scott Tanona]], _Theory, coordination, and empirical meaning in modern physics_, in Mary Domski and Michael Dickson (eds.), _Discourse on a New Method: Reinvigorating the Marriage of History and Philosophy of Science_. Open Court (2010), pp. 423-454.

* {#Friedman99} [[Michael Friedman]], _Poincaré's Convetionalism and the logical positivists_, chapter 4 in _Reconsidering Logical Positivism_, Cambridge University Press 1999   ([web](https://books.google.co.uk/books?id=e9TjZc9wNUAC&pg=PA71#v=onepage&q&f=false))

* {#Einstein16} [[Albert Einstein]], _Relativity: The Special and General Theory_, 1916, New York: H. Holt and Company
