
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Enriched category theory
+--{: .hide}
[[!include enriched category theory contents]]
=--
#### Additive and abelian categories
+--{: .hide}
[[!include additive and abelian categories - contents]]
=--
=--
=--



# $Ab$-enriched categories
* tic
{: toc}

## Idea

An _$Ab$-enriched category_  (or, if small, _ringoid_) is a [[category enriched]] over the [[monoidal category]] [[Ab]] of [[abelian groups]] with its usual [[tensor product]].

Sometimes they are called [[pre-additive category|pre-additive categories]], but sometimes that term also implies the existence of a [[zero object]].


## Definition

Explicitly, an __$Ab$-enriched category__ is a [[category]] $C$ such that
for all objects $a,b$ the [[hom-set]] $Hom_C(a,b)$
is equipped with the structure of an [[abelian group]]; and
such that for all triples $a,b,c$ of objects the
[[composition]] operation 
$
  \circ_{a,b,c} : Hom_C(a,b) \times Hom_C(b,c) \to Hom_C(a,c)
$
is bilinear. A __ringoid__ is small $Ab$-enriched category.


## Remarks

*  $Ab$-enriched categories are called ringoids since the concept is a [[horizontal categorification]] (or 'oidification') of the concept of a [[ring]].

*  There is a canonical forgetful functor $Ab \to Set_*$ from
abelian groups to [[pointed set]]s, which sends each group to its underlying set with point being the neutral element. Using this functor, every $Ab$-enriched category $C$ is in particular also a category that is enriched over pointed sets (that is, a category with [[zero morphisms]]). This is sufficient for there to be a notion of [[kernel]] and [[cokernel]] in $C$.

*  In general, [[abelian category|abelian categories]] are the most important examples of $Ab$-enriched categories.  See [[additive and abelian categories]].


## Finite products are absolute

One of the remarkable facts about $Ab$-enriched categories is that finite [[products]] (and [[coproducts]]) are [[absolute limit|absolute limits]].  This implies that finite products coincide with finite coproducts, and are preserved by _any_ $Ab$-enriched functor.


### Zero objects

In an $Ab$-enriched category $C$, any [[initial object]] is also a [[terminal object]], hence a [[zero object]], and dually.  An object $a\in C$ is a zero object just when its identity $1_a$ is equal to the zero morphism $0:a\to a$ (that is, the identity element of the abelian group $\hom_C(a,a)$).  Expressed in this way, it is easy to see that any $Ab$-enriched functor preserves zero objects.


### Biproducts

For $c_1, c_2 \in C$ two objects in an $Ab$-enriched category $C$,  [[generalized the|the]] [[product]] $c_1 \times c_2$ coincides  with [[generalized the|the]] [[coproduct]] $c_1 \sqcup c_2$ when either exists.  More precisely, when both exist, the canonical morphism
$$
  r : c_1 \sqcup c_2 \to c_1 \times c_2
$$
defined by
$$
  \left(
    c_i \to c_1 \sqcup c_2 \stackrel{r}{\to} c_1 \times c_2 \to c_j
  \right)
  =
  \left\{
    \array{
      Id_c_i & if i = j
      \\
      0 & if i \neq j
    }
  \right.
  \,,
$$
which exists whenever $c_1\sqcup c_2$ and $c_1\times c_2$ do, is an [[isomorphism]].  This object is called a [[biproduct]] or (sometimes) a [[direct sum]] and is generally denoted
$$
  c_1 \oplus c_2.
$$
It can be characterized diagrammatically as an object $c_1\oplus c_2$ equipped with morphisms $q_i:c_i\to c_1\oplus c_2$ and $p_i:c_1\oplus c_2 \to c_i$ such that $p_i q_j = \delta_{i j}$ and $q_1 p_1 + q_2 p_2 = 1_{c_1\oplus c_2}$.  Expressed in this form, it is clear that any $Ab$-enriched functor preserves biproducts.


## As a generalisation of rings

When using the term 'ringoid', one often assumes a ringoid to be [[small category|small]].

Ringoids share many of the properties of (noncommutative) [[rings]].  For instance, we can talk about (left and right) [[modules]] over a ringoid $R$, which can be defined as $Ab$-enriched [[functors]] $R\to Ab$ and $R^{op}\to Ab$.  [[bimodule|Bimodules]] over ringoids have a tensor product (the enriched [[tensor product of functors]]) under which they form a [[bicategory]], also known as the bicategory $Ab Prof$ of $Ab$-enriched [[profunctors]].  Modules over a ringoid also form an [[abelian category]] and thus have a [[derived category]].

One interesting operation on ringoids is the ($Ab$-enriched) [[Cauchy completion]], which is the completion under finite [[direct sums]] and [[split idempotents]].  In particular, the Cauchy completion of a ring $R$ is the category of [[finitely generated object|finitely generated]] [[projective object|projective]] $R$-modules (aka [[split monomorphism|split]] [[subobjects]] of finite-rank [[free object|free]] modules).  Every ringoid is [[equivalence|equivalent]] to its Cauchy completion in the bicategory $Ab Prof$, and two ringoids are equivalent in $Ab Prof$ if and only if their Cauchy completions are [[equivalence of categories|equivalent]] as $Ab$-enriched categories.  This sort of equivalence is naturally called [[Morita equivalence]].

See also [[dg-category]].


## Examples

* The category [[Ab]] is [[closed monoidal category|closed monoidal]] and hence canonically enriched over itself.

* An $Ab$-enriched category with one object is precisely a [[ring]].

* For any small $Ab$-enriched category $R$, the enriched [[presheaf category]] $[R^{op},Ab]$ is, of course, $Ab$-enriched.  If $R$ is a ring, as above, then $[R^{op},Ab]$ is the category of $R$-modules.


## Related concepts

* [[hom-group]]

* [[additive category]]

## References

* John Baez, [Ringoids](http://golem.ph.utexas.edu/category/2006/09/ringoids.html), blog
* C. Weibel, [[An Introduction to Homological Algebra]], Cambridge Univ. Press
* [[Daniel Murfet]], _Localisation of ringoids_, [pdf](http://therisingsea.org/notes/LocalisationOfRingoids.pdf) 2006 notes
* N. Popescu, _Abelian categories with applications to rings and modules_, London Math. Soc. Monographs 3, Academic Press 1973. xii+467 pp. MR0340375

[[!redirects Ab-enriched category]]
[[!redirects Ab-enriched categories]]
[[!redirects ringoid]]
[[!redirects ringoids]]
