
# Contents
* table of contents 
{: toc}

## Idea

The [[real number]] $\pi \in \mathbb{R}$ is the [[length]] of one [[hemisphere|hemi-circle]] of the [[unit circle]]. Hene $2 \pi$ is the circumference of the full [[unit circle]].

This number plays a central role in [[trigonometry]], but -- especially via its relation to [[complex analysis]] via [[Euler's formula]] -- it also appears in many other situations.

## Definition via real analysis 

The [[real number]] $\pi \in \mathbb{R}$ (occasionally called _Ludolph's number_ ---make that _very_ occasionally, nowadays--- or _Archimedes' constant_) is the minimal [[positive real number|positive]] [[root]] of the [[sine function]] $sin_\mathbb{R} : \mathbb{R}\to\mathbb{R}$, which itself is the unique solution to the [[differential equation]]/[[initial value problem]]
$$ sin_\mathbb{R}'' = -sin_\mathbb{R} $$
$$ sin_\mathbb{R}(0) = 0 $$
$$ sin_\mathbb{R}'(0) = 1 .$$

Alternatively, $\pi$ may be defined as $\frac{1}{2} \tau $, where $\tau$ is the [[period]] of the same function [[sin]].

An alternative description of $sin$ is as the unique function $\mathbb{R}\to\mathbb{R}$ continuous at $0$ and otherwise satisfying 
$$ 1 - x^2 \leq \frac{sin(x)}{x} \leq 1 $$
and 
$$ sin 3 x = 3 sin x - 4 sin^3 x $$
although this makes practical calculations rather difficult. (If you really care to know why this characterization works, you can look [here](http://ncatlab.org/toddtrimble/published/Characterization+of+sine). Or [here](http://nforum.mathforge.org/discussion/5773/a-short-note-for-todd-trimble/#Item_4).) 


### Tangential Remarks

Either of the definitions of $sin$ above mentions a thing, and claims some properties for it, in order to indirectly describe some other thing (in this case, $\pi$).  To properly make sense of either definition, it is necessary to ensure that one description or the other actually does define some thing, that there is in fact exactly one such thing so defined, and that it has the needed properties for the definition of $\pi$ to make sense — particularly, that the roots of $sin$ are isolated, and that there is a positive root.  These might make a decent [[exercise]] in a first course in classical analysis. 


## Definition via complex analysis 

A related but perhaps more conceptual description is via complex analysis. Recall that the standard [[exponential function]] is defined by the formula 

$$\exp(z) = \sum_{n \geq 0} \frac{z^n}{n!} = 1 + z + \frac{z^2}{2} + \frac{z^3}{6} + \ldots$$ 

for all [[complex numbers]] $z$ (as an absolutely [[Cauchy sequence|convergent series]]), and satisfies the equations 

* $\exp(z + w) = \exp(z) \cdot \exp(w)$, 

* $\exp(\widebar{z}) = \widebar{\exp(z)}$. 

It follows that for $z \in i \mathbb{R}$, where $z + \widebar{z} = 0$, we have ${|\exp(i t)|} = 1$. 

Hence $t \mapsto \exp(i t)$ defines a [[Lie group]] homomorphism $\phi$ from the additive group $\mathbb{R}$ to the multiplicative group $S^1$ of unit complex numbers. It may be checked that this is a local diffeomorphism: a local inverse to $z \mapsto \exp(z) - 1$ in a neighborhood of $0$ is given by 

$$z \mapsto \log (1 + z) = z - \frac{z^2}{2} + \frac{z^3}{3} - \ldots$$ 

Thus $\phi: \mathbb{R} \to S^1$ maps a small neighborhood $U$ of $0$ onto a small neighborhood $V$ of $1$ in $S^1$. As $S^1$ is [[connected space|connected]], we have $S^1 = \bigcup_{n \geq 1} V^n$ where $V^n$ consists of $n$-fold products of elements in $V$, and in fact a finite union $\bigcup_{n=1}^m V^n$ suffices since $S^1$ is [[compact space|compact]]. It follows easily that the homomorphism $\phi: \mathbb{R} \to S^1$ is surjective. 

In particular, there exists some element $t \in \mathbb{R}$ such that $\phi(t) = -1$. We may define $\pi$ to be the least positive $t$ such that $\phi(t) = -1$ (cf. Euler's formula $e^{\pi i} + 1 = 0$). Indeed, it is slightly nicer just to observe that $\ker(\phi)$ is nontrivial (since $S^1$ has [[torsion group|torsion elements]] whereas $\mathbb{R}$ does not) and must be a discrete subgroup, generated by a unique positive $\tau$, and one defines $\pi = \tau/2$. 

These considerations suggest why mathematicians sometimes consider $\tau = 2\pi$ to be "more fundamental" than $\pi$, or even that $2\pi i$ is the truly fundamental quantity, being (up to sign) the unique generator of the kernel of $\exp: \mathbb{C} \to \mathbb{C}^\times$. This is also reflected in the familiar contour integral formula 

$$\int_{{|z|} = 1} \frac{d z}{z} = 2\pi i$$ 

that on some level pervades complex analysis. 


## "Archimedean" definition 

A sequence that approximates $\pi$ that was available to [[Archimedes]] (using his "method of exhaustion") involves calculating perimeters of inscribed $2^n$-gons (squares, octagons, etc.) in a unit circle, using half-angle formulas. This brief description is, for that matter, available to high-school students, so we can just summarize the result. 

Define a sequence by the recursion $x_1 = 0$, $x_{n+1} = \sqrt{2 + x_n}$. A typical term has nested square roots, like $x_4 = \sqrt{2 + \sqrt{2 + \sqrt{2}}}$. This sequence rapidly approaches $2$ in the limit; put 

$$y_n = 2^n \sqrt{2 - x_n}.$$ 

The statement is that $y_n$ is half the perimeter of the inscribed $2^{n+1}$-gon for $n \geq 1$, so that $y_n$ is an increasing convergent sequence which tends to $\pi$ in the limit. Incidentally, simple high-school algebra shows 

$$y_n = 2 \prod_{k=2}^n \frac{2}{x_k}$$ 

and thus we may deduce Vieta's formula (see below).  

Archimedes used a similar idea, in effect viewing $2\pi$ as squeezed between the perimeters of inscribed and circumscribed polygons with $3 \cdot 2^n$ sides each (starting with a hexagon). By considering $n = 5$, he was eventually led to his famous estimate $3 + \frac{10}{71} \lt \pi \lt 3 + \frac1{7}$. 


## Other formulas 

* Leibniz formula: $\frac{\pi}{4} = 1 - \frac1{3} + \frac1{5} - \ldots$. Based on the power series for the [[arctangent]]
$$\arctan(x) = x - \frac{x^3}{3} + \frac{x^5}{5} - \ldots,$$ 
this series for $\pi/4$ obviously converges slowly, but more sophisticated expressions in terms of the arctangent have better convergence rates, such as the following first observed by Machin: 
$$\frac{\pi}{4} = 4\arctan(\frac1{5}) - \arctan(\frac1{239})$$ 

* Integral formulas (based ultimately on the [[Riemann integral]], the [[Henstock integral]], the [[Lebesgue integral]], or the like):

  * Also based on the [[arctangent]]:
    $$ \pi = 4 \int_{x=0}^1 \frac{\mathrm{d}x}{x^2 + 1} .$$

  * Or the [[arcsine]]:
    $$ \pi = 2 \int_{x=0}^1 \frac{\mathrm{d}x}{\sqrt{1 - x^2}} $$
    (but this is an [[improper integral]] if one is using the [[Riemann integral]]).

  Of course, you can come up with many modifications of these (including proper Riemann integrals based on the arcsine).

* Product formulas:

  * Vieta's formula:
$$\pi= 2\times\frac{2}{\sqrt{2}}\times
\frac{2}{\sqrt{2+\sqrt{2}}}\times
\frac{2}{\sqrt{2+\sqrt{2+\sqrt{2}}}}\times\frac{2}{\sqrt{2+\sqrt{2+\sqrt{2+\sqrt{2}}}}}\times\cdots$$ 
This was perhaps the first [[infinite product]] in the history of mathematics. 

  * Euler's product formula: 
$$\sin(x) = x \prod_{n \geq 1} (1 - \frac{x^2}{\pi^2 n^2})$$ 
One point is that putting $x = \frac{\pi}{2}$, one can derive another famous formula, namely 

  * Wallis's formula: 
$$\frac{\pi}{2} = \lim_{n \to \infty} \frac{2}{1} \cdot \frac{2}{3} \cdot \frac{4}{3} \cdot \frac{4}{5} \cdot \frac{6}{5} \cdot \frac{6}{7} \cdot \ldots \cdot \frac{2 n}{2 n - 1} \cdot \frac{2 n}{2 n + 1}$$ 
Alternatively, this may be derived from [[Stirling's approximation]] for $n!$, or rather starting from an asymptotic formula which follows from Stirling's approximation: 
$$\binom{2 n}{n} \sim \frac{2^{2 n}}{\sqrt{\pi n}}.$$ 

* Euler series: let $\zeta(s)$ be the Riemann [[zeta function]]. By applying the logarithmic derivative to Euler's product formula above, one may derive the following partial fraction expansion for the cotangent: 
$$\cot(x) = \frac1{x} - 2\sum_{n \geq 1} \frac{x}{\pi^2 n^2 - x^2}.$$ 
Expanding each of the summands in a geometric series and rearranging terms, one may derive 
$$x \cot(x) = 1 - 2\sum_{m \geq 1} \zeta(2 m)\frac{x^{2m}}{\pi^{2 m}}.$$ 
On the other hand, one has 
$$x\cot(x) = i x + \frac{2 i x}{e^{2 i x}-1} = 1 + \sum_{n \geq 2} B_n \frac{(2 i x)^n}{n!}$$ 
where the $B_n$ are the [[Bernoulli numbers]]. By comparing coefficients, one arrives at 
$$-\frac{2}{\pi^{2 m}} \zeta(2 m) = (-1)^m \frac{2^{2 m}}{(2 m)!}B_{2 m}$$ 
or, after rearranging, 
$$\pi^{2 k} = (-1)^{k-1} \frac{(2 k)!}{2^{2 k - 1}B_{2 k}}\zeta(2 k)$$ 
which has as special cases the formulas $\pi^2 = 6\zeta(2)$, $\pi^4 = 90\zeta(4)$, $\pi^6 = 945\zeta(6)$. 

* Continued fractions: the regular [[continued fraction]] expansion of $\pi$ is highly irregular, but several generalized continued fraction expansions listed in [Wikipedia](http://en.wikipedia.org/wiki/Pi#Continued_fractions) include 
$$\pi=\textstyle \frac{4}{1+\textstyle \frac{1^2}{2+\textstyle \frac{3^2}{2+\textstyle \frac{5^2}{2+\textstyle \frac{7^2}{2+\textstyle \frac{9^2}{2+\ddots}}}}}}
$$ 


## Irrationality and transcendence 

Famously, $\pi$ is an [[irrational number]], although proving this fact is no triviality. The first substantive idea of proof was given by Lambert, who discovered the following [[continued fraction]] expression for the [[tangent]]: 

$$\tan(z) = \textstyle \frac{z}{1 - \textstyle \frac{z^2}{3 - \textstyle \frac{z^2}{5 - \textstyle \frac{z^2}{7 - \ldots}}}}.$$ 

The basic inference was that $\tan(z)$ must therefore be irrational for rational values of $z$, and since $\tan(\pi/4) = 1$, it follows that $\pi/4$ is irrational. This was not a completely rigorous proof since Lambert had failed to prove the irrationality of certain infinite continued fractions, but Legendre provided the missing lemma in 1806. Actually [Legendre](#Leg) proves more: applying his lemma to the continued fraction for $\sqrt{q}\; \tan(\sqrt{q})$ (derived from the above), he shows this expression is irrational for rational $q$, and therefore not even $\pi^2$ can be rational. He goes on to speculate that $\pi$ is in fact transcendental. 

The transcendence of $\pi$ was finally established by Lindemann in 1882, by adapting methods of Hermite who had established the transcendence of [[e]] in 1873. This definitively proved the impossibility of solving the problem of "squaring the circle" by means of ruler-and-compass constructions. A far more general theorem was then established by Weierstrass: 

+-- {: .num_theorem #LindWeier} 
###### Theorem 
If $\alpha_1, \ldots, \alpha_n$ are algebraic numbers linearly independent over $\mathbb{Q}$, then $\exp(\alpha_1), \ldots, \exp(\alpha_n)$ are _algebraically_ independent over $\mathbb{Q}$ (which is to say that the [[field]] $\mathbb{Q}(\exp(\alpha_1), \ldots, \exp(\alpha_n))$ has [[transcendence degree]] $n$ over $\mathbb{Q}$). 
=-- 

A proof is given in [Wikipedia](http://en.wikipedia.org/wiki/Proof_that_%CF%80_is_transcendental#Proof). It follows that if $\pi$ and therefore $i\pi$ were algebraic, then $\exp(i\pi) = -1$ would be transcendental, which is absurd. 

## References 

A whole chapter on $\pi$ written for the mathematically literate is given in 

* Ebbinghaus et al., _Numbers_, GTM (Readings in Mathematics) 123, Springer (1991). 

The material on the Euler series for $\pi^{2 n}$ in terms of the zeta function was extracted from 

* Kenneth Ireland and Michael Rosen, _A Classical Introduction to Modern Number Theory_, Graduate Texts in Mathematics 84, Springer-Verlag (1982). 

The proof of irrationality of $\pi$ given by Legendre is said to be given in the following treatise: 

* A.-M. Legendre, _Eléments de géométrie_ (11th edition), Note IV. F. Didot, Paris (1817). Translation by Charles Davies: ([web](http://quod.lib.umich.edu/cgi/t/text/text-idx?c=moa;idno=ABN7066.0001.001)) 
 {#Leg} 


[[!redirects pi]]
[[!redirects π]]
[[!redirects Ludolph number]]
[[!redirects Ludolph's number]]
[[!redirects Ludolph's number]]
[[!redirects Ludolph\'s number]]
[[!redirects Ludolphian number]]
[[!redirects Ludolphian]]
[[!redirects Archimedes constant]]
[[!redirects Archimedes' constant]]
[[!redirects Archimedes' constant]]
[[!redirects Archimedes\' constant]]
[[!redirects Archimedes's constant]]
[[!redirects Archimedes's constant]]
[[!redirects Archimedes\'s constant]]
