
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Algebra
+-- {: .hide}
[[!include higher algebra - contents]]
=--
#### Topology
+-- {: .hide}
[[!include topology - contents]]
=--
#### Formal geometry
+-- {: .hide}
[[!include formal geometry -- contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Ideas

### General

Quite generally, the _completion of a ring_ is a [[completion]] of a [[topological ring]] to a [[complete space|complete]] [[topological ring]], when possible, for instance of a [[normed ring]] to a [[Banach ring]]. 

### Formal/adic completion and formal neighbourhoods

A special case of ring completion is the _formal completion_ or _adic completion_ of a [[commutative ring]] $R$, which is its topological completion with respect to the [[adic topology]] induced by a [[maximal ideal]] $I\subset R$ ([Sullivan 05, definition 1.3](#Sullivan05)). 

The underlying ring $\widehat R_I$ of this formal completion is the [[limit]]

$$
  \widehat R_I \coloneqq \underset{\leftarrow}{\lim} (R/I^n)
$$

(formed in the [[category]] [[CRing]] of [[commutative rings]]) of the [[quotients]] of $R$ by all the [[powers]] of this ideal, $I$ ([Sullivan 05, proposition 1.13](#Sullivan05)). Notice that this may be considered purely algebraically. 

In words, this limit construction says that the elements of $R_I$ are sequences of elements in $R$ which "successively add smaller and smaller elements, as seen by the ideal $I$". This is as for [[formal power series]] rings, which  are indeed the archetypical example of formal completions, see example \ref{FormalPowerSeries} below.

Generally, the [[Isbell duality|dual]] [[geometry|geometric]] meaning of formal ring completion is in [[formal geometry]]: the proper [[spectrum (geometry)|geometric spectrum]] of a formally completed ring is known as a _[[formal spectrum]]_ $Spf(R,I)$. Geometrically this is the [[formal neighbourhood]] of the [[spectrum of a commutative ring|spectrum]] $Spec(R/I)$ inside $Spec(R)$.

$$
  Spec(R/I)
  \hookrightarrow
  Spf(\widehat R_I)
  \hookrightarrow
  Spec(R)
  \,.
$$

### Derived completion functor

The [[derived functor]] of adic completion was originally discussed in ([Greenless-May 92](#GreenlessMay92) ("Greenlees-May duality"). For discussion of its relation to derived [[torsion subgroup]] functor see ([Porta-Shaul-Yekutieli 10](#PortaShaulYekutieli10)) and see at _[fracture theorem -- Arithmetic fracturing for chain complexes](http://ncatlab.org/nlab/show/fracture+theorem#CompletionAndTorsionOnDerivedCategories)_.


## Examples
 {#Examples}

The archetypical example which most clearly exhibits the [[geometry|geometric]] meaning of formal completions of rings is the following

+-- {: .num_example #FormalPowerSeries}
###### Example

For $R$ any [[ring]] and $R[x]$ the [[polynomial ring]] with [[coefficients]] in $R$, then the formal completion of $R[x]$ at the ideal $(x)$ generated by the free generator $x$ is the ring of [[formal power series]] $R[ [x] ]$.

If $R$ is a [[field]], then geometrically $Spec(R[x])$ is the [[affine line]] in [[algebraic geometry]]/[[arithmetic geometry]] over $R$, while $Spf(R[ [x] ])$ is the [[formal disk]] inside the affine line around the origin.

=--

The key class of example of completions in [[non-archimedean analytic geometry]] is the following.

+-- {: .num_example #pAdicNumbers}
###### Example

The [[p-adic integers]] are the completion of the ring of [[integers]] at the [[prime ideal]]  $(p) \subset \mathbb{Z}$.
Similarly the [[p-adic rational numbers]] are the completion of the [[rational numbers]] $(p)$, and the [[p-adic complex numbers]] are the completion of the [[complex numbers]] at $(p)$.

=--

+-- {: .num_remark}
###### Remark

In view of the example \ref{FormalPowerSeries} one sees that the $p$-adic numbers in \ref{pAdicNumbers} are in fact [[analogy|analogous]] to [[formal power series]] rings, hence that they behave like [[function rings]] on [[formal disks]] in _some_ kind of geometry. 

This [[analogy]] is part of what is known as the [[function field analogy]], which says that the ring of [[integers]] $\mathbb{Z}$ behaves like the  would-be "ring of polynomials $\mathbb{F}_1[x]$ over [[F1]]".

=--


+-- {: .num_example #AtiyahSegalTheorem}
###### Example

The [[Atiyah-Segal completion theorem]] states that for $G$ a [[topological group]] and $X$ a [[G-space]], then the [[topological K-theory]] ring $K(X//G)$ of the [[homotopy quotient]] $X//G$ (of the [[Borel construction]]) is the completion of the $G$-[[equivariant K-theory]] ring of $X$.

So this says that the "very naive" equivariant K-theory embodied by $K(X//G)$ is an infinitesimal approximation to the genuine equivariant K-theory. 

=--

+-- {: .num_example}
###### Example


The phenonemon of example \ref{AtiyahSegalTheorem} appears for other [[generalized cohomology theories]], too. For [[complex oriented cohomology theories]] it says that the [[formal group]] assigned by these to $\ast//U(1)$ is to be thought of as the formal completion of a more globally defined something.  One case where this "something" has been understood in some detail is that where the cohomology theory is [[elliptic cohomology]]. In that case the analog of equivariant K-theory is _[[equivariant elliptic cohomology]]_, see there for more details.

=--

## Properties


### Relation of formal completion to torsion approximation
 {#RelationToTorsionApproximation}

For suitable ideals $\mathfrak{a}\subset A$ of a commutative ring $A$, then the [[derived functor]] of $\mathfrak{a}$-adic [[completion of a module|completion of A-modules]] forms together with $\mathfrak{a}$-[[torsion approximation]] an [[adjoint modality]] on the  
[[(∞,1)-category of modules]] over $A$. See at _[arithmetic fracturing for chain complexes](fracture+theorem#CompletionAndTorsionOnDerivedCategories)_ for details.

### As modality in arithmetic cohesion

[[!include arithmetic cohesion -- table]]

## Related concepts

* [[analytic completion]]

* [[localization of a ring]], [[localization of a commutative ring]]

* [[completion of a module]]

* [[formal scheme]]

## References

A classical account is in section 1 of 

* {#Sullivan05} [[Dennis Sullivan]], _Geometric topology: localization, periodicity and Galois symmetry_, volume 8 of K- Monographs in Mathematics. Springer, Dordrecht, 2005. The 1970 MIT notes, Edited and with a preface
by [[Andrew Ranicki]] ([pdf](http://www.maths.ed.ac.uk/~aar/books/gtop.pdf))

Brief surveys include

* Wikipedia, _[Completion (ring theory)](https://en.wikipedia.org/wiki/Completion_%28ring_theory%29)_

* {#Bridges11} Brett Bridges, _An introduction to ring completions_, lecture notes 2011 ([pdf](http://www.math.uwo.ca/~srankin/courses/4123/2011/brett_presentation.pdf))

Discussion of the [[derived functor]] of adic completion ("Greenless-May duality") is in 

* {#GreenlessMay92} [[John Greenlees]], [[Peter May]], _Derived functors of I-adic completion and local homology_, J. Algebra 149 (1992), 438–453 ([pdf](http://math.uchicago.edu/~may/PAPERS/73.pdf))

* Leovigildo Alonso, Ana Jeremías, [[Joseph Lipman]], _Local Homology and Cohomology on Schemes_ ([arXiv:alg-geom/9503025](http://arxiv.org/abs/alg-geom/9503025))

* {#PortaShaulYekutieli10} Marco Porta, Liran Shaul, [[Amnon Yekutieli]], _On the Homology of Completion and Torsion_ ([arXiv:1010.4386](http://arxiv.org/abs/1010.4386))

for more on this see also at _[fracture theorem -- Arithmetic fracturing for chain complexes](http://ncatlab.org/nlab/show/fracture+theorem#CompletionAndTorsionOnDerivedCategories)_

Discussion of interrelation between completion and [[etale morphisms]] is in 

* Leovigildo Alonso, Ana Jeremias, Marta Perez, _Local structure theorems for smooth maps of formal schemes_ ([arXiv:math/0605115](http://arxiv.org/abs/math/0605115))

Discussion of formal completion of [[(infinity,1)-modules]] in terms of [[totalization]] of [[Amitsur complexes]] is in

* {#Carlsson07} [[Gunnar Carlsson]], _Derived completions in stable homotopy theory_ ([arXiv:0707.2585](http://arxiv.org/abs/0707.2585))


[[!redirects completion of a ring]]
[[!redirects completion of rings]]
[[!redirects completions of a ring]]
[[!redirects completions of rings]]
[[!redirects completion (ring theory)]]

[[!redirects completion of a commutative ring]]
[[!redirects completion of commutative rings]]

[[!redirects formal completion of a ring]]
[[!redirects formal completion of rings]]

