
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context
#### Analysis
+-- {: .hide}
[[!include analysis - contents]]
=--
#### Topology
+-- {: .hide}
[[!include topology - contents]]
=--
=--
=--

# Convergence spaces
* table of contents
{: toc}

## Idea

A _convergence space_ is a generalisation of a [[topological space]] based on the concept of [[convergence]] of [[filters]] (or [[nets]]) as fundamental.  The basic concepts of [[point-set topology]] ([[continuous functions]], [[compact space|compact]] and [[Hausdorff space|Hausdorff]] [[topological spaces]], etc) make sense also for convergence spaces, although not all theorems hold.  The [[category]] $Conv$ of convergence spaces is a [[quasitopos]] and may be thought of as a [[nice category of spaces]] that includes [[Top]] as a [[full subcategory]].


## Definitions

A __convergence space__ is a [[set]] $S$ together with a [[relation]] $\to$ from $\mathcal{F}S$ to $S$, where $\mathcal{F}S$ is the set of [[filters]] on $S$; if $F \to x$, we say that $F$ __converges__ to $x$ or that $x$ is a __limit__ of $F$.  This must satisfy some axioms:

1. Centred: The [[principal ultrafilter]] $F_x = \{ A \;|\; x \in A \}$ at $x$ converges to $x$;
2. Isotone: If $F \subseteq G$ and $F \to x$, then $G \to x$;
3. Directed: If $F \to x$ and $G \to x$, then some filter contained in the [[intersection]] $F \cap G$ converges to $x$.  In light of (2), it follows that $F \cap G \to x$ itself.  (Strictly speaking, the relation should not be called [[directed set|directed]] unless also every point is a limit of some filter, but this follows from 1.)

It follows that $F \to x$ if and only if $F \cap F_x$ does.  Given that, the convergence relation is defined precisely by specifying, for each point $x$, a filter of [[subfilter]]s of the principal ultrafilter at $x$.  (But that is sort of a tongue twister.)

A filter $F$ __clusters__ at a point $x$, written $F \rightsquigarrow x$, if there exists a [[proper filter]] $G$ such that $F \subseteq G$ and $G \to x$.

The definition can also be phrased in terms of [[nets]]; a net $\nu$ converges to $x$ if and only if its [[eventuality filter]] converges to $x$.

The morphisms of convergence spaces are the [[continuous functions]]; a function $f$ between convergence spaces is __continuous__ if $F \to x$ implies that $f(F) \to f(x)$, where $f(F)$ is the filter generated by the [[filterbase]] $\{F(A) \;|\; A \in F\}$.  In this way, convergence spaces form a [[concrete category]] $Conv$.

Note that the definition of 'convergence' varies in the literature; at the extreme end, one could define it as any relation whatsoever from $\mathcal{F}S$ (or even from the [[proper class|class]] of all nets on $S$) to $S$, but that is so little structure as to be not very useful.  An intermediate notion is that of [[filter space]], in which (3) is not required.  Here we follow the terminology of [Lowen-Colebunders](#LC).


## Examples

In [[measure theory]], given a [[measure space]] $X$ and a [[measurable space]] $Y$, the space of [[almost-everywhere defined]] [[measurable functions]] from $X$ to $Y$ becomes a convergence space under [[convergence almost everywhere]].  In general, this convergence space does not fit into any of the examples below.


A [[pseudotopological space]] is a convergence space satisfying the _star property_:

*  If $F$ is a filter such that every proper filter $G \supseteq F$ clusters at $x$, then $F$ converges to $x$.

Assuming the [[ultrafilter theorem]] (a weak version of the [[axiom of choice]]), it\'s enough to require that $F$ converges to $x$ whenever every [[ultrafilter]] that refines $F$ converges to $x$ (or clusters there, since these are equivalent for ultrafilters).


A [[subsequential space]] is a pseudotopological space that may be defined using only [[sequences]] instead of arbitrary nets/filters.  (More precisely, a filter converges to $x$ only if it refines (the eventuality filter of) a [[infinite sequence|sequence]] that converges to $x$.)


A [[pretopological space]] is a convergence space that is _infinitely filtered_:

*  If $(F_\alpha)_\alpha$ is any family of filters each of which converges to $x$, then $\bigcap_\alpha F_\alpha$ converges to $x$.

In particular, the [[intersection]] of all of the filters converging to $x$ (the [[neighbourhood filter]] of $x$) also converges to $x$.  Note that every pretopological space is pseudotopological.


Any [[topological space]] is a convergence space, and in fact a pretopological one: we define $F \to x$ if every [[neighbourhood]] of $x$ belongs to $F$.  A convergence space is __topological__ if it comes from a topology on $S$.  The [[full subcategory]] of $Conv$ consisting of the topological convergence spaces is [[equivalence of categories|equivalent]] to the category [[Top]] of topological spaces.  In this way, the definitions below are all suggested by theorems about topological spaces.

Every [[Cauchy space]] is a convergence space.


## Properties

The [[improper filter]] (the [[power set]] of $S$) converges to every point.  On the other hand, a convergence space $S$ is __[[Hausdorff space|Hausdorff]]__ if every [[proper filter]] converges to at most one point; then we have a [[partial function]] $\lim$ from the proper filters on $S$ to $S$.  A topological space is Hausdorff in the usual sense if and only if it is Hausdorff as a convergence space.

A convergence space $S$ is __[[compact space|compact]]__ if every proper filter clusters at some point; that is, every proper filter is contained in a convergent proper filter.  Equivalently (assuming the [[ultrafilter theorem]]), $S$ is compact iff every ultrafilter converges.  A topological space is compact in the usual sense if and only if it is compact as a convergence space.

The topological convergence spaces can be characterized as the pseudotopological ones in which the convergence satisfies a certain "associativity" condition.  In this way one can (assuming the ultrafilter theorem) think of a topological space as a "[[generalized multicategory]]" parametrized by ultrafilters.  In particular, note that a compact Hausdorff pseudotopological space is defined by a single function $\mathcal{U}S \to S$, where $\mathcal{U}S$ is the set of ultrafilters on $S$, such that the composite $S \to \mathcal{U}S \to S$ is the identity.  That is, it is an [[algebra for an endofunctor|algebra]] for the [[pointed object|pointed]] [[endofunctor]] $\mathcal{U}$.  The compact Hausdorff _topological_ spaces (the [[compacta]]) are precisely the [[algebra for a monad|algebras]] for $\mathcal{U}$ considered as a [[monad]].  If we treat $\mathcal{U}$ as a monad on [[Rel]], then the [[lax algebra]]s are the topological spaces in their guise as [[relational beta-modules]].


## Topological structure

Given a convergence space, a filter $F$ __star-converges__ to a point $x$, written $F \to^* x$, if every proper filter that refines $F$ clusters at $x$.  (Assuming the [[ultrafilter theorem]], $F$ star-converges to $x$ iff every ultrafilter that refines $F$ converges to $x$.)  The relation of star convergence makes any convergence space into a [[pseudotopological space]] with a weaker convergence.  In this way, $Ps Top$ becomes a [[reflective subcategory]] of $Conv$ over $Set$.

>Note: the term 'star convergence' and its symbol ‘$\to^*$’ are my own, formed from 'star property' above, which I got from _[[HAF]]_.  Other possibilities that I can think of: 'ultraconvergence', 'universal convergence', 'subconvergence'.  ---[[Toby Bartels|Toby]]


Given a convergence space, a set $U$ is a __[[neighbourhood]]__ of a point $x$, written $x \in^\circ U$, if $U$ belongs to every filter that converges to $x$; it follows that $U$ belongs to every filter that star-converges to $x$.  The relation of being a neighbourhood makes any convergence space into a [[pretopological space]], although the pretopological convergence is weaker in general.  In this way, $Pre Top$ is a [[reflective subcategory]] of $Conv$ (and in fact of $Ps Top$) over $Set$.

Other pretopological notions:  The __[[preinterior]]__ of a set $A$ is the set of all points $x$ such that $x \in^\circ A$.  The __[[preclosure]]__ of $A$ is the set of all points $x$ such that every neighbourhood $U$ of $x$ meets (has [[inhabited set|inhabited]] [[intersection]] with) $A$.  For more on these, see [[pretopological space]].


Given a convergence space, a set $G$ is __[[open subset|open]]__ if $G$ belongs to every filter that converges to any point in $G$, or equivalently if $G$ belongs to every filter that star-converges to any point in $G$, or equivalently if $G$ equals its preinterior.  The class of open sets makes any convergence space into a [[topological space]], although the topological convergence is weaker in general.  In this way, $Top$ is a [[reflective subcategory]] of $Conv$ (and in fact of $Ps Top$ and $Pre Top$) over $Set$.

Other topological notions:  A set $F$ is __[[closed subset|closed]]__ if $F$ meets every neighbourhood of every point that belongs to $F$, equivalently if $F$ equals its preclosure.  The __[[interior]]__ of $A$ is the [[union]] of all of the open sets contained in $A$; it is the largest open set contained in $A$.  The __[[closure]]__ of $A$ is the [[intersection]] of all of the closed sets that contain $A$; it is the smallest closed set that contains $A$.  (For a topological convergence space, the interior and closure match the preinterior and preclosure.)


+-- {: .num_theorem #subcats}
###### Theorem
The inclusions $Top \to Pre Top \to Ps Top \to Conv$ are all inclusions of [[full subcategories]] over $Set$.  That is, they all agree on what a [[continuous function]] is.
=--

+-- {: .proof}
###### Proof

The only hard part is proving that, if $f(\mathcal{F}) \to^* f(x)$ whenever $\mathcal{F} \to x$ in a [[pretopological space]], then $x \in^\circ f^*(V)$ whenever $f(x) \in^\circ V$.  This is usually proved [[proof by contradiction|by contradiction]] and flagrant use of [[axiom of choice|choice]]: supposing that $f(x) \in^\circ V$ but $x \notin^\circ f^*(V)$, then every neighbourhood $U$ of $x$ must satisfy $U \nsubseteq f^*(V)$, so choose for each such $U$ a point $y_U$ such that $y_U \in U$ but $f(y_U) \notin V$, defining a net $y$ (indexed by neighbourhoods of $x$ ordered by reverse inclusion), such that $y \to x$, but $\neg\big(f(y) \rightsquigarrow f(x)\big)$, so $y \nrightarrow^* f(x)$, getting a contradiction.

But the theorem is in fact perfectly [[constructive mathematics|constructive]]: the filter $\mathcal{N}_x$ of neighbourhoods of $x$ converges to $x$, so $f(\mathcal{N}_x) \to^* f(x)$; all that really matters is that $f(\mathcal{N}_x) \rightsquigarrow f(x)$, so that for each $V \ni^\circ f(x)$ and $U \ni^\circ x$, for some $W$ with $x \in^\circ W \subseteq U$, $f(W) \subseteq V$, so $W \subseteq f^*(V)$, making $f^*(V)$ a neighbourhood of $x$.
=--


## References

* Eva Lowen-Colebunders (1989). Function Classes of Cauchy Continuous Maps. Dekker, New York, 1989.
  {#LC}


[[!redirects convergence space]]
[[!redirects convergence spaces]]
[[!redirects convergence structure]]
[[!redirects convergence structures]]

[[!redirects convergence relation]]
[[!redirects convergence relations]]
