## Discrete Morse Theory ##

Discrete Morse theory aims to do for [[simplicial complexes]] and more generally, finite [[CW complexes]] what standard [[Morse theory]] does for manifolds. 

### Partial Matchings on CW Complexes ###

Let $X$ be a finite CW complex. The central idea is to make extensive use of [[simple homotopy theory]]. Although the initial formulation of discrete Morse theory involved certain families of locally constant functions $f:X \to \mathbb{R}$ playing the role of Morse functions, a cleaner treatment may be given as follows. An **acyclic matching** on $X$ consists of the following data: a partition of the cells into three disjoint classes $A, B$ and $C$ along with a distinguished set-bijection $w: A \to B$. This data is required to obey the following axioms:

* for each cell $a \in A$, the matched cell $w(a)$ is a regular co-face of $a$, meaning that $\dim (w(a)) = \dim (a) + 1$ and the degree of the attaching map from $w(a)$ to $a$ is $\pm 1$,
* the relation $\prec$ on $A$ generated by $a \prec a'$ whenever $a$ is a (not necessarily regular) face of $w(a')$ defines a partial order.


### Homotopy ###

A central result of discrete Morse theory is as follows: if $X$ is any finite CW complex which admits an acyclic matching with $n$ critical cells, then $X$  is homotopy equivalent to a CW complex with $n$ cells. The proof is similar in spirit to the traditional Morse lemmas: instead of deforming along flow lines between adjacent critical points, one uses simple homotopy collapses to obtain the desired equivalence.

### Gradient Paths and Morse Homology ###

The unmatched cells $C$ play the role of critical points, while the matched cells in $A$ and $B$ generate gradient-like paths between critical cells. In fact, if we denote the face relation in $X$ by $\leq$, then a gradient path from critical cell $c$ to critical cell $c'$ consists precisely of an alternating sequence of distinct matched cells which fit together like this:

$$c \geq a_0 \leq w(a_0) \geq a_1 \leq w(a_1) \geq \ldots \geq a_n \leq w(a_n) \geq c'$$

Each such path can be assigned an **multiplicity** given by a product of attaching degrees: reading from left to right, each time one sees $x \geq y$, one multiplies by the degree of the attaching map from $x$ to $y$, and each time one sees $y \leq x$ one divides by this degree. The first axiom of the partial matching guarantees that one only divides by $\pm 1$, while the second axiom guarantees that no such path can go "backwards" from $c'$ up to $c$.

The **Morse Complex** $(C,d)$ is the free chain complex built on the critical cells in $C$ where the component of the boundary operator $d$ from $c$ to $c'$ is the sum of multiplicity over all gradient paths from $c$ to $c'$. The main *Theorem* is that the Morse complex has the same integer homology groups as $X$.

### Applications ###

Discrete Morse theory has been used in topological combinatorics to show that certain simplicial complexes are homotopy-equivalent to wedges of spheres. It has also been used in commutative algebra to construct minimal resolutions of ideals in polynomial rings. Discrete Morse theory is also used extensively in [[homology]] and [[persistent homology]] computations as in the [CHomP](http://chomp.rutgers.edu) and [Perseus](http://www.sas.upenn.edu/~vnanda/perseus) software packages. 