
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Foundations
+-- {: .hide}
[[!include foundations - contents]]
=--
=--
=--

# The axiom of choice
* table of contents
{: toc}

## Statement

The __axiom of choice__ is the following statement:

* _Every [[surjection]] in the category [[Set]] of [[sets]] [[split epimorphism|splits]]._

This means: for every [[surjection]] $f\colon A \to B$ of sets, there is a function $\sigma\colon B \to A$ (a [[section]]), such that
$$
  (B \stackrel{\sigma}{\to} A \stackrel{f}{\to} B) 
  =
  (B \stackrel{Id_B}{\to} B)
  \,.
$$

Note that a surjection $A \to B$ of sets can be regarded as a $B$-indexed [[family of sets]], while the existence of a section is equivalent to a choice of one element in each set of this family.  This reproduces the more classical form of the axiom of choice.

When the full axiom of choice fails, it may still be valid for some restricted class of objects $A$ and/or $B$.  An object $B$ such that any [[epimorphism]] $A \to B$ splits is called [[projective object|projective]]; this means that one can make choices 'indexed by' $B$.  Dually, an object $A$ such that one can make choices 'with values in' $A$ is called a [[choice object]] (this is not quite equivalent to every epimorphism $A \to B$ splitting).


## In other categories

More generally, we may consider analogous statements in [[categories]] $C$ other than $Set$.

### External form

We say that $C$ satisfies the **external axiom of choice** if every epimorphism in $C$ splits.

In this form, the axiom of choice may look less mysterious than in its original formulation. For instance, it is clear that it fails in contexts such as $C =$ [[Top]] and $C = $[[Diff]], due to the existence of nontrivial topological and smooth [[fiber bundle]]s.

If $C$ is not [[balanced category|balanced]], such as a [[regular category|regular]] or [[coherent category]] which is not a [[pretopos]], it may be more appropriate to replace in this statement "epimorphism" by [[regular epimorphism]] (or [[extremal epimorphism]], [[effective epimorphism]], etc.)  In $Set$ (and in any [[topos]]), all of these notions of epimorphism are the same.

More generally still, if $C$ is a [[site]], then the axiom of choice for $C$ may be taken to say that any [[cover]] $U\to X$ admits a section.  Obviously this refers only to singleton covers, but if $C$ is [[superextensive site|superextensive]] then any covering family $(p_i\colon U_i \to X)_i$ can be replaced by a singleton cover $\coprod_u U_i \to X$.


### Internal form

However, when working in a category that has an [[internal logic]], we may want to "internalize" the axiom of choice by asserting, not that every epimorphism has a section, but that the statement "every epimorphism has a section" is true in the internal logic (or more precisely the [[stack semantics]]).  An equivalent statement is that every object is [[internally projective object|internally projective]].  We call this the **internal axiom of choice**.

This is generally a weaker statement: a [[topos]] satisfies the external AC if and only if it satisfies the internal AC and also (the external form of) [[supports split]].   Often, however, this is the more relevant notion to consider.

If a topos $C$ satisfies IAC, then so do all of its [[slice categories]], although this may not be obvious.  See [this answer](http://mathoverflow.net/questions/139874/pullback-stability-of-internally-projective-objects/140262#140262). 

### In toposes 

+-- {: .num_theorem} 
###### Theorem 
A [[Grothendieck topos]] satisfies the external axiom of choice iff it is equivalent to the [[category of sheaves]] on a [[complete Boolean algebra]]. 
=-- 

## Equivalents 

The following statements are all equivalent to the axiom of choice in $Set$ (although sometimes the proof in one direction requires [[excluded middle]]).  This is a *very* short list; much longer lists can be found elsewhere, such as at [Wikipedia](http://en.wikipedia.org/wiki/Axiom_of_choice#Equivalents).  Some of the statements on this list, though, may be of interest to nLabbers but are not commonly mentioned as equivalents of choice.

* The [[well-ordering theorem]] (that any set can be [[well-order|well-ordered]]),
* [[Zorn's lemma]],
* That ($L =$ [[monomorphism]]s, $R =$ [[epimorphism]]s) is a [[weak factorization system on Set]].
* That [[Set]] is equivalent to its own [[free exact completion]].
* That there exists a [[group]] structure on every [[inhabited set]] (see [[Hartogs number]], or [this MO answer](http://mathoverflow.net/questions/12973/does-every-non-empty-set-admit-a-group-structure-in-zf/12988#12988)).
* That every [[fully faithful functor|fully faithful]] and [[essentially surjective functor|essentially surjective]] functor between [[strict categories]] is a strong [[equivalence of categories]].
* That the [[nonabelian cohomology]] $H^1(X;G)$ is trivial for every set $X$ and every [[group]] $G$ (see [this post](http://golem.ph.utexas.edu/category/2013/07/cohomology_detects_failures_of.html)).


## Variants
 {#Variants}

There are a number of weaker axioms which are implied by the full axiom of choice.  Some of these are valid or accepted more generally than the full AC, and/or suffice for some of the usual applications of choice.  In particular, the full axiom of choice is generally rejected in [[constructive mathematics]], whereas some of these weaker forms of choice may be accepted, such as (in order of increasing strength) [[countable choice]], [[dependent choice]], and [[COSHEP]].

* Many applications of choice in [[logic]], [[topology]], and [[algebra]] require only the [[ultrafilter principle]] (UF), or equivalently the *Boolean prime ideal theorem*.

* From the perspective of [[constructive mathematics]], the principle of [[excluded middle]] (EM) may be seen as a form of the axiom of choice; EM is equivalent to the statement that every [[Kuratowski-finite set]] is projective.

* A very weak form of choice (which follows from EM) is the statement that [[supports split]] in $Set$.

* The axioms of [[countable choice]] (CC) and [[dependent choice]] (DC) suffice for many of the usual applications of choice in the analysis of [[separable space]]s.  CC states that the set $\mathbb{N}$ of [[natural number]]s is projective.  DC strenghtens CC by allowing the set of possible choices for $n+1$ to depend on the choice made for $n$.

* The axiom [[COSHEP]], also called the "presentation axiom," says that any set admits a surjection from a projective one (whereas full AC says that all sets are projective).  This implies CC and DC, and is moreover sufficient for the existence of [[projective resolution]]s and cofibrant replacements, as well as the usual theorems in algebra that (for example) [[Mod]] has enough projectives.  For example, see the [[canonical model structure on Cat]].

* The [[axiom of small violations of choice]] (SVC) asserts there is a set $S$ such that every set is a [[subquotient]] of $C\times S$ for some choice set $C$.  Intuitively, this says that the failure of AC is parametrized by a single set.  It can be regarded as a "dual" of COSHEP, since it deals with choice sets rather than projective ones, it implies the existence of (at least some) [[injective resolution]]s, and together with COSHEP and EM it implies full AC.

* The [[axiom of multiple choice]] is a different way of saying that choice is violated in only a small way, which is more "local" than SVC.  It apparently follows from SVC, at least in [[ZF]].

* The [[small cardinality selection axiom]] is another similar axiom.  It asserts that there is a class function selecting for every set an isomorphic set (its "cardinality") such that among each isomorphism class of sets, the collection of all "cardinalities" forms only a set.

* A still weaker axiom along the lines of "AC fails in only a small way," which is implied by AMC, is [[WISC]], i.e. that for any set $X$, the full subcategory of $Set/X$ consisting of the surjections has a [[weakly initial set]] (under COSHEP it has a single weakly initial object, namely a projective cover of $X$).  Two similar assertions are that the [[free exact completion]] $Set_{ex/lex}$ of $Set$ is a [[topos]] (i.e. that $Set$ has a [[generic proof]]), and that $Set_{ex/lex}$ is [[well-powered category|well-powered]]; both of these imply WISC.


The axiom of choice can also be strengthened in a few ways.

* While the ordinary axiom of choice says that any surjection of sets is split, the *axiom of global choice* says that this is also true for any surjection of [[proper classes]].  (Making this precise requires a bit of work.)  It is equivalent to the existence of a well-ordering of the class of all sets.

* One can also postulate a [[choice operator]], which gives a *specified* way to choose an element from any nonempty set.  This implies global choice, and conversely a choice operator can be defined from any well-ordering of the class of all sets.


Finally, one can instead adopt the *negation* of the axiom of choice, or a strengthened version of this negation:

* The assumption that every subset of the [[real line]] has the [[Baire property]] (BP) is consistent with DC but not AC; the same holds for the assumption that every subset of the real line is [[Lebesgue measure|measurable]] (LM) if at least one [[Grothendieck universe]] exists.  These assumptions leads to a very nice setting for analysis called [[dream mathematics]].

* The [[axiom of determinacy]] is a natural statement in [[game theory]] that is consistent with dependent choice; in fact, it implies dependent choices in certain models, such as in the constructible (in the sense of Goedel) closure of the set of reals. However, determinacy contradicts full AC (for example, it implies LM and BP, as in the previous entry). 

* Any of the varieties of [[constructive mathematics]] that contradict excluded middle necessarily contradict choice, but they are usually (if not always) consistent with DC (and even COSHEP).

### In higher category theory

To formulate a version of the axiom of choice in a higher category, one has to make an appropriate choice of the meaning of "epimorphism".  In most cases, it is best to choose [[effective epimorphisms|effective epimorphism in an (infinity,1)-category]] or a related notion such as [[eso morphisms]].

Less obviously, we usually want to also impose [[truncated object|truncation]] requirements on at least some of the objects involved in the axiom of choice.  It seems usually necessary to require the codomain to be 0-truncated (axioms of choice without this requirement tend to be inconsistent); as for the domain we can choose to or not.

* An $(\infty,1)$-category satisfies the **axiom of $n$-choice**, or $AC_n$, if every $n$-[[truncated morphism]] with 0-truncated codomain has a section.  We write $AC_\infty$ for the **axiom of infinity-choice**: the statement that *every* morphism with 0-truncated codomain has a section.

These are stronger axioms as $n$ increases.  The "difference" between $AC_0$ and $AC_\infty$ is roughly the axiom that [[sets cover]].

For $(n,k)$-categories with $k\gt 1$ it is unclear whether it is sensible to allow the domain to be non-groupoidal.

* In [[2-category theory]], the _[[michaelshulman:axiom of 2-choice]]_ has been proposed to mean that every [[eso morphism]] with groupoidal domain and 0-truncated codomain has a section.

There are also "internal" versions of these axioms.

* In [[homotopy type theory]] (the internal logic of an $(\infty,1)$-topos), the internal version of $AC_n$ is "every surjection onto a set with $n$-type fibers has a section", or equivalently
  $$ \prod_{(X:Set)} \prod_{(Y:X\to n Type)} \Big( \prod_{(x:X)} \Vert Y(x)\Vert \to \big\Vert \prod_{(x:X)} Y(x) \big\Vert \Big) $$

* More generally, we can replace the $(-1)$-truncation by the $k$-truncation to obtain a family of axioms $AC_{k,n}$.

* We can also replace the $(-1)$-truncation by the assertion of $k$-connectedness, obtaining the **axiom of $k$-connected choice**.

### In type theory

In [[Martin-Lof type theory]], if "there exists" and "for all" are interpreted in the classical way according to [[propositions as types]], then the statement of the axiom of choice comes out as simply the statement that products distribute over coproducts.  (See [[distributivity pullback]] for a discussion in terms of the internal type theory of a locally cartesian closed category.)  Since this statement is provable, traditionally type theorists say that "the axiom of choice is provable" in type theory.  However, this is arguably not really a faithful representation of the axiom of choice, not only because it is provable, but because it lacks the usual strong consequences of the set-theoretic axiom of choice.

A better type-theoretic form of the axiom of choice is obtained by inserting [[propositional truncations]] in the notion of "exists".  See for instance the [HoTT Book](#HoTTBook) for further discussion.

## Consequences

* The axiom of choice implies the [[principle of excluded middle]] (due to Diaconesu 1975) see [McLarty, theorem 17.9](#McLarty), and see at _[excluded middle -- Relation to axiom of choice](excluded+middle#RelationToTheAxiomOfChoice)_

See also the [choice consequences data base](#ConsequencesDatabase)

## Related concepts

* [[well-ordering]]

* [[anafunctor]]

* [[foundations]]

* [[Boolean topos]]


## References

### General

* [[HAF|Eric Schechter's analysis book]] surveys several variants of AC and its negation with a view to applications of [[analysis]], including this nice picture:

  ![a Hasse diagram of variants of AC.](http://www.math.vanderbilt.edu/~schectex/ccc/excerpts/acchart.gif)

  (Here, UF, DC, CC, BP, and LM are as defined above.)

Discussion in [[toposes]] is in 

* {#McLarty} [[Colin McLarty]], section 17.6 of _Elementary Categories, Elementary Toposes_

* {#ConsequencesDatabase} The [Consequences of the Axiom of Choice Project](http://consequences.emich.edu/conseq.htm) provides an interactive data base that can be used to search for implications between various (weakened) forms of the Axiom of Choice. [Choiceless grapher](http://cgraph.inters.co/) builds on this data and provides a graphical presentation.

* Gonçalo Gutierres da Conceição, _The Axiom of Countable Choice in Topology_, [pdf](http://www.mat.uc.pt/~ggutc/teses/teseingles.pdf)

  Despite the title, this covers more than countable choice, but the focus is on sequential aspects (metric spaces, first- and second-countable spaces, etc).

Relation to [[cohomology]] is discussed in 

* [[Andreas Blass]], _Cohomology detects failures of the axiom of choice_, Trans. Amer. Math. Soc. 279 (1983), 257-269 ([web](http://www.ams.org/journals/tran/1983-279-01/S0002-9947-1983-0704615-7/))

* [[Mike Shulman]], _Cohomology_ on the [[homotopy type theory]] blog [here](http://homotopytypetheory.org/2013/07/24/cohomology/)

An alternative form of AC in toposes using injectivity is explored in

* Toby Kenney, _Injective Power Objects and the Axiom of Choice_ , JPAA **215** (2011) pp.131–144.

### In homotopy type theory
 {#ReferencesInHomotopy}

Discussion in [[homotopy type theory]]:

* {#HoTTBook} [[Univalent Foundations Project]], section 3.8 of _[[Homotopy Type Theory -- Univalent Foundations of Mathematics]]_



category: foundational axiom

[[!redirects axioms of choice]]
[[!redirects Choice]]
[[!redirects AC]]
[[!redirects full choice]]
[[!redirects full AC]]

[[!redirects axiom of global choice]]
[[!redirects global axiom of choice]]

[[!redirects axiom of infinity-choice]]
[[!redirects axiom of n-choice]]
[[!redirects axiom of k-connected choice]]

[[!redirects type-theoretic axiom of choice]]
[[!redirects type theoretic axiom of choice]]
[[!redirects external axiom of choice]]
[[!redirects internal axiom of choice]]