
# Contents
* automatic table of contents goes here
{:toc}

## Idea 

Consider a [[category]] $C$ whose [[object]]s are thought of as _spaces_ and whose morphisms are regarded as structure-preserving morphisms between these spaces. 

There is then a general notion of

* **spaces** modeled on $C$ that are _testable_ by objects of $C$;

* **quantities** with values in $C$.

Very generally,

* a [[space]] modeled on the objects of $C$ is a [[presheaf]] on $C$, i.e. a [[functor]] 

  $X : C^{op} \to $ [[Set]]:

  we think of each such presheaf as being a rule that assigns to each test space $U \in C$ the set $X(U)$ of allowed maps _from_ $U$ into the would-be space $X$; 

* a [[quantity]] modeled on $C$ is a [[presheaf|copresheaf]] on $C$, i.e. a functor 

  $A : C \to Set$:

  we think of each such copresheaf $A$ as a rule that assigns to each test space $U \in C$ the set $A(U)$ of allowed maps from a would-be space _into_ $U$, hence as the collection of $U$-valued _functions_ on $X$. Since a function on a point is a "quantity", these are generalized quantities.

Typically the admissible (co)presheaves that are regarded as generalized spaces and quantities modeled on $C$ are required to respect certain properties of $C$:

* If $C$ carries the structure of a [[site]], one asks a generalized space to be a presheaf $X = PSh(C) = [C^{op},Set]$ that respects the way objects in $C$ are covered by other objects. These are the [[sheaf|sheaves]]. The [[category of sheaves]]

  $Sh(C) \hookrightarrow PSh(C)$

  is the [[topos]] of spaces modeled on objects in $C$. More details on how to think of sheaves as generalized spaces is at [[motivation for sheaves, cohomology and higher stacks]].


* Given any generalized spaces, functions out of it are expected to respect [[product]]s of coefficient objects, in that a function with values in $U \times V$ is the same as a pair of functions, one with values in $U$, one with values in $V$. Hence one is typically interested in copresheaves that preserve at least [[product]]

  $CoSh(C) \hookrightarrow CoPSh(C)$.


### Details

As indicated in

* [[Bill Lawvere]], _Taking categories seriously_, Reprints in Theory and Applications of Categories, No. 8, 2005, pp. 1–24. ([pdf](http://www.emis.de/journals/TAC/reprints/articles/8/tr8.pdf))

from [page 17](http://www.emis.de/journals/TAC/reprints/articles/8/tr8.pdf#page=17) on, the general situation involving

* (generalized) spaces;

* (generalized) quantities (e.g. function algebras);

* the [[duality]] between the two;

which underlies much of mathematics is at its heart controled by the following elementary category theoretic reasoning:

Let $S$ be some category whose objects we want to think of as certain simple spaces on which we want to model more general kinds of spaces. For instance $S = \Delta$, the simplicial category, or $S = $ [[CartSp]]. 

An ordinary [[manifold]], for instance, is a space required to be _locally isomorphic_ to an object in $S = CartSp$. But more generally, a space $X$ modeled on $S$ need only be _probeable_ by objects of $S$, giving a rule which to each test object $U \in S$ assigns the collection of admissible maps from $U$ to $X$,  such that this assignment is well-behaved with respect to morphisms in $S$. Such an assignment is nothing but a [[presheaf]] on $S$, i.e. a contravariant functor
$$
  X : S^{op} \to Set
  \,.
$$
Therefore general spaces modeled on $S$ are nothing but presheaves on $S$:
$$
  Spaces_S := PSh(S)
  \,.
$$
Of course this is an extremely general notion of spaces modeled on $S$. 

We have the [[Yoneda lemma|Yoneda embedding]]  $S \hookrightarrow Spaces_S$ and using this we can say that the collection of _functions_ on a generalized space $X$ with values in $U \in S$ is 
$$
  C(X,U) := Hom_{Spaces_S}(X,U)
  \,.
$$
This assignment is manifestly covariant in $U$, and hence more generally we can consider the functions on $X$, $C(X)$ to be a copresheaf on $S$, namely a covariant functor
$$
  C(X) := Hom(X,-) : S \to Sets
  \,.
$$
One can think of $C(X)$ as being a generalized quantity which may be _co-probed_ by objects of $S$.

In this vein, one can say, generally, that co-presheaves on $S$ are generalized quantities modeled on $S$, and we write
$$
  Quantities_S := CoPSh(S)
  \,.
$$

Given any such generalized quantity $A \in Quantities_S$, we can ask which generalized space it behaves like the algebra of functions on. This generalized space should be called $Spec(A)$ and can be defined as a presheaf by the assignment
$$
  Spec(A) 
  :
  U \mapsto Hom_{Quantities_S}(A, C(U))
  \,.
$$

In  total this yields an adjoint pair of functors between generalized spaces and generalized quantities:

$$
  Spaces_S
\stackrel{\stackrel{C(-)}{\to}}{\stackrel{Spec(-)}{\leftarrow}}
  Quantities_S
  \,.
$$

(That this is an adjunction can be understood as a special case of [[abstract Stone duality]] induced by a [[dualizing object]].)

Lawvere addresses this adjoint pair as **Isbell conjugation**.

In conclusion, the grand [[duality]] between spaces and quantities is a consequence of the [[duality|formal duality]] which reverses the arrows in the category $S$ of test spaces.

This story generalizes straightforwardly from [[presheaf|presheaves]] with values in [[Set]] to presheaves with values in other categories. Of relevance are in particular presheaves with values in the category [[Top]] of [[topological space]]s and presheaves with values in the category of [[spectrum|spectra]]. See the examples below. 


## Isbell duality: global functions and spectrum {#Isbell}

we describe the [[duality]] between space and quantity induced by forming

* functions on spaces;

* spectra of function algebras.

Let $V$ be a [[symmetric monoidal category]] and $C$ a $V$-[[enriched category]]. Write $[C^{op},V]$ for the [[enriched functor category]] and $j : C \to [C^{op},V]$ for the [[Yoneda embedding]].

There is canonically a $V$-[[adjunction]]

$$
  (\mathcal{O} \dashv Spec)  \;\;: \;\; [C, V]^{op}
  \stackrel{\overset{\mathcal{O}}{\leftarrow}}{\underset{Spec}{\to}}
  [C^{op},V]
$$

the **Isbell adjunction**. Here

* $\mathcal{O} := [C^{op},V](j(-), -)$ sends a presheaf $X$ to the copresheaf $U \mapsto [C^{op},V](X,j(U))$;

* $Spec := [C,V]^{op}(j(-),-)$ sends a copresheaf $A$ to the presheaf $U \mapsto [C,V](A, j^{op}(U))$.

If we assume that $C$ is [[copower|tensored]] over $V$, then that this is an adjunction may be seen in [[end]]/[[coend]]-calculus to express the [[hom-object]]s in the [[enriched functor category]] as follows. We compute

$$
  \begin{aligned}
    [C,V]^{op}(\mathcal{O}(X),A)
    & =
    \int_{u \in C} V(A(u), [C^{op},V](X,j(u)))
    \\
    & \simeq
    \int_{u \in C} V(A(u), [C^{op},V](\int^{v \in C} j(v) \cdot X(v),j(u)))   
    \\
    & \simeq
    \int_{u, v \in C} V(A(u) \cdot X(v), [C^{op},V](j(v),j(u)))    
    \\
    & \simeq
    \int_{u, v \in C} V(A(u) \cdot X(v), V(v,u))    
  \end{aligned}
  \,,
$$

where we used the [[Yoneda lemma]] $[C^{op},V](j(v),j(u)) \simeq V(v,u)$ and the [[co-Yoneda lemma]] $X \simeq \int^{v \in V} j(v) \cdot X(v)$ and the fact that the $V$-enriched hom sends colimits and coends in the first argument to limits and ends.

Analogously we find

$$
  \begin{aligned}
    [C^{op},V](X,Spec A)
    & =
    \int_{v \in C} V(X(v),[C,V](A, j^{op}(v)))
    \\
    & \simeq
    \int_{v \in C} V(X(v), [C,V](\int^{u \in C} j^{op}(u) \cdot X(v),j^{op}(u)))   
    \\
    & \simeq
    \int_{u, v \in C} V(A(u) \cdot X(v), [C,V](j^{op}(v),j^{op}(u)))    
    \\
    & \simeq
    \int_{u, v \in C} V(A(u) \cdot X(v), V(v,u))    
  \end{aligned}
  \,,
$$


## Examples

### Cartesian test spaces: diffeological spaces and smooth algebras

Consider the category of test spaces $C = $ [[CartSp]].

Then 

* spaces modeled on $C$ are [[generalized smooth space]]s such as [[diffeological space]]s;

* quantities modeled on $C$ are [[smooth algebra]]s ($C^\infty$-rings).

The adjunction $(\mathcal{O} \dashv Spec)$ sends a smooth space to its smooth algebra of functions and a smooth algebra of functions to its "spectrum".


## Higher space and higher quantity

There are various specializations of interest on this

* [[higher category theory|higher categorical]] version

  * [[∞-space]] modeled on $C$ is a [[simplicial presheaf]] on $C$, i.e. a functor $X : C^{op} \to $ [[SSet]].

  * [[∞-quantity]] modeled on $C$ is a cosimplicial copresheaf on $C$, i.e. a functor $X : C \to CoSSet$ .

With the advent of [[Higher Topos Theory]] abstract concepts of _space and quantity_ have been realized fully in the context of [[(∞,1)-topos]]es in terms of [[structured (∞,1)-topos]]es and [[generalized scheme]]s. For a summary see the tables at [notions of space](http://ncatlab.org/nlab/show/A+Survey+of+Elliptic+Cohomology+-+the+derived+moduli+stack+of+derived+elliptic+curves#NotionsOfSpace).




## References

The notion originates somewhere around

* [[Bill Lawvere]] _Categories of space and quantity_ in: J. Echeverria et al (eds.), _The Space of mathematics_ , de Gruyter, Berlin, New York (1992)

A kind of review is in

* [[Bill Lawvere]], _[Taking categories seriously](http://www.emis.de/journals/TAC/reprints/articles/8/tr8.pdf)_

[[!redirects quantity]]
[[!redirects space and quantity]]
[[!redirects duality between space and quantity]]
