
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Analysis
+-- {: .hide}
[[!include analysis - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Idea 

A **metric space** is a [[set]] which comes equipped with a [[function]] which measures _distance_ between points, called a _metric_. The metric may be used to generate a [[topology]] on the set, the _[[metric topology]]_, and a [[topological space]] whose topology comes from some metric is said to be _[[metrizable]]_. 


## Definitions

Traditionally, a __metric space__ is defined to be a [[set]] $X$ equipped with a __distance__ [[function]] 
$$ d\colon X \times X \to [0, \infty) $$ 
(valued in [[nonnegative number|non-negative]] [[real numbers]]) satisfying the following axioms: 

* [[triangle inequality|Triangle inequality]]: $d(x, y) + d(y, z) \geq d(x, z)$;

* Point inequality: $0 \geq d(x, x)$ (so $0 = d(x,x)$);

* Separation: $x = y$ if $d(x, y) = 0$ (so $x = y$ iff $d(x,y) = 0$);

* Symmetry: $d(x, y) = d(y, x)$.

Given a metric space $(X, d)$ and a point $x \in X$, the __[[open ball]]__ centered at $x$ of radius $r$ is  
$$ 
  B_r(x) \coloneqq \{y \in X : d(x, y) \lt r\}
$$ 
and it may be shown that the open balls form a [[basis for a topology|basis]] for a [[topological structure|topology]] on $X$, the _[[metric topology]]_. In fact, metric spaces are examples of [[uniform spaces]], and much of the general theory of metric spaces, including for example the notion of [[complete space|completion]] of a metric space, can be extrapolated to uniform spaces and even [[Cauchy spaces]].


### Metrizable spaces

A **metrizable space** is a [[topological space]] $X$ which admits a metric such that the  [[metric topology]] agrees with the topology on $X$. In general, many different metrics (even ones giving different [[uniform space|uniform structures]]) may give rise to the same topology; nevertheless, metrizability is manifestly a topological notion. 

Metrizable spaces enjoy a number of separation properties: they are [[Hausdorff space|Hausdorff]], [[regular space|regular]], and even [[normal space|normal]]. They are also [[paracompact space|paracompact]]. 

Metrizable spaces are closed under topological [[coproducts]] and of course [[subspaces]] (and therefore [[equalizers]]); they are closed under [[countable family|countable]] [[products]] but not general products (for instance, a product of uncountably many copies of the [[real line]] $\mathbb{R}$ is not a normal space). 

Fundamental early work in point-set topology established a number of metrization theorems, i.e., theorems which give sufficient conditions for a space to be metrizable. One of the more useful theorems is due to [[Urysohn]]: 

+-- {: .num_theorem} 
###### Theorem 
**(Urysohn metrization)** 
A [[separation axiom|regular, Hausdorff]] [[second-countable space]] is metrizable. 
=-- 

So, for instance, a compact Hausdorff space that is second-countable is metrizable. 

+-- {: .num_remark} 
###### Remark 
A compact Hausdorff space that is merely [[separable space|separable]] need not be metrizable; one example is the [[Stone-Cech compactification]] $\beta(\mathbb{N})$, in which $\mathbb{N}$ is dense but no non-principal [[ultrafilter]] $U$ is the limit of a sequence $X = \{x_n\} \subseteq \mathbb{N}$ of principal ultrafilters. (Supposing it were, choose complementary subsets $A, B \subseteq \mathbb{N}$ such that $A \cap X$ and $B \cap X$ are infinite. By the decomposition $\beta(\mathbb{N}) = \beta(A + B) = \beta(A) + \beta(B)$, we have $U$ belonging to exactly one of $\beta(A), \beta(B)$, say $\beta(B)$. But since the subsequence $A \cap X$ converges to $U$, the basic open neighborhood $\beta(B) = \{V \in \beta(\mathbb{N}): B \in V\}$ of $U$ intersects $A \cap X$ non-trivially, i.e., $B$ is contained in some principal ultrafilter $prin(a)$ with $a \in A \cap X$. Then $a$ lies in disjoint sets $B$ and $A \cap X$, contradiction.) 
=-- 


### Variations 

If we allow $d$ to take values in $[0,\infty]$ (the nonnegative [[lower reals]]) instead of just in $[0,\infty)$, then we get __extended metric spaces__.  If we drop separation, then we get __pseudometric spaces__.  If we drop the symmetry condition, then we get __quasimetric spaces__.  Thus the most general notion is that of an extended quasipseudometric space, which are also called __Lawvere metric spaces__ for the reasons below.

On the other hand, if we strengthen the [[triangle inequality]] to
$$ max(d(x,y), d(y,z)) \geq d(x,z) ,$$
then we get __ultrametric spaces__, a more restricted concept.  (This include for example $p$-[[adic completion]]s of [[number fields]].)  Extended quasipseudoultrametric spaces can also be called __Lawvere ultrametric spaces__.


## Lawvere metric spaces 
  {#LawvereMetricSpace}

In [Lawvere, 73](#Lawvere73), it was pointed out that Lawvere metric spaces are precisely [[enriched category|categories enriched]] in the [[monoidal category|monoidal]] [[partial order|poset]] $([0, \infty], \geq)$, where the [[tensor product]] is taken to be addition.  The [[composition]] operation in this enriched category identifies with the [[triangle identity]] in the metric space (see at _[triangle inequality -- Interpretation in enriched category theory](triangle+inequality#InterpretationInEnrichedCategoryTheory)_).

Alternatively, taking the monoidal product to be [[supremum]] instead, enriched categories amount to Lawvere ultrametric spaces.

Thus generalized, many constructions and results on metric spaces turn out to be special cases of yet more general constructions and results of [[enriched category theory]].  This includes for example the notion of [[Cauchy complete category|Cauchy completion]], which in general enriched category theory is related to [[Karoubi envelope|Karoubi envelopes]] and [[Morita equivalence]].

Imposing the symmetry axiom then gives us enriched $\dagger$-[[dagger category|categories]].  Note that when enriching over a [[cartesian monoidal category|cartesian monoidal]] poset, there is no difference between a $\dagger$-category and a [[groupoid]], so ultrametric spaces can also be regarded as [[enriched groupoid|enriched groupoids]], which is perhaps a more familiar concept.

(The requisite axioms for an enriched groupoid do not make sense when the enriching category is not cartesian, but one might argue that since in a poset "they would commute automatically anyway", it makes sense to call any poset-enriched $\dagger$-category also an "enriched groupoid".  However, perhaps it makes more sense just to speak about enriched $\dagger$-categories.)

The category of metric spaces and categories of random maps as generalised metric spaces were studied in the [thesis](#Meng) of Lawvere's student Xiao-qing Meng. 


## Motivation for the axioms 

The [[triangle inequality|triangle axiom]] is the fundamental idea behind a metric space; it goes back (at least) to Euclid and captures the idea that we are discussing the *shortest* distance between two points.  Given the triangle inequality, we have the polygon inequality
$$ d(x_0,x_1) + \cdots + d(x_{n-1},x_n) \geq d(x_0,x_n) $$
for all $n \gt 0$; the point inequality extends this to $n = 0$.

Besides extended metric spaces (where distances may be infinite), one might consider spaces where distances may be negative.  But in fact this gives us nothing new, at least if we have symmetry.  First,
$$ d(x,x) + d(x,x) \geq d(x,x) $$
forces $d(x,x) \geq 0$, so $d(x,x) = 0$; then
$$ 2 d(x,y) = d(x,y) + d(y,x) \geq d(x,x) $$
forces $d(x,y) \geq 0$.  A generalisation to negative distances is possible for quasimetric spaces, however; the simplest example has $2$ elements, with $d(x,y) = -d(y,x)$ (but necessarily $d(x,x) = 0$ still).

We can define a [[preorder]] $\leq$ on the points of a Lawvere metric space:
$$ x \leq y \;\Leftrightarrow\; d(x,y) = 0 .$$
Then the symmetry axiom implies that this relation is [[symmetric relation|symmetric]] and hence an [[equivalence relation]].  The [[quotient set]] under this equivalence relation satisfies separation; in this way, every pseudometric space is [[equivalence of categories|equivalent]] (as an enriched category) to a metric space.  Even for quasimetric spaces, we can still define an equivalence relation:
$$ x \equiv y \;\Leftrightarrow\; d(x,y) = 0 \;\wedge\; d(y,x) = 0 .$$
In [[constructive mathematics]], it works better to use $\lneq$:
$$ x \lneq y \;\Leftrightarrow\; d(x,y) \gt 0 ;$$
then the symmetry axiom implies that this is an [[apartness relation]], which (for quasimetric spaces) we can also define directly:
$$ x \# y \;\Leftrightarrow\; d(x,y) \gt 0 \;\vee\; d(y,x) \gt 0 .$$


## Examples 

* Every [[set]] carries the **[[discrete space|discrete metric]]** given by
  $$
    d(x,y) \coloneqq \left\{\array{
      0 & \text{if }x = y
      \\
      1 & \text{otherwise}
    }\right.
  $$

  For certain purposes, it makes more sense to make most the non-zero distance $\infty$ instead of $1$; then one has an extended metric space.

* Every [[normed vector space]] is a metric space by $d(x,y) \coloneqq {\|x - y\|}$; a pseudonormed vector space is a pseudometric space.

* Every [[connected space|connected]] [[Riemannian manifold]] becomes a pseudometric space (or a metric space if, as is often assumed, the manifold is [[Hausdorff space|Hausdorff]]) by taking the distance between two points to be [[infimum]] of the Riemannian lengths of all continuously differentiable [[path|paths]] connecting them:
  $$
    d(x,y) \coloneqq inf_{x \stackrel{\gamma}{\to} y} len(\gamma)
  .$$

  If the manifold might not be connected, then it still becomes an extended metric space.

## Properties

* [[Lebesgue number lemma]]

* [[sequentially compact metric spaces are totally bounded]]

* [[sequentially compact metric spaces are equivalently compact metric spaces]]

* [[countably compact metric spaces are equivalently compact metric spaces]]

* [[metric spaces are fully normal]]

* [[metric spaces are paracompact]]

## Related concepts

* [[induced metric]]

* [[metric jet]] -- a notion of "tangency" for maps of metric spaces

* [[complete metric space]] and [[localic completion]]

[[!include generalized uniform structures - table]]

## References

* Wikipedia, _[Metric space](https://en.wikipedia.org/wiki/Metric_space)_

*  {#Lawvere73}  [[Bill Lawvere]] (1973).  _Metric spaces, generalized logic and closed categories_.  Reprinted in [[TAC]], 1986.  [Web](http://www.tac.mta.ca/tac/reprints/articles/1/tr1abs.html).
   

* {#Meng} [[Xiao-qing Meng]], _Categories of convex sets and of metric spaces with applications to stochastic programming and related areas_, PhD thesis ([[Meng.djvu|djvu:file]]) 
 



[[!redirects metric space]]
[[!redirects metric spaces]]
[[!redirects metric]]
[[!redirects metrics]]
[[!redirects extended metric]]
[[!redirects extended metrics]]
[[!redirects extended metric space]]
[[!redirects extended metric spaces]]
[[!redirects pseudometric]]
[[!redirects pseudometrics]]
[[!redirects pseudometric space]]
[[!redirects pseudometric spaces]]
[[!redirects quasimetric]]
[[!redirects quasimetrics]]
[[!redirects quasimetric space]]
[[!redirects quasimetric spaces]]
[[!redirects quasipseudometric]]
[[!redirects quasipseudometrics]]
[[!redirects quasipseudometric space]]
[[!redirects quasipseudometric spaces]]
[[!redirects ultrametric]]
[[!redirects ultrametrics]]
[[!redirects ultrametric space]]
[[!redirects ultrametric spaces]]
[[!redirects Lawvere metric space]]
[[!redirects Lawvere metric spaces]]


[[!redirects distance]]
[[!redirects distances]]