
# Pseudotopological spaces
* tic
{: toc}

## Idea

A _pseudotopological space_ or _Choquet space_ is a generalisation of a [[topological space]] based on the concept of convergent [[ultrafilter]] as fundamental.  This view relies on the [[ultrafilter theorem]] to guarantee enough ultrafilters; however, we can also describe a pseudotopological structure in terms of convergence of arbitrary [[filters]] satisfying certain properties.  In this respect, a pseudotopological space is a special kind of [[convergence space]].

The [[category]] $Ps Top$ of pseudotopological spaces is a [[quasitopos]] and may be thought of as a [[nice category of spaces]] that includes [[Top]] as a [[full subcategory]]. It is the minimal quasitopos containing the [[cartesian closed category]] of [[sequential spaces]] (cf [[Johnstone's topological topos]] Thm 10.2).
It is also a reflective subcategory of [[filter spaces]] (Thm 10.3).

## Definitions

A **pseudotopological space** is a [[set]] $S$ together with a [[relation]] $\to$ from $\mathcal{F}S$ to $S$, where $\mathcal{F}S$ is the set of [[filters]] on $S$; if $F \to x$, we say that $F$ __converges__ to $x$.  This must satisfy some axioms:

1. Centred: The principal ultrafilter $F_x = \{ A \;|\; x \in A \}$ at $x$ converges to $x$;
2. Isotone: If $F \subseteq G$ and $F \to x$, then $G \to x$;
3. Star property: If $F$ is a filter such that for every proper filter $G \supseteq F$ there exists a proper filter $H \supseteq G$ with $H \to x$, then $F \to x$.

A pseudotopological space is a special case of a [[convergence space]]; the star property is a stronger version of the filter property of a convergence space:

*  If $F \to x$ and $G \to x$, then $F \cap G \to x$.

Assuming the [[ultrafilter principle]] (a weak version of the [[axiom of choice]]), the star property can be expressed in terms of [[ultrafilters]]:

*  If $F$ is a filter such that every ultrafilter $U \supseteq F$ converges to $x$, then $F \to x$.

The property of isotony gives the converse, so $F \to x$ if and only if every ultrafilter refining $F$ converges to $x$.  Thus a pseudotopology consists precisely of a convergence relation between ultrafilters and points satisfying the single axiom that $F_x$ converges to $x$ for every $x$.


A [[subsequential space]] is a pseudotopological space that may be defined using only [[sequences]] instead of arbitrary nets/filters.

As with other convergence spaces, a filter $F$ __clusters__ at a point $x$ if there exists a proper filter $G$ such that $F \subseteq G$ and $G \to x$; given the ultrafilter principle, we may assume that $G$ is an ultrafilter.  Note that an ultrafilter clusters at $x$ iff it converges to $x$.

The definition can also be phrased in terms of [[nets]]; a net $\nu$ converges to $x$ if and only if its [[eventuality filter]] converges to $x$.

The morphisms of convergence spaces are the [[continuous functions]]; a function $f$ between pseudotopological spaces is __continuous__ if $F \to x$ implies that $f(F) \to f(x)$, where $f(F)$ is the filter generated by the [[filterbase]] $\{f(A) \;|\; A \in F\}$.  In this way, pseudotopological spaces form a [[concrete category]] $PsTop$, which is in fact a [[quasitopos]].


## Properties

The [[topological spaces]] can be characterized as the pseudotopological ones in which the convergence satisfies a certain [[associativity]] condition; see [[relational β-module]].  In this way one can think of a topological space as a [[multicategory]] parametrized by ultrafilters; see [[generalized multicategory]].

In particular, note that a [[compact space|compact]] [[Hausdorff space|Hausdorff]] pseudotopological space is defined by a single function $\mathcal{U}S \to S$, where $\mathcal{U}S$ is the set of ultrafilters on $S$, such that the composite $S \to \mathcal{U}S \to S$ is the identity.  That is, it is an [[algebra for an endofunctor|algebra]] for the [[pointed endofunctor]] $\mathcal{U}$.  The compact Hausdorff _topological_ spaces (the [[compacta]]) are precisely the [[algebra for a monad|algebras]] for $\mathcal{U}$ considered as a [[monad]].

Every [[pretopological space]] is also a pseudotopological space; these may be characterised as the infinitely directed pseudotopological spaces.


## References

*  [[Mike Shulman]] (2008); Ultrafilters, Pseudotopological spaces, and [[Stone-Čech compactification]]; [pdf](http://home.sandiego.edu/~shulman/papers/pstonecech.pdf)


[[!redirects pseudotopological space]]
[[!redirects pseudotopological spaces]]
[[!redirects Choquet space]]
[[!redirects Choquet spaces]]
