
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Geometry
+--{: .hide}
[[!include higher geometry - contents]]
=--
#### Group Theory
+-- {: .hide}
[[!include group theory - contents]]
=--
=--
=--

#Contents#
* table of contents
{:toc}

## Idea
 {#Idea}

The _Erlangen program_ (in German, _Erlanger Programm_ ) is a project, begun by [[Felix Klein]] at Erlangen in the 19th century ([Klein 1872](#Klein1872)), to study [[geometry]] via [[symmetry]] [[groups]] of "geometric shapes", hence from the perspective of [[group theory]]. The idea is to take the elementary building blocks of geometry to be not just [[Euclidean spaces]] but more generally [[homogeneous spaces]] $G/H$. These have then also been called _[[Klein geometries]]_ .

In ([Klein 1872, section 1](#Klein1872)) the theme of the program is described as follows:

> Given a manifold and a transformation group acting on it, to investigate those properties of figures [Gebilde] on that manifold which are invariant under [all] transformations of that group.

In modern language this means to consider a group of [[homeomorphisms]] ([[diffeomorphisms]]) [[action|acting]] on a ([[smooth manifold|smooth]]) [[manifold]] together with its [[stabilizer subgroup]] of any prescribed [[submanifold]]. (The concept of [[Lie group]] only emerged at that time, in fact Klein and [[Sophus Lie]] were in close contact, see [Birkhoff-Bennett](#BirkhoffBennett).)

The group of all such transformations 

> by which the geometric properties of configurations in space remain entirely unchanged

is called the "Hauptgruppe", translated to "principal group".


A few lines below in ([Klein 1872, section 1](#Klein1872)) is the converse statement

> Given a manifold, and a transformation group acting on it, to study its invariants.

Hence to find the figures which are left invariant by a given group [[action]].

Then in ([Klein 1872, end of section 5](#Klein1872)) it says:

> Suppose in space some group or other, the principal group for instance, be given. Let us then select a single configuration, say a point, or a straight line, or even an ellipsoid, etc., and apply to it all the transformations of the principal group. We thus obtain an infinite manifoldness with a number of dimensions in general equal to the number of arbitrary parameters contained in the group, but reducing in special cases, namely, when the configuration originally selected has the property of being transformed into itself by an infinite number of the transformations of the group. Every manifoldness generated in this way may be called, with reference to the generating group, a body. 

This means in modern language, that if $G$ is the given group acting on a given space $X$, and if $S \hookrightarrow X$ is a given subspace (a configuration), then the "body" ("Körper") generated by this is the [[coset]] 

$$
  G/Stab_G(S)
$$ 

of $G$ by the [[stabilizer subgroup]] of that configuration. In the case that $S$ is a point we would now call this the [[orbit]] of $S$. See also there at _[Stabilizer of shapes -- Klein geometry](stabilizer%20group#KleinGeometry)_.

The text goes on to argue that spaces of this form $G/Stab_G(S)$ are of fundamental importance:

> If now we desire to base our investigations upon the group, selecting at the same time certain definite configurations as space-elements, and if we wish to represent uniformly things which are of like characteristics, we must evidently choose our space-elements in such a way that their manifoldness either is itself a body or can be decomposed into bodies.

Following this, such [[coset spaces]] $G/H$ have come to also be called _[[Klein geometries]]_.


When it was proposed, the Erlangen program served to unify various different kinds of geometry, discovered and studied at that time, into a common framwork. On the other hand, many kinds of geometries without global symmetries are not [[Klein geometries]], notably [[Riemannian geometry]] is (in general) not. But a ([[pseudo-Riemannian manifold|pseudo]]) [[Riemannian manifold]] is _locally_ (tangentially) modeled on [[Euclidean space]] ([[Minkowski spacetime]]) and this local model space _is_ a Klein geometry. The generalization of Klein geometry to such local situations is _[[Cartan geometry]]_, see [below](#CartanGeometry).

###In homotopy type theory

In [[homotopy type theory]] the idea of a group of symmetries preserving a figure inside the larger group of symmetries acting on what the figure is inscribed in is represented by any map of the form:

$$
B H \to B G
$$

The [[homotopy fiber]] of such a map is the Klein space $G/H$.

## Refinements and generalizations

### From local to global geometry -- Cartan geometry
 {#CartanGeometry}

While many types of geometries (such as [[Riemannian geometry]]) are not in general [[Klein geometries]], they are _locally_ like Klein geometries. This generalization of Klein geometry is known as _[[Cartan geometry]]_. 

 local model                |   global geometry
----------------------------|-----------------
 [[Klein geometry]]         |   [[Cartan geometry]]
 [[Klein 2-geometry]]       |   [[Cartan 2-geometry]]
 [[higher Klein geometry]]  |   [[higher Cartan geometry]]

In [[physics]] terminology this corresponds to "locally gauging" the [[symmetry group]]. For instance for $H \hookrightarrow G$ the inclusion of the [[Lorentz group]] into the [[Poincare group]], then the corresponding [[Klein geometry]] is just [[Minkowski spacetime]], but a corresponding [[Cartan geometry]] is any [[pseudo-Riemannian manifold]], i.e. a [[spacetime]] characterized in the [[first-order formulation of gravity]].

[[!include local and global geometry - table]]

### Higher Klein geometry

Aspects of Klein geometry may be generalized from groups to [[groupoids]] and even [[category|categories]] or $\infty$-[[infinity-groupoid|groupoids]]. See at _[[higher Klein geometry]]_.

### Logicality and invariance

Logicians have attempted to demonstrate that specifically _logical_ constructions are those invariant under the largest group of transformations, in the sense of the Erlangen program. See [[logicality and invariance]]. 


## References 

* {#Klein1872} [[Felix Klein]], _Vergleichende Betrachtungen über neuere geometrische Forschungen_ (1872)

  translation by M. W. Haskell, _A comparative review of recent researches in geometry_ , trans. M. W. Haskell, Bull. New York Math. Soc. 2, (1892-1893), 215-249. ([retyped pdf](http://math.ucr.edu/home/baez/erlangen/erlangen_tex.pdf), [[KleinRetyped.pdf:file]], [scan of original](http://math.ucr.edu/home/baez/erlangen/erlangen.pdf))

* [[John Baez]], [webpage on the Erlangen program](http://math.ucr.edu/home/baez/erlangen)


* {#BirkhoffBennett} Garrett Birkhoff, M. K. Bennett, _Felix Klein and His "Erlanger Program"_ ([pdf](http://www.mcps.umn.edu/11_6Birkhoff.pdf))

* Vladimir Kisil, _Erlangen Programme at Large: An Overview_ ([arXiv:1106.1686](http://arxiv.org/abs/1106.1686))

* Jeremy Gray, _Felix Klein's Erlangen programme_, in _Landmark Writings in Western Mathematics_, ed. I. Grattan-Guinness, Elsevier, p. 544-552, 2005



[[!redirects Erlangen programme]]

[[!redirects Erlanger program]]