[[!redirects reader monad]]

+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Type theory
+-- {: .hide}
[[!include type theory - contents]]
=--
#### Mapping space
+--{: .hide}
[[!include mapping space - contents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}

## Idea

In a [[cartesian closed category]]/[[type theory]] $\mathcal{C}$, given any [[object]]/[[type]] $W$ there is a [[monad]]

$$
  [W,-] \colon \mathcal{C} \to \mathcal{C}
$$

given by forming the [[internal hom]] out of $W$, hence the "space of functions" out of $W$. This is sometimes called the _function monad_.  Its [[unit of a monad]] is given by sending values to [[constant functions]] with that value, and the monad operation is given by evaluating on the [[diagonal]].

In the context of [[monads in computer science]] this monad is called the _reader monad_ or _environment monad_. It serves to write programs in which all operations may "read in" a state of type $W$ (an "environment").

## Properties

### Relation to the writer comonad and state monad

In a [[cartesian closed category]]/[[type theory]] $\mathcal{C}$,
the reader monad $[W,-] \colon \mathcal{C}\to \mathcal{C}$ is [[right adjoint]] to the [[writer comonad]] $W\times (-)$.

Just as the writer comonad is canonically a monad when $W$ is a [[monoid]], so the reader monad is a comonad in that case, and then it is sometimes called the 'traced comonad'.

The composite of writer comonad followed by [[reader monad]] is the [[state monad]].

### In terms of dependent type theory
 {#InTermsOfDependentTypeTheory}

If the type system is even a [[locally Cartesian closed category]]/[[dependent type theory]] then for each type $W$ there is the [[base change]] [[adjoint triple]]

$$
  \mathcal{C}_{/W}
    \stackrel{\overset{\sum_W}{\longrightarrow}}{\stackrel{\overset{W^\ast}{\longleftarrow}}{\underset{\prod_W}{\longrightarrow}}}
  \mathcal{C}
$$

In terms of this then the function monad is equivalently the composite

$$
  \prod_W W^\ast = [W,-] \;\colon\; \mathcal{C} \longrightarrow \mathcal{C}
$$

of [[context extension]] followed by [[dependent product]].

One may also think of this as being the [[polynomial functor]] associated with the span

$$
  \ast \leftarrow W \rightarrow \ast \rightarrow \ast
  \,.
$$

(Notice that the [[comonad]] obtained by composing the other way around, $W^\ast \prod_W$, is the [[modal operator]] usually called _[[necessity]]_.)


### Relation to random variables in probability theory
 {#RelationToRandomVariables}

It makes sense to think of $[W,-]$ as producing spaces of [[random variables]] ([Verdier 14](#Verdier14)) depending on [[possible worlds]] $w\in W$ ([Toronto-McCarthy 10b, slide 24](#TorontoMcCarthy10b)). 

>  The intuition behind the Reader monad, for a mathematician, is perhaps stochastic variables. A stochastic variable is a function from a probability space to some other space. So we see a stochastic variable as a monadic value. ([Verdier 14](#Verdier14))

> you could interpret this by regarding random variables as reader monad computations. ([Toronto-McCarthy 10b, slide 35](#TorontoMcCarthy10b))

[Toronto-McCarthy 10a, 2.2](#TorontoMcCarthy10a), [Toronto 14, 6.2](#Toronto14) call the function monad the _random variable idiom_.

(While, from the perspective of [[modal type theory]], its siblings $W^\ast \prod_W$ and $W^\ast \sum_W$ may be called _[[necessity]]_ and _[[possibility]]_, respectively).

In [[Haskell]], the traditional way to model that a program may depend on random states $w \in W$ is to consider not the reader monad but the [[state monad]] $[W,W \times (-)]$. This allows programs not only to depend on the state $w\in W$, but also to change it (for instance to a new number generated by a random number generator). If however one restricts attention to programs that just depend on/read in a random environment $w\in W$ but never change it, then these standard constructs may be reduced from using the state monad to using just the reader monad.

## Related concepts

* [[maybe monad]]

* [[continuation monad]]

* [[writer comonad]], [[state monad]]

## References

* Wikipedia, _[Environment monad](http://en.wikipedia.org/wiki/Monad_%28functional_programming%29#Environment_monad)_.
* {#TorontoMcCarthy10a} [[Neil Toronto]], [[Jay McCarthy]], _From Bayesian notation to pure Racket, via measuretheoretic probability_ , in _Implementation and Application of Functional Languages_, 2010 ([web](http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.298.4274))

* {#TorontoMcCarthy10b} [[Neil Toronto]], [[Jay McCarthy]], _From Bayesian Notation to Pure Racket_, talk notes 2010 ([pdf](http://jeapostrophe.github.io/home/static/toronto-2010ifl-slides.pdf))

* {#Toronto14} [[Neil Toronto]], _Useful Languages for Probabilistic Modeling and Inference_, PhD Thesis, 2014 ([pdf](http://cs.umd.edu/~ntoronto/papers/toronto-2014diss.pdf), [slides](http://cs.umd.edu/~ntoronto/papers/toronto-2014diss-slides.pdf))

* {#Verdier14} [[Olivier Verdier]], _[The Reader and Writer Monads and Comonads](http://www.olivierverdier.com/posts/2014/12/31/reader-writer-monad-comonad/)_, 2014

A treatment of _opacity_ via the function monad

* [[Gianluca Giorgolo]], [[Ash Asudeh]], _Monads as a Solution for Generalized Opacity_, [pdf](http://users.ox.ac.uk/~cpgl0036/pdf/giorgolo-asudeh-eacl2014.pdf)


[[!redirects reader monads]]

[[!redirects function monad]]
[[!redirects function monads]]

[[!redirects environment monad]]
[[!redirects environment monads]]