# Contents #
* table of contents
{:toc}


## Definition 

The *exponent* of a [[group]] $G$, denoted $\exp(G)$, is the least [[natural number]] $n$ such that $g^n = 1$, the [[identity element]], for all $g \in G$. 

Here "least" should, by all rights, refer to the *divisibility order* on $\mathbb{N}$, where $m \leq n$ means $m$ divides $n$. Notice that with this poset structure, $\mathbb{N}$ is a [[complete lattice]] with bottom element $1$ and top element $0$; under this convention, the exponent always exists as the least common multiple of the orders of elements, which is their join ([[supremum]]) in the lattice, and is $0$ if (for example) $G$ is a [[torsion|torsion-free group]]. 

## Properties 

If $G$ is a [[finite group]] of [[order of a group|order]] $n$, then $\exp(G)$ divides $n$ since $g^n = 1$ for all $g \in G$. 

+-- {: .num_prop} 
###### Proposition 
If $G$ is a finite abelian group and $\exp(G) = ord(G)$, then $G$ is [[cyclic group|cyclic]]. 
=-- 

+-- {: .proof} 
###### Proof 
Of course $ord(G)$ can't be $0$, so $e = \exp(G)$ here has a prime factorization 
$e = p_1^{r_1} p_2^{r_2} \ldots p_k^{r_k}$. Since $e$ is the least common multiple of the orders of elements, the exponent $r_i$ is the maximum multiplicity of $p_i$ occurring in orders of elements; any element realizing this maximum will have order divisible by $p_i^{r_i}$, and some power $y_i$ of that element will have order exactly $p_i^{r_i}$. Then $y = \prod_i y_i$ will have order $e = ord(G)$ by the following lemma and induction, so that powers of $y$ exhaust all $ord(G)$ elements of $G$, i.e., $y$ generates $G$ as desired. 
=-- 

+-- {: .num_lemma}
###### Lemma 
If $m, n$ are relatively prime and $x$ has order $m$ and $y$ has order $n$ in an abelian group, then $x y$ has order $m n$. 
=-- 

+-- {: .proof} 
###### Proof 
Suppose $(x y)^k = x^k y^k = 1$. For some $a, b$ we have $a m - b n = 1$, and so $1 = x^{k a m} y^{k a m} = y^{k a m} = y^k y^{k b n} = y^k$. It follows that $n$ divides $k$. Similarly $m$ divides $k$, so $m n = lcm(m, n)$ divides $k$, as desired. 
=-- 

+-- {: .num_prop} 
###### Proposition 
If $G$ is a finite group, then the prime factors of $\exp(G)$ coincide with the prime factors of $ord(G)$. 
=-- 

+-- {: .proof} 
###### Proof 
Since $\exp(G)$ divides $ord(G)$, every prime factor of $\exp(G)$ is a factor of $ord(G)$. If $p$ is a prime factor of $ord(G)$, then by the [[Cauchy group theorem]], $G$ has an element of order $p$, and thus $p$ divides $\exp(G)$. 
=-- 

## Examples 

* If $\exp(G) = 2$, then $G$ is abelian and is a [[vector space]] over the field $\mathbb{F}_2$. 

* Similarly, if $G$ is abelian and its exponent is a prime $p$, then $G$ is a vector space over $\mathbb{F}_p$. 

* A finitely generated group of exponent $3$, $4$, or $6$ must be finite. On the other hand, it is not known whether a group of exponent $5$ generated by $2$ elements must be finite. 

These last facts are part of the lore of the celebrated Burnside problem. The *free Burnside group* $B(m, n)$ of exponent $n$ with $m$ generators is presented by $\langle x_1, \ldots, x_m\; |\; w^n = 1 \; for\; all\; words\; w\; in \; x_1, \ldots, x_m \rangle$, and one formulation of the original Burnside problem was whether $B(m, n)$ is finite. It is now known that the answer is negative for all $m \gt 1$ and odd $n \gt 665$, and there is a similar result for certain even $n$ as well. 

* For a fixed prime $p$, a *Tarski monster* for $p$ is a finitely generated infinite group where every proper nontrivial subgroup is cyclic of order $p$. Such monsters exist for sufficiently large $p$, forming a class of dramatic counterexamples to the Burnside conjecture; they are of course of exponent $p$. 

* It was shown by Efim Zelmanov that there are only finitely many finite groups with $m$ generators and exponent $n$ (restricted Burnside problem). It was largely on the strength of this work that he was awarded the Fields Medal (1994). 

## References 

* Wikipedia, _Burnside problem_, [web](https://en.wikipedia.org/wiki/Burnside%27s_problem)