# Contents # 
* table of contents 
{:toc} 

## Definition 

Let $k$ be a [[field]], and $p \in k[x]$ a [[monic polynomial]] of degree $n$. A _splitting field_ for $p$ is a [[field extension]] $i: k \hookrightarrow E$ such that, regarding $p$ as a [[polynomial]] in $E[x]$ by applying the map 

$$k[x] \cong k \otimes_k k[x] \stackrel{i \otimes 1}{\to} E \otimes_k k[x] \cong E[x],$$ 

the polynomial factors or "splits" as a product of linear factors (possibly repeated): 

$$p(x) = (x - r_1)(x - r_2)\ldots (x - r_n)$$ 

with all the [[roots]] $r_i$ lying in $E$, and the smallest subfield of $E$ containing $k$ and these roots is $E$ itself (so that the roots generate $E$: $E = k(r_1, \ldots, r_n)$. 

More generally, given a set $S \subseteq k[x]$ of monic polynomials, an extension field $E/k$ for which each $p \in S$ splits over $E$, and which as a field is generated over $k$ by the set of accompanying roots, is called a splitting field for $S$. 

## Construction 

The existence of a splitting field for a single polynomial $p \in k[x]$ can be proven by [[induction]] on $n = \deg(p)$. As $k[x]$ is a [[unique factorization domain]], $p$ is a product of irreducible polynomials $p_1 p_2 \ldots p_k$. The [[ideal]] $(p_1)$ is [[maximal ideal|maximal]] and so $E = k[x]/(p_1)$ is an [[finite-dimensional vector space|finite]] [[field extension]] of $k$ where the [[coset]] $r_1 \coloneqq x + (p_1) \in E$ is a [[root]] of $p_1(x) \in E[x]$, and $E = k(r_1)$. Then $q(x) = p(x)/(x - r_1) \in E[x]$ has degree $n-1$, and thus has a splitting field $F$ by induction, whence $q(x)$ splits as $(x - r_2)\ldots (x-r_n)$ in $F[x]$, and then $p(x) = (x - r_1)(x - r_2) \ldots (x - r_n)$ in $F[x]$. Finally we have the generation condition: $F = E(r_2, \ldots, r_n) = k(r_1)(r_2, \ldots, r_n) = k(r_1, r_2, \ldots, r_n).$ 

What is not clear from this construction is that splitting fields are unique (up to [[isomorphism]]). This is the case however: 

+-- {: .num_theorem #unique} 
###### Theorem 
Splitting fields of a polynomial are unique up to (non-unique) isomorphism. 
=-- 

+-- {: .proof} 
###### Proof 
(After [Conrad](#Con).) Suppose $E = k(r_1, \ldots, r_n)$ and $E' = k(r_1', \ldots, r_n')$ are two splitting fields of a polynomial $p \in k[x]$. The [[tensor product]] $E \otimes_k E'$ is a [[coproduct]] of $E$ and $E'$ in the category of [[commutative algebras]] over $k$; let $i: E \to E \otimes_k E'$ and $i': E' \to E \otimes_k E'$ be the coproduct [[coprojection|injections]]. Observe that as a $k$-algebra, $E \otimes_k E'$ is generated by the $i(r_j)$ together with the $i'(r_j')$. 

Now let $m$ be any maximal ideal of $E \otimes_k E'$ (note that $E \otimes_k E'$ is finite-dimensional over $k$, so the existence of $m$ does not involve any choice principles), and consider the composite 

$$\phi = (E \stackrel{i}{\to} E \otimes_k E' \stackrel{quot}{\to} E \otimes_k E'/m).$$ 

As is the case for any homomorphism between fields, this composite $\phi$ is an [[injective map]]. Moreover, letting $\rho_j$ denote the coset $i(r_j) + m$ and $\rho_j'$ the coset $i'(r_j') + m$, the polynomial $p(x)$ splits over the field $E \otimes_k E'/m$ as 

$$\prod_j (x - \rho_j) = \prod_k (x - \rho_k')$$ 

and so by [[unique factorization domain|unique factorization]] of polynomials, for each $\rho_k'$ there is a $\rho_j = \phi(r_j)$ with $\rho_k' = \rho_j$. This means the $\phi(r_j)$ exhaust the generators $\rho_j, \rho_k'$ of $E \otimes_k E'/m$. In other words, $\phi$ is also surjective and provides an isomorphism $E \cong E \otimes_k E'/m$. By symmetry we also have an isomorphism $E' \cong E \otimes_k E'/m$, and thus $E \cong E'$. 
=-- 

### Splitting fields of sets of polynomials 

A splitting field for a finite set of polynomials $\{p_1, \ldots, p_k\}$ is just a splitting field of the product $p_1 p_2 \ldots p_k$. 

Now let $S \subseteq k[x]$ be an arbitrary set of monic polynomials. For each $p \in S$, let $n_p$ denote the degree of $p$, and let us introduce a set of indeterminates $X_p = \{x_{p, 1}, \ldots, x_{p, n_p}\}$. Let $X$ be the coproduct $\sum_{p \in S} X_p$, and form the [[polynomial|polynomial algebra]] $R = k[X]$. For each $p \in S$ let us write 

$$p(t) - \prod_{i = 1}^{n_p} (t - x_{p, i}) = \sum_{j = 0}^{n_p - 1} s_{p, j} t^j$$ 

for some elements $s_{p, j} \in R$. We claim that the set $\Sigma$ of all $s_{p, j}$ with $p$ ranging over $S$ generates a proper ideal in $R$. For given an $R$-linear combination $g = g_1 s_1 + \ldots + g_k s_k$ with $s_i \in \Sigma$, where $s_i$ is associated with a polynomial $p_i$, let $E$ be the splitting field of $p = p_1 \ldots p_k$, and define a homomorphism $k[X] \to E$ that sends distinct elements of the form $x = x_{p_i, j}$ to distinct roots $r_j$ of $p_i$, and otherwise sends $x = x_{f, j}$ with $f \notin \{p_1, \ldots, p_k\}$ to $0$. Then $g$ is sent to $0$ in $E$, hence $g$ cannot be $1$. 

Let $\mathfrak{p}$ be a [[prime ideal]] containing the ideal generated by $\Sigma$; the existence of such $\mathfrak{p}$ is guaranteed under the [[ultrafilter principle]]. The ring $R/\mathfrak{p}$ is an [[integral domain]]; by construction every $p \in S$ splits over $R/\mathfrak{p}$ and the roots of such $p$ generate $R/\mathfrak{p}$ as a $k$-algebra. These roots thus generate its [[field of fractions]] $F$ as a field and $F$ is therefore a splitting field for $S$. 

In particular, taking $S$ to be the set of all monic polynomials in $k[x]$, this gives an efficient construction of the [[algebraic closure]] of $k$ that invokes not the full strength of the [[axiom of choice]] (in the form of [[Zorn's lemma]]), but only of the weaker [[ultrafilter principle]]. 

+-- {: .num_theorem} 
###### Theorem  
Any two splitting fields of a given set $S$ of polynomials are isomorphic. 
=-- 

Again we prove this only under the assumption of the [[ultrafilter principle]], and not under the assumption of full [[axiom of choice]]. 

+-- {: .proof} 
###### Proof 
(After [Caicedo](#AC).) Let $E, F$ be splitting fields for $S$; without loss of generality we may suppose $S$ is closed under multiplication of polynomials. For $p \in S$ let $E_p, F_p$ denote the corresponding subfields obtained by adjoining all roots of $p$ that occur in $E, F$ to the ground field $k$. Any isomorphism $E \to F$ restricts to an isomorphism $E_p \to F_p$. Notice that the $E_p$ form a directed system of fields, with an inclusion morphism $E_p \to E_q$ if $p$ divides $q$, and $E$ is the [[colimit]] of the $E_p$ over this directed system. We are required to show that the set of isomorphisms $Iso(E, F)$ is nonempty; we have restriction maps $Iso(E, F) \to Iso(E_p, F_p)$ which exhibit $Iso(E, F)$ as the [[inverse limit]] of $Iso(E_p, F_p)$ over the corresponding system, with transition maps $Res_{p q}: Iso(E_q, F_q) \to Iso(E_p, F_p)$ for $p|q$ also given by restriction. So we are required to show that this inverse limit is [[inhabited set|inhabited]]. 

By Theorem \ref{unique}, the set of isomorphisms $Iso(E_p, F_p)$ is inhabited, and it is also [[finite set|finite]] (being a [[torsor]] of the group $Aut(E_p)$ which has cardinality at most $n!$ where $n$ is the number of roots). It can then be proven from the [[ultrafilter theorem]] that $\Phi = \prod_{p \in S} Iso(E_p, F_p)$ is nonempty; see [here](/nlab/show/compactness+theorem#surj) for a proof. Similarly, the subset 

$$\Phi_{p q} \coloneqq \{\phi = (\phi_p)_{p \in S} \in \Phi: Res_{p q}(\phi_q) = \phi_p\}$$ 

is also nonempty, as is any finite intersection of such subsets $\Phi_{p q}$ (which actually is another $\Phi_{p' q'}$, by considering the product of $p$'s and $q$'s). 

Now $\Phi$ topologized as a product of finite discrete spaces is a [[compact Hausdorff space]]; this version of the [[Tychonoff theorem]] also follows from the ultrafilter theorem. We conclude from compactness that the full intersection $\bigcap_{p|q} \Phi_{p q}$ is inhabited. But this intersection is just the inverse limit which is $Iso(E, F)$, which concludes the proof. 
=-- 

An alternative proof based on a similar pattern of reasoning, but more explicitly in the language of [[model theory]] and the [[compactness theorem]], was given by [Joel David Hamkins](#JDH), in an answer following Caicedo's at MathOverflow. 

## References 

* Bernhard Banaschewski, _Algebraic closure without choice_, Mathematical Logic Quarterly, Vol. 38 Issue 1 (1992), 383–385. (doi: 10.1002/malq.19920380136, [paywall](http://onlinelibrary.wiley.com/doi/10.1002/malq.19920380136/pdf)) 
 {#Ban} 

* Keith Conrad, _Isomorphisms of Splitting Fields_, Galois theory notes ([pdf](http://www.math.uconn.edu/~kconrad/blurbs/galoistheory/splittingisom.pdf)). 
 {#Con}

* Andres Caicedo (http://mathoverflow.net/users/6085/andres-caicedo), _Is the statement that every field has an algebraic closure known to be equivalent to the ultrafilter lemma?_, URL (version: 2010-11-19): [http://mathoverflow.net/q/46568](http://mathoverflow.net/q/46568) 
 {#AC} 

* Joel David Hamkins (http://mathoverflow.net/users/1946/joel-david-hamkins), _Is the statement that every field has an algebraic closure known to be equivalent to the ultrafilter lemma?_, URL (version: 2010-11-20): [http://mathoverflow.net/q/46729](http://mathoverflow.net/q/46729) 
 {#JDH} 
