

+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Homological algebra
+--{: .hide}
[[!include homological algebra - contents]]
=--
#### Algebraic topology
+--{: .hide}
[[!include algebraic topology - contents]]
=--
#### Stable Homotopy theory
+--{: .hide}
[[!include stable homotopy theory - contents]]
=--
=--
=--

#Contents#
* table of contents
{:toc} 

## Idea
 {#Idea}

The notion of _spectral sequence_ is an [[algorithm]] or computational tool in [[homological algebra]] and more generally in [[homotopy theory]] which allows to compute [[chain homology|chain homology groups]]/[[homotopy groups]] of _bi_-[[graded objects]] from the homology/homotopy of the two graded components. 

Notably there is a spectral sequence for computing the homology of the [[total complex]] of a [[double complex]] from the homology of its row and column complexes separately.
This in turn allows to compute [[derived functors]] of composite functors $G\circ F$ from the double complex $\mathbb{R}^\bullet G (\mathbb{R}^\bullet F(-))$ obtained by non-totally deriving the two functors separately (called the [Grothendieck spectral sequence](#GrothendieckSpectralSequence)). By choosing various functors $F$ and $G$ here this gives rise to various important classes of examples of spectral sequences, see [below](#SpecialGrothendieckSpectralSequence).

More concretely, a homology spectral sequence is a sequence of graded chain complexes that provides the higher order corrections to the _na&iuml;ve_ idea of computing the homology of the [[total complex]] $Tot(V)_\bullet$ of a [[double complex]] $V_{\bullet, \bullet}$: by first computing those of the vertical differential, then those of the horizontal differential induced on these vertical homology groups (or the other way around). This simple idea in general does not produce the correct homology groups of $Tot(V)_\bullet$, but it does produce a "first-order approximation" to them, in a useful sense. The spectral sequence is the sequence of higher-order corrections that make this naive idea actually work.

Being, therefore, an iterative perturbative approximation scheme of bigraded differential objects, fully-fledged spectral sequences can look a bit intricate. However, a standard experience in mathematical practice is that for most problems of practical interest the relevant spectral sequence "perturbation series" yields the exact result already at the second stage. This reduces the computational complexity immensely and makes spectral sequences a wide-spread useful computational tool.

Despite their name, there seemed to be nothing specifically "spectral" about spectral sequences, for any of the technical meanings of the word [[spectrum - disambiguation|spectrum]]. Together with the concept, this term was introduced by [[Jean Leray]] and has long become standard, but was never really motivated (see p. 5 of [Chow](#Chow)). But then, by lucky coincidence it turns out in the refined context of [[stable (∞,1)-category]] theory/[[stable homotopy theory]] that spectral sequences frequently arise by considering the [[homotopy groups]] of _[[sequential diagram|sequences]] of [[spectra]]_. This is discussed at _[[spectral sequence of a filtered stable homotopy type]]_.

While therefore spectral sequences are a notion considered in the context of [[homological algebra]] and more generally in [[stable homotopy theory]], 
there is also an "unstable" or [[nonabelian cohomology|nonabelian]] variant of the notion in plain [[homotopy theory]], called _[[homotopy spectral sequence]]_.


## Definition

We give the general definition of a (co)homology spectral sequence. For motivation see the example _[Spectral sequence of a filtered complex](#SpectralSequenceOfFilteredComplex)_ below.

Throughout, let $\mathcal{A}$ be an [[abelian category]]. 

### Spectral sequence

+-- {: .num_defn #CohomologySpectralSequence}
###### Definition

A __cohomology spectral sequence__ in $\mathcal{A}$ is 

* a family $(E^{p,q}_r)$ of [[objects]] in $\mathcal{A}$, for all [[integers]] $p,q,r$ with $r\geq 1$ 

  (for a fixed $r$ these are said to form the __$r$-th page__ of the spectral sequence)

* for each $p,q,r$ as above a [[morphism]] (called the __differential__) 
  
  $$
    d^{p,q}_r:E^{p,q}_r\to E^{p+r,q-r+1}_r
  $$ 

  satisfying $d_r^2 = 0$ (more precisely, $d_r^{p+r,q-r+1}\circ d_r^{p,q} = 0$)

* [[isomorphisms]] $\alpha_r^{p,q}: H^{p,q}(E_r)\to E^{p,q}_{r+1}$ where 
  the [[chain cohomology]] is given by
  
  $$
    H^{p,q}(E_r) = \mathrm{ker} d^{p,q}_r/ \mathrm{im} d^{p-r,q+r-1}_r
   \,.
  $$

=--

Analogously a **homology spectral sequence** is collection of objects $(E_{p,q}^r)$ with the differential $d_r$ of degree $(-r,r-1)$.



### Convergence
 {#ConvergenceOfSpectralSequences}

+-- {: .num_defn #LimitTerm}
###### Definition

Let $\{E^r_{p,q}\}_{r,p,q}$ be a [[spectral sequence]] such that for each $p,q$ there is $r(p,q)$ such that for all $r \geq r(p,q)$ we have

$$
  E^{r \geq r(p,q)}_{p,q} \simeq E^{r(p,q)}_{p,q}
  \,.
$$

Then one says equivalently that

1. the [[bigraded object]]

   $$
     E^\infty 
      \coloneqq 
     \{E^\infty_{p,q}\}_{p,q} \coloneqq \{ E^{r(p,q)}_{p,q} \}_{p,q}
   $$

   is the **limit term** of the spectral sequence;

1.  the spectral sequence **abuts** to $E^\infty$.

=--

+-- {: .num_example #Degeneration}
###### Example

If for a spectral sequence there is $r_s$ such that all [[differentials]] on pages after $r_s$ vanish, $\partial^{r \geq r_s} = 0$, then $\{E^{r_s}\}_{p,q}$ is limit term for the spectral sequence. One says in this cases that the spectral sequence **degenerates** at $r_s$.

=--

+-- {: .proof}
###### Proof

By the defining relation

$$
  E^{r+1}_{p,q} \simeq ker(\partial^r_{p-r,q+r-1})/im(\partial^r_{p,q}) = E^r_{pq}
$$

the spectral sequence becomes constant in $r$ from $r_s$ on if all the differentials vanish, so that $ker(\partial^r_{p,q}) = E^r_{p,q}$ for all $p,q$.

=--


+-- {: .num_example #Collaps}
###### Example

If for a [[spectral sequence]] $\{E^r_{p,q}\}_{r,p,q}$ there is $r_s \geq 2$ such that the $r_s$th page is concentrated in a single row or a single column, then the the spectral sequence degenerates on this pages, example \ref{Degeneration}, hence this page is a limit term, def. \ref{LimitTerm}. One says in this case that the spectral sequence **collapses** on this page.

=--

+-- {: .proof}
###### Proof

For $r \geq 2$ the [[differentials]] of the spectral sequence

$$
  \partial^r \colon E^r_{p,q} \to E^r_{p-r, q+r-1}
$$ 

have [[domain]] and [[codomain]] necessarily in different rows an columns (while for $r = 1$ both are in the same row and for $r = 0$ both coincide). Therefore if all but one row or column vanish, then all these differentials vanish.

=--


+-- {: .num_defn #Convergence}
###### Definition

A [[spectral sequence]] $\{E^r_{p,q}\}_{r,p,q}$ **converges weakly** to a [[graded object]] $H_\bullet$ with [[exhaustive filtering]] $F_\bullet H_\bullet$, traditionally denoted

$$
  E^r_{p,q} \Rightarrow H_\bullet
  \,,
$$

if the [[associated graded]] complex $\{G_p H_{p+q}\}_{p,q} \coloneqq \{F_p H_{p+q} / F_{p-1} H_{p+q}\}$ of $H$ is the limit term of $E$, def. \ref{LimitTerm}:

$$
  E^\infty_{p,q} \simeq G_p H_{p+q} \;\;\;\;\;\;\; \forall_{p,q}
  \,.
$$

Furthermore one says that $E$

* **converges** if $F_\bullet$ is also a [[Hausdorff filtration]];

* **converges strongly** if $F_\bullet$ is also a [[complete Hausdorff filtration]].

=--

([Boardman 99, def. 2.5](#Boardman99)) See also _[[conditional convergence]]_.

+-- {: .num_remark }
###### Remark

In practice, spectral sequences are often referred to via their first interesting page, usually the first or the second. Then one often uses notation such as

$$
  E^1_{p,q} \;\Rightarrow\; H_\bullet
$$

or

$$
  E^2_{p,q} \;\Rightarrow\; H_\bullet
$$

to be read as "There is a spectral sequence whose first/second page is as shown on the left and which converges (weakly, strongly, or conditionally) to a filtered object as shown on the right."

=--

+-- {: .num_example}
###### Example

The nature of the convergence condition in def. \ref{Convergence} is well illuminated for instance by the [[Serre spectral sequence|Serre]]-[[Atiyah-Hirzebruch spectral sequence]]: for $E^\bullet$ a [[generalized cohomology theory]] and $X$ a finite [[CW-complex]], then it converges to the $E$-cohomology of $X$, filtered by $E$-cohomology relative to the [[simplicial skeleton|skeleta]] $F^p E^{\bullet}(X) im(  E^\bullet(X,X_{p-1}) \to E^\bullet(X))$. Moreover, the second page is the [[ordinary cohomology]] of $X$ with coefficients in the $E$-ground ring, like so:

$$
  H^p(X,E^q(\ast)) \Rightarrow E^{p+q}(X)
  \,.
$$

Here the elements on the left in bidegree $(p,q)$ are manifestly given by cocycles that trivialize on the $(p-1)$-skeleton (being $p$-cocycles), hence it is natural that these contribute to the filtering stage $F^p E^{p+q}(X) = im(E^{p+q}(X,X_{p-1}) \to E^{p+q}(X))$.

=--



+-- {: .num_remark}
###### Remark

In applications one is interested in computing the $H_n$ and uses spectral sequences converging to this as tools for approximating $H_n$ in terms of the given filtration.

Therefore usually spectral sequences are required to converge in each degree, or even that for each pair $(p,q)$ there exists an $r_0$ such that for all $r\geq r_0$, $d_r^{p-r,q+r-1} = 0$.

=--

+-- {: .num_remark}
###### Remark

If $(E^r)$ collapses at $r$, then it converges to $H_\bullet$ with $H_n$ being the unique entry $E_{p,q}^r$ on the non-vanishing row/column with $p+q = n$.

=--


### Boundedness
 {#Boundedness}


+-- {: .num_defn #BoundedSpectralSequence}
###### Definition

A spectral sequence $\{E^r_{p,q}\}$ is called a **bounded spectral sequence** if for all $n,r \in \mathbb{Z}$ the number of non-vanishing terms of the form $E^r_{k,n-k}$ is finite.

=--

+-- {: .num_defn #QuadrantSpectralSequence}
###### Example

A [[spectral sequence]] $\{E^r_{p,q}\}$ is called

* a **first quadrant spectral sequence** if all terms except possibly for $p,q \geq 0$ vanish;

* a **third quadrant spectral sequence** if all terms except possibly for $p,q \leq 0$ vanish.

Such spectral sequences are bounded, def. \ref{BoundedSpectralSequence}.


=--

+-- {: .num_prop #BoundedSpectralSequenceHasLimitTerm}
###### Proposition

A bounded spectral sequence, def. \ref{BoundedSpectralSequence}, has a limit term, def. \ref{LimitTerm}.

=--

+-- {: .proof}
###### Proof

First notice that if a spectral sequence has at most $N$ non-vanishing terms of total degree $n$ on page $r$, then all the following pages have at most at these positions non-vanishing terms, too, since these are the homologies of the previous terms.

Therefore for a bounded spectral sequence for each $n$ there is $L(n) \in \mathbb{Z}$ such that $E^r_{p,n-p} = 0$ for all $p \leq L(n)$ and all $r$. Similarly there is $T(n) \in \mathbb{Z}$ such $E^r_{n-q,q} = 0$ for all $q \leq T(n)$ and all $r$.

We claim then that the limit term of the bounded spectral sequence is in position $(p,q)$ given by the value $E^r_{p,q}$ for 

$$
  r \gt max(  p-L(p+q-1), q + 1 - L(p+q+1) )
  \,.
$$

This is because for such $r$ we have

1. $E^r_{p-r, q+r-1} = 0$ because $p-r \lt L(p+q-1)$, and hence the [[kernel]] $ker(\partial^r_{p-r,q+r-1}) = 0$ vanishes;

1. $E^r_{p+r, q-r+1} = 0$ because $q-r + 1 \lt T(p+q+1)$, and hence the [[image]] $im(\partial^r_{p,q}) = 0$ vanishes.

Therefore

$$
  \begin{aligned}
    E^{r+1}_{p,q} 
    &= 
    ker(\partial^r_{p-r,q+r-1})/im(\partial^r_{p,q})
    \\
    & \simeq E^r_{p,q}/0
    \\
    & \simeq E^r_{p,q}
  \end{aligned}
  \,.
$$

=--


### Extension problem
 {#ExtensionProblem}


Given a spectral sequence, then even if it converges strongly (def. \ref{Convergence}), computing its infinity-page still just gives the [[associated graded]] of the [[filtered object]] that it converges to, not the filtered object itself. The latter is in each filter stage an [[extension]] of the previous stage by the corresponding stage of the infinity-page, but there are in general several possible extensions (the trivial extension or some twisted extensions). The problem of determining these extensions and hence the problem of actually determining the filtered object from a spectral sequence converging to it is often referred to as the _extension problem_.

More in detail, consider, for definiteness, a cohomology spectral sequence (def. \ref{CohomologySpectralSequence}) converging (def. \ref{Convergence}) to some [[filtered object|filtered]] $F^\bullet H^\bullet$

$$
  E^{p,q} \;\Rightarrow\; H^\bullet
  \,.
$$

Then by definition of convergence there are isomorphisms

$$
  E_\infty^{p,\bullet} \simeq F^p H^{p + \bullet} / F^{p+1} H^{p + \bullet}
  \,.
$$

Equivalently this means that there are [[short exact sequences]] of the form

$$
  0 \to F^{p+1}H^{p +\bullet} \hookrightarrow F^p H^{p +\bullet} \longrightarrow E_\infty^{p,\bullet} \to 0
  \,.
$$

for all $p$. The extension problem then is to inductively deduce $F^p H^\bullet$ from knowledge of $F^{p+1}H^\bullet$ and $E_\infty^{p,\bullet}$.

In good cases these short exact sequences happen to be [[split exact sequences]], which means that the extension problem is solved by the [[direct sum]]

$$
  F^p H^{p+\bullet} \simeq F^{p+1} H^{p+\bullet} \oplus E_\infty^{p,\bullet}
  \,.
$$

But in general this need not be the case. 

One sufficient condition that these exact sequences split is that they consist of homomorphisms of $R$-[[modules]], for some $R$, and that $E_\infty^{p,\bullet}$ are [[projective modules]] (for instance [[free modules]]) over $R$. Because then the [[Ext]]-group $Ext^1_R(E_\infty^{p,\bullet},-)$ vanishes, and hence all extensions are trivial, hence split.

So for instance for every spectral sequence in [[vector spaces]] the extension problem is trivial (since every vector space is a free module).


## Examples
 {#Examples}

The basic class of examples are

* [Spectral sequences of filtered complexes](#SpectralSequenceOfFilteredComplex)

which compute the cohomology of a [[filtered object|filtered complex]] from the cohomologies of its [[associated graded objects]]. 

From this one obtains as a special case the class of 

* [Spectral sequences of double complexes](#SpectralSequenceOfADoubleComplex)

which compute the cohomology of the [[total complex]] of a [[double complex]] using the two canonical filtrations of this by row- and by column-degree.

From this in turn one obtains as a special case the class of

* [Grothendieck spectral sequences](#GrothendieckSpectralSequence)

which compute the [[derived functor]] $\mathbb{R}^\bullet(G \circ F (-))$ of the composite of two functors from the spectral sequence of the double complex $\mathbb{R}^\bullet (F (\mathbb{R}^\bullet G (-)))$.

Many special cases of this for various choices of $F$ and $G$ go by special names, this we tabulate at

* _[List of examples](#ListOfExamples)_.




### Spectral sequence of a filtered complex
 {#SpectralSequenceOfFilteredComplex}

The fundamental example of a spectral sequence, from which essentially all the other examples arise as special cases, is the _[[spectral sequence of a filtered complex]]_. (See there for details). Or more generally in [[stable homotopy theory]]: the [[spectral sequence of a filtered stable homotopy type]].

If a [[cochain complex]] $C^\bullet$ is equipped with a [[filtered object|filtration]] $F^\bullet C^\bullet$, there is an induced filtration $F^\bullet H(C)$ of its [[cohomology groups]], according to which levels of the filtration contain representatives for the various cohomology classes.

A filtration $F$ also gives rise to an  [[associated graded object]] $Gr(F)$, whose grades are the successive level inclusion [[cokernels]].  Generically, the operations of grading and cohomology do not commute: 

$$
  Gr(F^\bullet H^\bullet(C)) \neq H^\bullet (Gr(F^\bullet) C)
  \,.
$$

But the [[spectral sequence of a filtered complex|spectral sequence associated to a filtered complex]] $F^\bullet C^\bullet$, passes through $H^\bullet (Gr(F^\star) C)$ in the page $E_{(1)}$ and in good cases converges to $Gr(F^* H^\bullet(C))$.


### Spectral sequence of a double complex
 {#SpectralSequenceOfADoubleComplex}

The [[total complex]] of a [[double complex]] is naturally filtered in two ways: by columns and by rows. By the above [[spectral sequence of a filtered complex]] this gives two different spectral sequences associated computing the cohomology of a double complex from the cohomologies of its rows and columns. Many other classes of spectral sequences are special cases of this cases, notably the [[Grothendieck spectral sequence]] and _its_ special cases. 

This is discussed at _[[spectral sequence of a double complex]]_.


### Spectral sequences for hyper-derived functors 
  {#HyperDerivedFunctors}

From the [[spectral sequence of a double complex]] one obtains as a special case a spectral sequence that computes [[hyper-derived functors]]. 

(...)

### Grothendieck spectral sequence 
 {#GrothendieckSpectralSequence}

The _[[Grothendieck spectral sequence]]_ computes the composite of two [[derived functors]] from the two derived functors separately.

Let $\mathcal{A} \stackrel{F}{\to} \mathcal{B} \stackrel{G}{\to} \mathcal{C}$ be two [[left exact functors]] between [[abelian categories]].

Write $R^p F : \mathcal{D} \to Ab$ for the [[cochain cohomology]] of the [[derived functor]] of $F$ in degree $p$ etc. .


+-- {: .num_theorem}
###### Theorem

If $F$ sends [[injective objects]] of $\mathcal{A}$ to $G$-[[acyclic objects]] in $\mathcal{B}$ then for each $A \in \mathcal{A}$ there is a [first quadrant](#FirstQuadrant) cohomology spectral sequence

$$
  E_r^{p,q} := (R^p G \circ R^q F)(A) 
$$

that converges to the right [[derived functor]] of the composite functor


$$
  E_r^{p,q} \Rightarrow R^{p+q} (G \circ F)(A).
$$

Moreover

1. the [[edge maps]] in this spectral sequence are the canonical morphisms
 
   $$
     R^p G (F A) \to R^p (G \circ F)(A)
   $$

   induced from applying $F$ to an injective resolution 
   $A \to \hat A$ and the morphism

   $$
     R^q (G \circ F)(A) \to G(R^q F (A))
     \,.
   $$

1. the [[exact sequence]] of low degree terms is

   $$
     0 \to (R^1 G)(F(A)) \to R^1(G \circ F)(A)
      \to G(R^1(F(A)))
      \to (R^2 G)(F(A))
      \to R^2(G \circ F)(A)
   $$

=--

This is called the _[[Grothendieck spectral sequence]]_.

+-- {: .proof}
###### Proof

Since for $A \to \hat A$ an injective [[resolution]] of $A$ the complex $F(\hat A)$ is a chain complex not concentrated in a single degree, we have that $R^p (G \circ F)(A)$ is equivalently the [[hyper-derived functor]] evaluation $\mathbb{R}^p(G) (F(A))$.

Therefore the second spectral sequence discussed at [hyper-derived functor spectral sequences](#HyperDerivedFunctors) converges as

$$
  (R^p G)H^q(F(\hat A)) \Rightarrow R^p (G \circ F)(A)
  \,.
$$

Now since by construction $H^q(F(\hat A)) = R^q F(A)$ this is a spectral sequence

$$
  (R^p G)(R^q F) A) \Rightarrow R^p (G \circ F)(A)
  \,.
$$

This is the Grothendieck spectral sequence.

=--

### Special Grothendieck spectral sequences 
 {#SpecialGrothendieckSpectralSequence}

* [Leray spectral sequence](#LeraySpectralSequence)

* [Hochschild-Serre spectral sequence](#HochschildSerreSpectralSequence)

* [Base-change spectral sequence](#BaseChangeSpectralSequence)

#### Leray spectral sequence
 {#LeraySpectralSequence}

The _[[Leray spectral sequence]]_ is the special case of the 
[[Grothendieck spectral sequence]] for the case where the two functors being composed are a [[direct image|push-forward]] of [[sheaves]] of [[abelian groups]] along a [[continuous map]] $f : X \to Y$ followed by the push-forward $X \to *$ to the point. This yields a spectral sequence that computes the [[abelian sheaf cohomology]] on $X$ in terms of the abelian sheaf cohomology on $Y$.

+-- {: .num_theorem}
###### Theorem

Let $X, Y$ be suitable [[sites]] and $f : X \to Y$ be a morphism of sites. () Let $\mathcal{C} = Ch_\bullet(Sh(X,Ab))$ and $\mathcal{D} = Ch_\bullet(Sh(Y,Ab))$ be the [[model structure on chain complexes|model categories of complexes of sheaves of abelian groups]]. The [[direct image]] $f_*$ and [[global section]] functor $\Gamma_Y$ compose to $\Gamma_X$:

$$
  \Gamma_X : \mathcal{C} \stackrel{f_*}{\to} \mathcal{D} \stackrel{\Gamma_Y}{\to} Ch_\bullet(Ab)
  \,.
$$

Then for $A \in Sh(X,Ab)$ a sheaf of abelian groups on $X$ there is a cohomology spectral sequence

$$
  E_r^{p,q} := H^p(Y, R^q f_* A)
$$

that converges as

$$
  E_r^{p,q} \Rightarrow H^{p+q}(X, A)
$$

and hence computes the cohomology of $X$ with coefficients in $A$ in terms of the cohomology of $Y$ with coefficients in the push-forward of $A$.

=--

#### Base change spectral sequence for $Tor$ and $Ext$
 {#BaseChangeSpectralSequence}

For $R$ a [[ring]] write $R$[[Mod]] for its category of [[modules]].
Given a [[homomorphism]] of [[ring]] $f : R_1 \to R_2$ and an $R_2$-[[module]] $N$ there are composites of [[base change]] along $f$ with the [[hom-functor]] and the [[tensor product]] functor

$$
  R_1 Mod \stackrel{\otimes_{R_1} R_2}{\to} R_2 Mod \stackrel{\otimes_{R_2} N}{\to} Ab
$$

$$
  R_1 Mod \stackrel{Hom_{R_1 Mod}(-,R_2)}{\to}
  R_2 Mod
  \stackrel{Hom_{R_2}(-,N)}{\to}
  Ab
  \,.
$$

The [[derived functors]] of $Hom_{R_2}(-,N)$ and $\otimes_{R_2} N$ are the [[Ext]]- and the [[Tor]]-functors, respectively, so the [[Grothendieck spectral sequence]] applied to these composites yields [[base change spectral sequence]] for these.

#### Hochschild-Serre spectral sequence
 {#HochschildSerreSpectralSequence}

* [[Hochschild-Serre spectral sequence]]

### Exact couples
 {: #exact_couples}

The above examples are all built on the [spectral sequence of a filtered complex](#SpectralSequenceOfFilteredComplex). An alternatively universal construction builds spectral sequences from _exact couples_.

An **[[exact couple]]** is an exact sequence of three arrows among two objects

$$ E \overset{j}{\to} D \overset{\varphi}{\to} D \overset{k}{\to} E \overset{j}{\to}. $$

These creatures construct spectral sequences by a two-step process:

*  first, the composite $ d \coloneqq k j \colon E\to E$ is nilpotent, in that $d^2=0$
*  second, the homology $E'$ of $(E,d)$ supports a map $j':E'\to \varphi D$, and receives a map $k':\varphi D\to E'$.  Setting $D'=\varphi D$, by general reasoning

$$ 
  E' \overset{j'}{\to} D' \overset{\varphi}{\to} D' \overset{k'}{\to} E' \overset{j'}{\to}
  \,. 
  $$
is again an exact couple.

The sequence of complexes $(E,d),(E',d'),\dots$ is a spectral sequence, by construction. For more see at _[exact couple -- Spectral sequences from exact couples](exact+couple#SpectralSequencesFromExactCouples)_

Examples of exact couples can be constructed in a number of ways. Notably there are naturally [exact couples of towers of (co-)fibrations](exact+couple#ExactCoupleOfATowerOfFibrations). For instance [[Adams spectral sequences]] are usually produced this way (from towers which are [[Adams resolutions]]). For a list of examples in this class see [below](#SpectralSequencesInducedFromTowersOfSpectra).

Importantly, any short exact sequence involving two distinct chain complexes provides an exact couple among their total homology complexes, via the Mayer-Vietoris long exact sequence; in particular, applying this procedure to the relative homology of a filtered complex gives precisely the spectral sequence of the filtered complex described (???) somewhere else on this page.  For another example, choosing a chain complex of flat modules $(C^\dot,d)$, tensoring with the short exact sequence
$$ \mathbb{Z}/p\mathbb{Z} \to \mathbb{Z}/p^2\mathbb{Z} \to \mathbb{Z}/p\mathbb{Z} $$
gives the exact couple

$$ 
  H^\bullet(d,\mathbb{Z}/p^2\mathbb{Z})
    \overset{[\cdot]}{\to} 
  H^\bullet(d,\mathbb{Z}/p\mathbb{Z})
   \overset{\beta}{\to}
  H^\bullet(d,\mathbb{Z}/p\mathbb{Z})
   \overset{p}{\to}H^\bullet(d,\mathbb{Z}/p^2\mathbb{Z})\cdots
$$

in which $\beta$ is the _mod-$p$ Bockstein_ homomorphism.

The exact couple recipe for spectral sequences is notable in that it doesn't mention any grading on the objects $D,E$; trivially, an exact couple can be specified by a short exact sequence $\coker \varphi\to E\to \ker\varphi$, although this obscures the focus usually given to $E$.  In applications, a bi-grading is usually induced by the context, which also specifies bidegrees for the initial maps $j,k,\varphi$, leading to the conventions mentioned earlier.


### List of examples
 {#ListOfExamples}


[[!include Lurie spectral sequences -- table]]


The following list of examples orders the various classes of spectral sequences by special cases: items further to the right are special cases of items further to the left.

* ***[[spectral sequence of a filtered complex]]*** (approximate [[chain homology]] by higher-order [[relative homology]] in the presence of a [[filtered object|filtering]])

  * [[Atiyah-Hirzebruch spectral sequence]] (compute [[generalized homology]] of a [[Serre fibration]] in terms of that of the base with [[coefficients]] in that of the [[fibers]])

    * [[Serre spectral sequence]] (compute [[ordinary homology]] of a [[Serre fibration]] in terms of that of the base with [[coefficients]] in that of the [[fibers]])

  * [[Eilenberg-Moore spectral sequence]] (compute homology of [[homotopy fiber products]])

  * **[[spectral sequence of a double complex]]** (compute homology of [[total complex]] by filtering by row/column degree)

    * **[[Grothendieck spectral sequence]]** (compute [[composition]] of two [[derived functors in homological algebra|derived functors]])

      * [[base change spectral sequence]] (compute [[base change]]/[[extension of scalars]] in two stages)

      * [[Leray spectral sequence]] (compute [[global sections]] in two stages)

      * [[Hochschild-Serre spectral sequence]] (compute [[group cohomology]] in two stages)

Here is a more random list (using material from [Wikipedia](#Wikipedia)). Eventually to be merged with the above.

* [[Adams spectral sequence]] in [[stable homotopy theory]]

* [[Adams–Novikov spectral sequence]], converging to [[homotopy groups]] of [[connective spectra]]

*  [[chromatic spectral sequence]] for calculating the initial terms of the [[Adams–Novikov spectral sequence]]


* [[Atiyah–Hirzebruch spectral sequence]] of an [[extraordinary cohomology theory]];

* [[descent spectral sequence]]

* [[Bar spectral sequence]] for the [[homology]] of the [[classifying space]] of a [[group]]

* [[Barratt spectral sequence]] converging to the [[homotopy]] of the initial space of a [[cofibration]]

* [[Bloch–Lichtenbaum spectral sequence]] converging to the [[algebraic K-theory]] of a [[field]]
    
* [[Bockstein spectral sequence]] relating the [[homology]] with $mod p$ coefficients and the homology reduced $mod p$

* [[Bousfield–Kan spectral sequence]] converging to the [[homotopy colimit]] of a [[functor]]

* [[Cartan–Leray spectral sequence]] converging to the [[homology]] of a [[quotient space]]

* [[Cech-to-derived functor spectral sequence]] from [[Čech cohomology]] to [[abelian sheaf cohomology]]
 
* [[change of rings spectral sequences]] for calculating [[Tor]] and [[Ext]] groups of modules


* [[Connes spectral sequences]] converging to the [[cyclic homology]] of an algebra

* [[EHP spectral sequence]] converging to [[stable homotopy groups of spheres]]

* [[Eilenberg–Moore spectral sequence]] for the [[singular cohomology]] of the [[pullback]] of a [[fibration]]

* [[Federer spectral sequence]] converging to [[homotopy groups]] of a function space

* [[Frölicher spectral sequence]] starting from the [[Dolbeault cohomology]] and converging to the algebraic [[de Rham cohomology]] of a [[variety]]

* [[Green's spectral sequence]] for [[Koszul cohomology]]

* [[Grothendieck spectral sequence]] for composing [[derived functors]]

* [[Hodge–de Rham spectral sequence]] converging to the algebraic [[de Rham cohomology]] of a [[variety]]

* [[Hurewicz spectral sequence]] for calculating the [[homology]] of a space from its [[homotopy groups]]

* [[hyperhomology spectral sequence]] for calculating [[hyperhomology]]
 
* [[Künneth spectral sequence]] for calculating the homology of a [[tensor product]] of [[differential graded algebras]]

* [[Leray spectral sequence]] converging to [[abelian sheaf cohomology]]

* [[Leray–Serre spectral sequence]] of a [[fibration]]


* [[Lyndon–Hochschild–Serre spectral sequence]] in [[group cohomology]]

* [[May spectral sequence]] for calculating the [[Tor]] or [[Ext]] groups of an algebra

* [[Miller spectral sequence]] converging to the $mod p$ [[stable homology]] of a space

* [[Quillen spectral sequence]] for calculating the homotopy of a [[simplicial group]]
    
* [[spectral sequence of an exact couple]]

* [[van Est spectral sequence]] converging to relative [[Lie algebra cohomology]]

* [[van Kampen spectral sequence]] for calculating the homotopy of a wedge of spaces.

* [[slice spectral sequence]]

## Properties

### Basic lemmas

+-- {: .num_lemma}
###### Lemma
**(mapping lemma)**

If $f : (E_r^{p,q} \to (F_r^{p,q}))$ is a morphism of spectral sequences such that for some $r$ we have that $f_r : E_r^{p,q} \toF_r^{p,q}$ is an isomorphism, then also $f_s$ is an isomorphism for all $s \geq r$.

=--

+-- {: .num_lemma}
###### Lemma
**(classical convergence theorem)**

(...)

=--

This is recalled in ([Weibel, theorem 5.51](#Weibel)).

### First quadrant spectral sequence 
 {#FirstQuadrant}

+-- {: .num_defn}
###### Definition

A **first quadrant spectral sequence** is one for wich all pages are concentrated in the first quadrant of the $(p,q)$-plane, in that

$$
  ((p \lt 0) or (q \lt 0))
  \;\;
  \Rightarrow
  E_r^{p,q} = 0
  \,.
$$


=--

+-- {: .num_prop}
###### Proposition

If the $r$th page is concentrated in the first quadrant, then so the $(r+1)st$ page. So if the first one is, then all are.

=--


+-- {: .num_prop}
###### Proposition

Every first quadrant spectral sequence converges at $(p,q)$ from $r \gt max(p,q+1)$ on

$$
  E_{max(p,q+1)+1}^{p,q} = E_\infty^{p,q}
  \,.
$$


=--

+-- {: .num_prop}
###### Proposition


If a first quadrant spectral sequence converges

$$
  E_r^{p,q} \Rightarrow H^{p+q}
$$

then each $H^n$ has a filtration of length $n+1$

$$
  0 = F^{n+1}H^n \subset F^n H^n \subset \cdots \subset F^1 H^n \subset F^0 H^n = H^n
$$

and we have

* $F^n H^n \simeq E_\infty^{n,0}$

* $H^n/F^1 H^n \simeq E_\infty^{0,n}$.

=--


### Cup product structure
 {#PropertiesCupProductStructure}

Cohomological spectral sequences are compatible with [[cup product]] structure on the $E_2$-page. (e.g. [Hutchings 11, sections 5 and 6](#Hutchings11))



## Related concepts

* [[edge morphism]]

* [[multiplicative spectral sequence]]

## References

* [[Frank Adams]], part III section 7 of _[[Stable homotopy and generalised homology]]_, 1974

### Abelian/stable theory

An elementary pedagogical introduction is in 

* [[Timothy Chow]], _You could have invented spectral sequences_, Notices of the AMS (2006) ([pdf](http://www.ams.org/notices/200601/fea-chow.pdf))
 {#Chow}

Textbook accounts include

* [[John McCleary]], _A User's Guide to Spectral Sequences_, Cambridge University Press 

* {#Weibel} [[Charles Weibel]], chapter 5, _An introduction to homological algebra_ Cambridge studies in advanced mathematics 38 (1994)


* [[Raoul Bott]], [[Loring Tu]], section 14 of _Differential forms in algebraic topology_, Graduate Texts in Mathematics __82__, Springer 1982. xiv+331 pp.


* [[Hal Schenck]], _Chapter 9: Cohomology and spectral sequences_ ([pdf](http://www.math.uiuc.edu/~schenck/tapp.pdf)) .

* {#Hatcher} [[Alan Hatcher]], _Spectral sequences in algebraic topology_ ([web](http://www.math.cornell.edu/~hatcher/SSAT/SSATpage.html))
 
* {#Kochmann96} [[Stanley Kochmann]], _[[Bordism, Stable Homotopy and Adams Spectral Sequences]]_, AMS 1996


The general discussion in the context of [[stable (∞,1)-category]] theory (the [[spectral sequence of a filtered stable homotopy type]]) is in section 1.2.2 of 

* [[Jacob Lurie]], _[[Higher Algebra]]_


A review Master thesis is

* Jennifer Orlich, _Spectral sequences and an application_ ([pdf](http://www.math.osu.edu/~flicker.1/orlich.pdf))

Reviews of and lecture notes on standard definitions and facts about spectral sequences include 

* Matthew Greenberg, _Spectral sequences_ ([pdf](http://www.math.mcgill.ca/goren/SeminarOnCohomology/specseq.pdf))

* {#Hutchings11} [[Michael Hutchings]], _Introduction to spectral sequences_ ([pdf](http://math.berkeley.edu/~hutching/teach/215b-2011/ss.pdf))

* Daniel Murfet, _Spectral sequences_ ([pdf](http://therisingsea.org/notes/SpectralSequences.pdf))

* [[Neil Strickland]], _Spectral sequences_ ([pdf](http://neil-strickland.staff.shef.ac.uk/courses/bestiary/ss.pdf))

* Ravi Vakil, _Spectral Sequences: Friend or Foe?_ ([pdf](http://math.stanford.edu/~vakil/0708-216/216ss.pdf)) 

* Brandon Williams, _Spectral sequences_ ([pdf](http://www.math.sunysb.edu/~mbw/notes/orals/Spectral%20Sequences.pdf))

* {#Boardman99} [[Michael Boardman]], _Conditionally convergent spectral sequences_, 1999 ([pdf](http://www.uio.no/studier/emner/matnat/math/MAT9580/v12/undervisningsmateriale/boardman-conditionally-1999.pdf))

See also 

* Wikipedia, _[Spectral sequence](http://en.wikipedia.org/wiki/Spectral_sequence)_
 {#Wikipedia}

* A. Romero, J. Rubio, F. Sergeraert, _Computing spectral sequences_ ([pdf](http://www-fourier.ujf-grenoble.fr/~sergerar/Papers/Ana-JSC.pdf))

* Eric Peterson, _[Ext chart](http://ext-chart.org)_ software for computing spectral sequences

### Nonabelian / unstable theory {#ReferencesNonabelian}

Homotopy spectral sequences in model categories are discussed in 

* [[Aldridge Bousfield]], _Cosimplicial resolutions and homotopy spectral sequences in model categories_ ([arXiv:math/0312531](http://arxiv.org/abs/math/0312531)).

Spectral sequences in general categories with [[zero morphisms]] are discussed in 

* [[Marco Grandis]], _Homotopy spectral sequences_ ([arXiv:1007.0632](http://arxiv.org/abs/1007.0632))

Discussion from a perspective of [[homotopy type theory]] is in 

* {#Shulman13} [[Mike Shulman]], _[[homotopytypetheory:spectral sequences|Spectral sequences]]_ 2013 ([part I](https://golem.ph.utexas.edu/category/2013/08/what_is_a_spectral_sequence.html), [part II](http://homotopytypetheory.org/2013/08/08/spectral-sequences/))

### History

* [[John McCleary]], _A history of spectral sequences: Origins to 1953_, in _History of Topology_, edited by Ioan M. James, North Holland (1999) 631–663

[[!redirects spectral sequences]] 