
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Deduction and Induction
+-- {: .hide}
[[!include deduction and induction - contents]]
=--
#### Type theory
+-- {: .hide}
[[!include type theory - contents]]
=--
#### Induction
+-- {: .hide}
[[!include induction - contents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}

## Idea

_Inductive families_ generalize [[inductive types]]. Instead of defining a single type inductively, one simultaneously defines a whole family of types. An alternative term is "Indexed inductive definition".

A simple example of an inductive family is the type of vectors Vect n indexed by the dimension n. This is defined by two constructors: one for the empty vector of dimension 0, and another for the operation which constructs a vector of dimension n+1 by adding a component to a vector of dimension n. The family of finite types Fin n (indexed by n) can also be defined as an inductive family: the constructor 0 is in any Fin n, and there is a successor operation which constructs an element in Fin (n+1) from an element in Fin n.

By the identification of [[propositions as types]], inductive families correspond to inductively defined predicates. For example, the [[identity type]] on a type A can be defined inductively by the reflexivity rule stipulating that a is identical to a for any a : A, that is, identity is the least reflexive relation. The identity family of types in intuitionistic type theory resuls from the identification of this relation with a family of types.

## History
The inductively defined identity type was introduced by Martin-Löf 1973 in his first published paper on Intuitionistic Type Theory.

A general schema for inductive families in Intuitionistic Type Theory was defined in [Dybjer91](#Dybjer91), [Dybjer94](#Dybjer94). This general schema was based on Martin-Löf's 1971 schema for inductive definitions in predicate logic. Simultaneously, [Coquand](#CoquandPaulin) and [Paulin](#Paulin93) extended the Calculus of Constructions with a similar schema for inductive families. This resulted in the [[calculus of inductive constructions]].

[Dybjer](#Dybjer2000) and [Dybjer and Setzer](#DybjerSetzer2001) generalized this schema to inductive-recursive definitions, resulting in "indexed induction-recursion".

[Dybjer and Setzer](#DybjerSetzer) also distinguish two kinds of inductive (and inductive-recursive) families, restricted (due to Coquand) and general ones. The identity type is an example of the latter, but not of the former.

Inductive families are part of the axiomatic foundation in [[Coq]] and [[agda]]. Instead, [[Lean]] does not have fix-point expressions, match expressions, or a termination checker in the kernel. Instead, recursive definitions and pattern matching are compiled into eliminators outside of the kernel.

## Semantics
Standard inductive types, [[W-types]] can be interpreted in any topos with [[natural numbers object]] (Moerdijk-Palmgren). Gambino and Hyland construct initial algebras for dependent [[polynomial functors]]. [Indexed containers](#AGHMM) are the same as dependent polynomial functors.
[Indexed containers](#AGHMM) are claimed to form a foundation for inductive families.

## Higher categorical version/ homotopy type theory
[van den Berg and Moerdijk](#vdBergMoerdijk13) show that (standard) W-types can be interpreted in certain [[model categories]].
In [[homotopy type theory]] with [[universes]], one can reduce indexed W-types to W-types. This has been formalized [here](https://github.com/pcapriotti/agda-base/blob/master/src/container/w/core.agda), [here](https://github.com/SkySkimmer/HoTTClasses/blob/inductives/theories/theory/inductives.v) and [here](https://github.com/jashug/IWTypes).
[Sattler](#Sattler) outlines a generalization of the reduction to [[homotopy type theory]] without the need of universes.

## References {#References} 
* Per Martin-Löf, _Hauptsatz for the intuitionistic theory of iterated inductive definitions_, 1971, Studies in Logic and the Foundations of Mathematics - Elsevier
* Per Martin-Löf, _An Intuitionistic Theory of Types: Predicative Part_, 1975, in Logic Colloquium 1973.
* {#Dybjer91}Peter Dybjer, _Inductive Families_  Formal aspects of computing 6 (4), 440-465 [PS](http://www.cse.chalmers.se/~peterd/papers/Inductive_Families.ps)
* Peter Dybjer, _Inductive sets and families in Martin-Löf’s type theory and their set-theoretic semantics_, 1991 Logical frameworks 2, 6
* {#Dybjer2000}Peter Dybjer, _A general formulation of simultaneous inductive-recursive definitions in type theory_, 2000, The Journal of Symbolic Logic 65 (02), 525-549
*{#DybjerSetzer2001} Peter Dybjer, Anton Setzer, _Indexed induction-recursion_, 2001
Proof Theory in Computer Science, 93-113
* {#Paulin93}Christine Paulin-Mohring, _Inductive definitions in the system Coq rules and properties_, 1993 Typed lambda calculi and applications, 328-345.
* {#CoquandPaulin}Thierry Coquand, Christine Paulin, _Inductively defined types_, COLOG-88 Volume 417 of the series Lecture Notes in Computer Science pp 50-66 [Springer](http://link.springer.com/chapter/10.1007%2F3-540-52335-9_47)
[G books](https://books.google.dk/books?id=o_f4UwiZtL0C&pg=PA50)
* {#AGHMM}Thorsten Altenkirch, Neil Ghani, Peter Hancock, Conor McBride, and Peter Morris, _Indexed containers_ [PDF](http://strictlypositive.org/indexed-containers.pdf)
* {#DybjerSetzer} Peter Dybjer and Anton Setzer, _Indexed induction-recursion_, Journal of Logic and Algebraic Programming, volume 66, Issue 1, January 2006, Pages 1-49. [PDF](http://www.cse.chalmers.se/~peterd/papers/Indexed_IR.pdf)
* Nicola Gambino and Martin Hyland, Wellfounded Trees and Dependent Polynomial Functors. [PDF](http://www1.maths.leeds.ac.uk/~pmtng/Research/Papers/gambino-hyland.pdf)
* [[Benno van den Berg]], [[Ieke Moerdijk]], _W-types in Homotopy Type Theory_ ([arXiv:1307.2765](http://arxiv.org/abs/1307.2765)) {#vdBergMoerdijk13}
* {#Sattler} Christian Sattler, _slides_ [slides](http://cs.ioc.ee/types15/slides/sattler-slides.pdf)

[[!redirects inductive families]]
[[!redirects indexed inductive definition]]
[[!redirects indexed inductive type]]
[[!redirects indexed inductive types]]