### General

The concept of $L_\infty$-algebras as graded vector spaces equipped with $n$-ary brackets satisfying a generalized Jacobi identity was introduced in this generality in

* {#LadaStasheff92} [[Tom Lada]], [[Jim Stasheff]],  _Introduction to sh Lie algebras for physicists_, Int. J. Theo. Phys. 32 (1993), 1087--1103. ([arXiv:hep-th/9209099](http://arxiv.org/abs/hep-th/9209099))

* {#LadaMarkl94} [[Tom Lada]], [[Martin Markl]], _Strongly homotopy Lie algebras_ Communications in Algebra Volume 23, Issue 6, (1995) ([arXiv:hep-th/9406095](http://arxiv.org/abs/hep-th/9406095))

These authors were following [Zwiebach 92](#Zwiebach92), who had found in his work on [[closed string field theory]] that the [[n-point functions]] equip the [[BRST complex]] of the [[closed string|closed]] [[bosonic string]] with such a structure. Zwiebach in turn was following the [[BV-formalism]] due to [Batalin-Vilkovisky 83](#BatalinVilkovisky83), [Batakin-Fradkin 83](#BatakinFradkin83)

See also at _[L-infinity algebra -- History](L-infinity-algebra#History)_.

A discussion in terms of [[resolutions]] of the [[Lie operad]] is for instance in

* {#KrizMay} [[Igor Kriz]], [[Peter May]], _Operads, algebras, modules and motives_ ([pdf](http://www.math.uchicago.edu/~may/PAPERS/kmbooklatex.pdf))

A historical survey is

* {#Stasheff16} [[Jim Stasheff]], _Higher homotopy structures, then and now_, talk at _[Opening workshop](https://www.mpim-bonn.mpg.de/node/6356)_ of _[Higher Structures in Geometry and Physics](https://www.mpim-bonn.mpg.de/node/5883)_, MPI Bonn 2016 ([[StasheffHomotopyStructuresReview.pdf:file]])

See also 

* {#Daily04} Marilyn Daily, _$L_\infty$-structures_, PhD thesis, 2004 ([web]( http://www.lib.ncsu.edu/resolver/1840.16/5282))

* Klaus Bering, [[Tom Lada]], _Examples of Homotopy Lie Algebras_ Archivum Mathematicum ([arXiv:0903.5433](http://arxiv.org/abs/0903.5433))
 

A detailed reference for Lie 2-algebras is:

* [[John Baez]] and Alissa Crans, _Higher-dimensional algebra VI: Lie 2-algebras_, [TAC](http://www.tac.mta.ca/tac/volumes/12/14/12-14abs.html) 12, (2004), 492--528. ([arXiv](http://arxiv.org/abs/math/0307263))
 
 
### $L_\infty$-algebras in physics
 {#ReferencesInPhysics}

The following lists, mainly in chronological order of their discovery, [[L-∞ algebra]] structures appearing in [[physics]], notably in [[supergravity]], [[BV-BRST formalism]], [[deformation quantization]], [[string theory]], higher [[Chern-Simons theory]]/[[AKSZ sigma-models]] and [[local field theory]].

For more see also at _[[higher category theory and physics]]_.


#### In supergravity

In their equivalent [[formal dual]] guise of [[Chevalley-Eilenberg algebras]] (see [above](#ReformulationInTermsOfSemifreeDGAlgebra)), $L_\infty$-algebras of [[finite type]] -- in fact [[super L-∞ algebras]] -- appear in pivotal role in the [[D'Auria-Fré formulation of supergravity]] at least since 

* {#DAuriaFre}  [[Riccardo D'Auria]], [[Pietro Fré]] _[[GeometricSupergravity.pdf:file]]_, Nuclear Physics B201 (1982) 101-140 

In the [[supergravity]] literature these CE-algebras are referred to as "FDA"s. This is short for "free differential algebra", which is a slight misnomer for what in mathematics are called [[semifree dga]]s (or sometimes "quasi-free" dga-s).

The translation of [[D'Auria-Fré formulation of supergravity|D'Auria-Fré formalism]] to explicit ([[super L-∞ algebra|super]]) $L_\infty$-algebra language is made in 

* [[Hisham Sati]], [[Urs Schreiber]], [[Jim Stasheff]], example 5 in section 6.5.1, p. 54 of _L-infinity algebra connections and applications to String- and Chern-Simons n-transport_, in Quantum Field Theory, Birkhäuser (2009) 303-424 ([arXiv:0801.3480](http://arxiv.org/abs/0801.3480))

* [[Domenico Fiorenza]], [[Hisham Sati]], [[Urs Schreiber]], _[[schreiber:The brane bouquet|Super Lie n-algebra extensions, higher WZW models and super p-branes with tensor multiplet fields]]_, International Journal of Geometric Methods in Modern Physics Volume 12, Issue 02 (2015) 1550018 ([arXiv:1308.5264]
(http://arxiv.org/abs/1308.5264))

connecting them to the [[higher WZW terms]] of the [[Green-Schwarz sigma models]] of fundamental [[super p-branes]] ([[schreiber:The brane bouquet]]).

Further exposition of this includes

* [[Urs Schreiber]],  _[Homotopy Lie n-algebras in Supergravity](https://www.physicsforums.com/insights/homotopy-lie-n-algebras-supergravity/)_, PhysicsForums-Insights 2015

See also at _[[supergravity Lie 3-algebra]]_, and _[[supergravity Lie 6-algebra]]_.

Notice that there is a _different_ concept of "Filipov [[n-Lie algebra]]" suggested in ([Bagger-Lambert 06](BLG+model#BaggerLambert06)) to play a role in the description of the [[conformal field theory]] in the [[near horizon limit]] of [[black p-branes]], notably the [[BLG model]] for the conformal [[worldvolume]] theory on the [[M2-brane]] .

A realization of thse "Filippov $3$-Lie algebras" as 2-term $L_\infty$-algebras ([[Lie 2-algebras]]) equipped with a binary [[invariant polynomial]] ("metric Lie 2-algebras") is in 

* Sam Palmer, [[Christian Saemann]], section 2 of _M-brane Models from Non-Abelian Gerbes_, JHEP 1207:010, 2012 ([arXiv:1203.5757](http://arxiv.org/abs/1203.5757))

* {#SaemannRitter13} [[Patricia Ritter]], [[Christian Saemann]], section 2.5 of _Lie 2-algebra models_, JHEP 04 (2014) 066 ([arXiv:1308.4892](http://arxiv.org/abs/1308.4892))  

based on 

* {#MFFMER08} Paul de Medeiros, [[José Figueroa-O'Farrill]], [[Elena Méndez-Escobar]], [[Patricia Ritter]], _On the Lie-algebraic origin of metric 3-algebras_, Commun.Math.Phys.290:871-902,2009 ([arXiv:0809.1086](http://arxiv.org/abs/0809.1086))

See also 

* [[José Figueroa-O'Farrill]], section _Triple systems and Lie superalgebras_ in _M2-branes, ADE and Lie superalgebras_, talk at IPMU 2009 ([pdf](http://www.maths.ed.ac.uk/~jmf/CV/Seminars/Hongo.pdf))


#### In BV-BRST formalism
 {#ReferencesBVBRSTFormalism}

The introduction of [[BV-BRST complexes]] as a model for the [[derived critical locus]] of the [[action functionals]] of [[gauge theories]] is due to
 
* {#BatalinVilkovisky81} [[Igor Batalin]], [[Grigori Vilkovisky]],  _Gauge Algebra and Quantization_, Phys. Lett. B 102 (1981) 27–31. doi:10.1016/0370-2693(81)90205-7

* {#BatalinVilkovisky83} [[Igor Batalin]], [[Grigori Vilkovisky]], _Feynman rules for reducible gauge theories_, Phys. Lett. B 120 (1983) 166-170.
doi:10.1016/0370-2693(83)90645-7

* {#BatakinFradkin83} [[Igor Batalin]], [[Efim Fradkin]], _A generalized canonical formalism and quantization of reducible gauge theories_, Phys. Lett. B122 (1983) 157-164.

* {#BatalinVilkovisky83b} [[Igor Batalin]], [[Grigori Vilkovisky]],  _Quantization of Gauge Theories with Linearly Dependent Generators_, Phys. Rev. D 28 (10): 2567–258 (1983) doi:10.1103/PhysRevD.28.2567.  Erratum-ibid. 30 (1984) 508 doi:10.1103/PhysRevD.30.508

as reviewed in 

* {#HenneauxTeitelboim92} [[Marc Henneaux]], [[Claudio Teitelboim]], _[[Quantization of Gauge Systems]]_, Princeton University Press 1992. xxviii+520 pp.

* [[Joaquim Gomis]], J. Paris, S. Samuel, _Antibrackets, Antifields and Gauge Theory Quantization_ ([arXiv:hep-th/9412228](http://arxiv.org/abs/hep-th/9412228))

The understanding that these [[BV-BRST complexes]] mathematically are the [[formal dual]] [[Chevalley-Eilenberg algebra]] of a [[derived L-∞ algebroid]] originates around

* {#Stasheff96} [[Jim Stasheff]], _Homological Reduction of Constrained Poisson Algebras_, J. Differential Geom. Volume 45, Number 1 (1997), 221-240 ([arXiv:q-alg/9603021](http://arxiv.org/abs/q-alg/9603021), [Euclid](https://projecteuclid.org/euclid.jdg/1214459757))

* {#Stasheff97} [[Jim Stasheff]], _The (secret?) homological algebra of the Batalin-Vilkovisky approach_ ([arXiv:hep-th/9712157](http://arxiv.org/abs/hep-th/9712157))

Discussion in terms of homotopy [[Lie-Rinehart pairs]] is due to

* {#Kjeseth01} [[Lars Kjeseth]], _Homotopy Rinehart cohomology of homotopy Lie-Rinehart pairs_, Homology Homotopy Appl. Volume 3, Number 1 (2001), 139-163. ([Euclid](https://projecteuclid.org/euclid.hha/1140370269))

The [[L-∞ algebroid]]-structure is also made explicit in ([def. 4.1 of v1](http://arxiv.org/abs/0910.4001v1)) of ([Sati-Schreiber-Stasheff 09](#SatiSchreiberStasheff09)).

#### In string field theory

The first _explicit_ appearance of $L_\infty$-algebras in theoretical physics is the $L_\infty$-algebra structure on the [[BRST complex]] of the [[closed string|closed]] [[bosonic string]] found in the context of closed bosonic [[string field theory]] in 

* {#Zwiebach92} [[Barton Zwiebach]], _Closed string field theory: Quantum action and the B-V master equation_ , Nucl.Phys. B390 (1993) 33 ([arXiv:hep-th/9206084](http://arxiv.org/abs/hep-th/9206084))

* [[Jim Stasheff]], _Closed string field theory, strong homotopy Lie algebras and the operad actions of moduli space_ Talk given at the _Conference on Topics in Geometry and Physics_ (1992) ([arXiv:hep-th/9304061](http://arxiv.org/abs/hep-th/9304061))

Generalization to open-closed bosonic string field theory yields [[L-∞ algebra]] interacting with [[A-∞ algebra]]:

* [[Hiroshige Kajiura]], _Homotopy Algebra Morphism and Geometry of Classical String Field Theory_ (2001) ([arXiv:hep-th/0112228](http://arxiv.org/abs/hep-th/0112228))

* {#KajiuraStasheff04} [[Hiroshige Kajiura]], [[Jim Stasheff]], _Homotopy algebras inspired by classical open-closed string field theory_, Comm. Math. Phys. 263 (2006) 553–581 (2004) ([arXiv:math/0410291](http://arxiv.org/abs/math/0410291))

* {#Markl} [[Martin Markl]], _Loop Homotopy Algebras in Closed String Field Theory_ (1997) ([arXiv:hep-th/9711045](http://arxiv.org/abs/hep-th/9711045))

See also

* [[Jim Stasheff]], _Higher homotopy algebras: String field theory and Drinfeld's quasiHopf algebras_, proceedings of _International Conference on Differential Geometric Methods in Theoretical Physics_, 1991 ([spire](https://inspirehep.net/record/327712))
 
For more see at _[string field theory -- References -- Relation to A-infinity and L-infinity algebras](string%20field%20theory#ReferencesHomotopyAlgebra)_.

#### In deformation quantization

The general solution of the [[deformation quantization]] problem of [[Poisson manifolds]] due to 

* {#Kontsevich97} [[Maxim Kontsevich]], _Deformation quantization of Poisson manifolds_,  Lett. Math. Phys. __66__ (2003),  no. 3, 157--216, ([arXiv:q-alg/9709040](http://arxiv.org/abs/q-alg/9709040)).
 
makes crucial use of [[L-∞ algebra]]. Later it was understood that indeed [[L-∞ algebras]] are equivalently the universal model for infinitesimal [[deformation theory]] (of anything), also called [[formal moduli problems]]:

* {#Hinich98} [[Vladimir Hinich]], _DG coalgebras as formal stacks_ ([arXiv:9812034](http://arxiv.org/abs/math/9812034))

* {#Lurie} [[Jacob Lurie]], _[[Formal Moduli Problems]]_

* {#Pridham} [[Jonathan Pridham]], _Unifying derived deformation theories_, Adv. Math. 224 (2010), no.3, 772-826 ([arXiv:0705.0344](http://arxiv.org/abs/0705.0344))
 

#### In heterotic string theory

Next it was again $L_\infty$-algebras of [[finite type]] that drew attention. It was eventually understood that the [[string structures]] which embody a refinement of the [[Green-Schwarz anomaly cancellation]] mechanism in [[heterotic string theory]] have a further smooth refinement as [[G-structures]] for the [[string 2-group]], which is the [[Lie integration]] of a [[Lie 2-algebra]] called the _[[string Lie 2-algebra]]_. This is due to

* {#BCSS} [[John Baez]], [[Alissa Crans]], [[Urs Schreiber]], [[Danny Stevenson]], _From loop groups to 2-groups_, _Homotopy, Homology and Applications_ **9** (2007), 101-135.  ([arXiv:math.QA/0504123](http://arxiv.org/abs/math.QA/0504123)) 

* {#Henriques} [[André Henriques]], _Integrating $L_\infty$ algebras_, Compos. Math. __144__  (2008), no. 4, 1017--1045 ([doi](http://dx.doi.org/10.1112/S0010437X07003405),[math.AT/0603563](http://arxiv.org/abs/math.AT/0603563))

and the relation to the Green-Schwarz mechanism is made explicit in 

* {#SatiSchreiberStasheff09} [[Hisham Sati]], [[Urs Schreiber]], [[Jim Stasheff]], _[[schreiber:Twisted Differential String and Fivebrane Structures]]_, Communications in Mathematical Physics, 2012, Volume 315, Issue 1, pp 169-213  ([arXiv:0910.4001](http://arxiv.org/abs/0910.4001))

This article also observes that an analogous situation appears in [[dual heterotic string theory]] with the _[[fivebrane Lie 6-algebra]]_ in place of the string Lie 2-algebra.

#### Higher Chern-Simons field theory and AKSZ sigma-models

Ordinary [[Chern-Simons theory]] for a simple gauge group is all controled by a [[Lie algebra cohomology|Lie algebra 3-cocycle]]. The generalization of Chern-Simons theory to [[AKSZ-sigma models]] was understood to be encoded by [[symplectic Lie n-algebroids]] (later re-popularized as "[[shifted symplectic structures]]") in 

* [[Dmitry Roytenberg]], _Courant algebroids, derived brackets and even symplectic supermanifolds_ PhD thesis ([arXiv:9910078](http://arxiv.org/abs/math/9910078))

* [[Pavol Ševera]], _[[Some title containing the words "homotopy" and "symplectic", e.g. this one]]_, based on a talk at "Poisson 2000", CIRM Marseille, June 2000; ([arXiv:0105080](http://arxiv.org/abs/math/0105080))


* [[Dmitry Roytenberg]], _On the structure of graded symplectic supermanifolds and Courant algebroids_ in _Quantization, Poisson Brackets and Beyond_ , [[Theodore Voronov]] (ed.), Contemp. Math., Vol. 315, Amer. Math. Soc., Providence, RI, 2002 ([arXiv](http://arxiv.org/abs/math/0203110))

* {#Roytenberg} [[Dmitry Roytenberg]], _AKSZ-BV Formalism and Courant Algebroid-induced Topological Field Theories_ Lett.Math.Phys.79:143-159,2007 ([arXiv:hep-th/0608150](http://arxiv.org/abs/hep-th/0608150)).

The globally defined AKSZ action functionals obtained this way were shown in 

* [[Domenico Fiorenza]], [[Chris Rogers]], [[Urs Schreiber]], _[[schreiber:AKSZ Sigma-Models in Higher Chern-Weil Theory]]_, Int. J. Geom. Methods Mod. Phys. 10 (2013) 1250078 ([arXiv:1108.4378](http://arxiv.org/abs/1108.4378))

to be a special case of the higher Lie integration process of 

* [[Domenico Fiorenza]], [[Urs Schreiber]], [[Jim Stasheff]], _[[schreiber:Cech cocycles for differential characteristic classes]]_, Advances in Theoretical and Mathematical Physics, Volume 16 Issue 1 (2012), pages 149-250 ([arXiv:1011.4735](http://arxiv.org/abs/1011.4735))

Further exmaples of non-symplectic $L_\infty$-Chern-Simons theory obtained this way include [[7-dimensional Chern-Simons theory]] on [[differential string structure|string 2-connections]]:
 
* [[Domenico Fiorenza]], [[Hisham Sati]], [[Urs Schreiber]], _[[schreiber:7d Chern-Simons theory and the 5-brane|Multiple M5-branes, String 2-connections, and 7d nonabelian Chern-Simons theory]]_, Advances in Theoretical and Mathematical Physics, Volume 18, Number 2 (2014) p. 229–321
 
#### In local prequantum field theory

Infinite-dimensional $L_\infty$-algebras that behaved similar to [[Poisson bracket]] [[Lie algebras]] -- _[[Poisson bracket Lie n-algebras]]_ -- were noticed

* {#Rogers10} [[Chris Rogers]], _$L_\infty$ algebras from multisymplectic geometry_ ,  Letters in Mathematical Physics April 2012, Volume 100, Issue 1, pp 29-50  ([arXiv:1005.2230](http://arxiv.org/abs/1005.2230), [journal](http://link.springer.com/article/10.1007%2Fs11005-011-0493-x)).

* {#Rogers11} [[Chris Rogers]], _Higher symplectic geometry_ PhD thesis (2011) ([arXiv:1106.4068](http://arxiv.org/abs/1106.4068))

In 

* [[Domenico Fiorenza]], [[Chris Rogers]], [[Urs Schreiber]], _[[schreiber:L-∞ algebras of local observables from higher prequantum bundles ]]_, Homology, Homotopy and Applications, Volume 16 (2014) Number 2, p. 107 – 142 ([arXiv:1304.6292](http://arxiv.org/abs/1304.6292))

these were shown to be the infinitesimal version of the symmetries of [[prequantum n-bundles]] as they appear in [[local prequantum field theory]], in higher generalization of how the [[Poisson bracket]] is the Lie algebra of the [[quantomorphism group]].

These also encode a homotopy refinement of the [[Dickey bracket]] on [[Noether theorem|Noether]] [[conserved currents]] which for [[Green-Schwarz sigma models]] reduces to Lie $n$-algebras of [[BPS charges]] which refine [[super Lie algebras]] such as the   [[M-theory super Lie algebra]]:

* [[Hisham Sati]], [[Urs Schreiber]], _[[schreiber:Lie n-algebras of BPS charges]]_ ([arXiv:1507.08692](http://arxiv.org/abs/1507.08692))

* [[Igor Khavkine]], [[Urs Schreiber]], _[[schreiber:Lie n-algebras of higher Noether currents ]]_

This makes concrete the suggestion that there should be $L_\infty$-algebra refinements of the [[Dickey bracket]] of [[conserved currents]] in [[local field theory]] that was made in 

* [[Glenn Barnich]], [[Ronald Fulp]], [[Tom Lada]], [[Jim Stasheff]], _The sh Lie structure of Poisson brackets in field theory_ ([arXiv:hep-th/9702176](http://arxiv.org/abs/hep-th/9702176))

Comprehesive survey and exposition of this situation is in 

* [[Urs Schreiber]], _[[schreiber:Higher Prequantum Geometry]]_, in [[Gabriel Catren]], [[Mathieu Anel]] (eds.), _[New Spaces for Mathematics and Physics](https://ncatlab.org/nlab/show/New+Spaces+for+Mathematics+and+Physics)_, 2016

#### In double field theory

In [[double field theory]]:

* [[Andreas Deser]], [[Jim Stasheff]], _Even symplectic supermanifolds and double field theory_, Communications in Mathematical Physics November 2015, Volume 339, Issue 3, pp 1003-1020 ([arXiv:1406.3601](http://arxiv.org/abs/1406.3601))

* [[Olaf Hohm]], [[Barton Zwiebach]], _$L_\infty$ Algebras and Field Theory_ ([arXiv:1701.08824](https://arxiv.org/abs/1701.08824))

### Related expositions

* [[fiber bundles in physics]]

* [[higher category theory and physics]]

* [[string theory FAQ]]

* [[motives in physics]]

* [[Hilbert's sixth problem]]

* [[model theory and physics]]

* [[motivation for sheaves, cohomology and higher stacks]]

* [[applications of (higher) category theory]]

* [[motivation for higher differential geometry]]

* [[motivation for cohesion]]




