# Contents 
* table of contents 
{:toc} 

## Idea 

A *shelf* is a set with a binary operation that distributes over itself. Shelves are similar to [[racks]] (and there are forgetful functors from racks to shelves), but shelves are axiomatically simpler. 

## Definitions 

A **left shelf** is a set with a binary operation $\triangleright$ obeying the left self-distributive law

$$ a \triangleright (b \triangleright c) = (a \triangleright b)\triangleright (a \triangleright  c)   .$$

Similarly a set with a binary operation $\triangleleft$ obeying the right self-distributive law is called a **right shelf**.

A unital left shelf (meaning a left shelf together with an element that acts as an [[identity element|identity]] on both the left and the right) is the same as a graphic monoid: for a proof see [[graphic category]]. 

## Examples 

Of course all the usual examples of [[racks]] and [[quandles]] are *a fortiori* shelves. But there are notable examples not of this type. 

### Infinite braid group 

Let $B_n$ be the $n^{th}$ [[braid group]]. With the usual inclusion $B_n \to B_{n+1}$ by appending a strand to the end of a braid on $n$ strands, the colimit of the chain $B_0 \to B_1 \to B_2 \to \ldots$ is the *infinite braid group* $B_\infty$. Let $sh: B_\infty \to B_\infty$ be the homomorphism that sends $\sigma_i$ to $\sigma_{i+1}$. Then there is a left distributive operation on $B_\infty$ where 

$$a \triangleright b \coloneqq a sh(b) \sigma_1 sh(a)^{-1}.$$ 

One may verify the left distributivity by a [[string diagram]] calculation (which appears on page 29 of this [Google book](https://books.google.com/books?id=XfsHCAAAQBAJ&pg=PA27&lpg=PA27&dq=braid+exponentiation&source=bl&ots=4ncxE2f7oT&sig=Mn-YDL97W9NWE0baexJEWrD4J4k&hl=en&sa=X&ved=0ahUKEwiB4saR3frKAhXBSiYKHbWaBEoQ6AEIHTAA#v=onepage&q=braid%20exponentiation&f=false), [Dehornoy3](#Deh3)). 

### In set theory 

Shelves make an appearance in set theory via [[large cardinal]] axioms. Let $(V, \in)$ be a model of [[ZFC]], and let $V_\lambda \subseteq V$ be the collection of elements of rank less than an [[ordinal]] $\lambda$ of $V$. One (rather strong) large cardinal axiom on (limit ordinals) $\lambda$ is: 

> There exists an [[elementary embedding]] $j: V_\lambda \to V_\lambda$ on the [[structure]] $(V_\lambda, \in)$ that is not the identity. 

Then, for $A \subseteq V_\lambda$, put 

$$j(A) \coloneqq \bigcup_{\alpha \lt \lambda} j(A \cap V_\alpha).$$ 

If we regard $A$ as an unary relation on $V_\lambda$, then $j$ induces an elementary embedding $(V_\lambda, \in, A) \to (V_\lambda, \in, j(A))$. In particular, if $k$ is any elementary embedding $(V_\lambda, \in) \to (V_\lambda, \in)$, which as a set of ordered pairs we may regard as a subset of $V_\lambda$, then $j(k)$ as a set of ordered pairs is also an elementary self-embedding of $(V_\lambda, \in)$. We get in this way a binary operation $(j, k) \mapsto j(k)$ on elementary embeddings, which we denote as $(j, k) \mapsto j \cdot k$, and it is not difficult to verify that $\cdot$ is left self-distributive. 

Let $F_1$ denote the [[free object|free]] left shelf generated by 1 element. If $E_\lambda$ denotes the collection of elementary embeddings on the structure $(V_\lambda, \in)$, then the preceding observations imply that $E_\lambda$ is a left shelf, so any $j \in E_\lambda$ induces a shelf homomorphism 

$$\phi_j: F_1 \to E_\lambda.$$ 

+-- {: .num_theorem} 
###### Theorem 
**(Laver)** 
If $j \in E_\lambda$ is not the identity, then $\phi_j$ is injective. 
=-- 

The famous *Laver tables* (derived from set-theoretic considerations which we omit for now) describe certain [[finite set|finite]] quotients of $F_1$. Letting $x$ denote the generator of $F_1$, define $x_n$ by $x_1 = x$ and $x_{n+1} = x_n \cdot x$. The quotient of $F_1$ by the single relation $x_{m+1} = x$ is a shelf of cardinality $2^k$, the largest power of $2$ dividing $m$; it is denoted $A_k$. It can be described alternatively as the unique left shelf on the set $\{1, 2, \ldots, 2^k\}$ such that $p \cdot 1 = p + 1 \mod 2^k$ (here $p$ represents the image of $x_p$ under the quotient $F_1 \to A_k$). 

The "multiplication table" of an $A_k$ is called a Laver table. The behavior of Laver tables is largely not understood, but we mention a few facts. The first row consisting of entries $1 \cdot p$ is periodic (of some order dividing $2^k$). Under the large cardinal assumption that a nontrivial elementary self-embedding on a $V_\lambda$ exists, this period $f(k)$ tends to $\infty$ as $k$ does, but whether it does as a consequence of ZFC is not known. What *is* known is that this period, even if it increases to $\infty$, does so quite slowly: if we define $g(m)$ to be the smallest $k$ such that $f(k) \geq m$, then $g$ grows more quickly than say the Ackermann function. 

## Action of positive braid monoid 

Let $B_n^+$ be the [[monoid]] of positive [[braid group|braids]], which as a monoid is presented by generators $\sigma_1, \ldots, \sigma_{n-1}$ subject to the braid relations 

$$\sigma_i \sigma_{i+1} \sigma_i = \sigma_{i+1} \sigma_i \sigma_{i+1}, \qquad \sigma_i \sigma_j = \sigma_j \sigma_i\; if \; {|i-j|} \gt 1.$$ 

+-- {: .num_prop} 
###### Proposition 
If $(X, \triangleright)$ is a shelf, then there is a monoid homomorphism $B_n^+ \to \hom(X^n, X^n)$ whose transform to an action $B_n^+ \times X^n \to X^n$ is described by the equations 

$$\sigma_i(x_1, \ldots, x_i, x_{i+1}, \ldots, x_n) = (x_1, \ldots, x_i \triangleright x_{i+1}, x_i \ldots, x_n);$$ 

conversely, if $\triangleright$ is any binary operation, then these equations describe an action of $B_n^+$ only if $\triangleright$ is left distributive. 
=-- 


## Related concepts 

* [[rack]] 

## References 

These are some general references:

* [[Alissa Crans]], _Lie 2-Algebras_, Chapter 3.1: Shelves, Racks, Spindles and Quandles, Ph.D. thesis, U.C. Riverside, 2004.  ([pdf](https://arxiv.org/abs/math/0409602)).

* [[Patrick Dehornoy]], _Braids and Self-Distributivity_, Progress in Mathematics 192, Birkh&auml;user Verlag, 2000. 

These develop the connection between the free shelf on one generator and elementary embeddings in set theory:

* Richard Laver, The left distributive law and the freeness of an algebra of elementary embeddings, <i>Adv. Math.</i> <b>91</b> (1992), 209&ndash;231.

* Richard Laver, <a href="http://arxiv.org/abs/math/9204204">On the algebra of elementary embeddings of a rank into itself</a>, <i>Adv. Math.</i> <b>110</b> (1995), 334&ndash;346.

* Randall Dougherty and Thomas Jech, <a href = "http://arxiv.org/abs/math/9209202">Finite left distributive algebras and embedding algebras</a>, <i>Adv. Math.</i> <b>130</b> (1997), 201&ndash;241.

* Randall Dougherty, <a href="http://arxiv.org/abs/math/9205202">Critical points in an algebra of elementary embeddings</a>, <i>Ann. Pure Appl. Logic</i> <b>65</b> (1993), 211&ndash;241.

* Randall Dougherty, <a href = "http://arxiv.org/abs/math/9503204">Critical points in an algebra of elementary embeddings, II</>.

For a popularized account of this material, see:

* John Baez, [Shelves and the infinite](https://johncarlosbaez.wordpress.com/2016/05/06/shelves-and-the-infinite/).

[[!redirects shelves]]
[[!redirects left shelf]]
[[!redirects left shelves]]
[[!redirects right shelf]]
[[!redirects right shelves]]
[[!redirects Laver table]] 
[[!redirects Laver tables]] 

