
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}

### Context
#### Philosophy
+-- {: .hide}
[[!include philosophy - contents]]
=--
#### Foundations
+-- {: .hide}
[[!include foundations - contents]]
=--
=--
=--

# Contents
* table of contents
{:toc}

## Idea

> Walfisch ist keine Tür.[^ref]

[^ref]: _The whale is no door_. Hegel ([1808/09](#Logik),p.108)

An **infinite judgement**, also called a limitative or indeterminate judgement, is a type of [[judgment|judgement]] in traditional logic that differs from a positive judgement by containing a negation operator and from a negative judgement by negating only the predicate term.

Infinite judgements enjoy a rather controversial status in traditional logic but have gained importance by being elevated to third position among the qualities of judgement in the table of judgement forms in Kant's _Kritik der reinen Vernunft_ (1781). 

## Preliminaries

Before diving into the various proposals concerning infinite judgement let us chart the territory roughly to get an idea what's at stake. A 'typical' example of an infinite judgement would be _'anima est non mortalis'_ which could be rendered as _'the soul is immortal'_ or _'the soul is not-mortal'_ , so in a first approximation we have to do with expressions containing negative or negated predicate terms and immediately the questions arises how one should treat lexicalized forms like _'immortal'_ vs. rule-produced forms like _'not-mortal'_ and in a wider sense how much grammar a logic concerned with infinite judgements should take into account here.

Next arises the question how _'anima est non mortalis'_ is related to the _negative judgement_ _'anima non est mortalis'_ as well as to the affirmative _'anima est mortalis'_. Intuitively, an infinite judgement ressembles the first by containing a negation and the latter by having a copula that is not modified by a negation, so in a sense an infinite judgement is both negative and positive at the same time.

Proceeding to get a first grip on the semantics of these judgement types let us consider two arbitrary terms A and B: The intended interpretation of an affirmative _A is B_ can be symbolically rendered as $A\cap B=A$, and $A\cap B=\emptyset$ and $A\cap\bar{B}=A$ for negative and infinite judgements, respectively. Obviously, these symbols invite a set-theoretic interpretation and picturing as Venn diagrams. In particular, the situation of the infinite judgement can be visualized by a textured plane containing an oval denoting $A$ and a disjoint oval carved out of the texture denoting $B$ - this situation ressembles the negative judgement in that $A$ and $B$ are disjoint but whereas the containment relation in the case of positive judgements is one between ovals in the infinite judgement the oval $A$ is contained in the infinite unbounded punctured plane!

The set-theoretic interpretation also suggests that negative and infinite judgements are indeed semantically the same! This equivalence underlies the wide-spread dismissal of infinite judgement in traditional or modern logic. Note that one could still accept the extensional equivalence of _A is not B_ and _A is not-B_ but attaching an intensional or procedural sense to the different judgements. Another option is of course to reject the set-theoretic equivalence and attach different interpretations to the negations and complementations involved. 

Note that the set-theoretic picture suggests a first idea on the difference between _'immortal'_ and _'not-mortal'_ in that one could assume that the former is tacitly type-restricted to _animated_ things so that the extension of _'immortal'_ is not the whole plane with mortal things cut out but merely the sphere of animated things with mortal things cut out! This in turn then raises the question whether the infinite judgement _'The soul is not-mortal'_ should be pictured like this as well since the soul is tacitly equipped with a type of animated things to which _'not-mortal'_ could be coerced as a bounded predicate, in other words one could challenge the idea that 'The soul is not-mortal' is an infinite judgement at all!

To sum up: the situation leaves open a lot of options and the way to choose among these might ultimately rely on the things one wants to accomplish with the resulting notion of 'infinite judgement'.

## Kant on infinite judgements

Due to the influence of Kant's philosophy in the 19th century, one could easily get the impression that the concept of an _infinite judgement_ originated with Kant, however the concept had already a long history in traditional logic going back to the example of _non-man_ as an _indeterminate noun_ in chap. X of Aristotle's _Peri Hermenaias_. Within this larger context the most relevant author for Kant was probably J. H. Lambert who gave the _termini infiniti_, how he called them, extensive discussion in his _'Neues Organon'_ (1764) and _'Anlage zur Architectonic'_ (1771).

For Kant, the concept becomes important for the table of judgements in _'Kritik der reinen Vernunft'_ (1781) in the transcendental analytics (B 95ff, A 70ff). He gives there a primarily syntactic definition differentiating them from negative judgements by the position of the negation particle _non_ with respect to the copula: _anima non est mortalis_ vs. (inifinite:) _anima est non mortalis_. He further distinguishes the latter from _anima est immortalis_  , though this is only implicit in the passage by his avoidance of the German 'ist unsterblich' and his use of 'ist nichtsterblich' instead which due to German word order fusions with the negative 'ist nicht sterblich'. The _Vienna logic_ (see below) is slightly more outspoken on the triple distinction which in fact is often ignored by later commentators like e.g. H. Cohen (or, more recently, O. Höffe or M. Wolff) who even recommends the less marked 'unsterblich' instead of 'nichtsterblich' (Cohen [1907](#Cohen07), p.48; Höffe [2003](#Hoeffe03) p.126; cf. Jesiolkiewicz [n.d.](#Jesiol) p.2).

Now, what does the distinction between 'unsterblich' and 'nichtsterblich' amount to ? We would like to suggest to the difference between _determination_ and _limitation_: both are formally positive in the sense that they behave like positive judgements in syllogism but only 'unsterblich' narrows the 'sphere' of its subject of predication whereas 'nichtsterblich' only limits the sphere in putting the subject in an infinite and effectively indeterminate sphere _'welches eigentlich gar keine Sphäre ist'_ (Jäsche-Logik §22).

Why would it be important for transcendental logic to make a difference between infinite and positive judgements ? Presumably, due to the role of infinite judgements in metaphysical 'reasoning' where the formally positive judgements create the dialectical illusion of positive determinations of thought objects (KdrV I.1 §23 B148; see also [Höffe 2003](#Hoeffe03), p.126) whereas thought actually meanders in an infinite space without ever being able to give an object in intuition corresponding to the negatively determined concept of reasoning e.g. the determination of the soul in rational psychology as not-mortal, not-material, not-spatial etc.

The so called _Vienna logic_ contains a lengthy passage on infinite judgements:

>Alle bejahende Sätze zeigen ihre Bejahung durch die copula _est_ , welche copula das Verhältniß zweyer Begriffe anzeigt. Wenn die
copula _est_ simpliciter besteht, bedeutet sie die Verknüpfung zweyer
— wenn die copula _est_ mit dem _non_ afficirt ist: so bedeutet sie Opposition der beyden Begriffe, und zeigt an, daß der eine Begriff nicht zum andern gehört, oder nicht in der sphaera des andern enthalten sey. Z. B. _anima non est mortalis_ , hier stelle ich mir vor, daß die Sterblichkeit die Seele nicht mit in sich schließt. Sage ich aber : _anima est non mortalis_ : so sage ich nicht bloß, daß die Seele nichts sterbliches enthalte, sondern daß sie auch in der sphaera alles deßen, was nicht sterblich ist, enthalten sey. Es ist also hierbey etwas besonders gesagt, daß ich einen Begriff nähmlich nicht bloß von der sphaera eines andern Begriffes ausschließe, sondern auch den Begriff unter der ganzen übrigen sphaera denke, die nicht unter dem Begriffe, der ausgeschlossen ist, gehört. Ich sage eigentlich nicht : _est immortalis_ , sondern ich sage : unter allen Begriffen überhaupt, die außerhalb dem Begriff der Sterblichkeit gedacht werden mögen, kann die Seele gezählt werden. Und dieses macht eigentlich die unendlichen Urtheile aus. — 

>Bejahung und Verneinung sind demnach qualitaeten im Urtheil. Ein verneinendes Urtheil ist nicht ein jedes Urtheil, das negativ ist, sondern ein solches verneinendes Urtheil, wo die negation die copula afficirt. Ein
solches Urtheil aber, wo sie nicht die copula afficirt, sondern das praedicat, wie bey einem unendlichen Urtheil geschieht, und die copula also ohne alle negation ist, ist demnach ein bejahendes Urtheil, folglich sind alle unendliche Urtheile bejahend, weil die negation nur das praedicat afficirt. Obgleich aber jedes unendliche Urtheil die Natur des Bejahenden hat: so ist doch immer eine Verneinung da, zwar nicht des Urtheiles, d. i. des Verhältnißes der Begriffe, sondern des praedicats.

>Das Verhältniß ist zwar daßelbe, wie bey einem bejahenden Urtheil, aber die negation ist doch immer da, und folglich sind sie vom bejahenden unterschieden. Diese Sache scheint in der Logic eine subtilitaet zu seyn. Aber in der Metaphysic wird es von Wichtigkeit, sie hier nicht übergangen zu haben. Denn da ist der Unterschied zwischen realitaet, negation und limitation größer. Bey den limitationen denk ich etwas positives, aber nicht bloß, sondern auch negatives, und es ist etwas eingeschränkt positives.- Sie heissen _judicia infinita_ , weil sie unbegränzt sind. Sie sagen nur immer, was nicht ist, und solcher praedicate kann ich unzählige machen, denn die sphaera der praedicate, die mit _non_ afficirt vom subjecte können gesagt werden, ist unendlich.

>Das Princip von allen möglichen praedicatis contrarie oppositis muß aus der Sache kommen. Dieses ist das princip der durchgängigen Bestimmung. Diese durchgängige Bestimmung eines Dinges aber ist unmöglich, weil eine unendliche Erkenntniß dazu gehöret, alle die praedicate aufzusuchen, die einem Dinge zukommen, und ich kann daher ins Unendliche fortgehen, und doch das Ding nicht durchgängig bestimmen. Z. B. die Seele ist körperlich, nicht körperlich. Die Seele ist sterblich, nicht sterblich. Im logischen Gebrauche können sie hier vor bejahende gelten. Denn jedes Ding ist durch Bestimmung von andern unterschieden. Alle andere Dinge mit non afficirt können davon gesagt werden. Z. B. das Merkmahl des Steines ist die Härte. Nun kann ich immer fortgehen bis ins Unendliche, und sagen: ein Stein ist nicht Metall, nicht Holz etc. Sag ich dadurch aber etwas Neues ? Denn was hilft es, daß ich weiß, daß alles Übrige ausser dem Begriff nicht Stein ist ? Die sphaera dieses alles Übrigen ist unendlich, und deshalb nennt man diese judicia infinita.

Kant ([1966](#KantXXIV2),pp.930-31).

Interestingly in contrast with _KdrV_ or the _Vienna-logic_, the later _Jäsche-Logik_ from 1800 seems to pair infinite judgments with negative judgments:

>Nach dem Principium der Ausschließung jedes Dritten (exclusi tertii) ist die Sphäre eines Begriffs relativ auf eine andre entweder ausschließend oder einschließend. - Da nun die Logik bloß mit der Form des Urteils, nicht mit den Begriffen ihrem Inhalte nach, es zu tun hat: so ist die Unterscheidung der unendlichen von den negativen Urteilen nicht zu dieser Wissenschaft gehörig.

Kant ([1800](#Jaesche), p.535).

One suggestion to clarify the tricky question of infinite judgement in Kant employing the language of modern logic would be to link it to the [[coherent logic|Morleyization]] of finitary first-order formulas:

This is a systematic way to replace formulas containing negation with formulas without negation by defining via extra symbols and axioms negative versions of all predicates e.g. for predicate $P(x)$, add $\bar{P} (x)$ together with stipulations that $P(x)\wedge \bar{P}(x)=\bot$ and $P(x)\vee \bar{P}(x)=\top$. One can then show that a first-order theory $\mathbb{T}$ and its Morleyization $\mathbb{T}'$ have exactly the same models over coherent [[Boolean category|Boolean categories]] (cf. [Johnstone 2002](#JT02), p.859).

This would capture the syntactic systematicity of turning negative judgements into formally positive infinite judgements as well as the semantic equivalence over classical formal logic i.e. the difference between a formula $\varphi (x)$ and its Morleyization $\varphi '(x)$ only comes to the surface when one considers non-Boolean models - the difference between positive and infinite judgements is relevant for transcendental (=intuitionistic) logic only.

## Fichte's take

In Fichte's _Wissenschaftslehre_ (1794) infinite judgements appear in a key passage on his dialectic in I.§3. He transforms Kant's triad of positive, negative and infinite judgments into _synthetic_ , _antithetic_ and _thetic_ judgement and says that the first two require each a 'double ground' - a _relational_ and a _differential_ ground: the relational ground giving the field where subject and predicate notion (can) concide whereas the differential ground gives the field where they (can) differ.[^def] The synthetic judgement then reflects on the first but abstracts from the second, whereas the antithetic judgement abstracts from the first and reflects on the second. 

[^def]: In the background here lurks the classical theory of definition by _genus proximum_ and _differentia specifica_.

>Ein thetisches Urteil würde ein solches sein, in welchem etwas keinem andern gleich- und keinem andern entgegengesetzt, sondern bloss sich selbst gleich gesetzt würde: es könnte mithin gar keinen Beziehungs- oder Unterscheidungsgrund voraussetzen: sondern das Dritte, das es der logischen Form nach doch voraussetzen muß, wäre bloß eine Aufgabe für einen Grund. Das ursprüngliche höchste Urteil dieser Art ist das: Ich bin, in welchem vom Ich gar nichts ausgesagt wird, sondern die Stelle des Prädikats für die mögliche Bestimmung des Ich ins Unendliche leer gelassen wird. ... Kant und seine Nachfolger haben daher diese Urteile sehr richtig unendliche genannt, obgleich keiner, soviel mir bewusst ist, sie auf eine deutliche und bestimmte Art erklärt hat.

Fichte, _Grundlage der gesamten Wissenschaftslehre_ , ([1794](#FichteI),pp.310-12).

This passage was rather consequential. First, Fichte frees the concept from its narrow relation to predicate term negation and considers purely positive judgements like 'I am' and 'A is beautiful' as infinite. Secondly, he elevates the infinite judgements to 'logico-ethical' tasks of determination of propositional grounds. Thirdly, he draws them near to identity statements.

For Schelling the connection to aethetic judgement as well as the interpretation of the 'I am' as infinite will become of capital importance. In Hegel's _Logik_ the connection to positive and identity statements
will return. But before we come to the latter let's have a look at what Fichte said on infinite judgements twenty years later.

In his 1812 lectures on transcendental logic, Fichte has apparently changed his views dramatically. Infinite judgements have now their own section in lecture 28 ([Werke VI](#FichteVI), pp.392-94). Contrary to the text of 1794 where he followed Kant in considering them as _logically positive_ , he now stresses that in syllogisms they behave like negative judgements, claims that the former position is actually unintelligible and criticizes Kant for following Leibniz who in this case 'didn't know what he was talking about'.

## Hegel's take

For Hegel infinite judgements become relevant in the third book of his _Wissenschaft der Logik_ (1816) on the subjective logic subsuming the '_logic formerly so called_'. His views present a synthesis of Kant and Fichte's contribution.

In the transcendental analytics of _KdrV_ , Kant had started from the table of judgement forms where he assigned infinite judgements to the third place in the second column of 'qualities of judgement' (B95, A70) and then went on to 'derive' the table of categories from it where now the category of _'limit'_ takes the place of infinite judgements in the third row of the second column (B107, A81). He goes on (B110-111):

>Über diese Tafel der Kategorien lassen sich artige Betrachtungen anstellen, die vielleicht erhebliche Folgen in Ansehung der wissenschaftlichen Form aller Vernunfterkenntniss haben könnten ...2te Anmerk. daß allerwärts eine gleiche Zahl der Kategorien jeder Klasse, nämlich drei sind, welches eben sowohl zum nachdenken auffodert, da sonst alle Einteilung a priori durch Begriffe Dichotomie sein muß. dazu kommt aber noch, daß die dritte Kategorie allenthalben aus der Verbindung der zweiten mit der ersten Klasse entspringt ...die Einschränkung (ist) nichts anders als Realität mit Negation verbunden.

One of the 'considerable consequences' of these 'well behaved' considerations would be the systematic logic (1812-16) of Hegel who turns Kant _'from the head on his feet'_ : in [[Science of Logic|WdL]] (1812-16) the categories in the first book on being precede now the judgement forms in the third book. Infinite judgements get the role, in analogy to the synthesis of 'reality' and 'negation' in the category of 'limit', to synthesize positive and negative judgements and to lead over from qualitative to reflective judgements by [[Aufhebung|sublation]].

Hegel overlays the (reversed) Kantian parallelism between qualitative 'being' and qualitative judgement with a theory of judgement as _division_ which in the case of quality takes the form of a successive predication S-P where the subject in analogy to the 'punctuality' of qualitative being is taken as the individual I of which is sucessively predicated the general G, the particular P, and, finally the individual $I$: I-G (the individual is the general), I-P (the individual is not the general) and I-I (the individual is the individual). The last tautology according to him sublates itself since it contradicts the division necessary for judgement (cf. Werckmeister [2009](#Werck09), pp.11f).

Apparently Hegel is in trouble at this point since the succession of predication around the subject I requires the tautology I-I as last step, on the other, the synthesis of positive and negative judgement suggests infinite judgements as last step and, finally, for the logic to move on he has to find a contradiction in both judgement forms!

Here Fichte's suggestions come to rescue who had already proposed a link between 'identity' statements and infinite judgements as well as identified purely positive aesthetic judgements as infinite (presumably not without input from Kant's _'Kritik der Urteilskraft'_). Hegel pushed by the necessity to find contradictory judgement forms goes a step further: for one he admits tautologies _tout court_ as infinite and, secondly, for the traditional infinite judgements he begins to stress their abolishment of the common sphere, e.g. the whale not-being-a-door, bringing the propositions on the verge of  absurdity. That is, in fact, he seems to work at the same time with Kants syntactic notion with, additionally, the nebulosity of the semantic sphere emphasized and a more intuitive notion of 'infinite judgement' influenced by Fichte where a judgement 'Peter is Peter' 'predicates' an infinity of predicates of Peter, unfortunately, without telling us what they are besides that Peter has them.

It goes without saying that all this, and especially the counting in of the tautologies which is mainly owed to the succession pattern of I-G, I-P, I-I, is a radical step that poses serious questions concerning its viability and was severely critized by [[J.M. Ellis McTaggart|J. M. Ellis McTaggart]] ([1910](#McT10), pp.202-205).

### A deontic aside

True to his conviction of the identity between thought and object Hegel uses in his writings on logic the _sphere of right_ to illustrate infinite judgements in action with crimes as actions that negate law totally e.g. theft vs. a repossession law suit where the latter corresponds to normal negation denying a specific property right within the framework of law. Interestingly, these examples return in his **philosophy of right** to bring out the logical structure of right as well (e.g. in Hegel [1983](#Law), p.84; also cf. Mohr [2014](#Mohr97)).

This analogy between actions and judgements of quality takes the following form in the philosophy of right: the lawful action is one where the individual will (I) is determined by the general will G, i.e. the law, resulting in the positive judgement I-G, whereas the lawsuit refutes or negates such a 'judgement' $\neg$ I-G, here both opponents accept the law (serving as the relational ground in the sense of Fichte) but (one of) the individual wills falls short of full generality resulting in I-P.

Finally, the infinite judgements correspond to (1.) _fraud_ i.e. the _positive_ infinite judgement I-I where the indiviual will I in predicate position takes on the appearance of generality, and (2.) to _crime_ using force i.e. the _negative_ infinite judgement where the individual will posits itself entirely outside the sphere of the general will: I-$\neg$G. These action and judgement forms are self defeating in that they are in conflict with the basic tenets of actions or judgements, namely, that they are determinations of the subjects.

These still to be fleshed out suggestions of Hegel are interesting for two reasons:

For one, they stress the importance of the social sphere as a background to read the science of logic against in the sense that the systematic logic takes its specific form because that form permits to display (social) reality as rational thereby illuminating the many oddities of the logic as well as proposing a motivation for the shift of the young Hegel from interest in the good society to systematic philosophy. 

On the other hand, they point to the possibility to decode a possible formalisation of Hegel's subjective logic along the [[Aufhebung|lines suggested by Lawvere]] for the objective logic as a new and very rich kind of _deontic logic_.

## More recent positions

B. Bolzano pointed out the imprecisions and contradictions of Kant's account of the qualities of judgment forms in his _Wissenschaftslehre_ ([1837](#BolzWLII)).

R. H. Lotze ([1874](#Lotze74)) in his influential logic assesses infinite judgements negatively calling them an 'obvious nonsense' - _offensichtliche Grillen_ and 'absurd'. He maintains that in actual reasoning they are always replaced by negative judgements.

G. Patzig ([1982](#Patzig82), pp.42f) calls them superfluous from the perspective of modern logic since depending on the definition of 'negation' they can either be subsumed under positive or negative judgements. He suggests that Kant was probably motivated by his triadic scheme since his revision of the traditional table of judgements and categories consisted mainly in the addition of third terms.[^uberweg]

[^uberweg]: Already like this: _'Zu der Dreitheilung hat sich Kant durch die Vorliebe für die schematische Regelmässigkeit seiner Kategorientafel verleiten lassen'_ , F. Ueberweg, _System der Logik_ , Marcus Bonn 1857 (p.154). This unfortunately misses the point that the particular triadic form of the table is indeed crucial for Kant since the completeness of his logic hinges on it and that Kant offers a derivation of the terms.

M. Wolff ([1995](#Wolff95), pp.157-58,290-92), extending a suggestion by C. S. Peirce (1903) who had tentatively hypothesized that Kant follows traditional logic in that existential presuppositions for the subject terms depend on the quality of judgement (positive judgements have existential import whereas negative judgements lack them), views the difference between negative and infinite judgement in the lack of existential import in the former. This squares with a remark by Kant that infinite judgements behave like positive judgements in syllogism and another remark that negative judgement serve only to 'prevent error' without extending knowledge. On the other hand, Kant clearly invokes purely formal thought objects to which the law of excluded middle applies as the context for infinite judgements complying with the property that infinite judgements appear in the context of 'general logic' which applies to possible objects i.e. a context to which the extension of the concepts involved are not yet relevant - note that _anima_ in his example does not correspond to an object that could possibly be given in intuition whence existence can not be predicated of it and that the avatar of infinite judgements in the table of categories _limit_ ranges among the class of 'mathematical' categories that concern objects of intuition but _not_ their existence (§11, B110, [KdrV](#Kdrv1), p.121). In particular, it would seem that for coherence Kant would either have to stick to a surface syntactic definition or propose an intensional conceptual characterization invoking relations between conceptual features along the lines that e.g. an affirmative judgement is one where the features of the predicate concept are contained in the features of the subject concept.

## The finite verdict

It should have become clear by now that the concept of infinite judgement can count itself as a _terminus infinitus_ given the universal disagreements and vague boundaries of its definition. Let us see if we can sort things out a bit here:

1. The passage from the Vienna logic backs the idea that infinite judgements were intended by Kant to play a role exclusively in the transcendental dialectic i.e. to uncover negative (metaphysical) judgements in positive (sheep's) clothing (cf. Höffe [2003](#Hoeffe03)).

2. On the one hand, Kant distinguishes 'non-mortalis' from 'immortalis', on the other hand, it seems that the passages were infinite reasoning occurs it is rejected actually in the 'immortalis'-form raising the puzzle whether the distinction does any work transcendentally after all. This gives some plausibility to the claim that, not unlike Hegel, Kant was rather driven by triadic patterning than by logical demand (cf. Patzig [1982](#Patzig82), pp.42).

3. Another peculiarity are the examples that Kant uses: a prototypical infinite judgement should be _'sella est non mortalis'_ (the chair is not-mortal) because this indeed brings out the contrast between _'non-mortalis'_ and _'immortalis'_ i.e. it is doubtful that _'anima est non mortalis'_ is actually an infinite judgement at all since it seems to be synonymuous with _'anima est immortalis'_.

4. Kant's syntactic definition also creates problems when one considers predicates like _'non-combatant'_ (Lotze) or _'non-conducting'_ since they are syntactically infinite but fail to produce the indeterminate infinite semantic sphere tacitly supposed by Kant. In particular for the latter, one sees that progress in electrodynamics turned this into a perfectly determinate predicate which then only applies to subjects equipped with an appropriate electron structure.

5. It is also not clear how Kant can prevent the truly infinite cases like _'sella est non mortalis'_ from coinciding (=being logically equivalent) with ordinary negative sentences (cf. Lotze [1874](#Lotze74)). This points to a further ambiguity in Kant, namely that although he works with semantic extension as a metaphor the real difference he targets seems to be rather _procedural_ i.e. the expression do not really differ in extension but in the way the extension is computed (cf. above the remark on Morleyization).

We would like to suggest now that by taking over ideas from Hegel the problems inherent in Kant (dis)appear under a new light. For one, infinite judgements should not be defined surface syntactically, moreover we should allow syntactically positive statements and insist on the disjointness of the spheres i.e. neither should _'anima est immortalis'_ count as infinite nor _'anima est non-mortalis'_. We exclude the latter because it is extensively equivalent to the former and reject the former because its negation _'anima non est immortalis'_ is equivalent to _'anima est mortalis'_ which is a perfectly normal positive proposition. However, the negation of _'sella est non mortalis'_ is the _absurd_ '_sella est mortalis'_ whereas _'sella est immortalis'_ as well as its negation is absurd since they violate the sphere restriction to animated things inherent in _'immortalis'_ or _'mortalis'_.

So we arrive at the hypothesis that _a judgement is infinite precisely when its negation is absurd_. This immediately admits trivial identity statements like 'the morning star is the morning star' as infinite while non-trivial statements like 'the morning star is the evening star' are ordinary positive judgements. With some generosity one might even waive Fichte's _'I am'_ as infinite since one might conceive of _'I am not'_ as absurd. Of course, this leaves open the questions (1.) of how to formalize such a logic of absurdity (for some related problems cf. Zeilberger [2008](#Zeilberger08)) and then (2.) how to fit the dialectics of judgements into such a putative formalisation i.e. the precise sense in which the infinite judgement becomes the unity of positive and negative judgements i..e. how to account for the triadic patterning that is crucial for the systematic completeness of both Kant's and Hegel's logic.

To sum up: it seems that the most promising direction to spell out a concept of infinite judgement in the context of foundations of logic is to use a structural definition as the synthesis of positive and negative judgements i.e. to take the claims of logical systematicity serious, and try to flesh this out materially within a logic of absurdity, absurdity understood here as _immediate_ falsity.

## Related entries

* [[transcendental ideal]]

* [[co-Heyting negation]]

* [[absolute conclusion]]

* [[construction in philosophy]]

* [[Attempt to Introduce the Concept of Negative Quantities into Philosophy|Concept of Negative Quantities]]

* [[Aufhebung]]

* [[Science of Logic]]

* [[syllogism]]

* [[judgment|judgement]]

## Link

* SEP _Kant's Theory of Judgment_ ([link](http://plato.stanford.edu/entries/kant-judgment/))

## References

* {#AL11} A. Achourioti, M. Van Lambalgen, _A Formalisation of Kant's Transcendental Logic_ , Review of Symbolic Logic **4** no.2 (2011) pp.254-289.

* {#BolzWLII}[[Bernard Bolzano|B. Bolzano]], _Wissenschaftslehre II_ , von Seidel Sulzbach 1837. (§ 189 pp.266ff, [link](http://dml.cz/dmlcz/400486))

* {#Cohen07} [[Hermann Cohen|H. Cohen]], _Kommentar zu Immanuel Kants Kritik der reinen Vernunft_ , Dürr Leipzig 1907.

* {#McT10} [[J.M. Ellis McTaggart|J. M. Ellis McTaggart]], _A Commentary on Hegel's Logic_ , Russell&Russell New York 1964[1910].

* {#Law} [[Georg Hegel|G. W. F. Hegel]], _Philosophie des Rechts - Die Vorlesung von 1819/20 in einer Nachschrift_ ,  Suhrkamp Frankfurt a. M. 1983.

* {#Logik} [[Georg Hegel|G. W. F. Hegel]], _Logik für die Mittelklasse (1808/09)_ , pp.86-110 in Moldenhauer, Michel (eds.), _Werke 4_ , Suhrkamp Frankfurt a. M. 1986.

* [[Georg Hegel|G. W. F. Hegel]], _Phänomenologie des Geistes_ , Suhrkamp Frankfurt a. M. 1986[1807]. (pp.260-62)

* [[Georg Hegel|G. W. F. Hegel]], _Wissenschaft der Logik II_ , Suhrkamp Frankfurt a. M. 1986[1816]. (pp.324ff)

* [[Georg Hegel|G. W. F. Hegel]], _Enzyklopädie der philosophischen Wissenschaften I_ , Suhrkamp Frankfurt a. M. 1986[1830]. (§173, pp.324ff)

* {#Hoeffe03} O. Höffe, _Kants Kritik der reinen Vernunft_ , Beck München 2003. (pp.126-27,148)

* F. Ishikawa, _Kants Denken von einem Dritten: Das Gerichtshof-Modell und das unendliche Urteil in der Antinomienlehre_ , Lang Frankfurt a. M. 1990.

* {#Jaesche} G. B. Jäsche (ed.), _Immanuel Kants Logik ein Handbuch zu Vorlesungen_ , pp.419-582 in Kant, _Schriften zur Metaphysik und Logik 2_ , Suhrkamp Frankfurt a. M. 1985[1800].

* {#Jesiol} J. Jesiolkiewicz, _Das unendliche Urteil "Seele ist nichtsterblich" bei Kant_ , ms. University of Munich not dated. ([pdf](http://www.philosophie.uni-muenchen.de/lehreinheiten/philosophie_1/betreuung/promotionen/jakub_jesiolkiewicz/skizze.pdf))

* K. Joël, _Das logische Recht der kantischen Tafel der Urteile_ , Kant- Studien **27** no.1/2 (1922) pp.298-327. ([philpapers](http://philpapers.org/rec/JOLDLR))

* {#JT02} [[Peter Johnstone|P. T. Johnstone]], _Sketches of an Elephant II_ , Oxford UP 2002. (D1.5.13-14, pp.858ff)

* {#KdrV1} I. Kant, _Kritik der reinen Vernunft 1_ , Suhrkamp Frankfurt a. M. 1985[1781, rev. 1787].

* {#KantXXIV2} I. Kant, _Akademie Ausgabe XXIV 2: Vorlesungen über Logik_ , de Gruyter Berlin 1966.

* {#RRZ94} M. La Palme Reyes, J. Macnamara, [[Gonzalo E. Reyes|G. E. Reyes]], H. Zolfaghari, _The non-Boolean logic of natural language negation_ , Phil. Math. **2** no.1 (1994) pp.45-68.

* M. La Palme Reyes, J. Macnamara, [[Gonzalo E. Reyes|G. E. Reyes]], H. Zolfaghari, _Models for non-Boolean negation in natural languages based on aspect analysis_ , pp.241-260 in Gabbay, Wansing (eds.), _What is Negation?_, Kluwer Dordrecht 1999. 

* {#Lotze74} R. H. Lotze, _Logica - Logik_ , bilingual ed. Bompiani Milano 2010[1874]. (§40, pp.214-16)

* A. Maier, _Kants Qualitätskategorien_ , Metzner Berlin 1930.

* {#FichteI} F. Medicus (ed.), _J. G. Fichte - Ausgewählte Werke in sechs Bänden I_ , Lambert Schneider Darmstadt 2013[1911].

* {#FichteVI} F. Medicus (ed.), _J. G. Fichte - Ausgewählte Werke in sechs Bänden VI_ , Lambert Schneider Darmstadt 2013[1911].

* A. Menne, _Das unendliche Urteil Kants_ , Philosophia Naturalis **19** (1982) pp.151-162. ([digizeit](http://www.digizeitschriften.de/dms/img/?PID=PPN510319696_0019%7Clog14))

* {#Mohr97}G. Mohr, _Unrecht und Strafe (§§ 82-1004)_ , pp.95-124 in Siep (ed.), _Klassiker Auslegen - G. W. F. Hegel: Grundlinien der Philosophie des Rechts_ , Akademie Verlag Berlin ³2014.

* {#Patzig82} G. Patzig, _Immanuel Kant: Wie sind synthetische Urteile apriori möglich?_ , pp.9-70 in Specht (ed.), Grundprobleme der großen Philosophen: Philosophie der Neuzeit II, Vandenhoeck Göttingen 1982. (pp.41-43)

* N. Stang, _Kant on Complete Determination and Infinite Judgement_ , Brit. J. Hist. Phil. **20** no. 6 (2012) pp.1117-1139.

* N. Tennant, _Negation, Absurdity, and Contrariety_ , pp.199-222 in Gabbay, Wansing (eds.), What is Negation?, Kluwer Dordrecht 1999. ([draft](http://u.osu.edu/tennant.9/files/2014/07/nac-2gav3mo.pdf))

* H. Wansing, _Negation_ , pp.415-436 in Goble (ed.), _The Blackwell Guide to Philosophical Logic_ , Blackwell Oxford 2001.

* {#Werck09} G. Werckmeister, _Hegels absoluter Schluss als logische Grundstruktur der Objektivität_ , PhD TU Kaiserslautern 2009. ([link](https://kluedo.ub.uni-kl.de/frontdoor/index/index/docId/2160))

* G. Wohlfahrt, _Das unendliche Urteil. Zur Interpretation eines Kapitels aus Hegels 'Wissenschaft der Logik'_ , Z. Phil. Forschung **39** no.1 (1985) pp.85-100. ([digizeit](http://www.digizeitschriften.de/dms/img/?PID=PPN511864582_0039%7Clog12))

* {#Wolff95}M. Wolff, _Die Vollständigkeit der kantischen Urteilstafel_ , Klostermann Frankfurt a. M. 1995.

* {#Zeilberger08}[[Noam Zeilberger|N. Zeilberger]], _On the unity of duality_ , APAL **153** (2008) pp.66-96.

[[!redirects infinite judgements]]
[[!redirects infinite judgment]]
[[!redirects infinite judgments]]