
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}

### Context
#### Philosophy
+-- {: .hide}
[[!include philosophy - contents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}


## Idea

**Kinship** is the collection of relations, rules and behaviors concerning alliance and fictive or real consanguinity that occur in the social organisation of the biological reproduction of individuals. Kinship relations play a significant role for individuals as well as for society as a whole.

In particular in pre-industrial societies, systems of marriage and kinship are often cast into rigid and intricate patterns that are a preferred playground for applications of mathematics to anthropology ever since [[André Weil]] contributed an algebraic appendix to [[Claude Lévi-Strauss|Claude Lévi-Strauss']] groundbreaking [_Les structures &#233;l&#233;mentaires de la parent&#233;_](#LS67).

## Permutation models

It is generally assumed that all societies explicitly impose some restrictions on the types of possible marriages. The resulting kinship systems then differ whether these restrictions take on the form of prohibitions like e.g. in modern societies that merely ban certain marriages due to considerations of consanguinity or age, or the form of prescriptions that specify positively to marry into a determinate 'marriage class' or category of kins.

The latter prescriptive systems have been called _elementary structures_ by L&#233;vi-Strauss and further divided into systems of _restricted exchange_ where two groups $A,B$ directly exchange spouses, or systems of _generalized exchange_ with longer cycles of exchange e.g. group $A$ gives spouses to $B$ that gives spouses to $C$ that gives spouses to $A$.

Since marriages become deterministic on the classes, elementary kinship systems are amenable to analysis via permutations on the set of marriage classes. This group-theoretic modeling of elementary structures has been pioneered by [[André Weil]] ([1949](#Weil49)). Here is L&#233;vi-Strauss on Weil's contribution:

> Historiquement parlant, ces pages ont une grande importance. Toute la math&#233;matique de la parent&#233; qui s'est beaucoup d&#233;velopp&#233;e depuis en est sortie. Et cela continue.[^LS]

[^LS]: Quoted from C. L&#233;vi-Strauss, D. Eribon, _De pr&#232;s et de loin_ , Odile Jacob Paris (1990, p.78). See also the quotation at [[Claude Lévi-Strauss]] concerning his encounters with Hadamard and Weil during the preparation of his thesis in New York during WW2.

Weil's ideas have later been systematized by Philippe Courr&#232;ge and others.

+-- {: .num_defn #kinship}
###### Definition 

An _(elementary) kinship system_ is a triple $(S,\omega,\mu)$ where $S$ is a finite set, and $\omega,\mu$ are permutations of $S$.

A _morphism of kinship systems_ $(S_1,\omega_1,\mu_1)\to (S_2,\omega_2,\mu_2)$ is a function $f:S_1\to S_2$ that is equivariant with respect to $\omega$ and $\mu$ i.e. $f\circ\omega_1 =\omega_2\circ f$ and $f\circ\mu_1 =\mu_2\circ f$.

The resulting [[category]] $\mathcal{K}$ is called the _category of kinship (systems)_.
=--

+-- {: .num_remark}
###### Remark
The axiomatics was proposed in [Courr&#232;ge (1965)](#Cour65) with the intended interpretation that $S$ represents the _set of (disjoint) marriage classes_, that the _conjugal_ function $\omega$ links the men in class $x$ to the class $\omega (x)$ that contains their wifes ('_men in $x$ marry women in $\omega (x)$_') and that the _matrilineal_ function $\mu$ links the mothers in class $x$ to the class $\mu (x)$ that contains their children ('_women in $x$ have children in $\mu(x)$_').

One can then define a _patrilineal_ function[^termin] $\pi:$$=\mu\circ\omega$ that links the fathers in $x$ to their children in $\mu(\omega (x))$ ('_men in $x$ have children in $\mu(\omega (x))$_').

Since a kinship structure $(S,\omega,\mu)$ contains an element $\omega$ of '_alliance_' and an element $\mu$ of '_descent_' one could view the axiomatics as a reconciliation of the Anglo-Saxon tradition in kinship studies that stressed descent and L&#233;vi-Strauss' views that stressed alliance. But this 'reconciliation' is more one of appearances as one could equally well use $\pi$ and $\mu$ as undefined terms and define $\omega =\mu^{-1}\circ \pi$.

[^termin]: $\mu$ and $\pi$ are called the _maternal_ resp. _paternal_ function in Courr&#232;ge (1965).
=--

+-- {: .num_defn #kinship}
###### Definition 
Given a system of kinship $(S,\omega,\mu)$, the subgroup $G$ of $Aut(S)$ generated by $\omega$ and $\mu$ is called the _group of kinship terms_ of $(S,\omega,\mu)$. The system $(S,\omega,\mu)$ is called _irreducible_ (resp. _regular_) when the natural action of $G$ on $S$ is _transitive_ (resp. _free_) i.e. :

* For all $x,y\in S$ there is a $g\in G$ such that $gx=y$.

* (resp. For all $g\in G$: if $g\neq 1$ then $gx\neq x$ for all $x\in S$.)
=--


To equip a [[set]] $S$ with a kinship structure amounts to give a function $f:\{1,2\}\to |Aut(S)|$ that picks out $f(1)=\omega$ and $f(2)=\mu$ from the set |Aut(S)| of [[automorphism|automorphisms]] of $S$. 
By the adjunction $F\dashv |\cdot|$ between the free-group functor $F:Set\to Grp$ and the underlying-set functor $|\cdot|: Grp\to Set$ this is the same as giving a group homorphism $\alpha: F(\{1,2\})\to Aut(S)$ from the [[free group]] on $\{1,2\}$, denoted $F_2$ in the following, to the group $Aut(S)$ of automorphisms of $S$, but this, in turn, is the same as giving an [[action]] of $F_2$ on the set $S$!

The group $G$ of kinship terms is none other than $im(\alpha)\subseteq Aut(S)$.

As this goes through regardless of whether $S$ is finite or not and makes sense with respect to the morphisms in $\mathcal{K}$ we have

+-- {: .num_prop}
###### Proposition

The category $\mathcal{K}$ of kinship systems is equivalent to the [[topos]] of finite $F_2$-sets where $F_2$ is the [[free group]] on two generators. $\qed$
=--

Hence, the category $\mathcal{K}$ has a rich mathematical structure and naturally admits not only finite products $S\times T$ that play an important role already in [Courr&#232;ge (1965)](#Cour65) but also more 'exotic' operations like [[exponential|exponentials]] $T^S$ and, in particular, power systems $\Omega^S$.

Here $\Omega$ is the truth-value object or [[subobject classifier]] which, in the case of a topos of group actions for a group $\tilde{G}$, is the set $\{\emptyset , \tilde{G}\}\cong\{0,1\}$ with trivial action $0\cdot \tilde{g}=0$ and
$1\cdot \tilde{g}=1$ for all $\tilde{g}\in \tilde{G}$. Whence in $\mathcal{K}$ the truth-value object $\Omega =(\{0,1\}, id, id)$ is a system with two classes with trivial structure. In fact, $\Omega = \mathbf{1}\times \mathbf{1}$ where $\mathbf{1}=(\{1\},id,id)$ is the [[terminal object]] of $\mathcal{K}$.

An $F_2$-[[torsor]] is a [[flat functor]] $T:F_2\to Set$ which by definition amounts to a functor $T$ such that the [[category of elements]] $\int _{F_2} T$ is [[filtered category|filtered]]. 

(...)

### Some terminology and properties

A system $\mathbf{S}=(S,\omega,\mu)\in \mathcal{K}$ is called _exogamic_ when $\omega\neq id$, and _endogamic_ otherwise. This simply says that spouses always stem from the same marriage class (resp. from different classes).

$\mathbf{S}$ is called _matrilineal_ (resp. _patrilineal_) when $\mu = id$ (resp. $\pi = id$). This says that the child is in the same class as the mother (resp. as the father).

$\mathbf{S}$ is called a _system of restricted exchange_ if $\omega^2=id$, a system of _generalized exchange_ otherwise.

A particular important category of kin are _cousins_ e.g. in many Western societies they are the closest type of kins eligible for marriage whereas in Arabian societies patrilateral parallel cousin marriage is often the preferred type of marriage.

This can be viewed as a consequence of the property that the cousin category is at the intersection of important poles of kinship relations as affinity and non-affinity, symmetry and asymmetry (in the case of cross-cousins e.g. the father'sister's daughter from male perspective and the mother's brother's son in reverse direction). This warrants

+-- {: .num_defn #cousin}
###### Definition 
A system $\mathbf{S}=(S,\omega,\mu)\in \mathcal{K}$ is said to _admit marriage with the (female) matrilateral cross-cousin_ if

* $\omega\mu = \mu\omega$  (MCC)

$\mathbf{S}$ is said to _admit marriage with the (female) patrilateral cross-cousin_ if

* $\omega\mu = \mu\omega^{-1}$  (PCC)
=--

A direct calculation yields

+-- {: .num_prop}
###### Proposition
Let $\mathbf{S}=(S,\omega,\mu)\in \mathcal{K}$ satisfy MCC. $\mathbf{S}$ satifies PCC iff $\mathbf{S}$ is of restricted exchange. $\qed$
=--

Since $\omega$ and $\mu$ generate the group $G$ of kinship terms the following is immediate

+-- {: .num_prop #commutative}
###### Proposition
A system $\mathbf{S}=(S,\omega,\mu)\in \mathcal{K}$ satisfies MCC iff the group $G$ of kinship terms of $\mathbf{S}$ is commutative. $\qed$
=--

In fact, the fullsubcategory $\mathcal{M}\subset \mathcal{K}$ of kinships systems satisfying MCC is equivalent to the topos of $\mathbb{Z}\times\mathbb{Z}$-actions, where $\mathbb{Z}\times\mathbb{Z}$ is the free [[Abelian group]] on two generators because actions of $F_2$ such that $G$ is commutative correspond precisely to actions of $\mathbb{Z}\times\mathbb{Z}$.

A more general way to view this, is to consider the surjective homomorphism $\alpha:F_2\to \mathbb{Z}\times\mathbb{Z}$ viewed as a functor that sends the generators $1,2$ to the generators $(1,0),(0,1)$, respectively. By general results (cf. [MM94, p.359](#MM94); [RRZ04, p.226](#RRZ04)), this induces an [[essential geometric morphism]]

$$

\alpha_!\dashv \alpha^*\dashv\alpha_*:Set^{F_2{^{op}}}\to Set^{(\mathbb{Z}\times\mathbb{Z})^{op}}

$$

(...)

## Topos-theoretic perspectives

In our exposition above we have already taken advantage of the categorical point of view advanced in Lawvere and Schanuel ([1997](#LawSchan97), [1999](#Law99)) by adapting it to the classical algebraic approach to kinship. In this section we summarize their ideas in the original setting.

Lawvere and Tierney proposed to study the concept of kinship starting from the notion of a (filiation structured) **society** modeled mathematically as a set $X$ (of _individuals_) together with two endofunctions $m,f$ that assign to an individual $x\in X$ his mother $m(x)\in X$ resp. his father $f(x)\in X$.

If one organizes these sets with filiation structure into a category the result is a [[topos]] namely the topos $Set^{M_2^{op}}$ of right actions of the free [[monoid]] $M_2$ on two symbols $\{m,f\}$.

Since the parental endofunctions $m,f$ are completely unconstrained[^Cour], the resulting 'kinship relations' are equally unconstrained, e.g. nothing prevents an individual's mother from coinciding with the same individual's father etc. It therefore becomes advantageous to equip the 'societies' with further structure. Lawvere and Schanuel propose to achieve this by introducing appropriate labeling objects $L$ and passage to the [[slice topos]] $Set^{M_2^{op}}/L$.

[^Cour]: so unconstrained indeed, that it might be better to think of the societies as being composed of 'sections' or 'marriage classes', or more generally of equivalence classes of _classificatory kinship_, instead of individuals and to think of $m,f$ as the assignment of the marriage classes  $m(x),f(x)$ of the respective parents of the individuals in the class $x$ in the spirit of [Courr&#232;ge (1965)](#Cour65). This has the drawback that it admits (hardly plausible) societies composed of infinitely many classes, whereas societies composed of (countably) infinitely-many individuals can be conceived of as an ideal self-image of a sucessful society projecting itself to eternity.

A minimal model of a society that at least keeps the **gender** of the parents apart is the set $G=\{female, male\}$ consisting of a 'female' and a distinct 'male' individual[^group] together with parental functions $m,f$ complying with the usual gender rules e.g. $m(female)=female$, $f(female)=male$ etc. Then a consistent gender distinction on the parental structure of an arbitrary society corresponds to a structure preserving map to $G$ i.e. an object of the slice topos $Set^{M_2^{op}}/G$.

[^group]: Again it makes more sense to consider $G$ to consist of two gender groups instead of two individuals.

Similarly, **exogamy** can be modeled by a _clans object_ $C$ e.g. consisting of two clans $C=\{bear, wolf\}$ obeying matrilinearity in the sense that the mother-of function $m$ is constant but the father-of function $f$ switches the clans expressing thereby that the father of an individual comes from another clan than the individual and his mother.[^Fox]

By labeling with the product $G\times C$ one can achieve gender distinction and exogamy at the same time:

$$
G\times C \quad=\qquad\array{
he-wolf &\overset{f}{\underset{f}{\leftrightarrows}}& he-bear\\
_{m}\downarrow&_{f}{\nearrow}  {\nwarrow}{_{f}}& \downarrow{_{m}}\\
\underset{\overset{\circlearrowleft}{m}}{she-wolf}& &\underset{\overset{\circlearrowleft}{m}}{she-bear}
}\quad 
$$

[^Fox]: The Fox tribe in Lawvere's home state Iowa indeed consists of two moieties called 'Bear' and 'Wolf' but they are patrilineal ([Liu 1986](#Liu86), p.21).

Occasionally, one can exploit the "biological unreasonability" inherent in the unconstrained parental mappings $m,f$: e.g. the Na society in Yunnan  (China) is a **fatherless society** lacking marriage or social acknowledgement of male contribution to procreation (cf. [Godelier, pp.494-509](#Godelier04)).

The society consists of matrilineal families consisting of a woman, her brothers and her children. Conception takes place via "nocturnal male visitors" from other houses. In first approximation we can model this absence of fatherhood by the triviality of the father-of-map $f=id$: every individual $x$ is his own father. This corresponds to the full subcategory of societies of form $(X,m:X\to X, id_X)$ which is equivalent to $Set^{M_1^{op}}$ where $M_1$ is the free monoid generated by $\{m\}$.

This subcategory is the image under the full and faithful $q^*$ arising from the adjunction

$$ q_!\dashv q^*\dashv q_*: Set^{M_2^{op}}\to Set^{M_1^{op}}$$ 

induced by the surjective morphism of monoids $q:M_2\to M_1$ with $q(f)=1$ and $q(m)=m$.

Even societies that entertain an elaborate pattern of kinship relations and terminologies tend to blur distinctions with increasing genealogical depth e.g. whereas parallel and cross kin differ terminologically in the parental generation $G^{+1}$, they are named with the same term in the generation $G^{+2}$ of the grandparents. This lumping to together of generations $G^{\leq i}$ to a cluster of 'ancestors' is achieved by quotienting $M_2$ with relations expressing the equivalence $G^{+j}\cong G^{+(j+1)}$ for $i\leq j$ e.g. for $i=2$ this amounts to equate all expressions of depth $3$ with an appropriate expression of depth $2$: $f^3=fmf=f^2$ etc. The resulting epimorphism of monoids $\alpha$:$M_2\to M_\approx$ induces functors $\alpha_!\dashv \alpha^*\dashv\alpha_*:Set^{M_2{^{op}}}\to Set^{{M_\approx}^{op}}$ like above.

At the end of his [paper](#Law99), Lawvere makes  the interesting suggestion to use as [[abstract general]] not the category corresponding to $M_2$ but the [[category]] $\mathcal{C}$ based on the diagram of three parallel arrows 

$$
\bullet{\underset{\rightarrow}{\overset{\rightarrow}{\rightarrow}}}\bullet
$$

The result still contains the topos of $M_2$-actions as a quotient topos because inverting one of the arrows turns the resulting diagram up to equivalence into the diagram of one point with two endomaps. Hence the objects in topos $Set^{\mathcal{C}^{op}}$ permit a more finely grained analysis than the objects in the topos of $M_2$-actions.

### Some further remarks

* The topos $Set^{M_2^{op}}$ lacks non-trivial [[level|essential subtoposes]] since by an result of Kelly-Lawvere ([1989](#KL89)) they correspond to two-sided (=left+right) ideals $I$ of $M_2$ that are _idempotent_ i.e. $I=I\cdot I=\{xy|x,y\in I\}$. But a non-empty ideal $I$ has a minimal length $#I$ such that there is a word $w\in I$ of length $#I$ but no word $v\in I$ of strictly smaller length. Since concatenation with non-empty words strictly increases the length of a word, one has $#(I\cdot I)=2\cdot #I$ hence $#I\neq #(I\cdot I)$ iff $\epsilon\notin I$ and, accordingly, $I\neq I\cdot I$ iff $\epsilon\notin I$.

* The [[Jónsson-Tarski topos]] $\mathcal{J}_T$ is a (non-essential) [[subtopos]] of $Set^{M_2^{op}}$.

* The construction $X\mathsf{mod}A$ that [Lawvere (1999)](#Law99) discusses p.417, is defined as the [[pushout]] of the inclusion $A\hookrightarrow X$ along the map $A\to\Pi_0(A)$ that maps $a\in A$ to its [[connected component]] $[a]\in\Pi_0(A)$ (where the set $\Pi_0(A)$ of connected components of $A$ is equipped with the trivial functions $\omega=id$ and $\mu=id$):
$$
\begin{matrix}
A &\hookrightarrow & X \\
\downarrow &          &\downarrow\\
\Pi_0(A) &\hookrightarrow  & X\mathsf{mod} A
\end{matrix}
$$

* The categories of the form $W/G$ occurring on p.420 and p.424 denote the [[category of elements]] $\int _{W} G$ of the [[presheaf]] $G:W^{op}\to Set$. The background here is that a [[slice topos]] $Set^{\mathcal{C}^{op}}/X$ is equivalent to $Set^{(\int _{\mathcal{C}}X)^{op}} $ (see at [[category of presheaves]] for more details). Whence labeling with $L$ can equivalently be achieved by taking presheaves over $\int _W L$ !

## Related entries

* [[Claude Lévi-Strauss]]

* [[canonical formula of myth]]

* [[structuralism]]

* [[quasicategory]]

## Link

* Wikipedia entry: kinship ([link](https://en.wikipedia.org/wiki/Kinship))

* Mathematical Anthropology and Cultural Theory ([online journal](http://mathematicalanthropology.org))

## References

Early pioneering attempts include

* Alexander Macfarlane, _Analysis of relationships of
consanguinity and affinity_ , J. Royal Anthr. Inst. **12** (1882) pp.46-63.

* John H. Greenberg, _The logical analysis of kinship_ , Philosophy of Science **15** (1949) pp.58-64.

* Rudolf Carnap, _Introduction to Symbolic Logic and its Applications_ , Dover New York 1958. (pp.220-225, 230)

An obstinate 70s' rumour has it that 'kinship' boils down to a Western folk myth. Already better informed:

* Ernest Gellner, _The concept of kinship_ , Philosophy of Science **27** (1960) pp.187&#8211;204. 

A comprehensive and highly recommendable anthology is

* {#PS04}Robert Parkin, Linda Stone (eds.), _Kinship and Family_ , Blackwell Oxford 2004.

Current textbooks include 

* Robert Parkin, _Kinship: An Introduction to the Basic Concepts_ , Blackwell Oxford 1997.

* Linda Stone, _Kinship and Gender: An Introduction_ , Westview 2013.

Classical anthropological texts are 

* {#Fox83}Robin Fox, _Kinship and Marriage_ , 2nd ed. Cambridge UP 1983.

* {#LS67}[[Claude Lévi-Strauss]], _Les structures &#233;l&#233;mentaires de la parent&#233;_ , 2nd ed. Mouton The Hague 1967.

* [[Claude Lévi-Strauss]], _R&#233;flexions sur l'atome de parent&#233;_ , L'Homme **13** no.3 (1973) pp.5-30. ([link](http://www.persee.fr/doc/hom_0439-4216_1973_num_13_3_367355))

More recent texts include

* German Dziebel, _The Genius of Kinship_ , Cambria Youngstown 2007.

* {#Godelier04}Maurice Godelier, _M&#233;tamorphoses de la parent&#233;_ , Fayard Paris 2004.

* {#GTT98}Maurice Godelier, Thomas R. Trautmann, Franklin E. Tjon Sie Fat (eds.), _Transformations of Kinship_ , Smithsonian Institute Washington 1998.

The permutation model originates with

* {#Weil49}[[André Weil]], _Sur l'&#233;tude alg&#233;brique de certains types de lois de mariage (Syst&#232;me Murngin)_ , pp.257-263 in [L&#233;vi-Strauss (1949/1967)](#LS67).

A review of Weil's approach as well as an overview of mathematical approaches to kinship is provided by

* Pin-Hsiung Liu, _Theory of groups of permutations, matrices and kinship: a critique of mathematical approaches to prescriptive marriage systems_ , Bulletin of the Institute of Ethnology Academia Sinica **26** (1968) pp.29&#8211;38. ([pdf](http://c.ianthro.tw/sites/c.ianthro.tw/files/da/df/407/407386_0001.pdf))

An overview of structuralist kinship theory and a criticism of permutation models is

* {#Sperber68} Dan Sperber, _Le structuralisme en anthropologie_ , pp.167-238 in Ducrot et al. , _Qu'est-ce que le structuralisme?_ , Seuil Paris 1968.

Courr&#232;ge's seminal paper is easily accessible and eminently readable:

* {#Cour65}Philippe Courr&#232;ge, _Un mod&#232;le math&#233;matique des structures &#233;l&#233;mentaires de parent&#233;_ , L'Homme **5** no.3-4 (1965) pp.248-290. ([link](http://www.persee.fr/doc/hom_0439-4216_1965_num_5_3_366751); Engl. translation in Ballonoff (ed.), _Genetics and Social Structure_ , Hutchinson&Ross 1974)

A useful overview and synthesis of the algebraic approach is

* Franklin E. Tjon Sie Fat, _Representing Kinship: Simple Models of Elementary Structures_ , PhD. Leiden University 1990.

A visit to the library is richly rewarded by the clear and comprehensive exposition in the following outstanding monograph:

* {#Liu86}Pin-Hsiung Liu, _Foundations of Kinship Mathematics_ , Academica Sinica Nankang 1986.

The category-theoretic point of view is sketched in

* {#Law99}[[William Lawvere|F. William Lawvere]], _Kinship and Mathematical Categories_ , pp.411-425 in Jackendoff, Bloom, Wynn (eds.), _Language, Logic, and Concepts_ , MIT Press Cambridge 1999.

* {#LawSchan97}[[William Lawvere|F. William Lawvere]], [[Stephen Schanuel|Stephen H. Schanuel]], _Conceptual Mathematics_ , Cambridge UP 1997. (pp.162-163)

The following pursues an abstract general approach to kinship:

* {#Allen86}N. J. Allen, _Tetradic Theory: An Approach to Kinship_ , J. Anthr. Soc. Oxford **17** (1986) pp.87-109. (Revised reprint pp.221-235 in [Parkin-Stone 2004](#PS04).)

The general role of group theory in culture is dicussed in

* P. Lucich, _Beyond Formalism: Group Theory in the Symmetries of Culture_ , J. Math. Sociology **16** (1991) pp.221-264.

A group-theoretic approach to Dravidian kinship and universal classification is proposed in

* {#Alm10}Mauro W. Barbosa De Almeida, _On the Structure of Dravidian Relationship Systems_ , MACT **3** no.1 (2010). ([pdf](http://mathematicalanthropology.org/pdf/BarbosadeAlmeida.0810.pdf))

A connection between Dravidian kinship terminology and [[supersymmetry]] is proposed in

* {#Vaz14}Ruth M. Vaz, _Relatives, Molecules and Particles_ , MACT **7** no. 1 (2014). ([pdf](http://mathematicalanthropology.org/pdf/RMVaz_MACT%200614.pdf))

Kinship systems are studied from a mathematical perspective in

* John P. Boyd, _The Algebra of Group Kinship_ , J. Math. Psychology **6** (1969) pp.139-167.

* John P. Boyd, John H. Haehl, Lee D. Sailer, _Kinship and Inverse Semigroups_ , J. Math. Sociology **2** no.1 (1972) pp.37-61.

* Aim&#233; Fuchs, _Les structures de parent&#233;: traitement math&#233;matique_ , Revue Europ&#233;enne des Sciences Sociales et Cahiers Vilfredo Pareto **19** (1981) pp.161-182.

* Alain Gottcheiner, _On some Classes of Kinship Systems I: Abelian Systems_ , MACT **2** no. 4 (2008). ([pdf](http://mathematicalanthropology.org/Pdf/GottscheinerI_0908.pdf))

* Alain Gottcheiner, _On some Classes of Kinship Systems II: Nonabelian Systems_ , MACT **2** no. 5 (2008). ([pdf](http://mathematicalanthropology.org/Pdf/GottscheinerII_0908.pdf))

* Labib Haddad, Yves Sureau, _Les groupes, les hypergroupes et l'&#233;nigme des Murngin_ , JPAA **87** (1993) pp.221-235.

* Per Hage, Frank Harary, _The Logical Structure of Asymmetric Marriage_ , L'Homme **36** no.139 (1996) pp.109-124. ([link](http://www.persee.fr/doc/hom_0439-4216_1996_num_36_139_370120))

* Frank Harary, Douglas R. White, _P-Systems: A Structural Model for Kinship Studies_ , Connections **24** no.2 (2001) pp.35-46. ([pdf](http://www.insna.org/PDF/Connections/v24/2001_I-2-6.pdf))
 
* Paul Jorion, Gis&#232;le De Meur, Trudeke Vuyk, _Le mariage Pende_  , L'Homme **22** no.1 (1982) pp.53-73. ([link](http://www.persee.fr/doc/hom_0439-4216_1982_num_22_1_368256))

* [[Claude Lévi-Strauss]], Georges Guilbaud, _Syst&#232;me parental et matrimonial au Nord Ambrym_ , J. Soci&#233;t&#233; des Oc&#233;anistes **26** no. 26 (1970) pp.9-32. ([link](http://www.persee.fr/doc/jso_0300-953x_1970_num_26_26_2281))

* Gis&#232;le De Meur (ed.), _New Trends in Mathematical Anthropology_ , Routledge London 1986.

* Gis&#232;le De Meur, Alain Gottcheiner, _Prescriptive Kinship Systems, Permutations, Groups, and Graphs_ , MACT **1** no. 1 (2000). ([pdf](http://mathematicalanthropology.org/Pdf/MACTdeMEUR1100.pdf))

* Harrison C. White, _An Anatomy of Kinship_ , Prentice-Hall Englewood Cliffs 1963.

For related ideas see also

* Wyllis Bandler, _Some Esomathematical Uses of Category Theory_ , pp.243-255 in Glir (ed.), _Applied General Systems Research_ , Springer Heidelberg 1978.

* John P. Boyd, _The Universal Semigroup of Relations_ , Social Networks **2** no.2 (1979) pp.91-117.

* John P. Boyd, _Social Semigroups_ , George Mason UP 1991.

* Fran&#231;ois Lorrain, _R&#233;seaux sociaux et classifications sociales: Essai sur l 'alg&#232;bre et la g&#233;om&#233;trie des structures sociales_ , Hermann Paris 1975.

* Fran&#231;ois Lorrain, Harrison C. White, _Structural Equivalence of Individuals in Social Networks_ , J. Math. Sociology **1** (1971) pp.49-80.

* Oystein Ore, _Sex in Graphs_ , Proc. AMS **11** (1960) pp.533-539. ([pdf](http://www.ams.org/journals/proc/1960-011-04/S0002-9939-1960-0117174-7/S0002-9939-1960-0117174-7.pdf))

First steps in [[topos theory]] can be undertaken with [Lawvere-Schanuel (1997)](#LawSchan97) whereas the level of sophistication then increases steadily from

* {#RRZ04} M. La Palme Reyes, [[Gonzalo E. Reyes|G. E. Reyes]], H. Zolfaghari, _Generic Figures and their Glueings_ , Polimetrica Milano 2004.

to the standard textbook 

* {#MM94} [[Saunders Mac Lane]], [[Ieke Moerdijk]], _[[Sheaves in Geometry and Logic]]_ , Springer Heidelberg 1994.

The result concerning essential localizations is in

* {#KL89}[[G. M. Kelly]], [[F. W. Lawvere]], *On the Complete Lattice of Essential Localizations*, Bull. Soc. Math. de Belgique **XLI** (1989) pp.289-319.

[[!redirects kinship system]]
[[!redirects mathematical anthropology]]