## Idea

__Elementary mathematics__ is a conventional term used in the mathematics education denoting the part of mathematics curriculum which does not require advanced, nonstandard or conceptually deep level of background (in particular, no infinitesimal calculus). 

Though most good approaches to elementary mathematics include setting up basic foundational issues at the appropriate level (for example the principles of proofs etc.), elementary mathematics should be distinguished from the foundations of mathematics. 

#### Terminological remark

In another, related but more narrow sense, in 20-th century education, high school and university mathematics was often divided into "elementary" and "higher" mathematics where elementary the part developed without usage of infinitesimal calculus. Higher mathematics in this obsolete sense denoted calculus and related subjects, but still not any research level, nonstandard or recent mathematics. 

## References

Related $n$Lab entries include [[mathematics education]], [[foundations]], [[axioms of plane geometry]]

### Educational theory on elementary mathematics

* wikipedia: [modern elementary mathematics](https://en.wikipedia.org/wiki/Modern_elementary_mathematics)

> Modern elementary mathematics is the theory and practice of teaching elementary mathematics according to contemporary research and thinking about learning. This can include pedagogical ideas, mathematics education research frameworks, and curricular material.

### General references on elementary mathematics

The following is a classics (vol. I in German 1908).

* [[Felix Klein]], _Elementary mathematics from an advanced standpoint_

The following overview of elementary mathematics is written by a Lebesgue's student Lucienne Félix (1901-1994) in French, a well known name in mathematics education (cf. <http://guy-brousseau.com/lucienne-felix>); there are English and Russian translations. The introduction says that many of the pedagogical ideas of Lebesgue are incorporated into the text.

* Lucienne Félix, _The modern aspect of mathematics_, (Rus. transl.: Элементарная математика в современном изложении, 1967)

Soviet mathematicains (A. D. Aleksandrov, complex analyst Markushevich and Hinchin) wrote in 1950s an ambitious 5-volume work "Encyclopaedia of elementary mathematics" (basic calculus included; geometry is volumes 4 and 5, redacted by Yaglom and Boltianskii):

* Александров, Марукушевич, Хинчин, _Энциклопедия элементарной математики_ 

### References on elementary geometry

Here we try to include only mathematically sound references which brought something new or are very influential, pedagogically original or well written. 

The following texts contain useful material for teaching elementary geometry at an intermediate high-school and undergraduate level:

* Robin Hartshorne, _Teaching geometry according to Euclid_ , Notices AMS __47__:4 (2000) 460-465 [pdf](http://www.ams.org/notices/200004/fea-hartshorne.pdf)

* Robin Hartshorne, _Geometry - Euclid and Beyond_ , UTM Springer 2000.

* [[David Hilbert]], Stephan Cohn-Vossen, _Anschauliche Geometrie_ , Springer Berlin 1932. ([gdz](http://gdz.sub.uni-goettingen.de/dms/load/toc/?PID=PPN379425343))

* David Henderson, Daina Taimina, _Experiencing Geometry_ , Prentice-Hall Upper Saddle River 2005. (Supplementary online material: [link](http://www.math.cornell.edu/~henderson/ExpGeom/ExpGeomSuppl.html))

* John Stillwell, _The Four Pillars of Geometry_ , UTM Springer 2005.
* Gustave Choquet, _Geometry in a modern setting_

The following very accurate books were intended to teach geometry to high school teachers of mathematics:

* Jacquelline Lelong-Ferrand, _Les fondements de la géométrie_, Presses Universitaires de France, 1985
* [[Jean Dieudonné]], _Linear algebra and geometry_

Comprehensive modern, more advanced but standard reference for classical geometry (emphasizing the role of transformation groups) starting from basics and going somewhat beyond elementary geometry is

* [[Marcel Berger]], _Geometrie_, 5 vol. Paris: CEDIC, Fernand Nathan 1977; Rus. transl. in 2 vols., Mir 1984; _Geometry. I._ Engl. transl. by M. Cole, S. Levy, Universitext Springer 1987, 1994. xiv+427 pp.

### Basic calculus adapted to physicists and engineers

Infinitesimal calculus is usually not listed as elementary mathematics. In US educational system infinitesimal calculus at rigorous and advanced level is usually
called mathematical analysis while at the beginner's level it is called simply
calculus. The textbooks are very numerous and widely available and will not be listed here; they witnessed many trends and reforms like calculator-intensive courses and so on. As these textbooks are usually rich in accompanying techniques like teacher manuals, problem sets, solution sets etc. their authors are usually professional mathematicians most often those dedicated to teaching, rather than leading research mathematians. 

A different project of a beginner calculus textbook written by a leading physicist together with a leading geometer came from former Soviet Union

* Ya. B. Zeldovich, I. M. Yaglom, _Higher math for beginners_, Mir 1987 (translated from Russian original published by Nauka in 1982) [pdf](https://ia801303.us.archive.org/29/items/ZeldovichYaglomHigherMathematics/Zeldovich-Yaglom-Higher-Mathematics.pdf)

Some argue that calculus is more intuitive for engineers if taught in the [[nonstandard analysis]] approach. One of the major such textbooks is free online

* H. Jerome Keistler, _Elementary calculus: an infinitesimal approach_, 2000 [files](http://www.math.wisc.edu/~keisler/calc.html); see also companion booklet
_Foundations of infinitesimal calculus_, [files](http://www.math.wisc.edu/~keisler/foundations.html)

### Foundations of mathematics and categories

Foundations of mathematics is a subject, which is beyond the very basics, NOT belonging to elementary mathematics, nor this entry. However, some readers of this page may find beneficial that we list just a very short choice of standard books on foundations for the first reading (but not that elementary).

* [[Practical Foundations of Mathematics]] 
* Elliott Mendelson, _Introduction to mathematical logic_

The following book is a unique attempt by two prominent mathematicians to give an elementary introduction to [[category theory]] directed at beginning students and general readers which is relevant to school education as well:

* [[F. William Lawvere]], [[Stephen H. Schanuel]], _Conceptual mathematics: a first introduction to categories_ , Cambridge UP 1997.

One should note that the category theory is not traditionally considered a part of elementary mathematics even if some parts can be explained in an elementary way (the same is true for the simplest parts of infinitesimal calculus). 

category: education