[[!redirects agar.io]]
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}

### Context
#### Philosophy
+-- {: .hide}
[[!include philosophy - contents]]
=--
#### Foundations
+-- {: .hide}
[[!include foundations - contents]]
=--
=--
=--

# Contents
* table of contents
{:toc}

[[!redirects Absolute conclusion]]
[[!redirects the absolute conclusion]]
[[!redirects Absoluter Schluss]]
[[!redirects der absolute Schluss]]

## Idea
The **absolute conclusion**, or in German, _der absolute Schluss_, is a key concept in the speculative philosophy of the German philosopher [[Georg Hegel|G. W. F. Hegel]].

The name of the concepts plays on the triple sense of _Schluss_ in German evoking _end_ , as well as 'Zusammenschluss' - _union_ and _logical deduction_. The primary sense is that the absolute conclusion unites three deductions into a deductive relation to conclude the development of a concept or part of the philosophical system. It is called _absolute_ because its ' premises' and 'conclusion' are themselves deductions that relate to other deductions, whence, it is a _deduction between deductions_.

The main idea is that this deductive pattern improves on ordinary 'relative' deductions that hinge on unmediated premises for their mediation, by elevating each premise into conclusive positions and vice versa, thereby solving a 'contradiction' well known in logic since Aristotle's _Analytica Posteriora_, namely that the desired proofs require unproved axioms.[^nat]

[^nat]: That it is also possible to proceed from (retractable) assumptions instead of (true) axioms was shown by the end of the 1920s by G. Gentzen and S. Jaskowski (cf. [[natural deduction]]).

Hegel's model for a logical deduction is an Aristotelian [[syllogism]] consisting of two premisses and a conclusion that involve a subject notion $S$ and a predicate notion $P$ and a middle term $M$. Hegel first identifies then  $S$ with a _general_ notion, $P$ with a _particular_ notion, and $M$ with a _singular_ notion. The absolute conclusion then consists of three syllogisms where the general, the particular and the singular change position in the syllogistic figure such that each takes the place thereby expressing the deep-structural identity between the three notions.

The _objectivity_ and _reality_ of an entity is viewed as the **absolute mediation** of the general, particular and singular parts involved in its notion as expressed by such an absolute conclusion. E.g. in the philosophy of religion Hegel ([Enzyklopädie III](#Hegel10), pp.374ff) interprets the Christian trinity as an absolute conclusion where the conceptions of god as father (generality), is united with the conception of god as a son (particularity) and the conception as holy spirit (singularity). Once the identity of these concepts is expressed, the trinitarian concept of god realizes itself as communital spirit in the church - i.e. once rightly understood god lives in and as the spirit of community in human society.

This might seem to be a somewhat speculative use of the absolute conclusion but a similar passage from a completed mediation to objectivity occurs in the subjective logic of "Wissenschaft der Logik" when the subjective notion transforms into 'objectivity'. That a mediation of moments yields to objectivity sounds rather strange but the background here is Hegel's reinterpretation of Kant's concept of 'transcendental apperception' where the integration of perceptions under the notion of an object is accompanied by the 'I think' i.e. the unity of perception gets correlated with the unity of a self. Hegel equates the unity of the self with the complete mediation of the concept's moments from which the thought of an object springs: the self that flows around such a circle of mediations is viewed as the generic invariant that imparts its invariance to objects.

Beyond all metaphysical speculation one can view Hegel's concept as a general proposal for the **architecture of foundational theories** that 'escapes' the Münchhausen problem of a foundational (vicious) circle by entangling three circles into a circle. Under this interpretation one would view it as the suggestion that foundations should ideally consists of three fundamental systems that interpret each other and thereby corroborate each other.

To get an intuition one might think of the three different notions of [[computability]] as Turing machines, recursive functions and lambda calculus whose mutual equivalence back the Church-Turing hypothesis resulting in an 'absolute' concept of algorithm. In a similar vein is [[Bob Harper|R. Harper's]] [[computational trinitarianism]]. Also relevant is the possibility in [[categorical logic]] to interpret classes of categories via an external 'objective' description, then as models of a 'subjective' internal language and as models of appropriate [[sketch|sketches]] at an intermediate level.

Notice the proximity of the triads involved in such foundations to the mathematical rendering of the triadic structure involving the imaginary, the real, and the symbolic in Lacan's theory of subjectivity as proposed in [[René Guitart|Guitart's]] theory of _Borromean objects_ ([2009](#Guitart09)).

To sum up: the concept of the absolute conclusion enjoys currently little popularity among philosophers not even among Hegelian philophers despite the importance Hegel attached to it. It might nevertheless be worthwhile to probe into this concept from the perspective of contemporary foundational theories in the mathematical sciences.

## Some background

Hegel apparently introduced the concept in his philosophy around 1800 in or shortly before the Jena period. He purloined it from Plato's [[Timaeus dialogue|Timaios dialogue]] (**7**, 32c):

>But it isn't possible to combine two things well all by themselves, without a third; there has to be some bond between the two that unites them. Now the best bond is one that really and truly makes a unity of itself together with the things bonded by it, and this in the nature of things is accomplished by proportion. For whenever of three numbers which are either solids or squares the middle term between any two of them is such that what the first term is to it, it is to the first, then, since the middle term turns out to be both first and and last, and the last and first likewise both turn out to be middle terms, they will all of necessity turn out to have the same relationship to each other, and, given this, will all be unified.[^cite]  

[^cite]: Translation by D. J. Zeyl, p.1237 in [Cooper (ed.) 1997](#Plato). Note that 'most harmonious bond' is closer to the Greek text than 'best bond'. Hegel quotes it as 'der Bande schönstes' in German.

Hegel cites this passage already in _'Differenz des Fichteschen und Schellingschen Systems der Philosophie'_ ([1801](#Hegel2), p.97). A similar configuration with triangles instead of circles occurs also in his (lost) fragment on the _'divine triangle'_ as reported and dated to 1804 by [[Karl Rosenkranz|Rosenkranz]] (cf. [Hegel Werke 2](#Hegel2), pp.534-539) which is somewhat reminiscent of an adjoint triple $L\dashv M\dashv R$ as an [[adjoint triple|adjunction between adjunctions]].

The conception seems to have been the subject of the discussions between Hegel and Schelling during their collaboration in Jena, since the latter alludes to the display of the absolute by the three judgements in two texts of the epoch, namely the dialogue _'Bruno oder Über das göttliche und natürliche Prinzip der Dinge'_ ([1802](#Bruno)) and _'Philosophie und Religion'_ ([1804](#SchellSchrift)).

The mature Hegel comments the Timaios passage extensively and with emphatic approval in his [[Lectures on the History of Philosophy]] (cf. [Hegel Werke 19](#Hegel19), pp.89-91).


## Related entries

* [[Aufhebung]]

* [[Science of Logic]]

* [[infinite judgement]]

* [[construction in philosophy]]

* [[computational trinitarianism]]

* [[syllogism]]

* [[Timaios]]

## References

* {#Plato} J. M. Cooper (ed.), _Plato - Complete Works_ , Hackett Indianapolis 1997.

* N. Füzesi, _Hegels drei Schlüsse_ , Alber München 2004.

* {#Guitart09}[[René Guitart| R. Guitart]], _Klein’s Group as a Borromean Object_ , Cah. Top. Géo. Diff. Cat. **L** no.2 (2009) pp.144-155. ([pdf](http://rene.guitart.pagesperso-orange.fr/textespublications/Guitart%202009%20G168CTGDC.pdf))

* {#Hegel2} [[Georg Hegel|G. W. F. Hegel]], _Jenaer Schriften 1801-1807 - Werke 2_ , Suhrkamp Frankfurt a. M 1986.

* {#Hegel8} [[Georg Hegel|G. W. F. Hegel]], _Enzyklopädie der philosophischen Wissenschaften I - Werke 8_ , Suhrkamp Frankfurt a. M 1986[1817, rev. 1830]. (§ 187 Zusatz, p.339f.)

* {#Hegel10} [[Georg Hegel|G. W. F. Hegel]], _Enzyklopädie der philosophischen Wissenschaften III - Werke 10_ , Suhrkamp Frankfurt a. M 1986[1817, rev. 1830]. (§§ 569-571, pp.376f; §§ 575-77, pp.393f)

* {#Hegel19} [[Georg Hegel|G. W. F. Hegel]], _Vorlesungen über die Geschichte der Philosophie II - Werke 19_ , Suhrkamp Frankfurt a. M 1986. (ch. III A. 2, pp.89-91)

* W. Jaeschke, _Die Schlüsse der Philosophie (§§ 574-577)_ , pp.479-486 in Drüe et al. (eds.), _Hegels 'Enzyklopädie der philosophischen Wissenschaften'  (1830) - Ein Kommentar zum Systemgrundriß_ , Suhrkamp Frankfurt a. M. 2000.

* G. Sans, _Die Realisierung des Begriffs - Eine Untersuchung zu Hegels Schlusslehre_ , Akademie Verlag Berlin 2004.

* {#SchellSchrift}F. W. J. Schelling, _Schriften 1804-1812_ , Union Berlin 1982. (sect. 1, p.48)

* {#Bruno}F. W. J. Schelling, _Bruno oder Über das göttliche und natürliche Prinzip der Dinge_ , Reclam Leipzig 1986. (sect. IIB 7b, p.88)

* G. Werckmeister, _Hegels absoluter Schluss als logische Grundstruktur der Objektivität_ , PhD TU Kaiserslautern 2009. ([link](https://kluedo.ub.uni-kl.de/frontdoor/index/index/docId/2160))