
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Topology
+-- {: .hide}
[[!include topology - contents]]
=--
#### Homotopy theory
+-- {: .hide}
[[!include homotopy - contents]]
=--
=--
=--

# Contents
* table of contents
{:toc}

## Idea

The suspension $S X$ of a [[topological space]] $X$ is a space of one higher dimension, which is (for [[inhabited set|inhabited]] $X$) a [[quotient object|quotient space]] of $X \times [0,1]$.  The difference between $S X$ and $X \times [0,1]$ is that the copy of $X$ at each endpoint ($0$ or $1$) is replaced by a single point.  

Compare the [[reduced suspension]] $\Sigma X$, where you start with a [[pointed space]] and identify all copies of the base point as well.  This is the special case in [[Top]] of a general operation in [[(∞,1)-categories]]: see [[suspension object]].  For [[CW-complex]]es the reduced suspension is [[weak homotopy equivalence|weakly homotopy equivalent]] to the ordinary suspension: $\Sigma X \simeq S X$.

This picture 

[[suspension.jpg:pic]]

from [Wikimedia](https://secure.wikimedia.org/wikipedia/commons/wiki/File:Suspension.svg) shows the suspension of the blue circle as $X$; the green dots correspond to $2$ in the first definition below.

Note that we *replace* $X$ by a single point at each endpoint; we don\'t merely *identify* all of the points in $X$ there.  This only makes a difference for the [[empty space]]; we should have $S \empty = \{\bot,\top\}$, not $S \empty = \empty$.  (This is related to the issues in the definition of [[connected space]].)

The suspension construction is part of the [[cofiber sequence]] induced from any [[mapping cone]] construction

<img src="http://ncatlab.org/nlab/files/mappingcone.jpg" width="660" >

(graphics taken from [Muro 10](http://personal.us.es/fmuro/praha.pdf))


## Definitions

Let $X$ be a [[space]] (such as a [[topological space]], or something more interesting like a [[generalized smooth space]]).  Let $I$ be the unit [[interval]] $[0,1]$ in the [[real line]]; let $2$ be the $2$-point [[discrete space]] $\{\bot,\top\}$.  Let $X \times I \times 2$ be the [[cartesian product]] of $X$, $2$, and $I$; let $X + (X \times 2 \times I) + 2$ be the [[disjoint union]] of $X$, $X \times I \times 2$ and $2$.  We will suppress reference to the inclusion maps into $X + (X \times I) + 2$; it will be clear from context how to parse an element of the latter.


### Generalisable definition

The __suspension__ $S X$ of $X$ is the [[quotient space]] of $X + (X \times I \times 2) + 2$ by the [[equivalence relation]] $\sim$ generated by:

*  $a \sim (a,0,\bot)$ for $a$ in $X$;
*  $a \sim (a,0,\top)$ for $a$ in $X$;
*  $(a,1,\bot) \sim \bot$ for $a$ in $X$;
*  $(a,1,\top) \sim \top$ for $a$ in $X$.


### Generalisation: the join

This generalises immediately to an operation called the _[[join of topological spaces|join]]_ $X \star Y$ of two spaces $X$ and $Y$; this is the quotient space of $X + (X \times I \times Y) + Y$ by the equivalence relation generated by:

*  $a \sim (a,0,b)$ for $a$ in $X$ and $b$ in $Y$;
*  $(a,1,b) \sim b$ for $a$ in $X$ and $b$ in $Y$.

(Compare [[join of simplicial sets]] and [[join of topological spaces]], the same operation in another guise.)  Then we have $S X = X \star 2$.


### Simplified definition

It is somewhat simpler to define $S X$ as the quotient space of $(X \times I) + 2$ by the equivalence relation generated by:

*  $(a,0) \sim \bot$ for $a$ in $X$;
*  $(a,1) \sim \top$ for $a$ in $X$.

This works to define a topological space, but it does not directly give the smooth structure that matches the picture above.


### Further simplified for pointed spaces

If $X$ has a point $p$, hence if it is [[inhabited set|inhabited]], then we can define $S X$ as the quotient space of $X \times I$ by the equivalence relation generated by:

*  $(a,0) \sim (b,0)$ for $a, b$ in $X$;
*  $(a,1) \sim (b,1)$ for $a, b$ in $X$.

This is probably the most common definition seen, but it only works for $X$ an inhabited space (and even then gives only the topological structure).

### Reduced suspension

To make the suspension of a [[pointed space]] $(X,p)$ again a [[pointed space]] one may further collapse in $S X$ the set $\{p\} \times I$ to the point. The result then is called the _[[reduced suspension]]_ of $(X,p)$ and is denoted 

$$
  \Sigma X \coloneqq
  S X / \{p \} \times I
  \simeq
  X \times I / \left(
    X \times \{0,1\}
    \cup
    \{p\} \times I
  \right)
  \,.
$$

## Properties

### As a functor

It\'s easy to extend the suspension operation $S$ to a [[functor]] from [[Top]] to itself.

### Relation between suspension and reduced suspension

For [[CW-complexes]] suspension and [[reduced suspension]] agree, up to [[weak homotopy equivalence]].

### Cogroup structure

In the pointed case ([[reduced suspension]]): [[suspensions are H-cogroup objects]]

## Examples

### Suspension of cubes

The suspension of the $n$-[[cube]] is the $(n+1)$-cube, probably best visualised as a diamond.  This gives a [[recursion|recursive]] definition of cube, starting with the $0$-cube as the [[point]], which is not the suspension of anything.  Note that this not only gives us the [[topological structure]] of the cube, but also (by working in an appropriate [[category]] of [[smooth spaces]] throughout) the correct [[smooth structure]] on the cube as a [[manifold with corners]].  You can probably even get the correct [[metric space|metric]] on the cube (normalised to have diagonals of length $1$) automatically by using a more complicated quotienting process.

### Suspension of spheres

Up to [[homeomorphism]], the suspension of the $n$-[[sphere]] is the $(n+1)$-sphere, and the [[reduced suspension]] is 

$$
  \Sigma S^n \simeq S^{n+1}
  \,.
$$

See at _[one-point compactification -- Examples -- Spheres](one-point+compactification#ExamplesSpheres)_ for details.

Notice that the $n$-sphere is (topologically) the [[boundary]] of the $(n+1)$-cube.  The coincidence that 'sphere' and 'suspension' both begin with 's' has not been ignored; we can write $S^n \cong S^n(2)$, where $S^n$ on the left is the $n$-sphere and $S^n$ on the right is the $n$-fold [[composite]] of the suspension functor.  (Actually, you should start with the $(-1)$-sphere as the [[empty space]], which is not the suspension of anything; then the $0$-sphere is $S \empty = 2$.)  However, this does not give the correct smooth structure on the sphere, unless perhaps there is some more sophisticated definition that fixes this (but then that would break the cube).  It might be more appropriate to say that the suspension of the $n$-[[globe]] is the $(n+1)$-globe.

### Suspension of simplices

Up to topological structure, the suspension of the $n$-[[simplex]] is the $(n+1)$-simplex, but now this is not very useful.  To study simplices, you should use the __cone__ functor instead, which is $\Lambda X = X \star 1$, where $1$ is the [[point]].

## Related concepts

* [[EHP spectral sequence]]

* [[loop space object]], [[free loop space object]],

  * [[delooping]]

  * [[loop space]], [[free loop space]], [[derived loop space]]

* [[suspension object]]

  * **suspension**, [[reduced suspension]]

    * [[Freudenthal suspension theorem]]

    * [[Spanier-Whitehead category]]

    * [[suspension isomorphism]]

  * [[suspension of a chain complex]]


## References

Everybody knows about the suspension, but [Wikipedia](http://secure.wikimedia.org/wikipedia/en/wiki/Join_%28topology%29) knows about the join.  See also the textbook by Hatcher and Postnikov, _Homotopy of CW-complexes_.

The question on what is the Eckman-Hilton dual to $X\star Y$ find in 

* D. B. Fuks, Eckmann--Hilton duality and the theory of functors in the category of topological spaces, 1966 Russ. Math. Surv. 21 1--33 [doi](http://dx.doi.org/10.1070/RM1966v021n02ABEH004149), [free Russian original pdf](http://www.mathnet.ru/php/getFT.phtml?jrnid=rm&paperid=5847&what=fullt&option_lang=rus)

Here is [Chapter 1](http://www.math.psu.edu/katok_a/TOPOLOGY/Chapter1.pdf) (pdf) of a textbook that knows that $S \empty = 2$, although even it regards this as an exception.

* [[George Whitehead]], _Some aspects of stable homotopy theory_ ([pdf](http://www.mathunion.org/ICM/ICM1962.1/Main/icm1962.1.0502.0506.ocr.pdf))

* [[Ralph Cohen]], _A model for the free loop space of a suspension_ Lecture Notes in Mathematics, 1987, Volume 1286/1987, 193-207 ([])


[[!redirects suspension]]
[[!redirects suspensions]]
[[!redirects suspension functor]]

[[!redirects join of spaces]]
[[!redirects joins of spaces]]

[[!redirects suspensions]]
