
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Topology
+--{: .hide}
[[!include topology - contents]]
=--
#### Algebra
+--{: .hide}
[[!include higher algebra - contents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}

## Idea

The _Zariski topology_ is a [[topological space|topology]] on the [[prime spectrum of a commutative ring]]. It serves as the basis for much of [[algebraic geometry]].

{#Outline} We consider the definition in increasing generality and sophistication:

1. First we discuss the naive Zariski topology [on affine spaces](#OnAffineSpace) $k^n$, consider the classical proofs and discover thereby the special role of prime ideals and maximal ideals;

1. then we turn to the modern definition of the Zariski topology [on affine varieties](#OnAffineVarieties) $Spec(R)$ which takes the concept of prime (and maximal) ideals as primary, and again we provide the classical arguments;

1. finally we discuss the abstract [[category theory|category theoretic]] perspective on these matters [in terms of Galois connections](#InTermsOfGaloisConnections) and obtain slick category theoretic proofs of all the previous statements.


Starting with [[affine space]] $k^n$, then the idea of the Zariski topology is to take as the _[[closed subsets]]_ those defined by the vanishing of any set of [[polynomials]] over $k$ in $n$ [[variables]], hence the solution sets to [[equations]] of the form

$$
  \underset{i \in I}{\forall}
  \left(
     f_i(x_1, \cdots, x_n) = 0
  \right)
$$

for $f_i \in k[X_1, \cdots, X_n]$ [[polynomials]]. The [[open subsets]] of the topology are the [[complements]] of these _vanishing sets_.

It is clear that the vanishing set such a set of polynomials depends only on the [[ideal]] in the [[polynomial ring]] which is generated by them. Under this translation then forming the intersection of closed subsets corresponds to forming the sum of these ideals, and forming the union of closed subsets corresponds to forming the product of the corresponding ideals. This way the Zariski topology establishes a dictionary between topological concepts of the affine space $k^n$, and algebra inside the polynomial ring.

In particular one finds that the [[irreducible closed subsets]] of the Zariski topology correspond to the [[prime ideals]] in the polynomial ring (prop. \ref{PrimeVanishingIdealOfIrreducibleZariskiClosed} and prop. \ref{PrimeIdealClosedsubspaceBijection} below), and that the [[closed points]] correspond to the [[maximal ideals]] among these (prop. \ref{MaximalIdealsAreClosedPoints}).

This motivates the modern refinement of the concept of the Zariski topology, where one considers any [[commutative ring]] $R$ and equips its set of [[prime ideals]] with a topology, by direct analogy with the previously naive affine space $k^n$, which is recovered with $R$ a polynomial ring and restricting attention to the maximal ideals (example \ref{AffinSpaceAsPrimeSpectrum} below).

These sets of prime ideals of a ring $R$ equipped with the Zariski topology are called the (topological spaces underlying) the _[[prime spectrum of a commutative ring]]_, denoted $Spec(R)$.

The Zariski topology is in general not [[Hausdorff topological space|Hausdorff]] (example \ref{AffineSpaceOverInfiniteFieldNotHausdorff} below) which makes it sometimes be regarded as an "exotic" type of topology. But it is in fact [[sober topological space|sober]] (prop. \ref{ZariskiTopologyIsSober} below) and hence as well-behaved in this respect as general [[locales]] are.


## On affine space
 {#OnAffineSpace}

We consider here, for $k$ a [[field]], the [[vector space]] $k^n$ equipped with a Zariski topology. This is the original definition of Zariski topology, and serves well to motivate the concept, but eventually it was superceded by a more refined concept of Zariski topologies of prime spectra, discussed in the next subsection [below](#OnAffineVarieties). In example \ref{AffinSpaceAsPrimeSpectrum} below we reconsider the naive case of interest in this subsection here from that more refined perspective.

### Definition

+-- {: .num_defn  #ZariskiOpenSubsetsOnAffineSpace}
###### Definition
**(Zariski topology on affine space)**

Let $k$ be a [[field]], let $n \in \mathbb{N}$, and write $k[X_1, \cdots, X_n]$ for the [[set]] of [[polynomials]] in $n$ [[variables]] over $k$.

For $\mathcal{F} \subset k[X_1, \cdots, X_n]$ a subset of polynomials, let the  subset $V(\mathcal{F}) \subset k^n$ of the $n$-fold [[Cartesian product]] of the underlying set of $k$ (the _vanishing set_ of $\mathcal{F}$) be the subset of points on which all these polynomials jointly vanish:

$$
  V(\mathcal{F})
    \coloneqq
  \left\{
     (a_1, \cdots, a_n) \in k^n
     \,\vert\,
     \underset{f \in \mathcal{F}}{\forall} f(a_1, \cdots, a_n) = 0
  \right\}
  \,.
$$

These subsets are called the _Zariski [[closed subsets]]_.

Write

$$
  \tau_{\mathbb{A}^n_k}
  \;\coloneqq\;
  \left\{
    k^n \backslash V(\mathcal{F}) \subset k^n
    \,\vert\,
    \mathcal{F} \subset k[X_1, \cdots, X_n]
  \right\}
$$

for the set of [[complements]] of the Zariski closed subsets. These are called the _Zariski [[open subsets]]_ of $k^n$.


=--

+-- {: .num_prop #VerifyingZariskiTopologyOnAffineSpace}
###### Proposition
**(Zariski topology is well defined)**

Assuming [[excluded middle]], then:

For $k$ a [[field]] and $n \in \mathbb{N}$, then the Zariski open subsets of $k^n$ (def. \ref{ZariskiOpenSubsetsOnAffineSpace}) form a [[topological space|topology]]. The resulting [[topological space]]

$$
  \mathbb{A}^n_k
  \;\coloneqq\;
  \left(
     k^n, \tau_{\mathbb{A}^n_k}
  \right)
$$

is also called the $n$-dimensional _[[affine space]]_ over $k$.

=--

+-- {: .proof}
###### Proof

We need to show for $\{\mathcal{F}_i \subset k[X_1, \cdots, X_n]\}_{i \in I}$ a set of subsets of polynomials that

1.  $\underset{i \in I}{\cup} \left(k^n \backslash V(\mathcal{F}_i)\right) = k^n \backslash V(\mathcal{F}_\cup)$ for some $\mathcal{F}_\cup \subset k[X_1, \cdots, X_n]$;

1. if $I$ is [[finite set|finite]] then $\underset{i \in I}{\cap} \left( k^n \backslash V(\mathcal{F}_{\cap})\right) = k^n \backslash \mathcal{F}_\cap$ for some $\mathcal{F}_{\cap} \subset k[X_1, \cdots, X_n]$.

By [[de Morgan's law]] for [[complements]] (and using [[excluded middle]]) this is equivalent to

1.  $\underset{i \in I}{\cap} V(\mathcal{F}_i) = V(\mathcal{F}_\cup)$ for some $\mathcal{F}_\cup \subset k[X_1, \cdots, X_n]$;

1. if $I$ is [[finite set|finite]] then $\underset{i \in I}{\cup} V(\mathcal{F}_i) =  V(\mathcal{F}_{\cap})$ for some $\mathcal{F}_{\cap} \subset k[X_1, \cdots, X_n]$.

We claim that we may take

1. $\mathcal{F}_\cup = \underset{i \in I}{\cup} \mathcal{F}_i$

1. $\mathcal{F}_{\cap} = \underset{i \in I}{\prod} \mathcal{F}_i \coloneqq \left\{ \underset{i \in I}{\prod} f_i \,\vert\, f_i \in \mathcal{F}_i \right\}$.

(In the second line we have the set of all those polynomials which arise as products of polynomials with one factor from each of the $\mathcal{F}_i$.)

Regarding the first point:

$$
  \begin{aligned}
    & (a_1, \cdots, a_n) \in \underset{i \in I}{\cap} V(\mathcal{F}_i)
    \\
    \Leftrightarrow\;
     &
     \underset{i \in I}{\forall}
     \left(
        (a_1, \cdots, a_n) \in V(\mathcal{F}_i)
     \right)
     \\
     \Leftrightarrow\;
    &
     \underset{i \in I}{\forall}
     \left(
       \underset{f \in \mathcal{F}_i}{\forall}
       \left(
         f(a_1, \cdots, a_n) = 0
       \right)
     \right)
    \\
    \Leftrightarrow\;
    &
    \underset{f \in \underset{i \in I}{\cup} \mathcal{F}_i}{\forall}
    \left(
       f(a_1, \cdots, a_n) = 0
    \right)
    \\
    \Leftrightarrow\;
    &
    (a_1, \cdots, a_n)
    \in
    V\left(
      \underset{i \in I}{\cup} \mathcal{F}_i
    \right)
  \end{aligned}
$$

Regarding the second point, in one direction we have the immediate implication

$$
  \begin{aligned}
    &
    (a_1, \cdots, a_n) \in \underset{i \in I}{\cup} V(\mathcal{F}_i)
    \\
    \Leftrightarrow\;
    &
    \underset{i \in I}{\exists}
      \left(
      \underset{f \in \mathcal{F}_i}{\forall}
      \left(
        f(a_1, \cdots, a_n) = 0
      \right)
    \right)
    \\
    \Rightarrow \;
    &
    \underset{(f_i) \in \underset{i \in I}{\prod} \mathcal{F}_i}{\forall}
    \left(
      \underset{i \in I}{\prod} f_i(a_1, \cdots, a_n) = 0
    \right)
    \\
    \Leftrightarrow\;
    &
    (a_1, \cdots, a_n)
    \in
    V\left(
      \underset{i \in I}{\prod} \mathcal{F}_i
    \right)
    \,.
  \end{aligned}
$$

For the converse direction we need to show that

$$
  \left(
    (a_1 , \cdots , a_n)
    \in
      V\left(
        \underset{i \in I}{\prod} \mathcal{F}_i
      \right)
   \right)
     \;\Rightarrow\;
   \left(
     (a_1, \cdots, a_n)
     \in
     \underset{i \in I}{\cup} V(\mathcal{F}_1)
   \right)
  \,.
$$

hence that

$$
  \left(
    \underset{(f_i) \in \underset{i \in I}{\prod} \mathcal{F}_i }{\forall}
    \left(
      \underset{i \in I}{\prod} f_i(a_1, \cdots, a_n) = 0
    \right)
  \right)
  \;\Rightarrow\;
  \left(
    \underset{i \in I}{\exists}
    \left(
      \underset{f_i \in \mathcal{F}_i}{\forall}
      \left(
         f_i(a_1, \cdots, a_n) = 0
      \right)
    \right)
  \right)
  \,.
$$

By [[excluded middle]], this is equivalent to its [[contraposition]], which by [[de Morgan's law]] is

$$
  \left(
    \underset{i \in I}{\forall}
    \left(
      \underset{f_i \in \mathcal{F}_i}{\exists}
      \left(
         f_i(a_1, \cdots, a_n) \neq 0
      \right)
    \right)
  \right)
  \;\Rightarrow\;
  \left(
    \underset{(f_i) \in \underset{i \in I}{\prod} \mathcal{F}_i }{\exists}
    \left(
      \underset{i \in I}{\prod} f_i(a_1, \cdots, a_n) \neq 0
    \right)
  \right)
  \,.
$$

This now is true by the assumption that $k$ is a [[field]]: If all factors $f_i(a_1, \dots a_n) \in k$ are non-zero, then their product $\underset{i \in I}{\prod} f_i(a_1, \cdots, a_n) \in k$ is non-zero.

=--


### Properties

#### Topological closures

+-- {: .num_prop}
###### Proposition

For $k$ a [[field]] and $n \in \mathbb{N}$, consider a [[subset]]

$$
  S \subset k^n
$$

of the underlying set of the $n$-fold [[Cartesian product]] of $k$ with itself. Then the [[topological closure]] $Cl(S)$ of this subset with respect to the Zariski topology $\tau_{\mathbb{A}^n_k}$ (def. \ref{ZariskiOpenSubsetsOnAffineSpace}) is the vanishing set of all those polynomials that vanish on $S$:

$$
  Cl(S)
  \;=\;
  \left\{
    f \in k[X_1, \cdots, X_n]
    \,\vert\,
    \underset{(a_1, \cdots, a_n) \in S}{\forall} f(a_1, \cdots, a_n) = 0
  \right\}
  \,.
$$

=--

+-- {: .proof}
###### Proof

We compute as follows:

$$
  \begin{aligned}
    Cl(S)
     & \coloneqq
    \underset{ {C \subset k^n \, \text{closed}} \atop {C \supset S} }{\cap}
    C
    \\
    & =
    \underset{
       { \mathcal{F} \subset k[X_1, \cdots, X_n] }
       \atop
       { S \subset V(\mathcal{F}) }
    }{\cap} V(\mathcal{F})
    \\
    & =
    V\left(
      \underset{
         { \mathcal{F} \subset k[X_1, \cdots, X_n] }
         \atop
         { S \subset V(\mathcal{F}) }
      }{\cup} \mathcal{F}
      \right)
    \\
    & =
    V \left(
      \left\{
        f \in k[X_1, \cdots, X_n]
        \,\vert\,
        \underset{(a_1, \cdots, a_n) \in S}{\forall} f(a_1, \cdots, a_n) = 0
      \right\}
    \right)
    \,.
  \end{aligned}
$$

Here the first equality is the definition of [[topological closure]], the second is the definition of closed subsets in the Zariski topology (def. \ref{ZariskiOpenSubsetsOnAffineSpace}), the third is the expression of intersections of these in terms of unions of polynomials as in the proof of prop. \ref{VerifyingZariskiTopologyOnAffineSpace}, and then the last one is immediate.

=--

#### Irreducible closed subsets as prime ideals

In every [[topological space]] the [[irreducible closed subsets]] play a special role, as being precisely the points in the space as seen in its incarnation as a [[locale]] ([this prop.](irreducible%20closed%20subspace#FrameHomomorphismsToPointAreIrrClSub)). The following shows that in the Zariski topology the irreducible closed subsets all come from [[prime ideals]] in the corresponding [[polynomial ring]], and that when the [[ground field]] is [[algebraically closed field|algebraically closed]], then they are in fact in bijection to the prime ideals. See also at _[[schemes are sober]]_.


+-- {: .num_defn #VanishingIdeal}
###### Definition
**([[vanishing ideal]] of Zariski closed subset)**#

Let $k$ be a [[field]], and let $n \in \mathbb{N}$. Then for $V(\mathcal{F}) \subset k^n$ a Zariski closed subset, according to def. \ref{ZariskiOpenSubsetsOnAffineSpace}, hence for $\mathcal{F} \subset k[X_1, \cdots, X_n]$ a set of polynomials, write

$$
  I(V(\mathcal{F}))
  \subset
  k[X_1, \cdots, X_n]
$$

for the maximal subset of polynomials that still has the same joint vanishing set:

$$
  I(V(\mathcal{F}))
    \;\coloneqq\;
  \left\{
    f \in k[X_1, \cdots, X_n]
    \,\vert\,
    \underset{(a_1, \cdots, a_n) \in V(\mathcal{F})}{\forall} f(a_1, \cdots, a_n) = 0
  \right\}
  \,.
$$

This set is clearly an [[ideal]] in the [[polynomial]] [[ring]]  $k[X_1, \cdots, X_n]$, called the _[[vanishing ideal]]_ of $V(\mathcal{F})$.

=--

+-- {: .num_prop #PrimeVanishingIdealOfIrreducibleZariskiClosed}
###### Proposition

With [[excluded middle]] then:

Let $k$ be a [[field]], let $n \in \mathbb{N}$, and let $V(\mathcal{F}) \subset k^n$ be a Zariski closed subset (def. \ref{ZariskiOpenSubsetsOnAffineSpace}). Then the following are equivalent:

1. $V(\mathcal{F})$ is an [[irreducible closed subset]];

1. The [[vanishing ideal]] $I(V(\mathcal{F}))$ (def. \ref{VanishingIdeal}) is a [[prime ideal]].

=--

+-- {: .proof}
###### Proof

In one direction, assume that $V(\mathcal{F})$ is irreducible and consider $f,g \in k[X_1, \cdots, X_n]$ with $f \cdot g \in I(V(\mathcal{F}))$. We need to show that then already $f \in I(V(\mathcal{F}))$ or $g \in I(V(\mathcal{F}))$.

Now since $k$ is a field, we have

$$
  \left(
    f(a_1, \cdots a_n) \cdot g(a_1, \cdots, a_n) = 0
  \right)
  \Rightarrow
  \left(
    \left(
      f(a_1, \cdots, a_n) = 0
      \,\text{or}\,
      g(a_1, \cdots, a_n) = 0
    \right)
  \right)
  \,.
$$

This implies that

$$
  V(\mathcal{F}) \subset V(\{f\}) \cup V(\{g\})
$$

and hence that

$$
  V(\mathcal{F})
   =
  (V(\mathcal{F}) \cap F(\{f\}))
  \,\,\cup\,\,
  (V(\mathcal{F}) \cap F(\{g\}) )
  \,.
$$

But since $V(\{f\})$, $V(\{g\})$ and  $V(\mathcal{F})$ are all closed, by construction, their intersections are closed and hence this is a decomposition of $V(\mathcal{F})$ as a union of closed subsets. Therefore now the assumption that $V(\mathcal{F})$ is [[irreducible closed subset|irreducible]] implies that

$$
  \begin{aligned}
    &
    \left(
      \,
      V(\mathcal{F}) = V(\mathcal{F}) \cap V(\{f\})
      \,
    \right)
    \,\text{or}\,
    \left(
      \,
      V(\mathcal{F}) = V(\mathcal{F}) \cap V(\{g\})
      \,
    \right)
    \\
    \Leftrightarrow \;
    &
    \left(
       \left(
         \,
         V(\mathcal{F}) \subset V(\{f\})
         \,
       \right)
       \,\text{or}\,
       \left(
         \,
         V(\mathcal{F}) \subset V(\{g\})
         \,
       \right)
    \right)
    \\
    \Leftrightarrow \,
    &
    \left(
      \left(
        \,
        f \in I(X)
        \,
      \right)
      \,\text{or}\,
      \left(
        \,
        g \in I(X)
        \,
      \right)
    \right)
  \end{aligned}
  \,.
$$

Now for the converse, assume that $I(V(\mathcal{F}))$ is a prime ideal, and that $V(\mathcal{F}) = V(\mathcal{F}_1) \cup V(\mathcal{F}_2)$. We need to show that $V(\mathcal{F})  = V(\mathcal{F}_1)$ or that $V(\mathcal{F}) = V(\mathcal{F}_2)$.

Assume on the contrary, that there existed elements

$$
  (a_1, \cdots, a_n) \in V(\mathcal{F}_1) \backslash V(\mathcal{F}_2)
  \;\text{and}\;
  (b_1, \cdots, b_n) \in V(\mathcal{F}_2) \backslash V(\mathcal{F}_1)
  \,
$$

Then in particular the vanishing ideals would not contain each other

$$
  \not\left(
     I(V(\mathcal{F}_1))
     \subset
     I(V(\mathcal{F}_2))
  \right)
  \,\,\,\text{and}\,\,\,
  \not\left(
     I(V(\mathcal{F}_2))
     \subset
     I(V(\mathcal{F}_1))
  \right)
$$

and hence there were polynomials

$$
  f\in I(V(\mathcal{F}_1)) \backslash I(V(\mathcal{F}_2))
  \,\,\,\text{and}\,\,\,
  g \in I(V(\mathcal{F}_2)) \backslash I(V(\mathcal{F}_1))
  \,.
$$

But since a product of polynomials vanishes at some point once one of the factors vanishes at that point, it would follows that

$$
  f \cdot g \in I(V(\mathcal{F}_1)) \cap I(V(\mathcal{F}_2)) = I(V(\mathcal{F}))
  \,,
$$

which were in contradiction to the assumption that $I(V(\mathcal{F}))$ is a prime ideal. Hence we have a [[proof by contradiction]].


=--

Proposition \ref{PrimeVanishingIdealOfIrreducibleZariskiClosed} gives an [[injection]]


$$
  \left\{
    \array{
      \text{irreducible Zariski closed}
      \\
      V(\mathcal{F}) \subset k^n
    }
  \right\}
  \overset{\phantom{AAA}}{\hookrightarrow}
  \left\{
    \array{
      \text{prime ideals}
      \\
      I \in k[X_1, \cdots, X_n]
    }
  \right\}
  \,.
$$

The following says that for [[algebraically closed fields]] then this is in fact a [[bijection]]:

+-- {: .num_prop #PrimeIdealClosedsubspaceBijection}
###### Proposition

Let $k = \overline{k}$ be an [[algebraically closed field]] and  let $n \in \mathbb{N}$. Then the function

$$
  \array{
    IrrClSub(\mathbb{A}^n_k)
      &\overset{}{\longrightarrow}&
    PrimeIdl(k[X_1, \cdots, X_n])
    \\
    V(\mathcal{F})
      &\overset{\phantom{AAA}}{\mapsto}&
    I(V(\mathcal{F}))
  }
$$

from prop. \ref{PrimeVanishingIdealOfIrreducibleZariskiClosed} is a [[bijection]].

=--

The **proof** uses [[Hilbert's Nullstellensatz]].


+-- {: .num_remark}
###### Remark
**(generalization to affine varieties)**

Prop \ref{ZariskiClosedSubsetsInSpecR} suggests to consider the set of [[prime ideals]] of a [[polynomial ring]] $k[X_1, \cdots, X_n]$ for general $k$ as more fundamental, in some sense, than the set $k^n$. Morover, the set of prime ideals makes sense for every [[commutative ring]] $R$, not just $R = k[X_1, \cdots, X_n]$, and hence this suggests to consider a Zariski topology on  sets of prime ideals. This leads to the more general concept of Zariski topologies for [[affine varieties]], def. \ref{ZariskiClosedSubsetsInSpecR} below.

=--


### Examples

+-- {: .num_example #AffineSpaceOverInfiniteFieldNotHausdorff}
###### Example

If the [[field]] $k$ is _not_ a [[finite field]], then the
Zariski topology on the [[affine space]] (def. \ref{ZariskiOpenSubsetsOnAffineSpace}) is _not_ [[Hausdorff topological space|Hausdorff]].

This is because the solution set to a system of [[polynomials]] over an infinite polynomial is always a [[finite set]]. This means that in this case all the Zariski closed subsets $V(\mathcal{F})$ are [[finite sets]]. This in turn implies that the [[intersection]] of _every_ pair of [[inhabited set|non-empty]] Zariski open subsets is [[inhabited|non-empty]].

But the Zariski topology is always [[sober topological space|sober]], see prop. \ref{ZariskiTopologyIsSober} below.

=--


## On affine varieties
 {#OnAffineVarieties}


### Definition


+-- {: .num_defn #ZariskiClosedSubsetsInSpecR}
###### Definition
**(Zariski topology on set of prime ideals)**

Let $R$ be a [[commutative ring]]. Write $PrimeIdl(R)$ for its set of [[prime ideals]]. For $\mathcal{F} \subset R$ any subset of elements of the ring, consider the subsets of those prime ideals that contain $\mathcal{F}$:

$$
  V(\mathcal{F})
   \;\coloneqq\;
  \left\{
    p \in PrimeIdl(R) \,\vert\, \mathcal{F} \subset p
  \right\}
  \,.
$$

These are called the _Zariski [[closed subsets]]_ of $PrimeIdl(R)$. Their [[complements]] are called the _Zariski open subsets_.


=--

+-- {: .num_prop #WellDefinedZariskiTopologyOnSpecR}
###### Proposition
**(Zariski topology well defined)**

Assuming [[excluded middle]], then:

Let $R$ be a [[commutative ring]]. Then the collection of Zariski open subsets (def. \ref{ZariskiClosedSubsetsInSpecR}) in its set of [[prime ideals]]

$$
  \tau_{Spec(R)} \subset P(PrimeIdl(R))
$$

satisfies the axioms of a [[topological space|topology]], the _Zariski topology_.

This [[topological space]]

$$
  Spec(R) \coloneqq (PrimeIdl(R), \tau_{Spec(R)})
$$

is called (the space underlying) the _[[prime spectrum of a commutative ring|prime spectrum of the commutative ring]]_.

=--

+-- {: .proof #WellDefinedZariskiTopologyOnSpecRProof}
###### Proof

For $\mathcal{F} \subset R$ write $I(\mathcal{F}) \subset \mathcal{F}$ for the [[ideal]] which is generated by $\mathcal{F}$. Evidently the Zariski closed subsets depend only on this ideal

$$
  V(I(\mathcal{F})) = V(\mathcal{F})
$$

and therefore it is sufficient to consider the $V(\mathcal{F})$ for the case that $\mathcal{F} \subset R$  is not just a subset, but an ideal.

So let $\{F_i \in Idl(R)\}_{i \in I}$ be a set of ideals in $R$ and let $\{V(\mathcal{F}_i) \subset PrimeIdl(R)\}_{i \in I}$ be the corresponding set of Zariski closed subsets. We need to show that there exists $\mathcal{F}_\cup, \mathcal{F}_\cap \subset R$ such that

1. $\underset{i \in I}{\cap} V(\mathcal{F}_i) = V(\mathcal{F}_\cup)$;

1. if $I$ is [[finite set]] then $\underset{i \in I}{\cup} V(\mathcal{F}_i) = V(\mathcal{F}_\cap)$.

We claim that

* $\mathcal{F}_{\cup} = \underset{i \in I}{\sum} \mathcal{F}_i \coloneqq \left\{ \underset{i \in I}{\sum} f_i  \,, \in R\;\vert\; f_i \in \mathcal{F}_i \right\}$

* $\mathcal{F}_{\cap} = \underset{i \in I}{\prod} \mathcal{F}_i \coloneqq \left\{ \underset{i \in I}{\prod} f_i \, \in R \;\vert\; f_i \in \mathcal{F}_i \right\}$,


Regarding the first point:

By using the various definitions, we get the following chain of logical equivalences:

$$
  \begin{aligned}
    & p \in \underset{i \in I}{\cap} V(\mathcal{F}_i)
    \\
    \Leftrightarrow\;
    &
    \underset{i \in I}{\forall}
    \left(
      p \in V(\mathcal{F}_i)
    \right)
    \\
    \Leftrightarrow\;
    &
    \underset{i \in I}{\forall}
    \left(
      \mathcal{F}_i \subset p
    \right)
    \\
    \Leftrightarrow\;
    &
    \left(\underset{i \in I}{\sum} \mathcal{F}_i\right)
    \subset p
    \\
    \Leftrightarrow\;
    &
    p \in V\left(
      \underset{i \in I}{\sum} \mathcal{F}_i
    \right)
    \,.
  \end{aligned}
$$



Regarding the second point, in one direction we have the immediate implication

$$
  \begin{aligned}
    &
    p \in \underset{i \in I}{\cup} V(\mathcal{F}_i)
    \\
    \Leftrightarrow\;
    &
    \underset{i \in I}{\exists}
    \left(
      \mathcal{F}_i \subset p
    \right)
    \\
    \Rightarrow \;
    &
    \underset{(f_i) \in \underset{i \in I}{\prod} \mathcal{F}_i}{\forall}
    \left(
      \underset{i \in I}{\prod} f_i \in p
    \right)
    \\
    \Leftrightarrow\;
    &
    p
    \in
    V\left(
      \underset{i \in I}{\prod} \mathcal{F}_i
    \right)
    \,.
  \end{aligned}
$$

For the converse direction we need to show that

$$
  \left(
    p
    \in
      V\left(
        \underset{i \in I}{\prod} \mathcal{F}_i
      \right)
   \right)
     \;\Rightarrow\;
   \left(
     p
     \in
     \underset{i \in I}{\cup} V(\mathcal{F}_1)
   \right)
  \,.
$$

hence that

$$
  \left(
    \underset{(f_i) \in \underset{i \in I}{\prod} \mathcal{F}_i }{\forall}
    \left(
      \underset{i \in I}{\prod} f_i \in p
    \right)
  \right)
  \;\Rightarrow\;
  \left(
    \underset{i \in I}{\exists}
    \left(
      \underset{f_i \in \mathcal{F}_i}{\forall}
      \left(
         f_i \in p
      \right)
    \right)
  \right)
  \,.
$$

By [[excluded middle]], this is equivalent to its [[contraposition]], which by [[de Morgan's law]] is

$$
  \left(
    \underset{i \in I}{\forall}
    \left(
      \underset{f_i \in \mathcal{F}_i}{\exists}
      \not
      \left(
         f_i \in p
      \right)
    \right)
  \right)
  \;\Rightarrow\;
  \left(
    \underset{(f_i) \in \underset{i \in I}{\prod} \mathcal{F}_i }{\exists}
    \not
    \left(
      \underset{i \in I}{\prod} f_i \in p
    \right)
  \right)is
  \,.
$$


This holds by the assumption that $p$ is a [[prime ideal]].


=--

### Properties
  {#PropertiesOnAffineVarieties}

We discuss some properties of the Zariski topology on [[prime spectra of commutative rings]].

#### Topological closures

+-- {: .num_lemma #ZariskiClorsuredOfPont}
###### Lemma
**([[topological closure]] of points)**

Let $R$ be a [[commutative ring]] and consider $Spec(R) = (PrimeIdl(R), \tau_{Spec(R)})$ its [[prime spectrum of a commutative ring|prime spectrum]] equipped with the Zariski topology (def. \ref{ZariskiClosedSubsetsInSpecR}).

Then the [[topological closure]] of a point $p \in PrimeIdl(R)$ is $V(p) \subset PrimeIdl(R)$ (def. \ref{ZariskiClosedSubsetsInSpecR}).

=--

+-- {: .proof}
###### Proof

By definition the topological closure of $\{p\}$ is

$$
  Cl(\{p\}) \underset{ {I \in Idl(R) } \atop { p \in V(I) }  }{\cap} V(I)
  \,.
$$

Hence unwinding the definitions, we have the following sequence of logical equivalences:

$$
  \begin{aligned}
    & q \in Cl(\{q\})
    \\
    \Leftrightarrow\; &
    q \in
    \underset{ {I \in Idl(R)} \atop { p \in V(I) }   }{\cap} V(I)
    \\
    \Leftrightarrow\;
    &
    \underset{ { I \in Idl(R) } \atop { I \subset p } }{\forall} (q \in V(I))
    \\
    \Leftrightarrow\;
    &
    \underset{ { I \in Idl(R) } \atop { I \subset p } }{\forall} (I \subset q)
    \\
    \Leftrightarrow\;
    &
    p \subset q
    \\
    \Leftrightarrow\;
     &
    q \in V(p)
  \end{aligned}
$$

=--

Recall:

+-- {: .num_lemma #PrimeIdealTheorem}
###### Lemma
**([[prime ideal theorem]])

Assuming the [[axiom of choice]] or at least the [[ultrafilter principle]] then:

For $R$ a [[commutative ring]] and $I \subset R$ a [[proper ideal]], then $I$ is contained in some [[prime ideal]].

=--

The [[axiom of choice]] even implies that every proper ideal is contained in a [[maximal ideal]] (by [this prop.](maximal+ideal#EveryProperIdealisContainedInAMaximalOne)).



+-- {: .num_prop #MaximalIdealsAreClosedPoints}
###### Proposition
**([[maximal ideals]] are [[closed points]])


Let $R$ be a [[commutative ring]], consider the [[topological space]] $Spec(R) = (PrimeIdl(R),\tau_{Spec(R)})$, i.e. its [[prime spectrum of a commutative ring|prime spectrum]] equipped with the Zariski topology from def. \ref{ZariskiClosedSubsetsInSpecR}.

Then the [[maximal ideals]] inside the prime ideals constitute [[closed points]].

Assuming the [[axiom of choice]] or at least the [[ultrafilter principle]] then also the converse is true:

Then the inclusion of [[maximal ideals]] $\mathfrak{m} \in MaxIdl(R) \subset PrimeIdl(R)$ into all [[prime ideals]] is precisely the inclusion of the subset of [[closed points]] into all points of $Spec(R)$.

$$
  ClosedPoints(Spec(R)) \simeq MaxIdl(R) \subset PrimeIdl(R)
  \,.
$$

=--

+-- {: .proof}
###### Proof

By lemma \ref{ZariskiClorsuredOfPont} we have

$$
  Cl(\{p\}) = V(p)
$$

and hence we need to show that

$$
  \mathfrak{m} = V(\mathfrak{m})
$$

precisely if $\mathfrak{m}$ is maximal.

In one direction, assume that $\mathfrak{m}$ is maximal. By definition $V(\mathfrak{m})$ contains all the prime ideals $p$ such that $\mathfrak{m} \subset p$. That $\mathfrak{m}$ is maximal means that it is not contained in a larger proper ideal, in particular not in any larger prime ideal, and hence $V(\mathfrak{m}) = \{\mathfrak{m}\}$.

In the other direction, assume that $\mathfrak{m}$ is a prime ideal such that $V(\mathfrak{m}) = \{\mathfrak{m}\}$. By definition this means equivalently that the only prime ideal $p$ with $\mathfrak{m} \subset p$ is $\mathfrak{m}$ itself. We need to show that more generally $\mathfrak{m} \subset I$ for $I$ any [[proper ideal]] implies that $\mathfrak{m} = I$.

But the [[axiom of choice]]/[[ultrafilter principle]] imply the [[prime ideal theorem]] (lemma \ref{PrimeIdealTheorem}), which says that there is a prime ideal $p$ with $I \subset p$, hence a sequence of inclusions $\mathfrak{m} \subset I \subset p$. This implies $\mathfrak{m} \subset p$, hence $\mathfrak{m} = p$, hence $I = \mathfrak{m}$.


=--



#### Irreducible closed subsets as prime ideals


+-- {: .num_prop #ZariskiIrreducibleClosedSubsetsArePreciselyPrimeIdeals}
###### Proposition
**([[irreducible closed subsets]] correspond to [[prime ideals]])**

With [[excluded middle]] then:

Let $R$ be a [[commutative ring]], and let $\mathcal{F} \subset R$ be an ideal in $R$, hence $V(\mathcal{F}) \subset Spec(R)$ be a Zariski closed subset in the [[prime spectrum of a commutative ring|prime spectrum]] of $R$. Then the following are equivalent:

1. $V(\mathcal{F})$ is an [[irreducible closed subset]];

1. $\mathcal{F}$ is a [[prime ideal]].

=--

+-- {: .proof}
###### Proof

In one direction, assume that $V(\mathcal{F})$ is irreducible, and that $f,g \in R$ with $f \cdot g \in \mathcal{F}$. We need to show that then already $f \in \mathcal{F}$ or $g \in \mathcal{F}$.

To this end, first observe that

$$
  V(\mathcal{F}) \subset V((f)) \cup V((g))
  \,.
$$

This is because

$$
  \begin{aligned}
    & p \in V(\mathcal{F})
    \\
    \Leftrightarrow\;
    &
    \mathcal{F} \subset p
    \\
    \Rightarrow \;
    &
    f \cdot g \in p
    \\
    \Rightarrow\;
    &
    \left(
      f \in p
    \right)
    \,\text{or}\,
    \left(
      g \in p
    \right)
    \\
    \Leftrightarrow\;
    &
    \left(
      p \in V(g)
    \right)
    \,\text{or}\,
    \left(
      p \in V(f)
    \right)
    \\
    \Leftrightarrow\;
    &
    p \in V(f) \cup V(g)
    \,,
  \end{aligned}
$$

where the implication in the middle uses that $p$ is a prime ideal.

It follows that

$$
  V(\mathcal{F})
  \;=\;
  \left(
    V(f) \cap V(\mathcal{F})
  \right)
   \cup
  \left(
    V(g) \cap V(\mathcal{F})
  \right)
  \,.
$$

This is a decomposition of $V(\mathcal{F})$ as a union of closed subsets,
hence the assumption that $V(\mathcal{F})$ is irreducible implies that

$$
  \begin{aligned}
     &
     \left(
       V(\mathcal{F}) = V(f) \cap V(\mathcal{F})
     \right)
     \,\text{or}\,
     \left(
        V(\mathcal{F}) = V(g) \cap V(\mathcal{F})
     \right)
     \\
     \Leftrightarrow
     &
     \left(
        V(\mathcal{F})
        \subset
        V(f)
     \right)
     \,\text{or}\,
     \left(
       V(\mathcal{F}) \subset V(g)
     \right)
     \\
     \Leftrightarrow\,
     &
     \left(
         f \in \mathcal{F}
     \right)
     \,\text{or}\,
     \left(
        g \in \mathcal{F}
     \right)
     \,.
  \end{aligned}
$$


Now for the converse. Assume that $\mathcal{F}$ is a prime ideal and that $V(\mathcal{F}) = V(\mathcal{F}_1) \cup V(\mathcal{F}_2)$. Observe (as in the [proof](#WellDefinedZariskiTopologyOnSpecRProof) of prop. \ref{WellDefinedZariskiTopologyOnSpecR}) that this means equivalently that $\mathcal{F} = \mathcal{F}_1 \cdot \mathcal{F}_2$.
We need to show
that then $V(\mathcal{F}) = V(\mathcal{F}_1)$ or that $V(\mathcal{F} = V(\mathcal{F}_2))$.

Suppose on the contrary that neither $\mathcal{F}_1$ nor $\mathcal{F}_2$ coincided with $\mathcal{F}$. This means that there were elements $f \in \mathcal{F}_1 \backslash \mathcal{F}$ and $g \in \mathcal{F}_2 \backslash \mathcal{F}$ such that still $f \cdot g \in \mathcal{F}$, in contradiction to the assumption. Hence we have a [[proof by contradiction]].

=--

As a corollary:

+-- {: .num_prop #ZariskiTopologyIsSober}
###### Proposition
**([[schemes are sober|Zariski topology on prime spectra is sober]])**

With [[excluded middle]] and [[axiom of choice]] (or at least the [[ultrafilter principle]]) then:

Let $R$ be a [[commutative ring]]. Then $Spec(R)$ (its [[prime spectrum of a commutative ring|prime spectr]] equipped with the Zariski topology of def. \ref{ZariskiClosedSubsetsInSpecR}) is a [[sober topological space]].

=--

+-- {: .proof}
###### Proof

We need to show that the function

$$
  Cl(\{-\})
   \;\colon\;
  PrimeIdl(R)
    \longrightarrow
  IrrClSub(Spec(R))
$$

which sends a point to its topological closure, is a [[bijection]].

By lemma \ref{ZariskiClorsuredOfPont} this function is given by sending a [[prime ideal]] $p \in PrimeIdl(R)$ to the Zariski closed subset $V(p)$. That this is a bijection is the statement of prop. \ref{ZariskiIrreducibleClosedSubsetsArePreciselyPrimeIdeals}.


=--




### Examples

+-- {: .num_example #AffinSpaceAsPrimeSpectrum}
###### Example
**(affine space as prime spectrum)**

Reconsider the case where $R = k[X_1,\cdots, X_n]$
is a [[polynomial ring]], for $k$ a [[field]], as in the discussion of the naive affine space $k^n$
[above](#OnAffineSpace).

Observe that, by \ref{MaximalIdealsAreClosedPoints}, the [[closed points]] in the [[prime spectrum of a commutative ring|prime spectrum]] $Spec(k[X_1, \cdots, X_n])$ correspond to the [[maximal ideals]] in the [[polynomial ring]]. These are of the form

$$
  (a_1, \cdots, a_n)
  \coloneqq
  \left(
   (X_1 - a_1) \cdot (X_2 - a_2) \cdots (X_n - a_n)
  \right)
$$

and hence are in bijection with the points of the naive affine space

$$
  k^n \simeq MaxIdl(k[X_1, \cdots, X_n])
  \,.
$$

There is however also [[prime ideals]] in $k[X_1, \cdots, X_n]$ which are not maximal. In particular there is the 0-ideal $(0)$.

=--

+-- {: .num_prop #SpecZ}
###### Proposition
**([[Spec(Z)]])**

Let $R = \mathbb{Z}$ be the [[commutative ring]] of [[integers]]. Consider the corresponding Zariski [[prime spectrum of a commutative ring|prime spectrum]] (prop. \ref{WellDefinedZariskiTopologyOnSpecR}) $Spec(\mathbb{Z})$.

The [[prime ideals]] of the ring of integers are

1. the ideals $(p)$ generated by [[prime numbers]] $p$ (this special case is what motivates the terminology "prime ideal");

1. the ideal $(0) = \{0\}$.

$$
  PrimeIdl(\mathbb{Z})
  =
  \left\{
    0, \; 2, 3, 5, 7, 11, \cdots
  \right\}
  \,.
$$

All the prime ideals $p \geq 2$ are [[maximal ideals]]. Hence by prop. \ref{MaximalIdealsAreClosedPoints} these are [[closed points]] of $Spec(\mathbb{Z})$.

Only the prime ideal $(0)$ is not maximal, hence the point $(0)$ is not closed.
Its closure is the entire space

$$
  Cl(\{0\}) = Spec(\mathbb{Z})
  \,.
$$

To see this, notice that in fact $Spec(\mathbb{Z})$ is the only closed subset containing the point $(0)$. This is because

$$
  \begin{aligned}
    & (0) \in V(I)
    \\
    \Leftrightarrow\;
    &
    I \subset (0)
    \\
    \Leftrightarrow\;
    &
    I = (0)
  \end{aligned}
$$

and $V(0) = Spec(\mathbb{Z})$, because

$$
  (p \in V(0))
  \Leftrightarrow
  (0 \subset p)
  \Leftrightarrow
  true
  \,.
$$


=--

## In terms of Galois connections
 {#InTermsOfGaloisConnections}


We now discuss how all of the above constructions and statements, and a bit more, follows immediately as a special case of the general theory of what is called _[[Galois connections]]_ or _[[adjoint functors]] between [[posets]]_.

### Background on Galois connections
 {#BackgroundOnGaloisConnections}



+-- {: .num_defn #GaloisConnection}
###### Definition
**([[Galois connection]] induced from a [[relation]])**

Consider two [[sets]] $X,Y \in Set$ and a [[relation]]

$$
  E \hookrightarrow X \times Y
  \,.
$$

Define two [[functions]] between their [[power sets]] $P(X), P(Y)$, as follows.
(In the following we write $E(x, y)$ to abbreviate the formula $(x, y) \in E$.)


1. Define

   $$
     V_E
       \;\colon\;
     P(X)
       \longrightarrow
     P(Y)
   $$

   by

   $$
     V_E(S)
       \coloneqq
     \left\{
       y \in Y \vert  \underset{x \in  X}{\forall} \left( \left(x \in S\right) \Rightarrow E(x, y)
    \right) \right\}
   $$

1. Define

   $$
     I_E
       \;\colon\;
     P(Y)
       \longrightarrow
     P(X)
   $$

   by

   $$
     I_E(T) \coloneqq \left\{x \in X \vert \underset{y \in Y}{\forall} \left( \left(y \in T \right) \Rightarrow E(x, y)  \right)\right\}
   $$

=--

+-- {: .num_prop #GaloisConnectionAsAdjunction}
###### Proposition

The construction in def. \ref{GaloisConnection} has the following properties:

1. $V_E$ and $I_E$ are [[contravariant functor|contravariant]] order-preserving in that

   1. if $S \subset S'$, then $V_E(S') \subset V_E(S)$;

   1. if $T \subset T'$, then $I_E(T') \subset I_E(T)$


1. The _[[adjunction]] law_ holds:
   $
     \left(
        T \subset V_E(S)
     \right)
       \,\Rightarrow\,
     \left(
       S \subset I_E(T)
     \right)
   $

   which we denote by writing

   $$
     P(X)
       \underoverset{\underset{V_E}{\longrightarrow}}{\overset{I_E}{\longleftarrow}}{\bot}
     P(Y)^{op}
   $$

1. both $V_E$ as well as $I_E$ take [[unions]] to [[intersections]].

=--

+-- {: .proof}
###### Proof

Regarding the first point: the larger $S$ is, the more conditions that are placed on $y$ in order to belong to $V_E(S)$, and so the smaller $V_E(S)$ will be.

Regarding the second point:  This is because both these conditions are equivalent to the condition $S \times T \subset E$.

Regarding the third point: Observe that in a poset such as $P(Y)$, we have that $A = B$ iff for all $C$, $C \leq A$ iff $C \leq B$ (this is the [[Yoneda lemma]] applied to posets). It follows that

$$
  \array{
    T \subset V_E(\bigcup_{i \in I} S_i) & iff & \bigcup_{i: I} S_i \subset I_E(T) \\
    & iff & \forall_{i: I} S_i \subset I_E(T) \\
    & iff & \forall_{i: I} T \subset V_E(S_i) \\
    & iff & T \subset \bigcap_{i: I} V_E(S_i)
}
$$

and we conclude $V_E(\bigcup_{i: I} S_i) = \bigcap_{i: I} V_E(S_i)$ by the [[Yoneda lemma]].


=--


+-- {: .num_prop #GaloisClosureOperator}
###### Proposition
**([[closure operators]] from [[Galois connection]])**

Given a [[Galois connection]] as in def. \ref{GaloisConnection}, consider the [[composition|composites]]

$$
  I_E \circ V_E \;\colon\; P(X) \longrightarrow P(X)
$$

and

$$
  V_E \circ I_E \;\colon\; P(Y) \longrightarrow P(Y)
  \,.
$$

These satisfy:

1. For all $S \in P(X)$ then  $S \subset I_E \circ V_E(S)$.

1. For all $S \in P(X)$ then $V_E \circ I_E \circ V_E (S)  =  V_E(S)

1. $I_E \circ V_E$ is [[idempotent]] and [[covariant functor|covariant]].


and

1. For all $T \in P(Y)$ then $T \subset V_E \circ I_E(T)$.

1. For all $T \in P(Y)$ then $I_E \circ V_E \circ I_E (T) = I_E(T)$.

1. $V_E \circ I_E$ is [[idempotent]] and [[covariant functor|covariant]].



This is summarized by saying that
$I_E \circ V_E$ and $V_E \circ I_E$ are _[[closure operators]]_ ([[idempotent monads]]).


=--

+-- {: .proof}
###### Proof

The first statement is immediate from the adjunction law (prop. \ref{GaloisConnectionAsAdjunction}).

Regarding the second statement:
This holds  because applied to sets $S$ of the form $I_E(T)$, we see $I_E(T) \subset I_E \circ V_E \circ I_E(T)$. But applying the contravariant map $I_E$ to the inclusion $T \subset V_E \circ I_E(T)$, we also have $I_E \circ V_E \circ I_E(T) \subset I_E(T)$.

This directly implies that the function $I_E \circ V_E$. is idempotent, hence the third statement.

The argument for $V_E \circ I_E$ is directly analogous.

=--

In view of prop. \ref{GaloisClosureOperator} we say that:

+-- {: .num_defn #GaloisClosedElements}
###### Definition
**(closed elements)**

Given a [[Galois connection]] as in def. \ref{GaloisConnection}, then

1. $S \in P(X)$ is called *closed* if $I_E \circ V_E(S) = S$;

1. the _closure_ of $S \in P(X)$ is $Cl(S) \coloneqq I_E \circ V_E(S)$

and similarly

1. $T \in P(Y)$ is called *closed* if $V_E \circ I_E(T) = T$;

1. the _closure_ of $T \in P(Y)$ is $Cl(T) \coloneqq V_E \circ I_E(T)$.

=--

It follows from the properties of [[closure operators]], hence form prop. \ref{GaloisClosureOperator}:

+-- {: .num_prop #GaloisFixedPoints}
###### Proposition
**([[fixed point of an adjunction|fixed points]] of a [[Galois connection]])**

Given a [[Galois connection]] as in def. \ref{GaloisConnection},
then

1. the closed elements of $P(X)$ are precisely those in the [[image]] $im(I_E)$ of $I_E$;

1. the closed elements of $P(Y)$ are precisely those in the [[image]] $im(V_E)$ of $V_E$.

We says these are the _[[fixed point of an adjunction|fixed points]]_ of the Galois connection. Therefore the restriction of the Galois connection

$$
  P(X)
    \underoverset{\underset{V_E}{\longrightarrow}}{\overset{I_E}{\longleftarrow}}{\bot}
  P(Y)^{op}
$$

to these fixed points yields an [[equivalence of categories|equivalence]]

$$
  im(I_E)
    \underoverset{\underset{V_E}{\longrightarrow}}{\overset{I_E}{\longleftarrow}}{\simeq}
  im(V_E)^{op}
$$

now called a _[[Galois correspondence]]_.

=--


+-- {: .num_prop}
###### Proposition

Given a [[Galois connection]] as in def. \ref{GaloisConnection}, then the sets of closed elements according to def. \ref{GaloisClosedElements} are closed under forming [[intersections]].

=--


+-- {: .proof}
###### Proof


If $\{T_i \in P(Y)\}_{i: I}$ is a collection of elements closed under the operator $K = V_E \circ I_E$, then by the first item in prop. \ref{GaloisClosureOperator} it is automatic that $\bigcap_{i: I} T_i \subset K(\bigcap_{i: I} T_i)$, so it suffices to prove the reverse inclusion. But since $\bigcap_{i: I} T_i \subset T_i$ for all $i$ and $K$ is covariant and $T_i$ is closed, we have $K(\bigcap_{i: I} T_i) \subset K(T_i) \subset T_i$ for all $i$, and $K(\bigcap_{i: I} T_i) \subset \bigcap_{i: I} T_i$ follows.

=--


### Applied to affine space
  {#GaloisConnectionAppliedToAffineSpace}

We now redo the discussion of the Zariski topology on the affine space $k^n$ from [above](#OnAffineSpace) as a special case of the general considerations of [[Galois connections]].


+-- {: .num_example #ZariskiClosedSubsetsInaffineViaGalois}
###### Example
**(Zariski closed subsets in affine space via Galois connection)**


Let $k$ be a [[field]] and let $n \in \mathbb{N}$, and write $k[X_1, \cdots, X_n]$ for the [[polynomial ring]] over $k$  in $n$ [[variables]].  Define a [[relation]]

$$
  E \hookrightarrow k[x_1, \ldots, x_n] \times k^n
$$

by

$$
  E(f, x)\coloneqq \left( f(x) = 0\right)
  \,.
$$

By def. \ref{GaloisConnection} and prop. \ref{GaloisConnectionAsAdjunction} we obtain the corresponding [[Galois connection]] of the form

$$
  P(k[X_1, \cdots, X_n])
     \underoverset{\underset{V_E}{\longrightarrow}}{\overset{I_E}{\longleftarrow}}{\bot}
  P(k^n)^{op}
$$

(where now $k[X_1, \cdots, X_n]$ and $k^n$ denote their underlying sets).

Here by def. \ref{GaloisConnection} the function

$$
  V_E \;\colon\; P(k[x_1, \ldots, x_n]) \longrightarrow P(k^n)
$$

sends a set $\mathcal{F}$ of [[polynomials]]  to its corresponding *[[variety]]*,

$$
  V_E(\mathcal{F}) = \{\vec x \in k^n \,\vert\, \forall_{f \in k[x_1, \ldots, x_n]} \; (f \in \mathcal{F}) \Rightarrow (f(x) = 0)\}
  \,.
$$

These are just the Zariski closed subsets from def. \ref{ZariskiOpenSubsetsOnAffineSpace}.

In the other direction,

$$
  I_E \;\colon\; P(k^n) \longrightarrow P(k[x_1, \ldots, x_n])
$$

sends a set of points $T \subseteq k^n$ to its corresponding *[[vanishing ideal]]*

$$
  I_E(T) = \{f \in k[x_1, \ldots, x_n] \,\vert\, \forall_{x: k^n} \; x \in T \Rightarrow f(x) = 0\}
$$

which we considered earlier in def. \ref{VanishingIdeal}.


=--

We may now use the abstract theory of Galois connections to verify that Zariski closed subsets form a [[topological space|topology]]:

+-- {: .num_prop #ZariskiTopologyOnAffineSpaceViaGaloisConnectionWellDefined}
###### Proposition
**(Zariski topology is well defined)**

Using [[excluded middle]], then:

The set of Zariski closed subsets of $k^n$ from example \ref{ZariskiClosedSubsetsInaffineViaGalois} constitutes a [[topological space|topology]] in that it is closed under

1. arbitrary intersections;

1. finite untions.

=--

+-- {: .proof}
###### Proof

Regarding the first point: From prop. \ref{GaloisConnectionAsAdjunction} we know that $V_E$ takes unions to intersections, hence that

$$
  \underset{i \in I}{\cap} V_E(\mathcal{F}_i)
  \;=\;
  V_E\left(
    \underset{i \in I}{\cup} \mathcal{F}_i
  \right)
  \,.
$$

Regarding the second point, we exploit the [[commutative ring]] structure of $k[x_1, \ldots, x_n]$. It is sufficient to show that the set of Zariski closed sets is closed under the empty union and under binary unions.

The empty union is the entire space $k^n$, which is $V(1)$ (the variety associated with the constant polynomial $1$),

Hence it only remains to see closure under binary unions.

To this end, recall from prop. \ref{GaloisClosureOperator} that we may replace $\mathcal{F}$ with the corresponding ideal

$$
  I \coloneqq I_E \circ V_E(\mathcal{F})
$$

without changing the variety:

$$
  V_E(I) = V_E(\mathcal{F})
  \,.
$$

With this it is sufficient to show that

$$
  V_E(I) \cup V_E(I') = V(I \cdot I')
$$

where $I \cdot I'$ is the ideal consisting of finite sums of elements of the form $f g$ with $f \in I$ and $g \in I'$.

We conclude by proving this statement:

Applying the contravariant operator $V_E$ to the inclusions $I \cdot I' \subseteq I$ and $I \cdot I' subseteq I'$ (which are clear since $I, I'$ are ideals), we derive $V_E(I) \subseteq V_E(I \cdot I')$ and $V_E(I') \subseteq V(I \cdot I')$, so the inclusion $V_E(I) \cup V_E(I') \subseteq V(I \cdot I')$ is automatic.

In the other direction, to prove $V(I \cdot I') \subseteq V_E(I) \cup V(I')$, suppose $x \in V(I \cdot I')$ and that $x$ *doesn't* belong to $V(I)$. Then $f(x) \neq 0$ for some $f \in I$. For every $g \in I'$, we have $f(x)g(x) = (f \cdot g)(x) = 0$ since $f \cdot g \in I \cdot I'$ and $x \in V_E(I \cdot I')$. Now divide by $f(x)$ to get $g(x) = 0$ for every $g \in I'$, so that $x \in V_E(I')$.

=--


+-- {: .num_example #ZariskiTopologyOnMaximalIdealsOfPolynomialRingViaGaloisConnection}
###### Example

Let $k$ be a [[field]], let $n \in \mathbb{N}$ and write $k[X_1, \cdots, X_n]$ for the [[polynomial ring]] over $k$ in $n$ [[variables]], and $MaxIdl(k[X_1, \cdots, X_n])$ for the [[set]] of [[maximal ideals]] in this ring. 

Define then a [[relation]] 

$$
  E \hookrightarrow k[x_1, \ldots, x_n] \times MaxIdeal(k[x_1, \ldots, x_n])
$$ 

by 

$$
  E(f, M) \Leftrightarrow (f \in M)
  \,.
$$

For a subset $T \subseteq MaxIdl(k[x_1, \ldots, x_n])$ we calculate 

$$
  I_E(T) = \{f \in k[x_1, ldots, x_n]: \forall_{\mathfrak{m} \in MaxIdl} M \in S \Rightarrow f \in \mathfrak{m}\} = \bigcap_{\mathfrak{m} \in S} \mathfrak{m}
$$ 

which is an ideal, since the intersection of any collection of ideals is again an ideal. (However, not all ideals are given as intersections of maximal ideals, a point to which we will return in a moment.) 


=--


+-- {: .num_remark}
###### Remark

This is a slight generalization of example \ref{ZariskiClosedSubsetsInaffineViaGalois} since each point $a = (a_1, \ldots, a_n)$ induces a maximal ideal 

$$
  \mathfrak{m}_a \coloneqq \langle x_1 - a_1, \ldots, x_n - a_n \rangle
  \,,
$$

i.e. the [[kernel]] of the function 

$$
  \array{
    k[x_1, \ldots, x_n] &\longrightarrow& k
    \\
    f &\mapsto& f(a)
  }
$$ 

which evaluates polynomials $f$ at the point $a$, where we have $f(a) = 0$ iff $f \in \mathfrak{m}_a$. 

Of course it need not be the case that all maximal ideals $\mathfrak{m}$ are given by points in this way; for example, the ideal $(x^2 + 1)$ is maximal in $\mathbb{R}[x]$ but is not given by evaluation at a point because $x^2 + 1$ does not vanish at any real point. However, if the [[ground field]] $k$ is [[algebraically closed field|algebraically closed]], then every maximal ideal of $k[x_1, \ldots, x_n]$ is given by evaluation at a point $a = (a_1, \ldots, a_n)$. This result is not completely obvious; it is sometimes called the "weak [[Nullstellensatz]]". 

=--

+-- {: .num_prop}
###### Proposition

The set $S \subseteq k^n$ that are closed under the operator $V_E \circ I_E: P(k^n) \to P(k^n)$ in example \ref{ZariskiTopologyOnMaximalIdealsOfPolynomialRingViaGaloisConnection} form a [[topology]]. 

=--

+-- {: .proof}
###### Proof


The proof is virtually the same as in the proof of prop. \ref{ZariskiTopologyOnAffineSpaceViaGaloisConnectionWellDefined}: they are closed under arbitrary intersections by our earlier generalities, and they are closed under finite unions by the similar reasoning: $V_E(S) = V_E(I)$ where $I = I_E \circ V_E(S)$ is an ideal, so there is no loss of generality in considering $V_E(I)$ for ideals $I$, and $V_E(I) \cup V_E(I') = V_E(I \cdot I')$. If $\mathfrak{m} \in V_E(I \cdot I')$ (meaning $I \cdot I' \subseteq M$) but $\mthfrak{m}$ *doesn't* belong to $V_E(I)$, i.e., $f \notin \mathfrak{m}$ for some $f \in I$, then for every $g \in I'$ we have $f \cdot g \in \mathfrak{m}$. Taking the [[quotient]] map $\pi: R \to R/\mathfrak{m}$ to the field $R/\mathfrak{m}$, we have $\pi(f \cdot g) = \pi(f)\cdot \pi(g) = 0$, and since $\pi(f) \neq 0$ we have $\pi(g) = 0$ for every $g \in I'$, hence $\mathfrak{m} \in V_E(I')$. 

=--

Thus the fixed elements of $V_E \circ I_E$ on one side of the Galois correspondence are the closed sets of a topology. The fixed elements of $I_E \circ V_E$ on the other side are a matter of interest; in the case where $k$ is [[algebraically closed field|algebraically closed]], they are the *[[radical ideals]]* of $k[X_1, \ldots, X_n]$ according to the "strong [[Nullstellensatz]]. 



### Applied to affine schemes
 {#GaloisAppliedToAffineSchemes}

We now redo the discussion of the Zariski topology on the [[prime spectrum of a commutative ring]] from [above](#OnAffineVarieties) as a special case of the general considerations of [[Galois connections]].


## Related concepts

* [[Zariski site]]

* [[schemes are sober]]

## References

Lecture notes include

* Jim Carrell, _Zariski topology_ etc [[CarrellZariskiTopology.pdf:file]]

See also 

* Wikipedia, _[Zariski topology](https://en.wikipedia.org/wiki/Zariski_topology)_

[[!redirects Zariski topologies]]
