# Hypergraph categories

* table of contents
{: toc}

## Idea

A *hypergraph category* is a [[monoidal category]] whose [[string diagrams]] are [[hypergraphs]].  Recall that in general the vertices of a string diagram correspond to morphisms in a category, and its edges to objects.  An ordinary string diagram is a [[quiver]], where the inputs and outputs of a vertex describe objects appearing in a tensor-product decomposition of the domain and codomain of a morphism; each edge is connected to only one vertex as input and one vertex as output because of how morphisms in a category are composed.  A hypergraph category allows edges to connect to many vertices as input and many vertices as output, which categorically means that we can compose many morphisms containing an object in their codomain with many morphisms containing that object in their domain.

Hypergraph categories have been reinvented many times and given many different names, such as "well-supported compact closed categories" ([Carboni](#Carboni) and [RSW](#RSW)), "dgs-monoidal categories" ([GH](#GH)), and "spidered/dungeon categories" ([Morton](#Morton)).  The name "hypergraph category" is more recent ([Kissinger](#Kissinger) and [Fong](#FongDC)).

## Definition

A **hypergraph category** is:

* a [[symmetric monoidal category]] in which
* each object is equipped with the structure of a special commutative [[Frobenius algebra]], such that
* the Frobenius algebra structure of any tensor product $X\otimes Y$ is induced in the canonical way from those of $X$ and $Y$.

Note in particular that we do *not* require the morphisms of the category to be Frobenius algebra morphisms.

## Remarks

* The reason for the definition is that if $X$ is a special commutative Frobenius algebra, then there is a unique morphism $X^{\otimes m}\to X^{\otimes n} $ induced by the Frobenius algebra structure.  It can of course be defined as the $m$-ary multiplication followed by the $n$-ary comultiplication; the real point is that the special commutative Frobenius axioms ensure that any composite of two such morphisms is again another such morphism.  This is what enables the hypergraph string diagrams described informally above.

* The free hypergraph category on one object is the category of finite sets and isomorphism classes of cospans.  This is a decategorification of the fact that the free monoidal category containing a (non-special) commutative Frobenius algebra is the category of 1-dimensional [[manifolds]] and isomorphism classes of 2-dimensional [[cobordisms]].  More general free hypergraph categories can be constructed using labeled cospans.

* Note that the special commutative Frobenius algebras are not required to be "extra-special", meaning that the morphism $I = X^{\otimes 0} \to X^{\otimes 0} = I$ need not be the identity.  Thus, the relevant sort of "hypergraphs" can contain "edges not incident to any vertices".  If we add the extra-special condition, the cospans are replaced by "co-relations", i.e. jointly surjective cospans.

## References

* Aleks Kissinger, *Finite matrices are complete for (dagger-)hypergraph categories*, [arxiv](https://arxiv.org/abs/1406.5942)
 {#Kissinger}

* Brendan Fong, *Decorated Cospans*, Theory and Applications of Categories, Vol. 30, 2015, No. 33, pp 1096-1120, [arxiv](https://arxiv.org/abs/1502.00872)
 {#FongDC}

* Brendan Fong, *The Algebra of Open and Interconnected Systems*, Ph.D. Thesis, [arxiv](https://arxiv.org/abs/1609.05382)
 {#FongThesis}

* A. Carboni. Matrices, relations and group representations. J. Algebra, 138(2):497–529, 1991
 {#Carboni}

* R. Rosebrugh, N. Sabadini, and R. F. C. Walters. *Generic commutative separable algebras and cospans of graphs*. Th. App. Cat. 15(6):164–177, 2005. [online](http://www.tac.mta.ca/tac/volumes/15/6/15-06abs.html).
 {#RSW}

* F. Gadducci, R. Heckel. *An inductive view of graph transformation*. In "Recent Trends in Algebraic Development Techniques", Lecture Notes in
Computer Science 1376:223–237. Springer–Verlag, Berlin Heidelberg, 1998.
 {#GH}

* J. Morton. Belief propagation in monoidal categories. In B. Coecke, I. Hasuo, P. Panangaden, editors, Quantum Physics and Logic 2014 (QPL 2014), EPTCS 172:262–269.
 {#Morton}

[[!redirects hypergraph category]]
[[!redirects hypergraph categories]]
[[!redirects well-supported compact closed category]]
[[!redirects well-supported compact closed categories]]
[[!redirects dgs-monoidal category]]
[[!redirects dgs-monoidal categories]]
[[!redirects spidered category]]
[[!redirects spidered categories]]
[[!redirects dungeon category]]
[[!redirects dungeon categories]]
