
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Functional analysis
+-- {: .hide}
[[!include functional analysis - contents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}

## Idea 

### Generally
 {#Generally}

The _product_ of two [[distributions]] is an operation that generalizes, when defined, the ordinary pointwise product of [[functions]], if we think of distributions as [[generalized functions]] (via [this prop.](non-singular+distribution#NonSingularDistributionsAreDenseInAllDistributions)). 

However, as opposed to ordinary functions, the product of distributions -- if it is required to [[extension|extend]] the pointwise product of functions and to satisfy [[associativity]] and the [[product law]] for [[derivatives of distributions]] -- is not defined for arbitrary pairs of distributions, but only [[partial function|partially defined]] for those pairs whose [[Fourier transform of distributions|Fourier transforms]] satisfies a certain compatibility condition. Roughly: whenever the Fourier transform around any point of one factor does not decay exponentially in one direction of wave vectors, then the Fourier transform of the other factor has to decay exponentially in the _opposite_ direction of wave vectors. 

This is known as _[[Hörmander's criterion]]_ on the _[[wave front set]]_ of the distributions ([H&#246;rmander90](#Hoermander90)), and the study of distributions with attention to this condition is part of what is called _[[microlocal analysis]]_.

(If one is willing to consider changing the _ordinary_ pointwise product of functions, then is possible to define the product operation globally on all distributions, see at _[[Colombeau algebra]]_.)


The product of distributions with H&#246;rmander's condition on their [[wave front set]] may be understood via [[Fourier transform of distributions|Fourier transform]], as follows.

Let $u,v \in  \mathcal{D}'(\mathbb{R}^1)$ be two [[distributions]], for simplicity of exposition taken on the [[real line]].

Since the product $u \cdot v$, is, if it exists, supposed to generalize the _pointwise_ product of smooth functions, it must be fixed locally: for every point $x \in \mathbb{R}$ there ought to be a [[compactly supported function|compactly supported]] [[smooth function]] ([[bump function]]) $b \in C^\infty_{cp}(\mathbb{R})$ with $f(x) = 1$ such that 

$$
  b^2 u \cdot v = (b u) \cdot (b v)
  \,.
$$

But now $b v$ and $b u$ are both [[compactly supported distributions]], and these have the special property that their [[Fourier transform of distributions|Fourier transforms]] $\widehat{b v}$ and $\widehat{b u}$ are, in particular, [[smooth functions]] (by the [[Paley-Wiener-Schwartz theorem]]). 

Moreover, the operation of [[Fourier transform]] intertwines pointwise products with [[convolution products]]. This means that if the product of distributions $u \cdot v$ exists, it must locally be given by the inverse Fourier transform of the [[convolution product]] of the Fourier transforms $\widehat {b u}$ and $\widehat b v$:

$$
  \widehat{ b^2 u \cdot v }(x)
  \;=\;
  \underset{\underset{k_{max} \to \infty}{\longrightarrow}}{\lim}
  \,
  \int_{- k_{max}}^{k_{max}} \widehat{(b u)}(k) \widehat{(b v)}(x - k) d k
  \,.
$$

(Notice that the converse of this formula holds as a fact: [this prop.](Fourier+transform#FourierTransformOfDistributionsInterchangesConvolutionOfDistributionsWithPointwiseProduct).)

This shows that the product of distributions exists once there is a [[bump function]] $b$ such that the [[integral]] on the right converges as $k_{max} \to \infty$.

Now the [[Paley-Wiener-Schwartz theorem]] says more, it says that the Fourier transforms $\widehat {b u}$ and $\widehat {b u}$ are polynomially bounded. On the other hand, the [[integral]] above is well defined if the [[integrand]] decreases at least quadratically with $k \to \infty$. 
This means that for the convolution product to be well defined, either $\widehat {b u}$ has to polynomially decrease faster with $k \to \pm \infty$ than $\widehat {b v}$ grows in the _other_ direction, $k \to \mp \infty$ (due to the minus sign in the argument of the second factor in the [[convolution product]]), or the other way around. 

Moreover, the degree of polynomial growth of the [[Fourier transform of distributions|Fourier transform]] increases by one with each [[derivative of distributions|derivative]]. Therefore if the [[product law]] for [[derivatives of distributions]] is to hold generally, we need that either $\widehat{b u}$ or $\widehat{b v}$ decays faster than _any_ polynomial in the opposite of the directions in which the respective other factor does not decay.

Here the set of directions of wave vectors in which the Fourier transform of a distribution localized around any point does not decay exponentially is called the _[[wave front set]]_ of a distribution. Hence the condition that the product of two distributions is well defined is that for each wave vector direction in the wave front set of one of the two distributions, the opposite direction must not be an element of the wave front set of the other distribution.

### In perturbative quantum field theory
 {#IdeaInPerturbativeQFT}

The issue of mutliplying distributions has prominently been perceived in [[perturbative quantum field theory]], where [[operator-valued distributions]] serve to give the [[algebra of observables]] such as the [[Wick algebra]] of the [[free fields]] or more generally the [[interacting field algebra]].

A popular impression is (or has been) that the failure of distributions to have a globally defined product is a failure of the mathematical formalism to support the structures needed to model [[perturbative quantum field theory]]. But in fact the opposite is true: Handling the product of distributions correctly via proper analysis of their [[wave front set]] and handling the [[point-extension of distributions]] properly via analysis of their [[scaling degree of a distribution|scaling degree]] leads to a mathematical rigorous construction and mathematically captures all the effects expected from the non-rigorous treatmeants, notably the [[renormalization]] freedom. This is the topic of [[causal perturbation theory]]/[[locally covariant perturbative quantum field theory]], see there for more.




## Definition
 {#Definition}


+-- {: .num_defn #ProductOfDistributions}
###### Definition
**(multiplication of distributions)

Let $u,v \in \mathcal{D}'(X)$ be two [[distributions]] such that the sum of their [[wave front sets]] $WF(u) + WF(v)$  does not intersect zero ([[Hörmander's criterion]]). Then their _product distribution_

$$
  u \cdot v \in \mathcal{D}'(X)
$$

is the [[pullback of a distribution|pullback]] (via [this prop.](pullback+of+a+distribution#PullbackOfDistributionsWhoseWaveFrontDoesNotIntersectNormalBundle)) of their [[tensor product of distributions|tensor product]] along the [[diagonal]] map $\Delta_X \;\colon\; X \to X \times X$:

$$
  u \cdot v 
    \;\coloneqq\; 
  \Delta_X^\ast( u \otimes v )
  \,.
$$

=--

+-- {: .num_prop #ProductOfDistributionsViaDiagonalPullbackOfTensorProductIsWellDefined}
###### Proposition

Def. \ref{ProductOfDistributions} is indeed well defined.

=--

([H&#246;rmander 90, theorem 8.2.10](#Hoermander90), [Melrose 03, prop. 4.11](#Melrose03))

+-- {: .proof}
###### Proof

We need to check that the [[pullback of distributions]] is well defined. By [this prop.](pullback+of+a+distribution#PullbackOfDistributionsWhoseWaveFrontDoesNotIntersectNormalBundle) this means to check that the [[wave front set]] of the $u \otimes v$ does not intersect the [[conormal bundle]] of the diagonal map

Now the conormal bundle of the diagonal map consists of those pairs of covectors whose sum vanishes:

$$
  N^\ast_{\Delta_X}
  = 
  \left\{
    (x,(\xi, -\xi))
    \;\vert\;
    \xi \in T^\ast_x X
  \right\}
  \,.
$$

Moreover, by [this example](tensor+product+of+distributions#WaveFrontOfTensorProductDistribution) the wave front set of the tensor product distribution $u \otimes v$ is

$$
  WF(u \otimes v)
  \;\subset\;
  \left(
     WF(u) \times WF(v)
  \right)
    \;\cup\;
  \left(
    \left( supp(u) \times \{0\} \right)
    \times WF(v)
  \right)
    \;\cup\;
   \left(
     WF(u)
     \times
     \left(
       supp(v) \times \{0\}
     \right)
   \right)
  \,,
$$

Since any wave front set excludes the zero-section by definition, the second and the third summand in this union never intersect the above conormal bundle. The first summand intersects the above conormal bundle precisely if there is a covector in $WF(u)$ which is minus a covector contained in $WF(v)$. That this is not the case is precisely the assumption.


=--

## Properties

### General

+-- {: .num_prop #WaveFrontSetOfProductOfDistributionsInsideFiberProductOfFactorWaveFrontSets}
###### Proposition
**([[wave front set]] of [[product of distributions]] is inside [[fiber]]-wise [[sum]] of [[wave front sets]])**

Let $u,v \in \mathcal{D}'(X)$ be a [[pair]] of [[distributions]] satisfying [[Hörmander's criterion]], so that their product of distributions $u \cdot v$ (def. \ref{ProductOfDistributions}) exists by prop. \ref{ProductOfDistributionsViaDiagonalPullbackOfTensorProductIsWellDefined}. Then the [[wave front set]] of the product distribution is contained inside the fiberwise [[sum]] of the wave front set elements of the two factors:

$$
  WF(u \cdot v)
  \;\subset\;
  (WF(u) \cup (X \times \{0\})) 
    + 
  (WF(v) \cup (X \times \{0\}))
  \,.
$$

=--

([Hörmander 90, theorem 8.2.10](#Hoermander90))

+-- {: .proof}
###### Proof

By def. \ref{ProductOfDistributions} and prop. \ref{ProductOfDistributionsViaDiagonalPullbackOfTensorProductIsWellDefined} we have $u \cdot v = \Delta_X^\ast(u \otimes v)$. By [this example](tensor+product+of+distributions#WaveFrontOfTensorProductDistribution) the wave front set of the tensor product distribution $u \otimes v$ is

$$
  WF(u \otimes v)
  \;\subset\;
  \left(
     WF(u) \times WF(v)
  \right)
    \;\cup\;
  \left(
    \left( supp(u) \times \{0\} \right)
    \times WF(v)
  \right)
    \;\cup\;
   \left(
     WF(u)
     \times
     \left(
       supp(v) \times \{0\}
     \right)
   \right)
$$

and by [this prop. ](pullback+of+a+distribution#PullbackOfDistributionsWhoseWaveFrontDoesNotIntersectNormalBundle) we have

$$
  WF(\Delta_X^\ast (u \otimes v))
    \subset 
  \Delta_X^\ast WF(u \otimes v)
  \coloneqq
  \left\{
    (x, k_1 + k_2 )
    \;\vert\;
    ((x,k_1),(x,k_2))
    \in 
    WF(u \otimes v)
  \right\}  
  \,.
$$


=--

More generally:

+-- {: .num_prop #PartialProductOfDistributionsOfSeveralVariables}
###### Proposition
**(partial product of [[distributions of several variables]])**

Let 

$$
  K_1 \in \mathcal{D}'(X \times Y)
  \phantom{AAA}
  K_2 \in \mathcal{D}'(Y \times Z)
$$

be two [[distributions of two variables]]. For their [[product of distributions]] to be defined over $Y$, [[Hörmander's criterion]] on the [[pair]] of [[wave front sets]] $WF(K_1), WF(K_2)$  needs to hold for the [[wave front set|wave front]] [[wave vectors]] along $X$ and $Y$ taken to be zero.

If this is satisfied, then composition of [[integral kernels]] (if it exists)

$$
  (K_1 \circ K_2)(-,-)
  \;\coloneqq\;
  \underset{Y}{\int}
    K_1(-,y) K_2(y,-)
  dvol_Y(y)
  \;\in\;
  \mathcal{D}'(X \times Z)
$$

has [[wave front set]] constrained by

$$
  WF'(K_1 \circ K_2)
  \;\subset\;
  WF'(K_1) \circ WF'(K_2)
  \;\cup\;
  (X \times \{0\}) \times WF'(K_2)_Z
  \;\cup\;
  WF(K_1)_X \times (Z \times \{0\})
  \,,
$$

where on the left the composition symbol means composition of [[relations]] of [[wave vectors]] over points in $Y$. Explicitly this means that

$$
  \label{CompositionOfIntegralKernelsWaveFronConstraint}
  WF(K_1 \circ K_2)
  \;\subset\;
  \left\{
    (x,z, k_x, k_z)
    \;\vert\;
    \array{
      \left(
      (x,y,k_x,-k_y) \in WF(K_1)
      \,\,
      \text{and}
      \,\,
      (y,z,k_y, k_z) \in WF(K_2)
      \right)
      \\ 
      \text{or}
      \\
      \left(
        k_x = 0 
        \,\text{and}\,
        (y,z,0,-k_z) \in WF(K_2)
      \right)
      \\
      \text{or}
      \\
      \left(
        k_z = 0
        \,\text{and}\,
        (x,y,k_x,0) \in WF(K_1)
      \right)
    }
  \right\}
$$


=--

([Hörmander 90, theorem 8.2.14](#Hoermander90))

$\,$

* for **continuity** see at _[[Hörmander topology]]_


### Non-existence of a global product
 {#NonExistenceOfAGlobalProduct}


The fact that there is no general extension of multiplication to distributions (without condition on the [[wave front set]]) is a famous [[no-go theorem]] of [[Laurent Schwartz]].

A quick way to see the problem is the following: 

Let $H(x)$ be the [[Heaviside function]], we clearly have

$$
      H(x) = H^{n} (x)
$$

where the product on the right side is the product of classical functions. Applying differentiation and the product rule naivly results in a contradiction immediatly:
$$
   \delta(x) = n H^{n-1} (x) \delta(x)
$$

The inconsistency of this product is detected by the [[wave front sets]] as follows: The wave front set both of the [[Heaviside distribution]] as well as of the [[delta distribution]] on the line is $\{(0,k) \vert k \neq 0\}$ ([this example](wavefront+set#WaveFrontOfDeltaDistribution) and [this example](wavefront+set#WaveFrontSetOfHeavisideDistribution)). Therefore for both of these distributions mutliplication is only defined, according to def. \ref{ProductOfDistributions}, with a distribution $u$ for which there exists a [[bump function]] $b$ with $b(0) = 1$ such that $b \cdot u$ is again a bump function. This excludes the products of these distributions with themselves and with each other.

## Examples
 {#Examples}

+-- {: .num_defn #ProductOfADistributionWithANonSingularDistribution}
###### Definition
**(product of a [[distribution]] with a [[non-singular distributions]] is [[product of a distribution with a smooth function]])**

The [[wave front set]] of a [[non-singular distribution]] $u_f$ corresponding to a [[smooth function]] $f \in C^\infty(\mathbb{R}^n)$, is [[empty]] ([this prop.](Paley-Wiener-Schwartz+theorem#DecayPropertyOfFourierTransformOfCompactlySupportedFunctions)). Therefore the product of distributions (def. \ref{ProductOfDistributions}) of a [[non-singular distribution]] with any distribution $u$ is defined, and given by the [[product of distributions with smooth functions]]:

$$
  u_f \cdot u = f \cdot u = u(f\cdot (-))
  \,.
$$

=--



## Related concepts

* [[product of a distribution with a smooth function]]

* [[convolution product of distributions]]

* [[Hadamard distribution]]

* [[Hörmander topology]]

* [[microcausal functional]], [[Wick algebra]]

* [[operator-valued distribution]]

* [[Fourier transform of distributions]]

## References

* {#Hoermander71} [[Lars Hörmander]], _Fourier integral operators. I_.  Acta Mathematica 127, 79–183 (1971) ([Euclid](https://projecteuclid.org/euclid.acta/1485889699))

* {#Hoermander90} [[Lars Hörmander]], section 8.1 of _The analysis of linear partial differential operators_, vol. I, Springer 1983, 1990

* {#Melrose03} [[Richard Melrose]], chapter 1 of _Introduction to microlocal analysis_, 2003 ([pdf](http://www-math.mit.edu/~rbm/iml90.pdf))


* [[Michael Oberguggenberger]], _Products of distributions_, Journal f&#252;r die reine und angewandte Mathematik (1986) Volume: 365, page 1-11 ([EuDML](https://eudml.org/doc/152801))

* [[Michael Oberguggenberger]], _Multiplication of Distributions and Applications to Partial Differential Equations_, Longman 1992

Slides with exposition of the role of multiplication of distributions in [[renormalization]] of [[Feynman diagrams]] via [[causal perturbation theory]]/[[perturbative AQFT]]:

* {#Brouder10} [[Christian Brouder]], _Multiplication of distributions_, 2010 ([[BrouderProductOfDistributions.pdf:file]])


[[!redirects products of distributions]]

[[!redirects multiplication of distributions]]
[[!redirects multiplications of distributions]]
