
## Spacetime
  {#Spacetime}

[[relativistic field theory|Relativistic field theory]] takes place on _[[spacetime]]_.

The concept of [[spacetime]] makes sense for every [[dimension]] $p+1$ with $p \in \mathbb{N}$.
The [[observable universe]] has macroscopic dimension $3+1$, but [[quantum field theory]] generally makes sense
also in lower and in higher dimensions. For instance quantum field theory in dimension 0+1 is the "[[worldline]]"
theory of [[particles]], also known as _[[quantum mechanics]]_; while quantum field theory in dimension $\gt p+1$
may be "[[Kaluza-Klein compactifications|KK-compactified]]" to an "[[effective field theory|effective]]"
field theory in dimension $p+1$ which generally looks more complicated than its higher dimensional incarnation.

However, every realistic field theory, and also most of the non-realistic field theories of interest, contain
[[spinor fields]] such as the [[Dirac field]] (example \ref{LagrangianDensityForDiracField} below) and
the precise nature and behaviour of [[spinors]] does depend sensitively on spacetime dimension.
In fact the theory of relativistic spinors is mathematically most natural in just the following four
spacetime dimensions:

$$
  p +1 = \phantom{AAAAA} \array{ 2+1,\; & 3+1,\; & \, &  5+1,\; &\, & \, & \, & \, 9+1 }
$$

In the literature one finds these four dimensions advertized for two superficially unrelated reasons:

1. in precisely these dimensions "[[twistors]]" exist (see [there](twistor+space#TwistorSpace));

1. in precisely these dimensions "[[Green-Schwarz superstrings|GS-superstrings]]" exist (see [there](geometry+of+physics+--+fundamental+super+p-branes#TheSuperStringAndTheSuperMembrane)).

However, both these explanations have a common origin in something simpler and deeper:
Spacetime in these dimensions appears from the "[[Pauli matrices]]" with entries in the real [[normed division algebras]].
(In fact it goes [deeper still](geometry+of+physics+--+supersymmetry#SupersymmetryFromTheSuperpoint), but this will not concern us here.)

This we explain now, and then we use this to obtain a slick handle on [[spinors]] in these dimensions,
using simple [[linear algebra]] over the four [[real number|real]] [[normed division algebras]].
At the end (in remark \ref{TwoComponentSpinorNotation}) we give a dictionary that expresses these constructions in terms
of the "two-component spinor notation" that is traditionally used in physics texts (remark \ref{TwoComponentSpinorNotation} below).

The relation between _[[real spin representations and division algebras]]_,
is originally due to [Kugo-Townsend 82](geometry+of+physics+--+supersymmetry#KugoTownsend82), [Sudbery 84](geometry+of+physics+--+supersymmetry#Sudbery84) and others. We follow the streamlined discussion in [Baez-Huerta 09](geometry+of+physics+--+supersymmetry#BaezHuerta09) and [Baez-Huerta 10](geometry+of+physics+--+supersymmetry#BaezHuerta10).

A key extra structure that the [[spinors]] impose on the underlying [[Cartesian space]] of [[spacetime]]
is its _[[causal structure]]_, which determines which points in [[spacetime]] ("[[events]]") are in
the [[future]] or the [[past]] of other points (def. \ref{SpacelikeTimelikeLightlike} below).
 This [[causal structure]] will turn out to tightly control
the [[quantum field theory]] on [[spacetime]] in terms of the "[[causal  additivity]] of the [[S-matrix]]"
(prop. \ref{TimeOrderedProductInducesPerturbativeSMatrix} below) and the induced "[[causal locality]]" of the
[[algebra of quantum observables]] (prop. \ref{PerturbativeQuantumObservablesIsLocalnet} below).
To prepare the discussion of these constructions, we end this chapter with some basics on the
[[causal structure]] of [[Minkowski spacetime]].

$\,$

1. [Real division algebras](#RealDivisionAlgebras)

1. [Spacetime in dimensions 3, 4, 6 and 10](#MinkowskiSpacetimeInCriticalDimensions)

1. [Lorentz group and Spin group](#LorentzGroupAndSpinGroup)

1. [Spinors in dimensions 3, 4, 6 and 10](#InTermsOfNormedDivisionAlgebraInDimension3To10)

1. [Causal structure](#CausalStructure)



$\,$

**Real division algebras**
 {#RealDivisionAlgebras}

To amplify the following pattern and to fix our notation for algebra generators, recall these definitions:

+-- {: .num_defn #TheComplexNumbers}
###### Definition
**([[complex numbers]])**

The _[[complex numbers]]_ $\mathbb{C}$ is the [[commutative algebra]] over the [[real numbers]] $\mathbb{R}$ which is [[generators and relations|generated]] from one generators $\{e_1\}$ subject to the [[generators and relations|relation]]

* $(e_1)^2 = -1$.

=--

+-- {: .num_defn #TheQuaternions}
###### Definition
**([[quaternions]])**

The _[[quaternions]]_ $\mathbb{H}$ is the [[associative algebra]] over the [[real numbers]] which is [[generators and relations|generated]] from three generators $\{e_1, e_2, e_3\}$ subject to the [[generators and relations|relations]]

<div style="float:right;margin:0 20px 10px 20px;">
<img src="https://ncatlab.org/nlab/files/QuaternionMultiplicationTable.jpg" width="300" alt="quaternion multiplication table">
</div>

1. for all $i$

   $(e_i)^2 = -1$

1. for $(i,j,k)$ a cyclic [[permutation]] of $(1,2,3)$ then

   1. $e_i e_j  = e_k$

   1. $e_j e_i  = -e_k$


> (graphics grabbed from [Baez 02](geometry+of+physics+--+supersymmetry#Baez02))

=--


+-- {: .num_defn #TheOctonions}
###### Definition
**([[octonions]])**

The _[[octonions]]_ $\mathbb{O}$ is the [[nonassociative algebra]] over the [[real numbers]] which is [[generators and relations|generated]] from seven generators $\{e_1, \cdots, e_7\}$ subject to the [[generators and relations|relations]]

<div style="float:right;margin:0 20px 10px 20px;">
<img src="https://ncatlab.org/nlab/files/OctonionMultiplicationTable.jpg" width="400" alt="octonion multiplication table">
</div>


1. for all $i$

   $(e_i)^2 = -1$

1. for $e_i \to e_j \to e_k$ an edge or circle in the diagram shown (a labeled version of the [[Fano plane]]) then

   1. $e_i e_j  = e_k$

   1. $e_j e_i  = -e_k$

   and all relations obtained by cyclic [[permutation]] of the indices in these equations.


> (graphics grabbed from [Baez 02](geometry+of+physics+--+supersymmetry#Baez02))

=--



One defines the following operations on these real algebras:

+-- {: .num_defn #Conjugation}
###### Definition
**(conjugation, [[real part]], [[imaginary part]] and [[absolute value]])**

For $\mathbb{K} \in \{\mathbb{R}, \mathbb{C}, \mathbb{H}, \mathbb{O}\}$, let

$$
  (-)^\ast
    \;\colon\;
  \mathbb{K}
    \longrightarrow
  \mathbb{K}
$$

be the [[antihomomorphism]] of real algebras

$$
  \begin{aligned}
    (r a)^\ast  = r a^\ast &, \text{for}\;\; r \in \mathbb{R}, a \in \mathbb{K}
    \\
   (a b)^\ast = b^\ast a^\ast &,\text{for}\;\; a,b \in \mathbb{K}
  \end{aligned}
$$

given on the generators of def. \ref{TheComplexNumbers}, def. \ref{TheQuaternions}
and def. \ref{TheOctonions}  by

$$
  (e_i)^\ast = - e_i
  \,.
$$

This operation makes $\mathbb{K}$ into a [[star algebra]].
For the [[complex numbers]] $\mathbb{C}$ this is called _[[complex conjugation]]_, and in general we call it _conjugation_.

Let then

$$
  Re \;\colon\; \mathbb{K} \longrightarrow \mathbb{R}
$$

be the [[function]]

$$
  Re(a) \;\coloneqq\; \tfrac{1}{2}(a + a^\ast)
$$

("[[real part]]") and

$$
  Im \;\colon\; \mathbb{K} \longrightarrow \mathbb{R}
$$

be the [[function]]

$$
  Im(a) \;\coloneqq \; \tfrac{1}{2}(a - a^\ast)
$$

("[[imaginary part]]").

It follows that for all $a \in \mathbb{K}$ then the product of a with its conjugate is in the real [[center]]
of $\mathbb{K}$

$$
  a a^\ast = a^\ast a \;\in \mathbb{R} \hookrightarrow \mathbb{K}
$$

and we write the [[square root]] of this expression as

$$
  {\vert a\vert}
    \;\coloneqq\;
  \sqrt{a a^\ast}
$$

called the _[[norm]]_ or _[[absolute value]]_ [[function]]

$$
  {\vert -\vert}
    \;\colon\;
  \mathbb{K}
    \longrightarrow
  \mathbb{R}
  \,.
$$

This norm operation clearly satisfies the following properties (for all $a,b \in \mathbb{K}$)

1. $\vert a \vert \geq 0$;

1. ${\vert a \vert } = 0 \;\;\;\;\; \Leftrightarrow\;\;\;\;\;\; a = 0$;

1. ${\vert a b \vert } = {\vert a \vert} {\vert b \vert}$

and hence makes $\mathbb{K}$ a [[normed algebra]].

Since $\mathbb{R}$ is a [[division algebra]], these relations immediately imply that each $\mathbb{K}$ is a [[division algebra]], in that

$$
  a b = 0 \;\;\;\;\;\; \Rightarrow \;\;\;\;\;\; a = 0 \;\; \text{or} \;\; b = 0
  \,.
$$

Hence the conjugation operation makes $\mathbb{K}$ a [[real numbers|real]] [[normed division algebra]].

=--

+-- {: .num_remark #SequenceOfInclusionsOfRealNormedDivisionAlgebras}
###### Remark
**(sequence of inclusions of real [[normed division algebras]])**

Suitably embedding the sets of generators in def. \ref{TheComplexNumbers}, def. \ref{TheQuaternions} and def. \ref{TheOctonions}
into each other yields sequences of real [[star-algebra]] [[monomorphisms|inclusions]]

$$
  \mathbb{R}
    \hookrightarrow
  \mathbb{C}
    \hookrightarrow
  \mathbb{H}
    \hookrightarrow
  \mathbb{O}
  \,.
$$

For example for the first two inclusions we may send each generator to the generator of the same name, and for the
last inclusion me may choose

$$
  \array{
    1 &\mapsto& 1
    \\
    e_1 &\mapsto & e_3
    \\
    e_2 &\mapsto& e_4
    \\
    e_3 &\mapsto& e_6
  }
$$

=--

+-- {: .num_prop #HurwitzTheorem}
###### Proposition
**([[Hurwitz theorem]]: $\mathbb{R}$, $\mathbb{C}$, $\mathbb{H}$ and $\mathbb{O}$ are the normed real division algebras)**

The four algebras of [[real numbers]] $\mathbb{R}$, [[complex numbers]] $\mathbb{C}$,
[[quaternions]] $\mathbb{H}$ and [[octonions]] $\mathbb{O}$
from def. \ref{TheComplexNumbers}, def. \ref{TheQuaternions} and def. \ref{TheOctonions} respectively,
which are real [[normed division algebras]] via def. \ref{Conjugation},
are, up to [[isomorphism]], the _only_ real normed division algebras that exist.

=--

+-- {: .num_remark}
###### Remark
**([[Cayley-Dickson construction]] and [[sedenions]])**

While prop. \ref{HurwitzTheorem} says that the sequence from remark \ref{SequenceOfInclusionsOfRealNormedDivisionAlgebras}

$$
  \mathbb{R}
    \hookrightarrow
  \mathbb{C}
    \hookrightarrow
  \mathbb{H}
    \hookrightarrow
  \mathbb{O}
$$

is maximal in the [[category]] of real normed non-associative [[division algebras]], there is a pattern that does
continue if one disregards the division algebra property. Namely each step in this sequence is given by
a construction called _forming the [[Cayley-Dickson double algebra]]_. This continues to an unbounded sequence of
real nonassociative star-algebras

$$
  \mathbb{R}
    \hookrightarrow
  \mathbb{C}
    \hookrightarrow
  \mathbb{H}
    \hookrightarrow
  \mathbb{O}
    \hookrightarrow
  \mathbb{S}
    \hookrightarrow
  \cdots
$$

where the next algebra $\mathbb{S}$ is called the _[[sedenions]]_.

=--

What actually matters for the following relation of the real normed division algebras to [[real spin representations]]
is that they are also [[alternative algebras]]:

+-- {: .num_defn #AlternativeAlgebra}
###### Definition
**([[alternative algebras]])**

Given any [[non-associative algebra]] $A$, then the trilinear map

$$
  [-,-,-] \;-\; A \otimes A \otimes A \longrightarrow A
$$

given on any elements $a,b,c \in A$ by

$$
  [a,b,c] \coloneqq (a b) c - a (b c)
$$

is called the _[[associator]]_ (in analogy with the _[[commutator]]_ $[a,b] \coloneqq a b - b a$ ).

If the associator is completely antisymmetric (in that for any [[permutation]] $\sigma$ of three elements then $[a_{\sigma_1}, a_{\sigma_2}, a_{\sigma_3}] = (-1)^{\vert \sigma\vert} [a_1, a_2, a_3]$ for $\vert \sigma \vert$ the [[signature of a permutation|signature of the permutation]]) then $A$ is called an _[[alternative algebra]]_.

If the [[characteristic]] of the [[ground field]] is different from 2, then alternativity is
readily seen to be equivalent to the conditions that for all $a,b \in A$ then

$$
  (a a)b = a (a b)
   \;\;\;\;\;
     \text{and}
   \;\;\;\;\;
   (a b) b = a (b b)
   \,.
$$

=--

We record some basic properties of associators in alternative star-algebras that we need below:

+-- {: .num_prop #PropertiesOfAssociatorInAlternativeAlgebra}
###### Proposition
**(properties of [[alternative algebra|alternative]] [[star algebras]])**

Let $A$ be an [[alternative algebra]] (def. \ref{AlternativeAlgebra}) which is also a [[star algebra]]. Then (using def. \ref{Conjugation}):

1. the [[associator]] vanishes when at least one argument is [[real part|real]]

   $$
     [Re(a),b,c]
   $$

1. the [[associator]] changes sign when one of its arguments is conjugated

   $$
     [a,b,c] = -[a^\ast,b,c]
     \,;
   $$

1. the [[associator]] vanishes when one of its arguments is the conjugate of another

   $$
     [a,a^\ast, b] = 0
     \,;
   $$

1. the [[associator]] is purely [[imaginary part|imaginary]]

   $$
     Re([a,b,c]) = 0
     \,.
   $$

=--

+-- {: .proof}
###### Proof

That the associator vanishes as soon as one argument is real is just the linearity of an algebra
product over the ground ring.

Hence in fact

$$
  [a,b,c] = [Im(a), Im(b), Im(c)]
  \,.
$$

This implies the second statement by linearity. And so follows the third statement by skew-symmetry:

$$
  [a,a^\ast,b] = -[a,a,b] = 0
  \,.
$$

The fourth statement finally follows by this computation:

$$
  \begin{aligned}
    \,[ a, b, c]^\ast
      & =
    -[c^\ast, b^\ast, a^\ast]
      \\
      & =
      -[c,b,a]
      \\
      & =
      -[a,b,c]
  \end{aligned}
  \,.
$$

Here the first equation follows by inspection and using that $(a b)^\ast = b^\ast a^\ast$,
the second follows from the first statement above, and the third is the anti-symmetry of the associator.

=--

It is immediate to check that:

+-- {: .num_prop #RCHOAreAlternative}
###### Proposition
**($\mathbb{R}$, $\mathbb{C}$, $\mathbb{H}$ and $\mathbb{O}$ are real [[alternative algebras]])**

The real algebras of [[real numbers]], [[complex numbers]],  def. \ref{TheComplexNumbers},[[quaternions]] def. \ref{TheQuaternions} and
[[octonions]] def. \ref{TheOctonions} are [[alternative algebras]] (def. \ref{AlternativeAlgebra}).

=--

+-- {: .proof}
###### Proof

Since the [[real numbers]], [[complex numbers]] and [[quaternions]] are [[associative algebras]],
their [[associator]] vanishes identically. It only remains to see that the associator of the
[[octonions]] is skew-symmetric. By linearity it is sufficient to check this on generators.
So let $e_i \to e_j \to e_k$ be a circle or a cyclic permutation of an edge in the [[Fano plane]].
Then by definition of the octonion multiplication we have

$$
  \begin{aligned}
    (e_i e_j) e_j
    &=
    e_k e_j
    \\
    &=
    - e_j e_k
    \\
    & =
    -e_i
    \\
    & =
    e_i (e_j e_j)
  \end{aligned}
$$

and similarly

$$
  \begin{aligned}
    (e_i e_i ) e_j
    &=
    - e_j
    \\
    &=
    - e_k e_i
    \\
    &=
    e_i e_k
    \\
    &=
    e_i (e_i e_j)
  \end{aligned}
  \,.
$$

=--

The analog of the [[Hurwitz theorem]] (prop. \ref{HurwitzTheorem}) is now this:

+-- {: .num_prop #ZornTheorem}
###### Proposition
**($\mathbb{R}$, $\mathbb{C}$, $\mathbb{H}$ and $\mathbb{O}$ are precisely the [[alternative algebra|alternative]] [[real number|real]] [[division algebras]])**

The only [[division algebras]] over the [[real numbers]] which are also [[alternative algebras]] (def. \ref{AlternativeAlgebra}) are the [[real numbers]] themselves, the [[complex numbers]], the [[quaternions]] and the [[octonions]] from prop. \ref{RCHOAreAlternative}.

=--

This is due to ([Zorn 30](normed+division#algebra#Zorn30)).


For the following, the key point of alternative algebras is this equivalent characterization:

+-- {: .num_prop #ArtinTheorem}
###### Proposition
**([[alternative algebra]] detected on subalgebras spanned by any two elements)**

A [[nonassociative algebra]] is alternative, def. \ref{AlternativeAlgebra},  precisely if the [[subalgebra]] generated by any two elements is an [[associative algebra]].

=--

This is due to [[Emil Artin]], see for instance ([Schafer 95, p. 18](alternative+algebra#Schafer95)).

Proposition \ref{ArtinTheorem} is what allows to carry over a minimum of [[linear algebra]] also to the [[octonions]]
such as to yield a representation of the [[Clifford algebra]] on $\mathbb{R}^{9,1}$. This happens in the proof
of prop. \ref{SpinorRepsByNormedDivisionAlgebra} below.

So we will be looking at a [[fragment]] of [[linear algebra]] over these four [[normed division algebras]].
To that end, fix the following notation and terminology:

+-- {: .num_defn #MatrixNotation}
###### Definition
**([[hermitian matrices]] with values in real [[normed division algebras]])**

Let $\mathbb{K}$ be one of the four real [[normed division algebras]] from prop. \ref{HurwitzTheorem}, hence equivalently one of the four
real [[alternative algebra|alternative]] [[division algebras]] from prop. \ref{ZornTheorem}.

Say that an $n \times n$ [[matrix]] with [[coefficients]] in $\mathbb{K}$

$$
  A\in Mat_{n\times n}(\mathbb{K})
$$

is a _[[hermitian matrix]]_ if the [[transpose matrix]] $(A^t)_{i j} \coloneqq A_{j i}$ equals the componentwise [[complex conjugation|conjugated]] matrix (def. \ref{Conjugation}):

   $$
     A^t = A^\ast
     \,.
   $$

   Hence with the notation

   $$
     (-)^\dagger \coloneqq ((-)^t)^\ast
   $$

   we have that $A$ is a [[hermitian matrix]] precisely if

   $$
     A = A^\dagger
     \,.
   $$

   We write $Mat_{2 \times 2}^{her}(\mathbb{K})$ for the [[real vector space]] of hermitian matrices.

=--

+-- {: .num_defn #TraceReversal}
###### Definition
**([[trace]] reversal)**

Let $A \in Mat_{2 \times 2}^{her}(\mathbb{K})$ be a hermitian $2 \times 2$ matrix as in def. \ref{MatrixNotation}.
Its _trace reversal_ is the result of subtracting its [[trace]] times the identity matrix:


$$
    \tilde A \;\coloneqq\; A - (tr A) 1_{n\times n}
    \,.
$$

=--



$\,$


**Minkowski spacetime in dimensions 3,4,6 and 10**
 {#MinkowskiSpacetimeInCriticalDimensions}

We now discover [[Minkowski spacetime]] of dimension 3,4,6 and 10, in terms of the
real [[normed division algebras]] $\mathbb{K}$ from prop. \ref{HurwitzTheorem}, equivalently the
real [[alternative algebra|alternative]] [[division algebras]] from prop. \ref{ZornTheorem}:
this is prop./def. \ref{SpacetimeAsMatrices} and def. \ref{MinkowskiSpacetime} below.

+-- {: .num_prop #SpacetimeAsMatrices}
###### Proposition/Definition
**([[Minkowski spacetime]] as [[real vector space]] of [[hermitian matrices]] in [[real number|real]] [[normed division algebras]])**

Let $\mathbb{K}$ be one of the four real [[normed division algebras]] from prop. \ref{HurwitzTheorem}, hence one of the four
real [[alternative algebra|alternative]] [[division algebras]] from prop. \ref{ZornTheorem}.

Then the [[real vector space]] of $2 \times 2$ [[hermitian matrices]] over $\mathbb{K}$ (def. \ref{MatrixNotation})
equipped with the [[inner product]] $\eta$ whose [[quadratic form]] ${\vert -\vert^2_\eta}$ is the negative of the [[determinant]] operation on matrices is _[[Minkowski spacetime]]_:

$$
  \label{MinkowskiSpacetimeFromHermitianMatricesWithDeterminant}
  \begin{aligned}
    \mathbb{R}^{dim_{\mathbb{R}}(\mathbb{K})+1,1}
    &
    \coloneqq
    \left(
      \mathbb{R}^{dim_{\mathbb{R}(\mathbb{K})}+2}
      ,
      {\vert -\vert^2_\eta}
    \right)
    & \coloneqq
    \left(Mat_{2 \times 2}^{her}(\mathbb{K}), -det \right)
  \end{aligned}
  \,.
$$

hence

1. $\mathbb{R}^{2,1}$ for $\mathbb{K} = \mathbb{R}$;

1. $\mathbb{R}^{3,1}$ for $\mathbb{K} = \mathbb{C}$;

1. $\mathbb{R}^{5,1}$ for $\mathbb{K} = \mathbb{H}$;

1. $\mathbb{R}^{9,1}$ for $\mathbb{K} = \mathbb{O}$.

Here we think of the [[vector space]] on the left as $\mathbb{R}^{p,1}$
with

$$
  p \coloneqq dim_{\mathbb{R}}(\mathbb{K})+1
$$

equipped with the canonical coordinates labeled $(x^\mu)_{\mu = 0}^p$.

As a [[linear map]] the identification is given by

$$
  (x^0, x^1, \cdots, x^{d-1})
    \;\mapsto\;
  \left(
    \array{
      x^0 + x^1 & y
      \\
      y^\ast & x^0 - x^1
    }
  \right)
  \;\;\;
  \text{with}\;
  y \coloneqq x^2 1 + x^3 e_1 + x^4 e_2 +   \cdots + x^{2 + dim_{\mathbb{R}(\mathbb{K})}} \,e_{dim_{\mathbb{R}}(\mathbb{K})-1}
  \,.
$$

This means that the [[quadratic form]] ${\vert - \vert^2_\eta}$ is given on an element $v = (v^\mu)_{\mu = 0}^p$ by

$$
  {\vert v \vert}^2_{\eta}
    \;=\;
  - (v^0)^2 + \underoverset{j = 1}{p}{\sum} (x^j)^2
  \,.
$$

By the [[polarization identity]] the [[quadratic form]] ${\vert - \vert^2_\eta}$ induces a [[bilinear form]]

$$
  \eta \;\colon\; \mathbb{R}^{p,1}\otimes \mathbb{R}^{p,1} \longrightarrow \mathbb{R}
$$

given by

$$
 \begin{aligned}
    \eta(v_1, v_2)
    & =
    \eta_{\mu \nu} v_1^\mu v_1^\nu
    \\
    & \coloneqq
    - v_1^0 v_2^0 + \underoverset{j  = 1}{p}{\sum} v_1^j v_2^j
  \end{aligned}
  \,.
$$

This is called the _[[Minkowski metric]]_.

Finally, under the above identification the operation of trace reversal from def. \ref{TraceReversal}
corresponds to _time reversal_ in that

$$
  \widetilde{
  \left(
    \array{
      x^0 + x^1 & y
      \\
      y^\ast & x^0 - x^1
    }
  \right)
  }
   \;=\;
  \left(
    \array{
      -x^0 + x^1 & y
      \\
      y^\ast & -x^0 - x^1
    }
  \right)
  \,.
$$

=--

+-- {: .proof}
###### Proof

We need to check that under the given identification, the Minkowski norm-square is indeed given by minus the determinant on the
corresponding hermitian matrices.
This follows from the nature of the conjugation operation $(-)^\ast$ from def. \ref{Conjugation}:

$$
  \begin{aligned}
    -
    det
    \left(
      \array{
        x^0 + x^1 & y
        \\
        y^\ast & x^0 - x^1
      }
    \right)
    & =
    -(x^0 + x^1)(x^0 - x^1)
    +
    y y^\ast
    \\
    & =
    -(x^0)^2 + \underoverset{i = 1}{p}{\sum} (x^i)^2
  \end{aligned}
  \,.
$$

=--

+-- {: .num_remark #MinkowskiMetricAndPhysicalUnitOfLength}
###### Remark
**([[physical units]] of [[length]])**

As the term "[[metric]]" suggests, in application to [[physics]], the [[Minkowski metric]] $\eta$ in prop./def. \ref{SpacetimeAsMatrices} is regarded as a _measure of [[length]]_: for $v \in \Gamma_x(T \mathbb{R}^{p,1})$ a [[tangent vector]] at a point $x$ in Minkowski spacetime, interpreted as a displacement from [[event]] $x$ to event $x + v$, then

1. if $\eta(v,v) \gt 0$ then

   $$
     \sqrt{\eta(v,v)} \in \mathbb{R}
   $$

   is interpreted as a measure for the _[[spacelike|spatial]] [[distance]]_ between $x$ and $x + v$;

1. if $\eta(v,v) \lt 0$ then

   $$
     \sqrt{-\eta(v,v)} \in \mathbb{R}
   $$

   is interpreted as a measure for the _[[timelike|time]] [[distance]]_ between $x$ and $x + v$.

But for this to make physical sense, an operational prescription needs to be specified that tells the experimentor how the _[[real number]]_ $\sqrt{\eta(v,v)}$ is to be translated into an physical distance between actual [[events]] in the [[observable universe]].

Such an operational prescription is called a _[[physical unit]] of [[length]]_.
For example "[[centimeter]]" $cm$ is a physical unit of length, another one is "[[femtometer]]" $fm$.

The combined information of a [[real number]] $\sqrt{\eta(v,v)} \in \mathbb{R}$ and a [[physical unit]] of [[length]] such as [[meter]], jointly written

$$
  \sqrt{\eta(v,v)} \, cm
$$

is a prescription for finding actual distance in the [[observable universe]]. Alternatively

$$
  \sqrt{\eta(v,v)} \, fm
$$

is another prescription, that translates the same [[real number]] $\sqrt{\eta(v,v)}$ into another physical distance.

But of course they are related, since [[physical units]] form a [[torsor]] over the [[group]] $\mathbb{R}_{\gt 0}$ of [[non-negative number|non-negative]] [[real numbers]], meaning that any two are related by a unique rescaling. For example

$$
  fm = 10^{-13} cm
  \,,
$$

with $10^{-13} \in \mathbb{R}_{\gt 0}$.

This means that once any one prescription of turning real numbers into spacetime distances is specified, then any other such prescription is obtained from this by rescaling these real numbers. For example

$$
  \begin{aligned}
    \sqrt{\eta(v,v)} \, fm
    & = \left( 10^{-13} \sqrt{\eta(v,v)}\right) \,cm
    \\
    & =
    \sqrt{ 10^{-26} \eta(v,v) } \, cm
  \end{aligned}
  \,.
$$

The point to notice here is that, via the last line, we may think of this as
_rescaling the [[metric]]_ from $\eta$ to $10^{-30} \eta$.

In [[quantum field theory]] [[physical units]] of [[length]] are typically expressed in terms of a
[[physical unit]] of "[[action]]", called "[[Planck's constant]]" $\hbar$, via the
combination of units called the _[[Compton wavelength]]_

$$
  \label{ComptonWavelength}
  \ell_m = \frac{2\pi \hbar}{m c}
  \,.
$$

parameterized, in turn, by a [[physical unit]] of [[mass]] $m$. For the mass of the [[electron]],
the [[Compton wavelength]] is

$$
  \ell_e =  \frac{2\pi \hbar}{m_e c} \sim 386 \, fm
  \,.
$$


Another [[physical unit]] of [[length]] parameterized by a [[mass]] $m$ is the _[[Schwarzschild radius]]_ $r_m \coloneqq 2 m G/c^2$, where $G$ is the [[gravitational constant]]. Solving the [[equation]]

$$
  \array{
    & \ell_m &=& r_m
    \\
    \Leftrightarrow & 2\pi\hbar / m c &=& 2 m G / c^2
  }
$$

for $m$ yields the _[[Planck mass]]_

$$
   m_{P} \coloneqq \tfrac{1}{\sqrt{\pi}} m_{\ell = r} = \sqrt{\frac{\hbar c}{G}}
  \,.
$$

The corresponding [[Compton wavelength]] $\ell_{m_{P}}$ is given by the _[[Planck length]]_ $\ell_P$

$$
  \ell_{P} \coloneqq \tfrac{1}{2\pi} \ell_{m_P} = \sqrt{ \frac{\hbar G}{c^3} }
  \,.
$$


=--


+-- {: .num_defn #MinkowskiSpacetime}
###### Definition
**([[Minkowski spacetime]] as a [[pseudo-Riemannian manifold|pseudo-Riemannian]] [[Cartesian space]])**

Prop./def. \ref{SpacetimeAsMatrices} introduces [[Minkowski spacetime]] $\mathbb{R}^{p,1}$
for $p+1 \in \{3,4,6,10\}$ as a
a [[vector space]] $\mathbb{R}^{p,1}$ equipped with a [[norm]] ${\vert - \vert_\eta}$. The genuine [[spacetime]] corresponding to this
is this vector space regaded as a [[Cartesian space]], i.e. with [[smooth functions]] (instead of just [[linear maps]])
to it and from it (def. \ref{CartesianSpacesAndSmoothFunctionsBetweenThem}).
This still carries one copy of $\mathbb{R}^{p,1}$ over each point $x \in \mathbb{R}^{p,1}$, as its [[tangent space]] (example \ref{TangentVectorFields})

$$
  T_x \mathbb{R}^{p,1} \simeq \mathbb{R}^{p,1}
$$

and the [[Cartesian space]] $\mathbb{R}^{p,1}$ equipped with the Lorentzian inner product from
prop./def. \ref{SpacetimeAsMatrices} on each [[tangent space]] $T_x \mathbb{R}^{p,1}$
(a "[[pseudo-Riemannian manifold|pseudo-Riemannian]] [[Cartesian space]]") is  _[[Minkowski spacetime]]_ as such.

We write

$$
  \label{MinkowskiVolume}
  dvol_\Sigma
   \;\coloneqq\;
  d x^0 \wedge d x^1 \wedge \cdots \wedge d x^p
  \in \Omega^{p+1}(\mathbb{R}^{p,1})
$$

for the canonical [[volume form]] on Minkowski spacetime.

We use the [[Einstein summation convention]]: Expressions with repeated indices indicate [[sum|summation]] over the
range of indices.

For example a [[differential 1-form]] $\alpha \in \Omega^1(\mathbb{R}^{p,1})$ on Minkowski spacetime may be expanded as

$$
  \alpha = \alpha_\mu d x^\mu
  \,.
$$

Moreover we use square brackets around indices to indicate skew-symmetrization. For example a [[differential 2-form]]
$\beta \in \Omega^2(\mathbb{R}^{p,1})$ on Minkowski spacetime may be expanded as

$$
  \begin{aligned}
    \beta
    & = \beta_{\mu \nu} d x^\mu \wedge d x^\nu
    \\
    & = \beta_{[\mu \nu]} d x^\mu \wedge d x^\nu
  \end{aligned}
$$

=--

$\,$

The identification of [[Minkowski spacetime]] (def. \ref{MinkowskiSpacetime}) in the exceptional dimensions with the
generalized [[Pauli matrices]] (prop./def. \ref{SpacetimeAsMatrices}) has some immediate useful implications:

+-- {: .num_prop #DeterminantViaProductWithTraceReversal}
###### Proposition
**([[Minkowski spacetime|Minkowski metric]] in terms of [[trace]] reversal)**

In terms of the trace reversal operation $\widetilde{(-)}$ from def. \ref{TraceReversal},
the [[determinant]] operation on [[hermitian matrices]] (def. \ref{MatrixNotation}) has the following alternative expression

$$
  \begin{aligned}
    -det(A) & = A \tilde A
      \\
      & = \tilde A A
  \end{aligned}
  \,.
$$

and the Minkowski inner product from prop. \ref{SpacetimeAsMatrices} has the alternative expression

$$
  \begin{aligned}
    \eta(A,B) & = \tfrac{1}{2}Re(tr(A \tilde B))
    \\
    & = \tfrac{1}{2} Re(tr(\tilde A B))
  \end{aligned}
  \,.
$$

=--

([Baez-Huerta 09, prop. 5](geometry+of+physics+--+supersymmetry#BaezHuerta09))



+-- {: .num_prop #SLGrupOnPaulimatrices}
###### Proposition
**([[special linear group]] $SL(2,\mathbb{K})$ acts by linear [[isometries]] on [[Minkowski spacetime]] )**

For $\mathbb{K} \in \{\mathbb{R}, \mathbb{C}, \mathbb{H}, \mathbb{O}\}$ one of the four real [[normed division algebras]]
(prop. \ref{HurwitzTheorem}) the [[special linear group]] $SL(2,\mathbb{K})$ [[action|acts]] on [[Minkowski spacetime]] $\mathbb{R}^{p,1}$
in dimension $p+1 \in \{2+1, \,3+1, \, 5+1. \, 9+1\}$ (def. \ref{MinkowskiSpacetime})
by [[linear map|linear]] [[isometries]] given under the identification with the [[Pauli matrices]] in prop./def. \ref{SpacetimeAsMatrices} by [[conjugation]]:

$$
  \array{
    SL(2,\mathbb{K}) \times \mathbb{R}^{dim(\mathbb{K}+1,1)}
      & \simeq &
    SL(2, \mathbb{K}) \times Mat^{herm}_{2 \times 2}(\mathbb{K})
      &\overset{}{\longrightarrow}&
    Mat^{herm}_{2 \times 2}(\mathbb{K})
     & \simeq &
    \mathbb{R}^{dim(\mathbb{K}+1,1)}
    \\
    &&
    (G, A) &\mapsto& G \, A \, G^\dagger
  }
$$

=--

+-- {: .proof}
###### Proof

For $\mathbb{K} \in \{\mathbb{R}, \mathbb{C}, \mathbb{H}\}$ this is immediate from [[matrix calculus]], but we spell it out now.
While the argument does not directly apply to the case $\mathbb{K} = \mathbb{O}$ of the [[octonions]], one can check that it
still goes through, too.

First we need to see that the [[action]] is well defined. This follows from the [[associativity]] of [[matrix multiplication]]
and the fact that forming [[conjugate transpose matrices]] is an [[antihomomorphism]]: $(G_1 G_2)^\dagger = G_2^\dagger G_1^\dagger$.
In particular this implies that the action indeed sends [[hermitian matrices]] to hermitian matrices:

$$
  \begin{aligned}
    \left(
      G \, A \, G^\dagger
    \right)^\dagger
    & =
    \underset{= G}{\underbrace{\left( G^\dagger \right)}} \, \underset{= A}{\underbrace{A^\dagger}} \, G^\dagger
    \\
    & =
    G \, A \, G^\dagger
  \end{aligned}
  \,.
$$

By prop./def. \ref{SpacetimeAsMatrices} such an action is an [[isometry]] precisely if it preserves the
[[determinant]]. This follows from the multiplicative property of determinants: $det(A B) = det(A) det(B)$
and their compativility with conjugate transposition: $det(A^\dagger) = det(A^\ast)$, and
finally by the assumption that $G \in SL(2,\mathbb{K})$ is an element of the [[special linear group]], hence
that its determinant is $1 \in \mathbb{K}$:

$$
  \begin{aligned}
    det\left(
      G \, A \, G^\dagger
    \right)
    & =
    \underset{ = 1}{\underbrace{det(G)}} \, det(A) \, \underset{= 1^\ast = 1}{\underbrace{det(G^\dagger)}}
    \\
    & = det(A)
  \end{aligned}
  \,.
$$

=--

In fact the [[special linear groups]] of [[linear map|linear]] [[isometries]] in prop. \ref{SLGrupOnPaulimatrices}
are the [[spin groups]] (def. \ref{SpinGroup} below) in these dimensions.

[[!include exceptional spinors and division algebras -- table]]

This we explain now.



$\,$

**Lorentz group and spin group**
 {#LorentzGroupAndSpinGroup}


+-- {: .num_defn #LorentzGroup}
###### Definition
**([[Lorentz group]])**

For $d \in \mathbb{N}$, write

$$
  O(d-1,1)  \hookrightarrow GL(\mathbb{R}^d)
$$

for the [[subgroup]] of the [[general linear group]] on those [[linear maps]] $A$ which preserve this bilinear form
on [[Minkowski spacetime]] (def \ref{MinkowskiSpacetime}), in that

$$
  \eta(A(-),A(-)) = \eta(-,-)
  \,.
$$

This is the **[[Lorentz group]]** in dimension $d$.

The elements in the Lorentz group in the image of the [[special orthogonal group]] $SO(d-1) \hookrightarrow O(d-1,1)$ are _[[rotations]]_ in space. The further elements in the special Lorentz group $SO(d-1,1)$, which mathematically are "hyperbolic rotations" in a space-time plane, are called _[[boosts]]_ in [[physics]].

One distinguishes the following further [[subgroups]] of the [[Lorentz group]] $O(d-1,1)$:

* the _[[proper Lorentz group]]_

  $$
    SO(d-1,1) \hookrightarrow O(d-1,1)
  $$

  is the subgroup of elements which have [[determinant]] +1 (as elements  $SO(d-1,1)\hookrightarrow GL(d)$ of the [[general linear group]]);

* the _[[proper orthochronous Lorentz group|proper orthochronous]]_ (or _restricted_) Lorentz group

  $$
    SO^+(d-1,1) \hookrightarrow SO(d-1,1)
  $$

  is the further [[subgroup]] of elements $A$ which preserve the time orientation of vectors $v$ in that
  $(v^0 \gt 0) \Rightarrow ((A v)^0 \gt 0)$.

=--

+-- {: .num_prop #ConnectedComponentsOfLorentzGroup}
###### Proposition
**([[connected component]] of [[Lorentz group]])**

As a [[smooth manifold]], the [[Lorentz group]] $O(d-1,1)$ (def. \ref{LorentzGroup})
has four [[connected components]]. The connected component of the identity is the
[[proper orthochronous Lorentz group]] $SO^+(3,1)$ (def. \ref{LorentzGroup}). The other three components are

1. $SO^+(d-1,1)\cdot P$

1. $SO^+(d-1,1)\cdot T$

1. $SO^+(d-1,1)\cdot P T$,

where, as [[matrices]],

$$
  P \coloneqq diag(1,-1,-1, \cdots, -1)
$$

is the operation of point reflection at the origin in space, where

$$
  T \coloneqq diag(-1,1,1, \cdots, 1)
$$

is the operation of reflection in time and hence where

$$
  P T = T P = diag(-1,-1, \cdots, -1)
$$

is point reflection in spacetime.

=--






The following concept of the [[Clifford algebra]] (def. \ref{CliffordAlgebra}) of [[Minkowski spacetime]]
encodes the structure of the [[inner product space]] $\mathbb{R}^{d-1,1}$
in terms of algebraic operation ("[[geometric algebra]]"), such that the action of the
[[Lorentz group]] becomes represented by a [[conjugation action]] (example \ref{CliffordConjugtionReflectionAndRotation} below).
In particular this means that every element of the proper orthochronous Lorentz group may be "split in half"
to yield a [[double cover]]: the [[spin group]] (def. \ref{SpinGroup} below).



+-- {: .num_defn #CliffordAlgebra}
###### Definition
**([[Clifford algebra]])**

For $d \in \mathbb{N}$, we write

$$
  Cl(\mathbb{R}^{d-1,1})
$$

for the $\mathbb{Z}/2$-[[graded algebra|graded]] [[associative algebra]] over $\mathbb{R}$
which is generated from $d$ generators $\{\Gamma_0, \Gamma_1, \Gamma_2, \cdots, \Gamma_{d-1}\}$
in odd degree ("Clifford generators"), subject to the [[generators and relations|relation]]

$$
  \label{RelationCliffordAlgebra}
  \Gamma_{a} \Gamma_b + \Gamma_b \Gamma_a = - 2\eta_{a b}
$$

where $\eta$ is the [[inner product]] of [[Minkowski spacetime]] as in def. \ref{MinkowskiSpacetime}.

These relations say equivalently that

$$
  \begin{aligned}
    & \Gamma_0^2 = +1
    \\
    & \Gamma_i^2 = -1 \;\; \text{for}\; i \in \{1,\cdots, d-1\}
    \\
    & \Gamma_a \Gamma_b = - \Gamma_b \Gamma_a \;\;\; \text{for}\; a \neq b
  \end{aligned}
  \,.
$$

We write

$$
  \Gamma_{a_1 \cdots a_p}
    \;\coloneqq\;
  \frac{1}{p!}
  \underset{{permutations \atop \sigma}}{\sum} (-1)^{\vert \sigma\vert } \Gamma_{a_{\sigma(1)}} \cdots \Gamma_{a_{\sigma(p)}}
$$

for the antisymmetrized product of $p$ Clifford generators.
In particular, if all the $a_i$ are pairwise distinct, then this is simply the plain product of generators

$$
  \Gamma_{a_1 \cdots a_n}
  =
  \Gamma_{a_1} \cdots \Gamma_{a_n}
  \;\;\;
  \text{if}
  \;
  \underset{i,j}{\forall} (a_i \neq a_j)
  \,.
$$

Finally, write

$$
  \overline{(-)}
  \;\colon\;
    Cl(\mathbb{R}^{d-1,1})
      \longrightarrow
    Cl(\mathbb{R}^{d-1,1})
$$

for the algebra [[antihomomorphism|anti-]][[automorphism]] given by

$$
  \overline{\Gamma_a}
    \coloneqq
  \Gamma_a
$$

$$
  \overline{\Gamma_a \Gamma_b}
    \coloneqq
  \Gamma_b \Gamma_a
  \,.
$$

=--

+-- {: .num_remark #VectorsInsideCliffordAlgebra}
###### Remark
**([[vectors]] inside [[Clifford algebra]])**

By construction, the [[vector space]] of [[linear combinations]] of the generators
in a [[Clifford algebra]] $Cl(\mathbb{R}^{d-1,1})$ (def. \ref{CliffordAlgebra}) is canonically identified
with [[Minkowski spacetime]] $\mathbb{R}^{d-1,1}$ (def. \ref{MinkowskiSpacetime})

$$
  \widehat{(-)}
    \;\colon\;
  \mathbb{R}^{d-1,1}
    \hookrightarrow
  Cl(\mathbb{R}^{d-1,1})
$$

via

$$
  x_a \mapsto \Gamma_a
  \,,
$$

hence via

$$
  v = v^a x_x \mapsto \hat v = v^a \Gamma_a
  \,,
$$

such that the defining [[quadratic form]] on $\mathbb{R}^{d-1,1}$ is identified with
the [[anti-commutator]] in the Clifford algebra

$$
  \eta(v_1,v_2) = -\tfrac{1}{2}( \hat v_1 \hat v_2 + \hat v_2 \hat v_1)
  \,,
$$

where on the right we are, in turn, identifying $\mathbb{R}$ with the linear span of the unit in $Cl(\mathbb{R}^{d-1,1})$.

=--

The key point of the [[Clifford algebra]] (def. \ref{CliffordAlgebra}) is that it realizes
spacetime [[reflections]], [[rotations]] and [[boosts]] via [[conjugation actions]]:

+-- {: .num_example #CliffordConjugtionReflectionAndRotation}
###### Example
**(Clifford conjugation)**

For $d \in \mathbb{N}$ and $\mathbb{R}^{d-1,1}$ the [[Minkowski spacetime]] of def. \ref{MinkowskiSpacetime},
let $v \in \mathbb{R}^{d-1,1}$ be any [[vector]], regarded as an element $\hat v \in Cl(\mathbb{R}^{d-1,1})$ via remark \ref{VectorsInsideCliffordAlgebra}.

Then

1. the [[conjugation action]] $\hat v \mapsto -\Gamma_a^{-1} \hat v \Gamma_a$
   of a single Clifford generator $\Gamma_a$ on $\hat v$ sends $v$ to its
  [[reflection]] at the hyperplane $x_a = 0$;

1. the [[conjugation action]]

   $$
     \hat v \mapsto \exp(- \tfrac{\alpha}{2} \Gamma_{a b}) \hat v \exp(\tfrac{\alpha}{2} \Gamma_{a b})
   $$

   sends $v$ to the result of [[rotation|rotating]] it in the $(a,b)$-plane through an angle $\alpha$.

=--

+-- {: .proof}
###### Proof

This is immediate by inspection:

For the first statement, observe that conjugating the Clifford generator $\Gamma_b$ with $\Gamma_a$
yields $\Gamma_b$ up to a sign, depending on whether $a = b$ or not:

$$
  - \Gamma_a^{-1} \Gamma_b \Gamma_a
  =
  \left\{
    \array{
      -\Gamma_b & \vert \text{if}\, a = b
      \\
      \Gamma_b & \vert \text{otherwise}
    }
  \right.
  \,.
$$

Therefore for $\hat v = v^b \Gamma_b$ then $\Gamma_a^{-1} \hat v \Gamma_a$ is the result of
multiplying the $a$-component of $v$ by $-1$.

For the second statement, observe that

$$
  -\tfrac{1}{2}[\Gamma_{a b}, \Gamma_c]
  =
  \Gamma_a \eta_{b c} - \Gamma_b \eta_{a c}
  \,.
$$

This is the canonical action of the Lorentzian [[special orthogonal Lie algebra]] $\mathfrak{so}(d-1,1)$.
Hence

$$
  \exp(-\tfrac{\alpha}{2} \Gamma_{ab}) \hat v \exp(\tfrac{\alpha}{2} \Gamma_{ab})
    =
  \exp(\tfrac{1}{2}[\Gamma_{a b}, -])(\hat v)
$$

is the rotation action as claimed.

=--

+-- {: .num_remark #AmbiguityInCliffordConjugation}
###### Remark

Since the [[reflections]], [[rotations]] and [[boosts]] in example \ref{CliffordConjugtionReflectionAndRotation} are given by [[conjugation actions]], there is a crucial ambiguity in the Clifford elements that induce them:

1. the conjugation action by $\Gamma_a$ coincides precisely with the conjugation action by $-\Gamma_a$;

1. the [[conjugation action]] by $\exp(\tfrac{\alpha}{4} \Gamma_{a b})$ coincides precisely with the
   conjugation action by $-\exp(\tfrac{\alpha}{2}\Gamma_{a b})$.

=--


+-- {: .num_defn #SpinGroup}
###### Definition
**([[spin group]])**

For $d \in \mathbb{N}$, the **[[spin group]]** $Spin(d-1,1)$ is the group of
even graded elements of the Clifford algebra $Cl(\mathbb{R}^{d-1,1})$ (def. \ref{CliffordAlgebra})
which are [[unitary operator|unitary]] with respect to the conjugation operation $\overline{(-)}$
from def. \ref{CliffordAlgebra}:

$$
  Spin(d-1,1)
   \;\coloneqq\;
  \left\{
    A \in Cl(\mathbb{R}^{d-1,1})_{even}
    \;\vert\;
    \overline{A} A = 1
  \right\}
  \,.
$$

=--

+-- {: .num_prop #SpinDoubleCover}
###### Proposition

The [[function]]

$$
  Spin(d-1,1)
    \longrightarrow
  GL(\mathbb{R}^{d-1,1})
$$

from the [[spin group]] (def. \ref{SpinGroup}) to the [[general linear group]] in $d$-dimensions
given by sending $A \in Spin(d-1,1) \hookrightarrow Cl(\mathbb{R}^{d-1,1})$ to the
[[conjugation action]]

$$
  \overline{A}(-) A
$$

(via the identification of Minkowski spacetime as the subspace of the [[Clifford algebra]]
containing the [[linear combinations]] of the generators, according to remark \ref{VectorsInsideCliffordAlgebra})

is

1. a [[group]] [[homomorphism]] onto the [[proper orthochronous Lorentz group]] (def. \ref{LorentzGroup}):

   $$
     Spin(d-1,1) \longrightarrow SO^+(d-1,1)
   $$

1. exhibiting a $\mathbb{Z}/2$-[[central extension]].

=--

+-- {: .proof}
###### Proof

That the function is a group homomorphism into the [[general linear group]], hence that it acts by [[linear transformations]]
on the generators follows by using that it clearly lands in [[automorphisms]] of the Clifford algebra.

That the function lands in the [[Lorentz group]] $O(d-1,1) \hookrightarrow GL(d)$ follows from remark \ref{VectorsInsideCliffordAlgebra}:

$$
  \begin{aligned}
    \eta(\overline{A}v_1A , \overline{A} v_2 A)
    &=
    \tfrac{1}{2}
    \left(
    \left(\overline{A} \hat v_1 A\right) \left(\overline{A}\hat v_2 A\right)
    +
    \left(\overline{A} \hat v_2 A\right) \left(\overline{A} \hat v_1 A\right)
    \right)
    \\
    & =
    \tfrac{1}{2}
    \left(
    \overline{A}(\hat v_1 \hat v_2 + \hat v_2 \hat v_1) A
    \right)
    \\
    & =
    \overline{A} A \tfrac{1}{2}\left( \hat v_1 \hat v_2 + \hat v_2 \hat v_1\right)
    \\
    & =
    \eta(v_1, v_2)
  \end{aligned}
  \,.
$$

That it moreover lands in the [[proper Lorentz group]] $SO(d-1,1)$ follows from
observing (example \ref{CliffordConjugtionReflectionAndRotation}) that every reflection is given by the [[conjugation action]] by
a linear combination of generators, which are excluded from the group $Spin(d-1,1)$
(as that is defined to be in the even subalgebra).


To see that the homomorphism is surjective, use that all elements of $SO(d-1,1)$
are products of [[rotations]] in hyperplanes. If a hyperplane is spanned by the [[bivector]]
$(\omega^{a b})$, then such a rotation is given, via example \ref{CliffordConjugtionReflectionAndRotation}
by the conjugation action by
$$
  \exp(\tfrac{\alpha}{2} \omega^{a b}\Gamma_{a b})
$$

for some $\alpha$, hence is in the image.

That the [[kernel]] is $\mathbb{Z}/2$ is clear from the fact that the only even Clifford elements which commute
with all vectors are the multiples $a \in \mathbb{R} \hookrightarrow Cl(\mathbb{R}^{d-1,1})$ of the identity.
For these $\overline{a} = a$ and hence
the condition $\overline{a} a = 1$ is equivalent to $a^2 = 1$. It is clear that these two elements
$\{+1,-1\}$ are in the [[center]] of $Spin(d-1,1)$. This
kernel reflects the ambiguity from remark \ref{AmbiguityInCliffordConjugation}.

=--


$\,$

**Spinors in dimensions 3, 4, 6 and 10**
 {#InTermsOfNormedDivisionAlgebraInDimension3To10}

We now discuss how [[real spin representations]] (def. \ref{SpinGroup}) in
spacetime dimensions 3,4, 6 and 10 are naturally induced from
[[linear algebra]] over the four real [[alternative algebras|alternative]] [[division algebras]] (prop. \ref{HurwitzTheorem}).



+-- {: .num_defn #CliffordAlgebraInTermsOfNormedDivisionAlgebra}
###### Definition
**([[Clifford algebra]] via [[normed division algebra]])**

Let $\mathbb{K}$ be one of the four real [[normed division algebras]] from prop. \ref{HurwitzTheorem}, hence one of the four
real [[alternative algebra|alternative]] [[division algebras]] from prop. \ref{ZornTheorem}.


Define a [[real numbers|real]] [[linear map]]

$$
  \Gamma \;\colon\; \mathbb{R}^{dim_{\mathbb{R}}(\mathbb{K})+1,1} \longrightarrow End_{\mathbb{R}}(\mathbb{K}^4)
$$

from (the real vector space underlying) [[Minkowski spacetime]] to real [[linear maps]] on $\mathbb{K}^4$

$$
  \Gamma(A)
  \left(
    \array{
      \psi
      \\
      \phi
    }
  \right)
  \;\coloneqq\;
  \left(
    \array{
      - \tilde A \phi
      \\
      A \psi
    }
  \right)
  \,.
$$

Here on the right we are using the isomorphism from prop. \ref{SpacetimeAsMatrices} for identifying
a spacetime vector with a $2 \times 2$-matrix, and we are using the trace reversal $\widetilde(-)$
from def. \ref{TraceReversal}.

=--

+-- {: .num_remark}
###### Remark
**([[Clifford algebra|Clifford multiplication]] via [[octonion]]-valued matrices)**

Each operation of $\Gamma(A)$ in def. \ref{CliffordAlgebraInTermsOfNormedDivisionAlgebra} is clearly a [[linear map]],
even for $\mathbb{K}$ being the non-associative [[octonions]]. The only point to beware of is that for $\mathbb{K}$
the octonions, then the composition of two such linear maps is not in general given by the
usual matrix product.

=--


+-- {: .num_prop #SpinorRepsByNormedDivisionAlgebra}
###### Proposition
**([[real spin representations]] via [[normed division algebras]])**

The map $\Gamma$ in def. \ref{CliffordAlgebraInTermsOfNormedDivisionAlgebra} gives a [[representation]] of the [[Clifford algebra]]
$Cl(\mathbb{R}^{dim_{\mathbb{R}}}(\mathbb{K}+1,1)  )$
([this def.](geometry+of+physics+--+supersymmetry#CliffordAlgebra)), i.e of

1. $Cl(\mathbb{R}^{2,1})$ for $\mathbb{K} = \mathbb{R}$;

1. $Cl(\mathbb{R}^{3,1})$ for $\mathbb{K} = \mathbb{C}$;

1. $Cl(\mathbb{R}^{5,1})$ for $\mathbb{K} = \mathbb{H}$;

1. $Cl(\mathbb{R}^{9,1})$ for $\mathbb{K} = \mathbb{O}$.

Hence this Clifford representation induces [[spin representations|representations]]
of the [[spin group]] $Spin(dim_{\mathbb{R}}(\mathbb{K})+1,1)$  on
the real vector spaces

$$
  S_{\pm } \coloneqq \mathbb{K}^2
  \,.
$$

and hence on

$$
  S \coloneqq S_+ \oplus S_-
  \,.
$$

=--

([Baez-Huerta 09, p. 6](geometry+of+physics+--+supersymmetry#BaezHuerta09))

+-- {: .proof}
###### Proof

We need to check that the Clifford relation

$$
  \begin{aligned}
    (\Gamma(A))^2
      & = -\eta(A,A)1
      \\
      & = + det(A)
  \end{aligned}
$$

is satisfied (where we used (eq:RelationCliffordAlgebra) and (eq:MinkowskiSpacetimeFromHermitianMatricesWithDeterminant)). Now by definition, for any $(\phi,\psi) \in \mathbb{K}^4$ then

$$
  (\Gamma(A))^2
  \left(
    \array{
      \phi
      \\
      \psi
    }
  \right)
  \;=\;
  -
  \left(
    \array{
      \tilde A(A \phi)
      \\
      A(\tilde A \psi)
    }
  \right)
  \,,
$$

where on the right we have in each component ordinary matrix product expressions.

Now observe that both expressions on the right are sums of triple products that involve either
one real factor or two factors that are conjugate to each other:

$$
  \begin{aligned}
    A (\tilde A \psi)
    & =
    \left(
      \array{
        x_0 + x_1 & y
        \\
        y^\ast & x_0 - x_1
      }
    \right)
      \cdot
    \left(
      \array{
        (-x_0 + x_1) \phi_1 + y \phi_2
        \\
        y^\ast \phi_1 - (x_0 + x_1)\phi_2
      }
    \right)
    \\
    & =
    \left(
      \array{
        (-x_0^2 + x_1^2) \phi_1 + (x_0 + x_1)(y \phi_2) + y (y^\ast \phi_1) - y( (x_0 + x_1) \phi_2 )
        \\
        \cdots
      }
    \right)
  \end{aligned}
  \,.
$$

Since the [[associators]] of triple products that involve a real factor and those involving both an element and its
conjugate vanish by prop. \ref{PropertiesOfAssociatorInAlternativeAlgebra} (hence ultimately by Artin's theorem, prop. \ref{ArtinTheorem}).
In conclusion all associators involved vanish, so that we may rebracket to obtain

$$
  (\Gamma(A))^2
  \left(
    \array{
      \phi
      \\
      \psi
    }
  \right)
  \;=\;
  -
  \left(
    \array{
      (\tilde A A) \phi
      \\
      (A \tilde A) \psi
    }
  \right)
  \,.
$$

This implies the statement via the equality $-A \tilde A = -\tilde A A = det(A)$ (prop. \ref{DeterminantViaProductWithTraceReversal}).

=--


+-- {: .num_prop #RealSpinorPairingsViaDivisionAlg}
###### Proposition
**([[spinor]] [[bilinear map|bilinear]] pairings)**

Let $\mathbb{K}$ be one of the four real [[normed division algebras]] and $S_\pm \simeq_{\mathbb{R}}\mathbb{K}^2$
the corresponding [[spin representation]] from prop. \ref{SpinorRepsByNormedDivisionAlgebra}.

Then there are [[bilinear maps]] from two [[spinors]] (according to prop. \ref{SpinorRepsByNormedDivisionAlgebra})
to the [[real numbers]]

$$
  \overline{(-)}(-) \;\colon\; S_+ \otimes S_-\longrightarrow \mathbb{R}
$$

as well as to $\mathbb{R}^{dim(\mathbb{K}+1,1)}$

$$
  \overline{(-)}\Gamma (-) \;\colon\; S_\pm \otimes S_{\pm}\longrightarrow \mathbb{R}^{dim(\mathbb{K}+1,1)}
$$

given, respectively, by forming the [[real part]] (def. \ref{Conjugation}) of the canonical $\mathbb{K}$-[[inner product]]

$$
  \overline{(-)}(-) \colon S_+\otimes S_- \longrightarrow \mathbb{R}
$$
$$
  (\psi,\phi)\mapsto \overline{\psi} \phi \coloneqq Re(\psi^\dagger \cdot \phi)
$$

and by forming the product of a column vector with a row vector to produce a matrix, possibly up to trace reversal (def. \ref{TraceReversal})
under the identification $\mathbb{R}^{dim(\mathbb{K})+1,1} \simeq Mat^{her}_{2 \times 2}(\mathbb{K})$ from prop. \ref{SpacetimeAsMatrices}:

$$
  S_+ \otimes S_+ \longrightarrow \mathbb{R}^{dim(\mathbb{K})+1,1}
$$
$$
  (\psi , \phi) \mapsto \overline{\psi}\Gamma \phi \coloneqq
  \widetilde{\psi \phi^\dagger + \phi \psi^\dagger}
$$

and

$$
  S_- \otimes S_- \longrightarrow \mathbb{R}^{dim(\mathbb{K}+1,1)}
$$
$$
  (\psi , \phi) \mapsto {\psi \phi^\dagger + \phi \psi^\dagger}
$$

For $A \in Mat^{her}_{2 \times 2}(\mathbb{K})$ the $A$-component of this map is

$$
  \eta(\overline{\psi}\Gamma \phi, A)
  =
  Re (\psi^\dagger (A\phi))
 \,.
$$

These pairings have the following properties

1. both are $Spin(dim(\mathbb{K})+1,1)$-equivalent;

1. the pairing $\overline{(-)}\Gamma(-)$ is _[[symmetric bilinear form|symmetric]]_:

   $$
     \label{SpinorToVectorPairingIsSymmetric}
     \overline{\psi_1} \,\Gamma\, \psi_2 = + \overline{\phi_2}\, \Gamma\, \psi_1
     \phantom{AAAA}
     \text{for} \phantom{AA} \psi_1, \psi_2 \in S_+ \oplus S_-
   $$

=--

([Baez-Huerta 09, prop. 8, prop. 9](geometry+of+physics+--+supersymmetry#BaezHuerta09)).


+-- {: .num_remark #TwoComponentSpinorNotation}
###### Remark
**(two-component [[spinor]] notation)**

In the [[physics]]/[[QFT]] literature the expressions for [[spin representations]]
given by prop. \ref{SpinorRepsByNormedDivisionAlgebra} are traditionally written in
_two-component spinor notation_ as follows:

* An element of $S_+$ is denoted $(\chi_a \in \mathbb{K})_{a = 1,2}$
  and called a _[[Weyl spinor|left handed spinor]]_;

* an element of $S_-$ is denoted $(\xi^{\dagger \dot a})_{\dot a = 1,2}$
  and called a _[[Weyl spinor|right handed spinor]]_;

* an element of $S = S_+ \oplus S_-$ is denoted

  $$
    \label{TwoComponentNotationForDiracSpinor}
    (\psi^\alpha) = \left( (\chi_a), (\xi^{\dagger \dot a}) \right)
  $$

  and called a _[[Dirac spinor]]_;

and the Clifford action of prop. \ref{CliffordAlgebraInTermsOfNormedDivisionAlgebra} corresponds to the generalized "[[Pauli matrices]]":

* a hermitian matrix $A \in Mat^{her}_{2\times 2}(\mathbb{K})$ as in prop \ref{SpacetimeAsMatrices} regarded as a linear map $S_- \to S_+$ via def. \ref{CliffordAlgebraInTermsOfNormedDivisionAlgebra} is denoted

  $$
    \left(x_\mu \sigma^\mu_{a \dot a}\right)
    \;\coloneqq\;
    \left( \array{  x_0 + x_1 & y  \\ y^\ast & x_0 - x_1 } \right)    \,;
  $$

* the negative of the trace-reversal (def. \ref{TraceReversal}) of such a hermitian matrix, regarded as a linear map $S_+ \to S_-$, is denoted

  $$
    \left(
      x_\mu \widetilde \sigma^{\mu \dot a a}
    \right)
    \;\coloneqq\;
    -
    \left( \array{  -x_0 + x_1 & y  \\ y^\ast & -x_0 - x_1 } \right)
    \,.
  $$

* the corresponding Clifford generator $\Gamma(A) \;\colon\; S_+ \oplus S_- \to S_+ \oplus S_-$ (def. \ref{CliffordAlgebraInTermsOfNormedDivisionAlgebra})
  is denoted

  $$
    x_\mu (\gamma^\mu)_{\alpha \beta}
    \;\coloneqq\;
    \left(
      \array{
         0 & x_\mu \sigma^\mu_{a \dot b}
         \\
         x_\mu \widetilde \sigma^{\mu \dot a b}
      }
    \right)
  $$

* the bilinear spinor-to-vector pairing from prop. \ref{RealSpinorPairingsViaDivisionAlg}
  is written as the [[matrix multiplication]]

  $$
    \left( \overline{\psi} \, \gamma^\mu \, \phi\right)
    \;\coloneqq\;
    \overline{\psi}\,\Gamma \,\phi
    \,,
  $$

  where the _[[Dirac conjugate]]_ $\overline{\psi}$  on the left is given
  on $(\psi_\alpha) = (\chi_a, \xi^{\dagger \dot c})$ by

  $$
    \label{DiracConjugate}
    \begin{aligned}
      \overline{\psi}
      & \coloneqq
      \psi^\dagger \gamma^0
      \\
      & =
      ( \xi^a, \chi^\dagger_{\dot a} )
    \end{aligned}
  $$

  hence, with (eq:TwoComponentNotationForDiracSpinor):

  $$
    \label{TwoComponentNotationForSpinorToVectorPairing}
    \begin{aligned}
      \overline{\psi_1} \,\gamma^\mu\, \psi_2
      & =
      \psi_1^\dagger \, \gamma^0 \gamma^\mu \, \psi_2
      \\
      & =
      (\xi_1)^a \, \sigma^\mu_{a \dot c}\, (\xi_2)^{\dagger \dot c}
      +
      (\chi_1)^\dagger_{\dot a} \, \widetilde \sigma^{\mu \dot a c} \, (\chi_2)_c
    \end{aligned}
  $$

Finally, it is common to abbreviate contractions with the [[Clifford algebra]] generators $(\gamma^\mu)$
by a slash, as in

$$
  k\!\!\!/\, \;\coloneqq\; \gamma^\mu k_\mu
$$

or

$$
  \label{FeynmanSlashNotationForMasslessDiracOperator}
  i \partial\!\!\!/\,
  \;\coloneqq\;
  i \gamma^\mu \frac{\partial}{\partial x^\mu}
  \,.
$$

This is called the _[[Feynman slash notation]]_.

=--

(e.g. [Dermisek I-8](Dirac+field#DermisekI8), [Dermisek I-9](Dirac+field#DermisekI9))




Below we spell out the example of the [[Lagrangian field theory]] of the [[Dirac field]]
in detail (example \ref{LagrangianDensityForDiracField}). For discussion of
_massive chiral spinor fields_ one also needs the following, here we just mention this for
completeness:

+-- {: .num_defn #ChiralSpinorMassPairing}
###### Proposition
**(chiral spinor mass pairing)**

In dimension 2+1 and 3+1, there exists a non-trivial skew-symmetric pairing

$$
  \epsilon
  \;\colon\;
  S \wedge S
    \longrightarrow
  \mathbb{R}
$$

which may be normalized such that in the two-component spinor basis of
remark \ref{TwoComponentSpinorNotation} we have

$$
  \label{ConjugationOfLeftRightCliffordGeneratorToRightLeft}
  \tilde \sigma^{\mu \dot a a} = \epsilon^{a b} \epsilon^{\dot a \dot b} \sigma^\mu_{b \dot b}
  \,.
$$

=--

+-- {: .proof}
###### Proof

Take the non-vanishing components of $\epsilon$ to be

$$
  \epsilon^{1 2} = \epsilon^{\dot 1 \dot 2} = \epsilon_{21} = \epsilon_{\dot 2 \dot 1} =  1
$$

and

$$
  \epsilon^{2 1} = \epsilon^{\dot 2 \dot 1} = \epsilon_{1 2} = \epsilon_{\dot 1 \dot 2} = -1
  \,.
$$

With this equation (eq:ConjugationOfLeftRightCliffordGeneratorToRightLeft) is checked explicitly.
It is clear that $\epsilon$ thus defined is skew symmetric as long as the component algebra
is commutative, which is the case for $\mathbb{K}$ being $\mathbb{R}$ or $\mathbb{C}$.


=--







$\,$

**Causal structure**
 {#CausalStructure}

We need to consider the following concepts and constructions related to the [[causal structure]] of [[Minkowski spacetime]] $\Sigma$ (def. \ref{MinkowskiSpacetime}).


+-- {: .num_defn #SpacelikeTimelikeLightlike}
###### Definition
**([[spacelike]], [[timelike]], [[lightlike]] [[direction of a vector|directions]]; [[past]] and [[future]])**

Given two points $x,y \in \Sigma$ in [[Minkowski spacetime]] (def. \ref{MinkowskiSpacetime}),
write

$$
  v \coloneqq y - x \in \mathbb{R}^{p,1}
$$

for their difference, using the [[vector space]] structure underlying [[Minkowski spacetime]].

Recall the Minkowski [[inner product]] $\eta$  on $\mathbb{R}^{p,1}$, given by prop./def. \ref{SpacetimeAsMatrices}.
Then via remark \ref{MinkowskiMetricAndPhysicalUnitOfLength} we say that the difference vector $v$ is

1. _[[spacelike]]_ if $\eta(v,v) \gt 0$,

1. _[[timelike]]_ if $\eta(v,v) \lt 0$,

1. _[[lightlike]]_ if $\eta(v,v) = 0$.

If $v$ is [[timelike]] or [[lightlike]] then we say that

1. $y$ is in the _[[future]]_ of $x$ if $y^0 - x^0 \geq 0$;

1. $y$ is in the _[[past]]_ of $x$ if $y^0 - x^0 \leq 0$.

=--

+-- {: .num_defn #CausalPastAndFuture}
###### Definition
**([[causal cones]])**

For $x \in \Sigma$ a point in spacetime (an [[event]]), we write

$$
  V^+(x), V^-(x) \subset \Sigma
$$

for the [[subsets]] of [[events]] that are in the [[timelike]] [[future]] or in the [[timelike]] [[past]] of $x$, respectively (def. \ref{SpacelikeTimelikeLightlike})
called the _[[open future cone]]_ and _[[open past cone]]_, respectively, and

$$
  \overline{V}^+(x), \overline{V}^-(x) \subset \Sigma
$$

for the [[subsets]] of [[events]] that are in the [[timelike]] or [[lightlike]] [[future]] or [[past]], respectivel,
called the _[[closed future cone]]_ and _[[closed past cone]]_, respectively.

The [[union]]

$$
  J(x) \coloneqq \overline{V}^+(x) \cup \overline{V}^-(x)
$$

of the closed [[future cone]] and [[past cone]] is called the full _[[causal cone]]_ of the [[event]] $x$.
Its [[boundary]] is the _[[light cone]]_.

More generally for $S \subset \Sigma$ a [[subset]] of [[events]] we write

$$
  \overline{V}^\pm(S)
  \;\coloneqq\;
  \underset{x \in S}{\cup} \overline{V}^{\pm}(x)
$$

for the [[union]] of the future/past closed cones of all events in the subset.

=--

+-- {: .num_defn #CompactlySourceCausalSupport}
###### Definition
**(compactly sourced causal support)

Consider a [[vector bundle]] $E \overset{}{\to} \Sigma$ (def. \ref{VectorBundle}) over [[Minkowski spacetime]] (def. \ref{MinkowskiSpacetime}).

Write $\Gamma_{\Sigma}(E)$ for the [[space of sections|spaces of smooth sections]] (def. \ref{Sections}), and write

$$
  \begin{aligned}
    \Gamma_{cp}(E) & \,\text{compact support}
    \\
    \Gamma_{\Sigma,\pm cp}(E) & \,\text{compactly sourced future/past support}
    \\
    \Gamma_{\Sigma,scp}(E) & \,\text{spacelike compact support}
    \\
    \Gamma_{\Sigma,(f/p)cp}(E) & \,\text{future/past compact support}
    \\
    \Gamma_{\Sigma,tcp}(E) & \,\text{timelike compact support}
  \end{aligned}
$$

for the subsets on those smooth sections whose [[support]] is

1. ($cp$) inside a [[compact subset]],

1. ($\pm cp$) inside the [[closed future cone]]/[[closed past cone]], respectively, of a [[compact subset]],

1. ($scp$) inside the [[closed causal cone]] of a [[compact subset]], which equivalently means that the [[intersection]] with every ([[spacelike]]) [[Cauchy surface]] is compact ([Sanders 13, theorem 2.2](#Sanders12)),

1. ($fcp$) inside the past of a Cauchy surface ([Sanders 13, def. 3.2](#Sanders12)),

1. ($pcp$) inside the future of a Cauchy surface ([Sanders 13, def. 3.2](#Sanders12)),

1. ($tcp$) inside the future of one Cauchy surface and the past of another ([Sanders 13, def. 3.2](#Sanders12)).

=--

([B&#228;r 14, section 1](space+of+sections#Baer14), [Khavkine 14, def. 2.1](Green+hyperbolic+differential+operator#Khavkine14))



+-- {: .num_defn #CausalOrdering}
###### Definition
**([[causal order]])**

Consider the [[relation]] on the set $P(\Sigma)$ of [[subsets]] of [[spacetime]]
which says a [[subset]] $S_1 \subset \Sigma$ is _not prior_ to a subset $S_2 \subset \Sigma$,
denoted $S_1 {\vee\!\!\!\wedge} S_2$, if $S_1$ does not [[intersection|intersect]] the [[causal past]] of $S_2$ (def. \ref{CausalPastAndFuture}),
or equivalently that $S_2$ does not intersect the [[causal future]] of $S_1$:

$$
  \begin{aligned}
    S_1 {\vee\!\!\!\wedge} S_2
    & \;\;\coloneqq\;\;
    S_1 \cap \overline{V}^-(S_2) = \emptyset
    \\
    & \;\;\Leftrightarrow\;\; S_2 \cap \overline{V}^+(S_1) = \emptyset
   \end{aligned}
   \,.
$$

(Beware that this is just a [[relation]], not an [[ordering]], since it is not [[transitive relation|relation]].)

If $S_1 {\vee\!\!\!\wedge} S_2$ and $S_2 {\vee\!\!\!\wedge} S_1$ we say that the two subsets are _[[spacelike]] separated_ and write

$$
  S_1 {\gt\!\!\!\!\lt} S_2
  \;\;\;\coloneqq\;\;\;
  S_1 {\vee\!\!\!\wedge} S_2 \;\text{and}\; S_2 {\vee\!\!\!\wedge} S_1
  \,.
$$

=--

+-- {: .num_example #CausalComplementOfSubsetOfLorentzianManifold}
###### Definition
**([[causal complement]] and [[causal closure]] of subset of [[spacetime]])**

For $S \subset X$ a [[subset]] of [[spacetime]], its _[[causal complement]]_ $S^\perp$ is the [[complement]] of the [[causal cone]]:

$$
  S^\perp \;\coloneqq\; S \setminus J_X(S)
  \,.
$$

The causal complement $S^{\perp \perp}$ of the causal complement $S^\perp$ is called the _[[causal closure]]_. If

$$
  S = S^{\perp \perp}
$$

then the subset $S$ is called a _[[causally closed subset]]_.

Given a [[spacetime]] $\Sigma$, we write

$$
  CausClsdSubsets(\Sigma) \;\in\; Cat
$$

for the [[partially ordered set]] of causally closed subsets, partially ordered by
inclusion $\mathcal{O}_1 \subset \mathcal{O}_2$.

=--


+-- {: .num_defn #CutoffFunctions}
###### Definition
**([[adiabatic switching]])**

For a [[causally closed subset]] $\mathcal{O} \subset \Sigma$ of [[spacetime]] (def. \ref{CausalComplementOfSubsetOfLorentzianManifold}) say that an _[[adiabatic switching]] function_ or  _[[infrared cutoff]] function_ for $\mathcal{O}$
is a [[smooth function]] $g_{sw}$ of [[compact support]] (a [[bump function]]) whose
restriction to some [[neighbourhood]] $U$ of $\mathcal{O}$ is the [[constant function]]
with value $1$:

$$
  Cutoffs(\mathcal{O})
  \;\coloneqq\;
  \left\{
    g_{sw} \in C^\infty_c(\Sigma)
    \;\vert\;
    \underset{ {U \supset \mathcal{O}} \atop { \text{neighbourhood} } }{\exists}
    \left(
      g_{sw}\vert_U = 1
    \right)
  \right\}
  \,.
$$

Often we consider the vector space space $C^\infty(\Sigma)\langle g \rangle $ spanned by a formal
variable $g$ (the [[coupling constant]]) under multiplication with smooth functions, and consider as adiabatic switching functions
the corresponding images in this space,

$$
  \array{
     C_c^\infty(\Sigma) &\overset{\simeq}{\longrightarrow}& C_c^\infty(X)\langle g\rangle
  }
$$

which are thus bump functions constant over a neighbourhood $U$ of $\mathcal{O}$ not on 1 but on
the formal parameter $g$:

$$
  g_{sw}\vert_U = g
  \,
$$

In this sense we may think of the adiabatic switching as _being_ the spacetime-depependent coupling "constant".

=--

The following lemma \ref{CausalPartition} will be key in the derivation (proof of prop. \ref{CausalLocalityOfThePerturbativeSMatrix} below) of the [[causal locality]] of [[algebra of quantum observables]] in [[perturbative quantum field theory]]:

+-- {: .num_lemma #CausalPartition}
###### Lemma
**(causal partition)**

Let $\mathcal{O} \subset \Sigma$ be a [[causally closed subset]] (def. \ref{CausalComplementOfSubsetOfLorentzianManifold})
and let $f \in C^\infty_{cp}(\Sigma)$ be a [[compact support|compactly supported]] [[smooth function]] which vanishes
on a [[neighbourhood]] $U \supset \mathcal{O}$, i.e. $f\vert_U = 0$.

Then there exists a _causal partition_ of $f$ in that there
exist compactly supported smooth functions $a,r \in C^\infty_{cp}(\Sigma)$
such that

1. they sum up to $f$:

   $$
     f = a + r
   $$

1. their [[support]] satisfies the following causal ordering (def. \ref{CausalOrdering})

   $$
     supp(a) {\vee\!\!\!\wedge} \mathcal{O} {\vee\!\!\!\wedge} supp(r)
     \,.
   $$

=--

+-- {: .proof}
###### Proof idea

By assumption $\mathcal{O}$ has a [[Cauchy surface]]. This may be
extended to a Cauchy surface $\Sigma_p$ of $\Sigma$, such that this is one [[leaf]]
of a [[foliation]] of $\Sigma$ by Cauchy surfaces, given by a [[diffeomorphism]]
$\Sigma \simeq (-1,1) \times \Sigma_p$ with the original $\Sigma_p$ at zero.
There exists then $\epsilon \in (0,1)$ such that
the restriction of $supp(f)$ to the interval $(-\epsilon, \epsilon)$ is
in the [[causal complement]] $\overline{\mathcal{O}}$ of the given region (def. \ref{CausalComplementOfSubsetOfLorentzianManifold}):

$$
  supp(f) \cap (-\epsilon, \epsilon) \times \Sigma_p
  \;\subset\;
  \overline{\mathcal{O}}
  \,.
$$

Let then $\chi \colon \Sigma \to \mathbb{R}$ be any [[smooth function]] with

1. $\chi\vert_{(-1,0] \times \Sigma_p} = 1$

1. $\chi\vert_{(\epsilon,1) \times \Sigma_p} = 0$.

Then

$$
  r \coloneqq \chi \cdot f
  \phantom{AAA}
  \text{and}
  \phantom{AAA}
  a \coloneqq (1-\chi) \cdot f
$$

are smooth functions as required.

=--

$\,$

This concludes our discussion of [[spin]] and [[spacetime]]. In the [next chapter](#Fields) we consider the concept of _[[field (physics)|fields]]_ on [[spacetime]].
