
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Differential geometry
+-- {: .hide}
[[!include synthetic differential geometry - contents]]
=--
=--
=--

# Differential forms
* table of contents
{: toc}

## Idea

A differential form is a geometrical object on a [[manifold]] that can be integrated. A differential form $\omega$ is a [[section]] of the [[exterior algebra]] $\Lambda^* T^* X$ of a [[cotangent bundle]], which makes sense in many contexts (e.g. [[manifolds]], [[algebraic varieties]], [[analytic space]]s, ...). 

What we\'re actually describing here are the *exterior* differential forms; for more general concepts, see [[absolute differential form]] and [[cogerm differential form]].


## Definitions

### Standard definition

Given a differentiable [[manifold]] $X$, or even a [[generalized smooth space]] $X$ for which this definition makes sense, a __differential form__ on $X$ is a [[section]] of the [[exterior algebra]] of the [[cotangent bundle]] over $X$; sometimes one refers to an __exterior differential form__ to be more precise.  One often requires differential forms to be smooth, or at least continuous, but we will state this explicitly when we want it.  A __differential $p$-form__ on $X$ is a section of the $p$th [[exterior power]] of the cotangent bundle; the [[natural number]] $p \geq 0$ is the __rank__ of the form.  A general differential form is a $p$-indexed [[sequence]] of differential $p$-forms of which all but finitely many are zero; on a finite-dimensional manifold, this latter condition is automatic.


The _space_ $C^\infty\Omega^*(X)$ of *smooth* forms on $X$ may also be defined as the [[universal differential envelope]] of the space $C^\infty\Omega^0(X)$ of smooth functions on $X$ (which are the same as the smooth $0$-forms as defined above); more concretely:

It is generated by the smooth functions and three operations:

*  an associative binary operation of addition generalising the usual addition of functions,
*  an associative binary operation $\wedge$ (the __exterior product__ or __[[wedge product]]__) generalising the usual multiplication of functions,
*  a unary operation $\mathrm{d}$ (the __exterior derivative__, or __differential__);

subject to these identities:

*  addition makes $C^\infty\Omega^*(X)$ into an [[abelian monoid]],
*  both $\mathrm{d}$ and $\wedge$ distribute over addition,
*  $\mathrm{d}\mathrm{d}f = 0$,
*  $\mathrm{d}f \wedge \mathrm{d}f = 0$,
*  $\mathrm{d}(f \wedge \eta) = \mathrm{d}f \wedge \eta + f \wedge \mathrm{d}\eta$,
*  $\mathrm{d}(\mathrm{d}f \wedge \eta) + \mathrm{d}f \wedge \mathrm{d}\eta = 0$,

in which $f$ is a smooth function and $\eta$ is an arbitrary smooth form.  (Note that one often drops the '$\wedge$' after a $0$-form; thus, $f \eta = f \wedge \eta$.  There is hardly any ambiguity if one drops the '$\wedge$' entirely, but it\'s traditional.)

Although not directly stated, it can be proved that addition makes $C^\infty\Omega^*(X)$ into an [[abelian group]]; in fact, it is a [[module]] of the [[commutative ring]] of smooth functions on $X$.  This is further a [[graded module]], graded by the [[natural numbers]], with the elements of grade $p$ being the $p$-forms defined earlier; the space of these is $C^\infty\Omega^p(X)$.  If $\omega$ is a $p$-form and $\eta$ is a $q$-form, we have:

*  $\mathrm{d}\omega$ is a $(p+1)$-form,
*  $\omega \wedge \eta$ is a $(p+q)$-form.

The law
$$\mathrm{d}\mathrm{d}\eta = 0$$
holds for any form $\eta$, but the other laws become more complicated; if $\omega$ is a $p$-form and $\eta$ is a $q$-form, then we get

*  $\omega \wedge \omega = 0$ if $p$ is odd,
*  $\omega \wedge \eta = (-1)^{pq}\, \eta \wedge \omega$,
*  $\mathrm{d}(\omega \wedge \eta) = \mathrm{d}\omega \wedge \eta + (-1)^p\, \omega \wedge \mathrm{d}\eta$.

That is, $C^\infty\Omega^*(X)$ is a [[skew-commutative algebra]] over the ring of smooth functions, equipped with a [[derivation]] $\mathrm{d}$ of degree $1$.  In fact, the description above in terms of generators and relations makes it the [[free functor|free]] skew-commutative algebra over that ring equipped with such a derivation.  (Or if it doesn\'t, then it\'s because I left something out of that description.)

More general forms (in $\Omega^*(X)$) can be recovered as sums of terms, each of which is the wedge product of a function and a smooth form.  (This can also be seen as a special case of a vector-valued form as below.)  One can still define the exterior derivative of a $C^1$ (once continuously differentiable) form; in general, the differential of a $C^k$ form is a $C^{k-1}$ form.  If $X$ is not a smooth manifold but only $C^k$ for some $1 \leq k \lt \infty$, then one has to take more care here, but the definition of the skew-commutative algebra of $C^k$ differential forms can still be made to work.


Given local coordinates $(x^1, \ldots, x^n)$ on a patch $U$ in an $n$-dimensional manifold $X$, any differential form $\eta$ on $U$ can be expressed uniquely as a sum of $2^n$ terms
$$ \eta = \sum_I \eta_I \wedge \mathrm{d}x^I ,$$
where $I$ runs over *increasing* [[lists]] of indices from $(1,\ldots,n)$, each $\eta_I$ is a function on $U$ (continuous, smooth, etc according as $\eta$ is), and
$$ \mathrm{d}x^I = \mathrm{d}x^{I_1} \wedge \cdots \wedge \mathrm{d}x^{I_p} $$
(for $p$ the length of the list $I$) is simply an abbreviation.  For a $p$-form, there are $\left(n \atop p\right)$ terms that appear.


### Twisted and vector-valued forms {#twisted}

Recall that a differential form on $X$ is a section of the exterior algebra of the cotangent bundle over $X$; call this bundle $\Lambda$.  Then given any [[vector bundle]] $V$ over $X$, a __$V$-valued form__ on $X$ is a section of the vector bundle $V \otimes \Lambda$.  The wedge product of a $V$-valued form and a $V'$-valued form is a $(V \otimes V')$-valued form, but if there is a commonly used multiplication map $V \otimes V' \to W$, then we may think of their wedge product as a $W$-valued form.

Of particular importance are $L$-valued forms when $L$ is a [[line bundle]]; these are also called __$L$-twisted forms__.  (Compare the notion of [[twisted form]] in a more general context.)  In local coordinates, a twisted form looks just like an ordinary form, once you choose a nonzero vector in $L$ as a basis.  Therefore, they can seem sneaky and confusing sometimes when you realise that they do not behave in the same way!

Let $\Psi$ be the [[pseudoscalar]] bundle; that is, a section of $\Psi$ (a pseudoscalar field) is given locally by a simple [[scalar]] field (a real-valued function) for each [[orientation]] of a local patch, with opposite orientations giving oppositely-signed scalars.  A __pseudoform__ is a $\Psi$-twisted form.

On an $n$-dimensional manifold $X$, the space $\Omega^n(X)$ of $n$-forms is itself a line bundle; a $p$-form twisted by this line bundle is a __densitised form__.  Sometimes an $n$-form is itself called a __density__.  Actually, as we will see under integration below, it is really an $n$-*pseudo*form that should be called a density, but that is not the traditional terminology.

Given any real number $w$, there is a line bundle called the line bundle of $w$-[[weighted representation|weighted]] scalars; a form twisted by this line bundle is a __$w$-weighted form__.  Note that a $0$-weighted form is just an ordinary form; also, an $n$-pseudoform turns out to be equivalent to a $1$-weighted $0$-form.  (And thus a densitised form is equivalent to a $1$-weighted pseudoform.)

The line bundle of $n$-pseudoforms (that is of $1$-weighted $0$-forms) is the [[absolute value]] of the line bundle of $n$-forms (that is of densitised $0$-forms), so we may take the absolute value of one of either and get one of the latter.  (Similarly, the line bundle of $0$-forms is the absolute value of the line bundle of pseudo-$0$-forms; that is, the trivial bundle is the absolute value of the pseudoscalar bundle.)


### As smooth functors on $n$-paths

One way to exhibit this statement nicely is:
+-- {: .standout}
A differential $n$-form on $X$ is a smooth $n$-[[n-functor|functor]] $P_n(X) \to \mathbf{B}^n \mathbb{R}$ from the [[path n-groupoid]] of $X$ to the $n$-fold [[delooping]] of the additive [[Lie group]] of real numbers.
=--
+-- {: .query}
Urs, do you know where the need for orientation comes in here?  I don\'t follow it in enough detail to see, although I intend to read Moerdijk--Reyes.  ---Toby

[[Eric]]: I'm probably confused, but if $\sigma_n$ is a morphism in $P_n(X)$, then (unless $X$ is a [[directed space]]), the opposite $\sigma_n^{-1}$ is also in $P_n(X)$ and I think $\omega(\sigma_n) = -\omega(\sigma_n^{-1})$.

_Toby_:  Between Eric\'s comment here and Urs\'s at [[latest changes]], I\'m happy to remove this query box.

[[Eric]]: I think it is a good question. Maybe we should keep the query box here until the answer is incorporated in the page.

[[Urs Schreiber]]: here is my reply, that I originally posted at [[latest changes]]. I'll try to eventually work this into the main text of the entry

The orientation of the diffential form corresponds to the inherent orientation of [[k-morphism]]s: as we identify the differential form with a smooth functor on the [[path n-groupoid]], that [[path n-groupoid]] necessarily has _oriented_ $k$-volumes as its [[k-morphism]]s, simply because these $k$-morphisms need to come with information about their (higher categorical) source and target.

To get pseudo-differential forms that may be integrated also over non-oriented and possibly non-orientable manifolds one needs to consider parallel transport functors not with coefficients in just $\mathbf{B}^n \mathbb{R}$ coming from the [[crossed complex]] 
     
$$
   (\mathbb{R} \to {*} \to \cdots \to {*})
$$

but the more refined crossed complex

$$
  (\mathbb{R} \to {*} \to \cdots \to \mathbb{Z}_2)
$$

where the $\mathbb{Z}_2$-factor acts by sign reversal on $\mathbb{R}$ (one can also use $U(1)$ instead of $\mathbb{R}$, this way $[P_n(-), \mathbf{B}^n U(1)]$ becomes the [[Deligne cohomology|Deligne complex]] and knows not just about differential forms but about $U(1)$ $n-1$-gerbes with connection even).

A little bit of discussion of this unoriented case is currently at [[orientifold]]. There for the case $n=2$.
=--

Note that an $n$-morphism in $P_n(X)$ is an oriented $n$-dimensional submanifold of $X$.

Such a functor (as described in more detail at [[connection on a bundle]]) assigns a real number to each parametrised $n$-dimensional cube of $X$, that is a subspace by a smooth map $\Sigma\colon [0,1]^n \to X$.  If the differential form that this $n$-functor defines is denoted $\omega \in \Omega^n(X)$, then this real number is denoted by the [[integration|integral]]
$$
  \int_{[0,1]^n} \Sigma^* \omega
  \,.
$$

This integral in turn encodes the $n$-functoriality of the $n$-functor: it effectively says that
* if we decompose the standard $n$-cube $[0,1]^n$ into $N^n$ little subcubes $(C_k)_{k\in \mathbb{N}^n}$  for $N \in \mathbb{N}$
* and apply the $n$-functor to each of these to obtain a result (a real number) to be denoted $\omega(C_k)$;
* then by $n$-functoriality the result of the application of the functor to the full $\Sigma$ is the composition of all the $\omega(C_k)$ in $\mathbb{R}$. i.e. their sum
  $$
    \int_{[0,1]^n} \Sigma^* \omega
    =
    \sum_k \omega(C_k)
    \,.
  $$

Since one can let $N$ increase arbitrarily in this prescription -- $N \to \infty$ -- it follows that the value of the functor on $\Sigma$ is already determined by all its values on all "infinitesimal $n$-cubes" in some sense. 


The notion of **differential form** is the one that makes this precise: a differential form is a rule for assigning to each "infinitesimal $n$-cube" a number.

There are in turn different ways to make that last statement precise: 

* In [[differential geometry]] an "infinitesimal $n$-cube" is modeled by an $n$-tuple of [[tangent bundle|tangent vectors]] and a differential form is a fiberwise linear map from the $n$-fold exterior power of the [[tangent bundle]] to the real numbers, as given below.

* In [[synthetic differential geometry]] the statement is in essence the same one, but the difference is that there the notion of "infinitesimal $n$-cube" has a concrete meaning on the same footing of other $n$-cubes. If $D^n$ denotes the abstract infinitesimal $n$-cube in this context, then the mapping space $X^{D^n}$ of morphisms from $D^n\to X$ is the $n$-fold [[tangent bundle]] of $X$ and a differential form is precisely nothing but a morphism
  $$
    \omega\colon X^{D^n} \times D^n \to \mathbb{R}
  $$ 
  (where $\mathbb{R}$ is now the synthetic differential version of the real numbers) subject to three constraints. (These constraints can be seen as the infinitesimal analog of the $n$-functoriality discussed above).

  This is described in detail in section 4 of 

  * Moerdijk-Reyes, [[Models for Smooth Infinitesimal Analysis]]

  For more on this see [[differential forms in synthetic differential geometry]].

### More general kinds of forms

While differential forms are usually restricted to the linear case, there are also more general kinds of "differential forms" which can be integrated.  See for instance [[absolute differential form]] and [[cogerm differential form]].

## Operations on differential forms

### Pulling back forms

Given manifolds $X$ and $Y$ and a [[continuously differentiable map]] $f\colon X \to Y$, any differential form $\eta$ on $Y$ defines a __pullback__ form $f^*(\eta)$ on $X$.  See at _[[pullback of differential forms]]_.

Thus, the operation that maps $X$ to $\Omega^*(X)$ extends to a [[contravariant functor]] $\Omega^*$.  Perhaps confusingly, forms are traditionally known in physics as 'covariant' concepts, because of how the components transform under a change of coordinates.  (Ultimately, this confusion goes back to that between active and passive [[coordinate transformation]]s.)

Note that twisted and (more general) vector-valued forms cannot be pulled back so easily.  One needs some extra structure on $f$ to do so; see the discussion of integration of $p$-pseudoforms at [[integration of differential forms]] for an example.


### Integration of forms

Let $X$ be an $n$-dimensional manifold, and let $\omega$ be an $n$-pseudoform on $X$.  At least when $X$ is [[paracompact space|paracompact]] and [[Hausdorff space|Hausdorff]], we may turn $\omega$ into a [[measure]] on $X$ and thereby find its [[integral]].  Conversely, any [[absolutely continuous measure|absolutely continuous]] [[Radon measure]] on $X$ arises in this way from a unique $n$-pseudoform $\omega$.

If we wish to integrate untwisted (or differently twisted or vector-valued) forms and/or forms of smaller rank, then we may do so on [[submanifolds]] of $X$ equipped with some appropriate structure.  In particular, if $X$ itself is equipped with an [[orientation]], then $n$-pseudoforms on $X$ are the same as (untwisted) $n$-forms, and so we can integrate those on $X$.  See [[integration of differential forms]] for the general case.


+-- {: .query}
[[Zoran Škoda]]: Should maybe this entry have a discussion on heuristics behind the usual trick in supersymmetry which asserts that the inner hom for supermanifolds, gives the statement that the algebra of smooth differential forms on $M$ is the space of functions on the odd tangent bundle $\Pi T M$? I am not the most competent to do this succinctly enough... 

_Toby_:  Possibly that should go at [[differential forms on supermanifolds]]?

[[Zoran Škoda]]: By no means. Ordinary differential forms on ORDINARY manifolds are the same as functions on odd tangent bundle. I did not want to say anything about the generalization of differential forms on  supermanifolds. So it is NOT a different notion, but a different way to define it. If going to toposes hence synthetic framework is not separated why would be separated the equality which involves a parity trick...

_Toby_:  Ah, I see; your $M$ above need not be super, and it still works.  Then yes, that should be mentioned here too.
=--


### Cohomology of forms

There is a [[cohomology]] theory of smooth differential forms; we have a [[chain complex]]
$$ \cdots \stackrel{\mathrm{d}}\to C^\infty\Omega^2(X) \stackrel{\mathrm{d}}\to C^\infty\Omega^1(X) \stackrel{\mathrm{d}}\to C^\infty\Omega^0(X) \stackrel{\mathrm{d}}\to 0 ;$$
the [[chain cohomology]] of this complex is the __[[de Rham cohomology]]__ of $X$.

As smooth differential forms are the cochains in de Rham cohomolgy, the theory of integration of forms allows us to interpret [[relatively compact subspace|relatively compact]] oriented submanifolds as chains on $X$, giving us a [[homology]] theory.  Combining these, we have __[[Stokes's theorem]]__
$$ \int_{\partial{R}} \omega = \int_R \mathrm{d}\omega ,$$
where $\partial{R}$, which may be interpreted as the __boundary__ of $R$, is also called the __codifferential__ as it is dual to $\mathrm{d}$.


## Related concepts

* [[closed differential form]], [[exact differential form]]

* [[wedge product]]

* [[decomposable differential form]]

* [[integration of differential forms]]

* [[horizontal differential form]], [[vertical differential form]]

* [[harmonic differential form]]

* [[differential form on a supermanifold]]

* [[Kähler differential form]]

* [[de Rham complex]], [[de Rham cohomology]]

* [[differential cohomology]]

* [[absolute differential form]], [[cogerm differential form]]

* [[holomorphic differential form]]

* [[differential form with logarithmic singularities]]

## References

The concept of differential forms (and their [[exterior algebra]]), at least on [[affine spaces]]/[[Euclidean spaces]] originates in

* [[Hermann Grassmann]], _[[Ausdehnungslehre]]_, 1844

A standard reference is

* [[Raoul Bott]], [[Loring Tu]], _Differential forms in algebraic topology_.

A basic introduction with an eye towards applications in [[physics]] is in section 2.1 of

* [[Theodore Frankel]], _[[The Geometry of Physics - An Introduction]]_

An introductory wiki-format textbook is

* {#Dray_GDF} Tevian Dray, _The Geometry of Differential Forms_, [web](http://physics.oregonstate.edu/coursewikis/GDF/)

published as half of

* Tevian Dray, _Differential Forms and the Geometry of General Relativity_, A K Peters/CRC Press, 2014,
 [web](http://physics.oregonstate.edu/coursewikis/DFGGR/bookinfo/).

The equivalence between differential forms and smooth functors on the [[path groupoid]] in low degree is discussed in

* Schreiber & Waldorf, _Smooth Functors vs. Differential Forms_ ([arXiv](http://arxiv.org/abs/0802.0663))

Much fun discussion between [[Eric Forgy]], [[Toby Bartels]], and [[John Baez]], about whether integration of forms or pseudoforms is most fundamental (and about whether twisted forms in general are useful and interesting geometric objects or the bastard spawn of hell) may be found in [this giant Usenet thread](https://groups.google.com/group/sci.physics.research/browse_thread/thread/6a231426b3a313c0/2888a120a9b1f5ad).  More specifically:

*  [John\'s alter ego the Wizard](https://groups.google.com/group/sci.physics.research/msg/3c6a1a7237b66c8c?dmode=source) explains why $n$-pseudoforms are the most natural things to integrate on an $n$-dimensional manifold;
*  [applications of pseudoforms](https://groups.google.com/group/sci.physics.research/msg/2774cbbc982e200e?dmode=source) to classical contexts where absolute values appear;
*  [the general notion of form](https://groups.google.com/group/sci.physics.research/msg/47bbd29289f208f8?dmode=source) corresponding to an arbitrary representation of the [[general linear group]] (towards the end of the post);
*  [absolute values of forms](https://groups.google.com/group/sci.physics.research/msg/424da828e75b6b90?dmode=source) and how to integrate them (near the end of the post, a precursor to [[absolute differential forms]]).


[[!redirects differential form]]
[[!redirects differential forms]]
[[!redirects exterior form]]
[[!redirects exterior forms]]
[[!redirects exterior differential form]]
[[!redirects exterior differential forms]]
[[!redirects differential p-form]]
[[!redirects differential p-forms]]
[[!redirects p-form]]
[[!redirects p-forms]]
[[!redirects n-form]]
[[!redirects n-forms]]

[[!redirects differential n-form]]
[[!redirects differential n-forms]]
[[!redirects smooth differential n-form]]
[[!redirects smooth differential n-forms]]


[[!redirects integration of forms]]

[[!redirects differential pseudoform]]
[[!redirects differential pseudoforms]]
[[!redirects differential pseudo-form]]
[[!redirects differential pseudo-forms]]
[[!redirects differential pseudo form]]
[[!redirects differential pseudo forms]]
[[!redirects pseudoform]]
[[!redirects pseudoforms]]
[[!redirects pseudo-form]]
[[!redirects pseudo-forms]]
[[!redirects pseudo form]]
[[!redirects pseudo forms]]
[[!redirects p-pseudoform]]
[[!redirects p-pseudoforms]]
[[!redirects n-pseudoform]]
[[!redirects n-pseudoforms]]
[[!redirects pseudo-p-form]]
[[!redirects pseudo-p-forms]]
[[!redirects pseudo-n-form]]
[[!redirects pseudo-n-forms]]
[[!redirects pseudo p-form]]
[[!redirects pseudo p-forms]]
[[!redirects pseudo n-form]]
[[!redirects pseudo n-forms]]


[[!redirects densitized form]]
[[!redirects densitized forms]]
[[!redirects densitised form]]
[[!redirects densitised forms]]
[[!redirects densitized pseudoform]]
[[!redirects densitized pseudoforms]]
[[!redirects densitised pseudoform]]
[[!redirects densitised pseudoforms]]
[[!redirects weighted form]]
[[!redirects weighted forms]]
[[!redirects weighted pseudoform]]
[[!redirects weighted pseudoforms]]

[[!redirects differential 2-form]]
[[!redirects differential 2-forms]]
[[!redirects smooth differential 2-form]]
[[!redirects smooth differential 2-forms]]

[[!redirects differential 3-form]]
[[!redirects differential 3-forms]]
[[!redirects smooth differential 3-form]]
[[!redirects smooth differential 3-forms]]

[[!redirects differential 4-form]]
[[!redirects differential 4-forms]]
[[!redirects smooth differential 4-form]]
[[!redirects smooth differential 4-forms]]

[[!redirects smooth differential k-form]]
[[!redirects smooth differential k-forms]]
