
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Super-Algebra and Super-Geometry
+-- {: .hide}
[[!include supergeometry - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Idea

The **exterior algebra** $\Lambda V$ of a vector space is the [[free object|free]] [[graded-commutative algebra]] over $V$, where the elements of $V$ are taken to be of degree $1$.  (That is, the [[forgetful functor]] takes a graded-commutative algebra to its vector space of degree-$1$ elements.)

This construction generalizes to [[group representations]], [[chain complexes]], [[vector bundles]], [[coherent sheaves]], and indeed objects in any [[symmetric monoidal category|symmetric monoidal]]  [[linear category|linear categories]] with enough [[colimit|colimits]], where the tensor product distributes over those colimits (as in a [[2-rig]]).


## Explicit definition

We begin with the construction for vector spaces and then sketch how to generalize it.

### For vector spaces

Suppose $V$ is a [[vector space]] over a [[field]] $K$.  Then the **exterior algebra** $\Lambda V$ is generated by the elements of $V$ using these operations:

*  addition and scalar multiplication
*  an associative binary operation $\wedge$ called the **exterior product** or **wedge product**,

subject to these identities:

*  the identities necessary for $\Lambda V$ to be an [[associative algebra]]
*  the identity $v \wedge v = 0$ for all $v \in V$.

It then follows that $\Lambda V$ is a [[graded algebra]] where $\Lambda^p V$ is spanned by $p$-fold wedge products, that is, elements of the form 

$$v_1 \wedge \cdots \wedge v_p $$

where $v_1, \dots, v_p \in V$.  It also follows that $\Lambda V$ is [[graded commutative algebra|graded commutative]]: that is, if $\omega \in \Lambda^p V$ and $\nu \in \Lambda^q V$, then

*  $\omega \wedge \nu = (-1)^{p q}\, \nu \wedge \omega$.

If $K$ is a field not of [[characteristic]] $2$, we may replace the relations 

\[ \label{alternating} v \wedge v = 0 \]

by the relations

\[ \label{antisymmetric} v \wedge w = - w \wedge v \]

for all $v, w \in V$ ([Grassmann 1844, &#167;37, &#167;55](#Grassmann1844)).  If we can divide by $2$, then the relations (eq:antisymmetric) imply (eq:alternating), while the converse holds in any characteristic.

The exterior algebra of a vector space is also called the **Grassmann algebra** or **alternating algebra**.  It is also denoted $\bigwedge V$, $\bigwedge^\bullet V$, or $Alt V$.


### In general

More generally, suppose $C$ is any [[symmetric monoidal category]] and $V \in C$ is any object.  Then we can form the [[tensor power|tensor powers]] $V^{\otimes n}$.  If $C$ has countable coproducts we can form the [[coproduct]] 

$$  T V = \bigoplus_{n \ge 0} V^{\otimes n} $$

(which we write here as a [[direct sum]]), and if the tensor product distributes over these coproducts, $T V$ becomes a [[monoid]] object in $C$, with multiplication given by the obvious maps

$$   V^{\otimes p} \otimes V^{\otimes q} \to V^{\otimes (p+q)} $$

This monoid object is called the [[tensor algebra]] of $V$.

The [[symmetric group]] $S_n$ acts on $V^{\otimes n}$, and if $C$ is a [[linear category]] over a [[field]] of [[characteristic]] zero, then we can form the antisymmetrization map 

$$  p_A : V^{\otimes n} \to V^{\otimes n} $$

given by

$$ p_A = \frac{1}{n!} \sum_{\sigma \in S_n} sgn(\sigma) \, \sigma $$

The [[cokernel]] of $1 - p_A$ is called the $n$th **antisymmetric tensor power** or **alternating power** $\Lambda^n V$.  The coproduct

$$  \Lambda V = \bigoplus_{n \ge 0} \Lambda^n V $$

becomes a monoid object called the **exterior algebra** of $V$.

If $C$ is a linear category over a field of positive characteristic (or more generally, over a [[commutative ring]] in which not every positive integer is invertible, that is which is not itself an [[associative algebra|algebra]] over the [[rational numbers]]), then we need a different construction of $\Lambda^n V$; we define ... (please complete this!).


## Examples

### Over a super vector space

For $V$ a [[super vector space]], the exterior algebra $\Lambda V$ is often called the **Grassmann algebra** over $V$.  This $\Lambda V$ or $\wedge^\bullet V$ is the [[free object|free]] [[supercommutative algebra|graded commutative]] [[superalgebra]] on $V$.
 
Explicitly, this is the quotient of the [[tensor algebra]] $T V$ by the [[ideal]] generated by elements of the form

$$v \otimes w + (-1)^{deg v \cdot deg w } w \otimes v \, .$$

The product in this algebra is denoted with a wedge, and called the **wedge product**.  It obeys the relation

$$
  v \wedge w = - (-1)^{deg v \cdot deg w} w \wedge v
  \,.
$$


#### With an inner product

If $V$ is equipped with a [[bilinear form]] then there is also the [[Clifford algebra]] on $V$. This reduces to the Grassmann algebra for vanishing bilinear form. 

But sometimes it is useful to consider the Grassmann algebra even in the presence of a non-degenerate bilinear form, in which case the inner product still serves to induce identifications between elements of the Grassmann algebra in different degree.

Let $V$ be $\mathbf{R}^3$ equipped with its standard inner product.  Then an element of $\Lambda^0 V$ is a scalar (a [[real number]]), an element of $\Lambda^1 V$ may be identified with a vector in the elementary sense, an element of $\Lambda^2 V$ may be identified with a [[bivector]] or [[pseudovector]], and an element of $\Lambda^2 V$ may be identified a [[pseudoscalar]].

More generally, let $V$ be $\mathbf{R}^n$, or indeed any real [[inner product space]].  Then an element of $\Lambda^p V$ is a $p$-vector as studied in [[geometric algebra]].  Using the inner product, we can identify $p$-vectors with $(n-p)$-pseudovectors.

On a [[manifold]] (or [[generalized smooth space]]) $X$, let $T^*X $ be the [[cotangent bundle]] of $X$.   Then we may define $\Lambda T^*X$ using the abstract nonsense describe earlier, taking $C$ to be the category of [[vector bundle|vector bundles]] over $X$.  Then a [[differential form]] on $X$ is a [[section]] of the vector bundle $\Lambda T^*X $.  If $X$ is an oriented (semi)-[[Riemannian manifold]], then we can identify $p$-forms with $(n-p)$-forms using the [[Hodge star]] operator.


### Semi-free dg-algebras

A [[semifree dga|semi-free dg-algebra]] is a [[dg-algebra]] whose underlying graded commutative algebra is free, i.e. is an exterior algebra. Examples include in particular [[Chevalley-Eilenberg algebra]]s of [[Lie algebra]]s, of $L_\infty$-[[L-∞ algebra|algebras]] and [[Lie ∞-algebroids]]. 


#### Differential forms / deRham complex

For $X$ a [[manifold]] consider the category of [[module]]s over its [[ring]] of smooth functions $C^\infty(X)$. One such module is $\Omega^1(X) = \Gamma(T^* X)$, the space of smooth sections of the [[cotangent bundle]] of $X$.

The [[deRham complex]] of $X$ is the exterior algebra 

$$
  \Omega^\bullet(X) = \bigwedge_{C^\infty(X)} \Gamma(T^* X)
  \,.
$$

This is really a special case of the previous class of examples, as $\Omega^\bullet(X)$ equipped with the [[deRham complex|deRham differential]] is the [[Chevalley-Eilenberg algebra]] of the [[tangent Lie algebroid]]. 

## Related concepts

* [[decomposable differential forms]]

* [[body]]/[[soul]]

* [[Fock space]], [[!-modality]]

* [[differential form]], [[de Rham complex]]

* [[Clifford algebra]], [[spin geometry]]

## References

The concept originates in

* {#Grassmann1844} [[Hermann Grassmann]], _[[Ausdehnungslehre]]_, 1844

where the graded-commutativity of the exterior product appears in  &#167;37, &#167;55.

For the case of [[modules]] over a [[commutative ring]], see

* [[Stacks Project]], [Tag 00DM](http://stacks.math.columbia.edu/tag/00DM).

* [[Bourbaki]], _Alg&#232;bre_, chap. III, &#167; 7.

Discussion of Grassmann algebras [[internalization|internal]] to any [[symmetric monoidal category]] is on p. 165 of

* {#Deligne90} [[Pierre Deligne]], _[[Catégories Tannakiennes]],  [[Grothendieck Festschrift]], vol. II, Birkh&#228;user Progress in Math. 87 (1990) pp.111-195.    
  
  
See also at _[[signs in supergeometry]]_.

[[!redirects exterior algebra]]
[[!redirects exterior algebras]]
[[!redirects Grassmann algebra]]
[[!redirects Grassmann algebras]]
[[!redirects alternating power]]
[[!redirects alternating powers]]
[[!redirects exterior power]]
[[!redirects exterior powers]]
[[!redirects exterior product]]
[[!redirects exterior products]]
[[!redirects wedge product]]
[[!redirects wedge products]]