
# Noncommutative schemes
* table of contents
{: toc}

## Idea

One would like to have a proper extension of a notion of [[scheme]] in [[noncommutative algebraic geometry]] which should include also noncommutative spaces represented by noncommutative rings ("noncommutative affine schemes") and "noncommutative projective schemes" represented by graded rings, but *not* including commutative spaces which are not schemes ([[stacks]], [[algebraic space]]s, etc.). To this aim, one notices that schemes are glued from affine schemes in the [[Zariski topology]], i.e. they are a subclass of [[locally affine space]]s where locally pertains to the [[Zariski site]]. At the level of the category $QCoh_X$ of [[quasicoherent sheaf|quasicoherent sheaves]] on a scheme $X$, affine subschemes $Y\subset X$ correspond to especially nice [[localization]] functors $Q^*_Y$: first of all they are affine localizations (i.e. have a [[right adjoint]] which is [[fully faithful functor|fully faithful]] and which has its own right adjoint), second they are exact ([[flat functor|flat]]) and their
right adjoint is also flat. Second the localizations pertaining to Zariski topology are of finite type (a fortiori, Zariski topology on an affine scheme is generated by the principal open subsets $D_f$). The fact that a family of affine subschemes covers $X$ is expressed via the property that the family of localizations $Q_Y$ for $Y$ in the cover is a (jointly) conservative family (i.e. a morphism is invertible iff it is invertible in each element of a cover). Using the idea of Grothendieck which says, according to Manin, that _to do a geometry you do not need a space you only need an algebra of functions on this would-be space_, we express all the properties of gluing affine schemes via catgories of quasicoherent sheaves. This is justified by various evidence including Serre's theorem on $Proj$, the observation that important notions in noncommutative geometry are Morita-invariant, and the reconstruction theorems of Gabriel--Rosenberg and, in the monoidal and monoidal triangulated case, by Balmer and by Garkusha, that a scheme $X$ can be reconstructed up to isomorphism from $QCoh_X$. 


## Formal frameworks

The above ideas are sometimes loosely expressed by practioners to take an [[abelian category]] as a noncommutative space (Smith calls it a _quasischeme_ in that case). Some prefer to have a pair of an abelian category and a distinguished object in it. The work of Kontsevich--Rosenberg on noncommutative smooth spaces notices that the main noncommutative examples (those close to [[free object|free]] algebras, rather than almost commutative quantum, PI and similar examples) like noncommutative projective spaces and noncommutative grassmanians (unlike quantum projective spaces and quantum flag varieties) are *not* locally affine with respect to the covers by biflat affine localizations, but rather locally affine in certain noncommutative smooth topologies (covers by Cohn localizations, which are not biflat, also appear occasionally). For the projective case, F. van Oystaeyen prefers to work with Ore localizations only and defines an interesting class of so-called __schematic algebras__ and axiomatizes a more general property of torsion lattices which can play a role in an extension of quasicoherent sheaf theory to similar situations ("noncommutative topology"). T. Maszczyk prefers to generalize categories of quasicoherent sheaves to monoidal abelian categories and requires that the corresponding direct or inverse image functors respect the monoidal structure in a lax or colax way. That means that the commutative modules are viewed as [[central bimodule]]s. Bimodules can be related to correspondences ([[spans]]), that is in one-sided module point of view they correspond to functors: however Maszczyk argues that this point of view is only partial and that monoidal categories should be put in the fundamentals. 

Rosenberg notices that the considerations from the Idea section force one to consider not noncommutative schemes in an absolute sense, but rather noncommutative schemes relative to the ground category $C = QCoh_{Spec k}$. Suppose all categories involved are abelian and functors [[additive functor|additive]] (there is a more subtle variant in the nonabelian case). Then the general nonsense basically forces one to a unique notion of a noncommutative scheme. 


## Rosenberg's definition

(A. Rosenberg, _Noncommutative schemes_, Compos. Math. __112__ (1998) 93--125, [doi](http://dx.doi.org/10.1023/A:1000479824211))

A quasicompact __relative noncommutative scheme__ over a category $C$ is a category $A$ with an [[adjoint functor|adjoint pair]] of functors (direct and inverse image)  $g_* : A\to C : q^*$, such that there exists a finite conservative family of affine localizations $\{Q^*_\lambda : A\to A_\lambda\}_{\lambda\in\Lambda}$ whose direct image $Q_{\lambda *}$ and inverse image $Q_\lambda^*$ parts are exact and such that the composition of the direct image functor of each localization $Q_{\lambda*} : A_\lambda\to A$ followed by the direct image functor $g_* : A\to C$ is also affine. 

(A pair of adjoint functors, inverse and direct image represent an affine morphism if the direct image is faithtful and it has its own right adjoint, so we have an adjoint triple with middle term, that is the direct image, faithful. For the affine localizations, the direct image is in addition full.)


## Properties

The word 'localization' here is in the sense of Gabriel--Zisman. Notice that if the ground category $C$ has a distinguished object (say the generator in the category of vector spaces over a field) then its direct image functor is a distinguished object in $A$. In general this is not required. The exactness properties required above guarentee that the quasicoherent sheaves can be glued from the restrictions on the covers, and moreover that the derived functors of the direct image like functors can be computed using standard resolutions. If the cover is semiseparated (a notion from Thomason--Trobaugh), that is the localization functors for the cover mutually commute, then the standard resolutions can be replaced by alternating Čech resolutions. 

See also [[zoranskoda:gluing categories from localizations]]. 


## Examples

Quantum projective spaces, quantum flag varieties, commutative quasicompact schemes, the $D$-schemes of Beilinson, the almost schemes of Gabber etc. 


## Nonexamples

Noncommutative projective spaces, noncommutative grassmannians, universal noncommutative flag variety. 


## Literature

* [[Tomasz Maszczyk]], _Noncommutative geometry through monoidal categories_, [math.QA/0611806] (http://arxiv.org/abs/math.QA/0611806)

* A. Rosenberg, _Noncommutative schemes_, Compos. Math. __112__ (1998) 93--125, [doi](http://dx.doi.org/10.1023/A:1000479824211)

* P. Gabriel, M. Zisman, _Calculus of Fractions and Homotopy Theory_, Springer 1967.

* S. Paul Smith, _Subspaces of non-commutative spaces_, Trans. Amer. Math. Soc. __354__(2002), 2131--2171

* V. A. Lunts, A. L. Rosenberg, _Localization for quantum groups_, Selecta Math. (N.S.) 5 (1999), no. 1, pp. 123--159.

* Z. Škoda, _Some equivariant constructions in noncommutative geometry_, Georgian Math. J. __16__ (2009) 1; 183--202 ([arXiv:0811.4770](http://front.math.ucdavis.edu/0811.4770))

* F. van Oystaeyen, L. Willaert, _Grothendieck topology, coherent sheaves and Serre's theorem for schematic algebras_, J. Pure Appl. Alg. __104__(1995), p. 109--122

* M. Artin, J. Zhang, _Noncommutative projective schemes_, Adv. Math. 109, 228--287 (1994).

* [[Dmitri Orlov]], _Smooth and proper noncommutative schemes and gluing of DG categories_, [arXiv](http://arxiv.org/abs/1402.7364v1).

category: algebraic geometry, noncommutative geometry
[[!redirects noncommutative scheme]]
[[!redirects noncommutative schemes]]
[[!redirects non-commutative scheme]]
[[!redirects non-commutative schemes]]