
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Algebra
+-- {: .hide}
[[!include higher algebra - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Definitions

+-- {: .num_defn #AlternativeAlgebra}
###### Definition

Consider the following [[equational laws]] of a [[binary operation]] (written multiplicatively):

* __left alternativity__: $(x x) y = x (x y)$;
* __flexibility__: $(x y) x = x (y x)$;
* __right alternativity__: $(y x) x = y (x x)$.

An operation satisfying one of these conditions is __left-alternative__, __flexible__, or __right-alternative__, respectively, and it is __alternative__ if it is both left-alternative and right-alternative.  A [[magma]] is so if its binary operation is so, and a [[nonassociative algebra]] (or [[nonassociative ring]]) is so if its multiplication operation is so.
=--


## Properties

A [[commutative operation|commutative]] operation/magma/algebra must be flexible, and it is left-alternative iff it is right-alternative (and so simply alternative).  An [[associative operation|associative]] operation/magma/algebra is both alternative and flexible.

Among algebras (but not magmas), any algebra with two of these three properties must have the third.  In particular, an alternative algebra must be flexible.  This follows from the characterization in terms of the associator below.


### In terms of the associator

+-- {: .num_prop #InTermsOfAssociator}
###### Proposition

For a [[nonassociative algebra]] $A$, alternativity according to def. \ref{AlternativeAlgebra} is equivalent to the condition that the [[associator]], i.e. the [[multilinear map|tri-linear map]]

$$
  [-,-,-] \;\colon\; A \otimes A \otimes A \longrightarrow A
$$

given by

$$
  [a,b,c] \coloneqq (a b) c - a (b c)
$$

is [[alternating map|alternating]], in that whenever two of the three arguments are equal, the result is zero.
=--

+-- {: .num_cor #skewsymmetry}
###### Corollary

Alternativity implies that the associator is [[skew-symmetric function|skew-symmetric]], in that for any [[permutation]] $\sigma$ of three elements then $[a_{\sigma_1}, a_{\sigma_2}, a_{\sigma_3}] = (-1)^{\vert \sigma\vert} [a_1, a_2, a_3]$ for ${\vert\sigma\vert}$ the [[signature of a permutation|signature of the permutation]].  Over a [[field]] whose [[characteristic]] is different from $2$, or more generally over any [[commutative ring]] in which $2$ is invertible or even cancellable, alternativity is equivalent to skew-symmetry of the associator.
=--

+-- {: .proof}
###### Proof

In one direction, left alternativity says directly that the associator is alternating in the first two arguments:

$$
  [x,x,y] = (x x) y - x (x y) = (x x) y - (x x) y = 0 ,
$$

and right alternativity says the same thing in the last two arguments:

$$
  [x,y,y] = (x y) y - x (y y) = (x y) y - (x y) y = 0 .
$$

To be fully alternating, we then argue using multi-linearity of the associator:

$$
  [x,y,x] = [x,x,x] + [x,y,x] + [y,x,x] + [y,y,x] = [(x+y),(x+y),x] = 0 .
$$

Multilinearity also proves that the associator is skew-symmetric, in adjacent arguments:

$$
  0 = [(x+y),(x+y),z] = [x,y,z] + [y,x,z]
$$

$$
  0 = [z,(x+y),(x+y)] = [z,x,y] + [z,y,x]  
$$

and hence in all arguments.

In the other direction, skew-symmetry of the associator implies alternativity by 

$$
  \begin{aligned}
    & [x,x,y] = -[x,x,y] 
    \\
    \Leftrightarrow & 2 [x,x,y] = 0
    \\
    \Leftrightarrow & [x,x,y] = 0
  \end{aligned}
$$

using the assumption that $2$ is cancellable in $A$, and similarly for $[y,x,x] = 0$. 
=--

+-- {: .num_prop #ArtinTheorem}
###### Proposition

A [[nonassociative algebra]] is alternative, def. \ref{AlternativeAlgebra}, prop. \ref{InTermsOfAssociator}, precisely if the [[subalgebra]] generated by any two elements is an [[associative algebra]].
=--

This is due to [[Emil Artin]], see for instance ([Schafer 95, p. 18](#Schafer95)).

+-- {: .num_prop #ZornTheorem}
###### Proposition

The only alternative [[division algebras]] over the [[real numbers]] are the [[real numbers]] themselves, the [[complex numbers]], the [[quaternions]] and the [[octonions]].
=--

This is due to ([Zorn 30](#Zorn30)).


## Examples

Every [[associative algebra]] is alternative and flexible.  Every [[Lie algebra]] or [[Jordan algebra]] is flexible.

Every [[Cayley–Dickson algebra]] over a [[commutative ring]] $R$ is flexible.  The first three (corresponding, if we start with the [[real numbers]], to the real numbers, [[complex numbers]], and [[quaternions]]) are associative and hence alternative.  The next one (corresponding to the [[octonions]]) is still alternative despite not being associative (unless $R$ has characteristic $2$).  After that (corresponding to the [[sedenions]] and above), they are not even alternative (unless $R$ has characteristic $2$).


## Related concepts 

* [[Cayley-Dickson construction]] 

* [[composition algebra]]


## References

* {#Schafer95} R. D. Schafer, chapter III of _Introduction to Non-Associative Algebras_ Dover, New York, 1995. ([web](https://archive.org/details/anintroductionto25156gut))

* {#Zorn30} [[Max Zorn]], _Theorie der alternativen Ringe_, Abhandlungen des Mathematischen Seminars der Universität Hamburg 8 (1930), 123-147

* Wikipedia, _[Alternative algebra](https://en.wikipedia.org/wiki/Alternative_algebra)_, _[Flexible algebra](https://en.wikipedia.org/wiki/Flexible_algebra)_


[[!redirects alternativity]]
[[!redirects alternative binary operation]]
[[!redirects alternative binary operations]]
[[!redirects alternative operation]]
[[!redirects alternative operations]]
[[!redirects alternative magma]]
[[!redirects alternative magmas]]
[[!redirects alternative algebra]]
[[!redirects alternative algebras]]

[[!redirects left alternativity]]
[[!redirects left-alternativity]]
[[!redirects left-alternative binary operation]]
[[!redirects left-alternative binary operations]]
[[!redirects left alternative binary operation]]
[[!redirects left alternative binary operations]]
[[!redirects left-alternative operation]]
[[!redirects left-alternative operations]]
[[!redirects left alternative operation]]
[[!redirects left alternative operations]]
[[!redirects left-alternative magma]]
[[!redirects left-alternative magmas]]
[[!redirects left alternative magma]]
[[!redirects left alternative magmas]]
[[!redirects left-alternative algebra]]
[[!redirects left-alternative algebras]]
[[!redirects left alternative algebra]]
[[!redirects left alternative algebras]]

[[!redirects right alternativity]]
[[!redirects right-alternativity]]
[[!redirects right-alternative binary operation]]
[[!redirects right-alternative binary operations]]
[[!redirects right alternative binary operation]]
[[!redirects right alternative binary operations]]
[[!redirects right-alternative operation]]
[[!redirects right-alternative operations]]
[[!redirects right alternative operation]]
[[!redirects right alternative operations]]
[[!redirects right-alternative magma]]
[[!redirects right-alternative magmas]]
[[!redirects right alternative magma]]
[[!redirects right alternative magmas]]
[[!redirects right-alternative algebra]]
[[!redirects right-alternative algebras]]
[[!redirects right alternative algebra]]
[[!redirects right alternative algebras]]

[[!redirects flexibility]]
[[!redirects flexible binary operation]]
[[!redirects flexible binary operations]]
[[!redirects flexible operation]]
[[!redirects flexible operations]]
[[!redirects flexible magma]]
[[!redirects flexible magmas]]
[[!redirects flexible algebra]]
[[!redirects flexible algebras]]
