
> This entry is about [[geometry]] based on the study of _[[analytic functions]]_, hence about [[analytic varieties]]. 

> This is unrelated to "analytic geometry" in the sense of methods in the geometry of $n$-dimensional [[Euclidean space]] involving *[[coordinate]] calculations* (as opposed to [[synthetic geometry]]); which is usually combined with linear algebra taught in a geometric way. For this latter meaning see at _[[coordinate system]]_.


+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Geometry
+--{: .hide}
[[!include higher geometry - contents]]
=--
#### Analytic geometry
+--{: .hide}
[[!include analytic geometry -- contents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}



## Idea

In research mathematics, when one says _analytic geometry_, then "analytic" refers to [[analytic functions]] in the sense of [[Taylor expansion]] and by __analytic geometry__ one usually means the study of geometry of [[complex manifolds]]/[[complex analytic spaces]], as well as their analytic subsets, [[Stein domains]] and related notions. More generally one may replace the complex numbers by [[non-archimedean fields]] in which case one speaks of _[[rigid analytic geometry]]_.

Similarly to an [[algebraic variety]], an [[analytic variety]] is locally given as a [[zero locus]] of a [[finite set]] of [[analytic functions]], i.e. of [[holomorphic functions]] in complex analytic geometry. 

A short survey can be found in a chapter of Dieudonne's _Panorama of pure mathematics_. 

In addition to analytic geometry over complex numbers, there is also another formalism which allows for [[archimedean field|nonarchimedean]] [[ground fields]]. This is the subject of [[rigid analytic geometry]] or [[global analytic geometry]]. Similarly to [[schemes]], rigid analytic varieties are glued from [[Bercovich spectrum|Bercovich spectra]] of certain commutative Banach algebras, so-called [[affinoid]]s, in a certain [[Grothendieck topology]]. (See _[[analytic space]]_.) There are several variants of the formalism (e.g. due Huber). The subject is closely related to [[formal geometry]] and has its main applications in [[arithmetic geometry]] and [[representation theory]]. 

It is an open problem to find an appropriate analogue of rigid analytic geometry in [[noncommutative geometry]], which is supposed to play an important role in [[mirror symmetry]].

Local properties of analytic manifolds and spaces are studied in [[local analytic geometry]]. 

## Theorems

(...)

* [[Ostrowski's theorem]]

(...)
## Holomorphic functions of several complex variables

This section is about certain aspects of 
[[holomorphic functions]] $\mathbb{C}^n \to \mathbb{C}$.

Currently it concentrates on aspects of relevance in the application to [[AQFT]], such as a version of the [edge-of-the-wedge] (http://en.wikipedia.org/wiki/Edge-of-the-wedge_theorem) theorem.

From the viewpoint of complex [[manifold]]s this is the _local_ theory that describes the situation in coordinate patches.

* [Wikipedia] (http://en.wikipedia.org/wiki/Several_complex_variables)

When we talk about holomorphic functions in the following and do not specify the domain, we will always assume that the domain is an open, simply connected subset of $\mathbb{C}^n$.

### relevance to quantum field theory (QFT)

In the [[AQFT]] formulation (actually the following description is the [[Heisenberg picture]] of quantum mechanics in a nutshell) [[selfadjoint operator]]s $A$ on a [[Hilbert space]] $\mathcal{H}$ are the [[observables]] of a physical system, while normed vectors $x, y \in \mathcal{H}$ represent the [[states]] the system can be in. The [[real number]] $\langle y, A x \rangle$ represents the [[probability]] that a system starting in state $x$ will be in state $y$ after a [[measurement]] of $A$. 

In [[AQFT]] we often encounter a set of operators indexed by several complex variables $z = (z_1, z_2, ...)$ and try to deduce properties of the theory from the function $f(z) := \langle y, A(z)x \rangle$. In this way, the theory of [[holomorphic functions]] of several variables is promoted to an irreplaceable tool in quantum field theory.   

### Hartogs' theorem

One striking difference of functions of several _real_ variables and several _complex_ variables is described by Hartogs' theorem on separate analyticity:

* Theorem (Hartogs): Let f be a $\mathbb{C}$-valued function defined in an open set $U \subset \mathbb{C}^n$. Suppose that f is analytic in each variable $z_j$ when the other coordinates $z_k$ are fixed. Then f is analytic as a function of all n
coordinates.

_remark_: There are no other assumptions about f necessary, it needs not to be continous or even measurable. Note that in the real case the property of being partially differentiable alone encodes nearly no information about a function.

Reference:

* Paul Garrett: [Hartogs theorem] (http://www.math.umn.edu/~garrett/m/complex/hartogs.pdf)

_relevance_: When reading [[AQFT]] literature you will often encounter the claim that given functions are holomorphic, Hartogs' theorem simplifies the task of checking these claims considerably, because you have to check the holomorphy in every single variable only.

### analogues from the one-dimensional theory
Some results remain true in the multi dimensional case.

* Identity theorem: If a holomorphic function is zero in a neighbourhood of a point, it is the zero function.

_remark_: As usual the domain is supposed to be an open, simply connected (not necessarily proper) subset of $\mathbb{C}^n$, which implies that the point of the precondition of the theorem is an interior point of the domain.

### domains of holomorphy
One of the most notably difference of the theory of _one_ complex variable and of _several_ complex variables is that the [riemann mapping theorem] (http://en.wikipedia.org/wiki/Riemann_mapping_theorem) fails in several complex variables, which is in a certain sense the reason why in several complex variables there are domains which can be enlarged such that _all_ holomorphic functions extend to the larger domain.

_handwaving_ why this is not possible in one dimension: According to the riemann mapping theorem every domain (open, simply connected proper subset of $\mathbb{C}$) is biholomorph equivalent to the open disk $E: = \{ z: |z| \lt 1 \}$, which means that the rings of holomorphic functions are isomorph, too. But the ring of holomorphic functions on E has to every point in the boundary of E a function that has a pole in this point, so that E cannot be enlarged in a way that all holomorphic functions are extentable. Therefore this applies to every domain.

Some domains in $\mathbb{C}^n$ _do_ have the property that they cannot be enlarged, and since this is an interesting property, the name **domain of holomorphy** was coined for these, and the question how they could be described was promoted to an interesting research topic in the beginning of the 20th century.
   
* [Wikipedia] (http://en.wikipedia.org/wiki/Domain_of_holomorphy)

#### edge of the wedge theorems
These theorems desribe situations where holomorphic functions defined on specific domains (the wedges) can be continued to holomorphic functions of larger domains. 

* [Wikipedia] (http://en.wikipedia.org/wiki/Edge-of-the-wedge_theorem)

They are a valuable tool in [[AQFT]] (and were in fact discovered by one of the fathers of the theory, [Nikolay Bogolyubov] (http://en.wikipedia.org/wiki/Nikolay_Bogoliubov)).

We state here one version that will be of use to the nLab:

* theorem (edge of the wedge): Let $K := \{ z \in \mathbb{C}^n: |z| \le r \}$ be a ball in $\mathbb{C}^n$ and let $\mathcal{C} \subset \mathbb{R}^n$ be an open convex cone such that $\mathcal{C} \cap (- \mathcal{C}) \neq \emptyset $. We put $z = x + iy$ with $x, y \in \mathbb{R}^n$ and define an open domain G by $G:= \{ z = x + iy: z \in K, y \in \mathcal{C} \}$. Let $f$ be a holomorphic function in G and assume that 
$$
        \lim_{y \to 0, y \in \mathcal{C}} f(x + iy)
$$
exists for all $x \in B_r \subset \mathbb{R}^n$, where $B_r$ is an open ball with radius r. (The limit may not depend on the specific sequence chosen). Then $f$ is holomorph extendable into an open region $G \cup G_0$ with 
$$
        G_0 := \bigcup_{x \in B_r} \{ z: |z-x| \le \theta \cdot dist(x, \partial U) \}
$$
with $0 \lt \theta \lt 1$ a constant that is independent from $x, B_r$, and $f$.

_proof_: V.S.Vladimirov, "theory of functions of several complex variables" ([ZMATH entry](http://www.zentralblatt-math.org/zmath/en/advanced/?q=an:0125.31904&format=complete))

## Related concepts

* [[several complex variables]], 

* [[rigid analytic geometry]], [[analytic spectrum]], [[analytic space]], [[Stein space]], [[Berkovich space]], [[additive analytic geometry]]

* [[G-topology]]

* [[Oka principle]]

* [[p-adic geometry]]

* [[B1-homotopy theory]]

* [[global analytic geometry]]

  * [[overconvergent global analytic geometry]]

## References
 {#References}

Course notes on ([[global analytic geometry|global]]) analytic geometry are in 

* [[Frédéric Paugam]], _Global analytic geometry and the functional equation_ (2010) ([pdf](http://www.math.jussieu.fr/~fpaugam/documents/enseignement/master-global-analytic-geometry.pdf))

and for [[rigid analytic geometry]] in 

* Kiran Sridhara Kedlaya, _Introduction to Rigid Analytic Geometry_ ([web](http://www-math.mit.edu/~kedlaya/18.727/notes.html))

* [[Brian Conrad]], _Several approaches to non-archimedean geometry_ ([pdf](http://math.stanford.edu/~conrad/papers/aws.pdf))


A gentle and modern introduction to [[complex manifolds]] that starts with an extensive exposition of the local theory is this:

* [[Daniel Huybrechts]], _Complex geometry. An introduction._ ([ZMATH entry] (http://www.zentralblatt-math.org/zmath/en/advanced/?q=an:1055.14001&format=complete))

* [[Hans Grauert]], Reinhold Remmert, _Theory of Stein spaces_, Grundlehren der Math. Wissenschaften __236__, Springer 1979, xxi+249 pp.; _Coherent analytic sheaves_, Grundlehren der Math. Wissenschaften __265__, Springer 1984. xviii+249 pp.; _Komplexe R&#228;ume_, Math. Ann. __136__, 1958, 245&#8211;318, [DOI](http://dx.doi.org/10.1007/BF01362011)

Discussion of [[Berkovich space]] analytic geometry as [[algebraic geometry]] in the general sense of [[Bertrand Toën]] and [[Gabriele Vezzosi]] is in 

* [[Oren Ben-Bassat]], [[Kobi Kremnizer]], _Non-Archimedean analytic geometry as relative algebraic geometry_ ([arXiv:1312.0338](http://arxiv.org/abs/1312.0338))

For more see the references at [[rigid analytic geometry]] and at [[analytic space]].



category: analysis, geometry