Let $F$ be a [[free group]] with basis $X = \{ x_i\}_{i\in I}$ and $\mathbb{Z}F$ the integer [[group ring]]. 

 Differentiation or [[derivation on a group|derivation]], $D$, in this context is defined using a sort of nonsymmetric analogue of the Leibniz rule: it is an additive map $D:\mathbb{Z}F\to\mathbb{Z}F$ such that for all $u,v\in F$, 

$$D(u v) = D(u) + u D(v). $$ 

The __Fox partial derivatives__ $\frac{\partial}{\partial x_i}$ are defined by the rules 

$$ \frac{\partial 1}{\partial x_i} = 0$$

$$ \frac{\partial x_i}{\partial x_i} = 1$$


extended to the products $u = y_1\ldots y_n$ where $y_i = x_k$ or $y_i=x_k^{-1}$ for some $k = k(i)$ by the formula

$$
\frac{\partial u }{\partial x_i} = \sum_{s=1}^n y_1\cdots y_{s-1} \frac{\partial y_s }{\partial x_i}.
$$ 

This then implies that 

$$ \frac{\partial x_i^{-1}}{\partial x_i} = -x_i^{-1}$$

$$ \frac{\partial x_j^{\pm 1}}{\partial x_i} = 0,\;\;i\neq j$$  

Notice that the summands on the right-hand side are "of different length". 


The lemma given in [[derivation on a group]] allows the following alternative form of the above definition to be given:

+-- {: .un_defn}
###### Definition

For each $x \in X$, let 
$$\frac{\partial}{\partial x} : F \to \mathbb{Z}F$$
be defined by

1. for $y \in X$, 

   $$\frac{\partial y}{\partial x} = 1\,\,\, if\,\,\,  x = y\,\,\, and \,\,\,=
   0  \,\,\, y \neq x;
   .$$


2. for any words, $w_1,w_2 \in F$,

   $$\frac{\partial}{\partial x}(w_1w_2) = \frac{\partial}{\partial x}w_1 + w_1\frac{\partial}{\partial x}w_2.$$

Then these uniquely determine the Fox derivative of $F$ with respect to $x$.
=--


The Fox derivatives give a way of expanding any derivation (differentiation) defined on $F$. For every differentiation 

$$
D(u)=\sum_{i\in I} \frac{\partial u }{\partial x_i} D(x_i)
$$ 

(This is a finite sum since $u$ will only involve finitely many of the generators.) 

In particular if  $\epsilon:\mathbb{Z}F\to\mathbb{Z}$ is the augmentation map given by $\epsilon:x_i\mapsto 1$, then the differentiation $u\mapsto u-\epsilon(u) 1_F$ satisfies

$$
u - \epsilon(u) 1_F = \sum_i \frac{\partial u }{\partial x_i} (x_i -1)
$$

hence it belongs to the left [[ideal]] in $\mathbb{Z}F$ which is generated by $(x_i-1)$. 

This construction is important in [[combinatorial group theory]], particularly in the study of [[free product]]s of groups and the study of [[metabelian group]]s. 

Given any group $G$ with a [[group presentation|presentation]] $\langle X; R\rangle = F/N$ such that $F=\langle X\rangle$ is the [[free group]] on the set of letters $X$ and $N$ the [[normal subgroup|normal closure]] of the set of relations $R$, let $\bar{G}:=G/[G,G]$, let $\phi:F\to G$, $\bar\phi:F\to \bar{G}$ be the canonical projections; denote by the same letter their linearizations for group rings $\phi:\mathbb{Z}F\to \mathbb{Z}G$ and $\bar\phi:\mathbb{Z}F\to\mathbb{Z}\bar{G}$. The __Jacobi matrix__ of the presentation is the matrix 

$$
J = \left(\phi(\frac{\partial r_i}{\partial x_j})\right)
$$
and also the projected matrix $\bar{J}$ which is the image of $J$ as a matrix over $\mathbb{Z}\bar{G}$. The __determinant ideal__ $D_i$ of order $i$ of the matrix $\bar{J}$ is the ideal of $\mathbb{Z}\bar{G}$ generated by all minors (= determinants of submatrices) of size $i\times i$ in $\bar{J}$. The sequence $D_1,D_2,\ldots$ is invariant (up to some technical details), that is does not depend on the presentation. In the case when $G=\pi(S)$ where $S$ is the complement of a [[knot]], $\bar{G}$ is an infinite cyclic group. Let $t$ be its generator; then the highest nonzero determinant ideal (of $\bar{J}$) in $\mathbb{Z}\bar{G}$ is a principal ideal, hence it has a normalized (in the sense that the heighest coefficient is $1$) generator, which is a polynomial in $t$. This polynomial is an invariant of the knot, the __Alexander polynomial__ of the knot.


###References

The orginal articles include:

* R. H. Fox, _Free differential calculus I: Derivation in the free group ring_, Annals Math. (2) __57__, 547--560 (1953) [doi:10.2307/1969736](http://dx.doi.org/10.2307/1969736)

* R. H. Fox, _Free differential calculus II: The Isomorphism Problem of Groups_, Annals Math. (2) __59__ 196--210 (1954); _III:Subgroups_, Annals Math. (2)  __64__, 407--419; IV: __71__, 408--422 (1960)

with a nice introduction in 

* * [[R. H. Crowell]] and [[R. H. Fox]], Introduction to Knot Theory, Springer, Graduate Texts 57, 1963.

see also
 
* B. Chandler, [[W. Magnus]], _The history of combinatorial group theory: a case study in the history of ideas_, Springer 1982

* [[R. Lyndon]], [[P. Schupp]], _Combinatorial group theory_, Ch. II.3, Springer 1977(Russian transl. Mir, Moskva 1980)

and more recently

* Valentino Zocca, _Fox calculus, symplectic forms and moduli spaces_, Trans. AMS__350__, 4, (1998) 1429-1466, [pdf](http://www.ams.org/journals/tran/1998-350-04/S0002-9947-98-02052-2/S0002-9947-98-02052-2.pdf)

* [en.wikipedia:Fox derivative](http://en.wikipedia.org/wiki/Fox_derivative)

Connections to double Poisson structures/brackets are discussed in

* Gwenael Massuyeau, [[Vladimir Turaev]], _Quasi-Poisson structures on representation spaces of surfaces_, [arxiv/1205.4898](http://arxiv.org/abs/1205.4898), [irma pdf](http://www-irma.u-strasbg.fr/~massuyea/papers/double_brackets.pdf)

See also 

* Gwenael Massuyeau, Vladimir Turaev, _Fox pairings and generalized Dehn twists_, [arxiv/1109.5248](http://arxiv.org/abs/1109.5248)

For a pro-$l$-version of Fox calculus see

* _Pro-$l$ Fox free differential calculus_, section 8.3 of Masanori Morishita, _Knots and primes: an introduction to arithmetic topology_, Springer 2012

[[!redirects Fox derivatives]]