
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Analysis
+-- {: .hide}
[[!include analysis - contents]]
=--
#### Functional analysis
+-- {: .hide}
[[!include functional analysis - contents]]
=--
#### Topology
+-- {: .hide}
[[!include topology - contents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}

## Idea
 {#Idea}

In [[mathematics]], _analysis_ usually refers to any of a broad family of fields that deals with a general theory of _[[limit of a sequence|limits]]_ in the sense of [[convergence]] of [[sequences]] (or more generally of [[nets]]), particularly those fields that pursue developments that originated in "the [[calculus]]", i.e., the theory of [[differentiation]] ([[differential calculus]]) and [[integration]] ([[integral calculus]]) of [[real numbers|real]] and [[complex numbers|complex]]-valued [[functions]]. The classical foundation of this general subject is usually based on the idea that the [[real numbers|real number system]] is describable as the (essentially unique) [[complete space|complete]] [[ordered field]], or more generally on the concept of [[metric spaces]]. Their [[distance]] functions allow to formalize concepts like [[continuous functions|continuity]] and [[convergence]] in terms of existence of sufficiently small [[open balls]]. Many concepts of this "[[epsilontic analysis]]" have equivalent formulations in terms of simple [[combinatorics]] of [[open subsets]] with respect to the [[metric topology]] of metric spaces, and this way the field of analysis has a large overlap with the field of _[[topology]]_, this is particularly true for [[functional analysis]] and the theory of [[topological vector spaces]].

Analysis can also refer to other responses to the problem of founding these developments, especially "[[infinitesimal analysis]]" which admits [[infinitesimal quantities]] not found in the classical real number system and which takes various forms, for example the [[nonstandard analysis]] first introduced by [[Abraham Robinson]], or "[[synthetic differential geometry|synthetic differential analysis]]" whose rigorous foundations were largely introduced by [[William Lawvere]] and other [[category theory|category theorists]] who, following the example of [[Alexander Grothendieck]], consider [[nilpotent infinitesimals]] (instead of invertible ones &agrave; la Robinson) as a basis for understanding [[differentiation]].


## Entries related to analysis

### On mainstream analysis

Some of the $n$lab entries related to __mathematical analysis__ include  [[metric space]], [[normed vector space]], [[metric topology]], [[sequence]], [[net]], [[convergence]],  

[[functional analysis]], [[harmonic analysis]], [[complex analysis]], [[Weierstrass preparation theorem]], [[several complex variables]], [[Fourier transform]], [[Pontrjagin dual]], [[differential geometry]], [[Legendre polynomial]], [[dilogarithm]], [[Hilbert space]], [[Banach space]], [[Banach algebra]], [[topological vector space]], [[locally convex space]], [[operator algebras]], [[Gelfand spectrum]], [[measure space]], [[measurable function]], [[Lebesgue space]], [[Sobolev space]], [[bounded operator]], [[compact operator]], [[Fredholm operator]], [[distribution]] (generalized function), [[hyperfunction]].[[spectral theory]], [[integral]], [[integration]]...and a book entry [[Handbook of analysis and its foundations]]. Many of the basic notions used in analysis courses are described in $n$lab in the more general [[topology|topological]] context if they belong there, e.g. [[compact space]], [[continuous map]], [[compact-open topology]] and so on. Many of the aspects of [[analytic geometry]] are treated in terms of Riemann surfaces, [[monodromy]], [[local system]]s and so on. 

### On foundations 

Alternative [[foundations]], especially [[constructive mathematics|constructive]] and those using [[topos theory]], are of traditional interest to the [[category theory]] community. For example the [[synthetic differential geometry]] of Lawvere and Kock (more in next paragraph) and the [[nonstandard analysis]] of Robinson, and its variant, [[internal set]] theory of Nelson are some of the principal examples. See also [[Fermat theory]], [[natural numbers object]], [[infinitesimal number]] etc. Many statements are about the versions without the [[axiom of choice]] and so on; we like to state clean and minimal conditions when possible.  


### On smoothness and generalized Lie theory

Various smoothness concepts in geometry, rarely studied in standard courses of analysis, but sometimes relevant, were studied to fair extent (and sometimes with innovations) in the $n$lab. These smoothness concepts are built using some primitive notions in rather generalized (often categorical) setups: [[Kähler differential]], [[differential form]], [[tangent space]], [[jet bundles]], resolution of diagonal, [[infinitesimal object]], [[microlinear space]], [[generalized smooth algebra]], [[tangent category]], [[cotangent complex]] as defining ingredients of various notions of smoothness and smooth spaces. Main framework to systematize in geometry similar notion studied in $n$lab is [[synthetic differential geometry]] but many other examples are also represented. Let us mention [[generalized smooth space]], [[stratifold]], [[Frölicher space]], and some graded and super analogues ([[supermanifold]], [[NQ-supermanifold]], [[integration over supermanifolds]]); some concepts of smoothness are rather algebraic, e.g. [[formal smoothness]] of [[Grothendieck]]; see also [[algebraic approaches to differential calculus]]. Special attention in $n$lab has been paid to smooth group like objects like [[Lie group]], [[Lie groupoid]] and their superanalogues and [[categorification]]s, as well as to their tangent structures like [[Lie algebroids]] and their interrelations ([[Lie theory]]: [[integration]], [[Lie integration]]). 

### On geometric function theory and quantization

Some other entries are related to the conceptual and categorical understanding of Feynman [[path integral]], however so far from physical, conceptual and formal point of view only (and not of analytic theory). This is closely related to understanding various higher categorical spaces of [[sections]] in geometry and in study of sigma-models in physics. This is here called [[geometric function theory]] (cf. [[space and quantity]], [[geometric quantization]]...). 

### On quantization and the geometry of differential operators

Very relevant for [[quantization]] is also the geometric study of differential operators (see [[D-geometry]], [[diffiety]]) and distributions (cf. [[microlocal analysis]]), by analysis of oscillating integrals ([[semiclassical approximation]]), [[symplectic geometry]] (esp. the geometry of [[lagrangian submanifold]]s which could often be viewed as quantum points) etc. Some of the topological properties of differential operators are studied in [[index theory]], where special role have so called [[Dirac operator]]s. Sometimes it is possible or even useful to avoid fine analysis by using the [[algebraic approaches to differential calculus]] and [[regular differential operator|differential operators]], what also makes possible some noncommutative analogues. 

### On contructivism and computable analysis

* [[constructive analysis]], [[computable analysis]]


## Related concepts

* [[epsilontic analysis]]

* [[infinitesimal analysis]]


## References
 {#References}


### General
 {#ReferencesGeneral}

Textbooks include

* {#Rudin64} [[Walter Rudin]], _Principles of Mathematical Analysis_, McGraw-Hill (1964, 1976) ([pdf](https://notendur.hi.is/vae11/%C3%9Eekking/principles_of_mathematical_analysis_walter_rudin.pdf))

* [[Eric Schechter]], _[[Handbook of Analysis and its Foundations]]_, Academic Press (1996) ([web](http://www.math.vanderbilt.edu/~schectex/ccc/))

Discussion of the history, amplifying its roots all the way back in [[Zeno's paradoxes of motion]] is in 

* {#Boyer49} Carl Benjamin Boyer, _The history of the Calculus and its conceptual development_, Dover 1949

See also

* Wikipedia, _[Mathematical analysis](https://en.wikipedia.org/wiki/Mathematical_analysis)_

See also the references at _[[calculus]]_.



### Constructive analysis
 {#ReferencesConstructiveAnalysis}

The formulation of [[analysis]] in [[constructive mathematics]], hence [[constructive analysis]], was maybe inititated in 

* {#Bishop} [[Errett Bishop]], _Foundations of constructive analysis._ McGraw-Hill, (1967)
 
together with the basic notion of [[Bishop set]]/[[setoid]]. Implementations of constructive [[real number]] analysis in [[type theory]] implemented in [[Coq]] are discussed in 

* R. O'Connor, _A Monadic, Functional Implementation of Real Numbers_. MSCS, 17(1):129-159, 2007 ([arXiv:0605058](http://arxiv.org/abs/cs/0605058))

* R. O'Connor, _Certified exact transcendental real number computation in Coq_, In TPHOLs 2008, LNCS 5170, pages 246--261, 2008.

* R. O'Connor, _Incompleteness and Completeness: Formalizing Logic and Analysis in Type Theory_, PhD thesis, Radboud University Nijmegen, 2009.

* Robbert Krebbers, [[Bas Spitters]], _Type classes for efficient exact real arithmetic in Coq_ ([arXiv:1106.3448](http://arxiv.org/abs/1106.3448/))

[[!redirects mathematical analysis]]