
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Monoidal categories
+--{: .hide}
[[!include monoidal categories - contents]]
=--
#### Category theory
+--{: .hide}
[[!include category theory - contents]]
=--
=--
=--

# Semicartesian monoidal categories

* table of contents
{: toc}

## Definition

A [[monoidal category]] is **semicartesian** if the unit for the tensor product is a [[terminal object]], a weakening of the concept of [[cartesian monoidal category]].

Many semicartesian monoidal categories are also [[symmetric monoidal category|symmetric]], and sometimes that is included in the definition.

## Examples

Some examples of semicartesian monoidal categories that are not cartesian include the following.

* The category of [[Poisson manifold]]s with the usual product of Poisson manifolds as its tensor product.

* The opposite of the category of [[associative algebra]]s over a given [[base field]] $k$ with its usual tensor product $A \otimes B$.

* The category [[Cat]] with the non-standard non-cartesian [[funny tensor product]].

* The category of [[strict 2-categories]] with the [[Gray tensor product]], and the category of [[strict omega-categories]] with the [[Crans-Gray tensor product]].

* The category of [[affine space|affine spaces]] made into a [[closed monoidal category]] where the [[internal hom]] has $hom(x,y)$ being the set of affine linear maps from $x$ to $y$, made into an affine space via pointwise operations.

* The category of [[convex space|convex spaces]], also known as 'barycentric algebras', made into a closed monoidal category where the internal hom has $hom(x,y)$ being the set of convex linear maps from $x$ to $y$, made into an barycentric algebra via pointwise operations.

* The thin category associated to the linear order $([0, \infty], \ge)$ of extended nonnegative real numbers with addition as the tensor product and [[internal hom]] as truncated subtraction. 

* If $(M, \otimes, I)$ is any monoidal category, $I$ being the monoidal unit, the [[slice category]] $M/I$ inherits a monoidal product given by 
$$(X \stackrel{f}{\to} I) \otimes (Y \stackrel{g}{\to} I) = (X \otimes Y \stackrel{f \otimes g}{\to} I \otimes I \cong I)$$ 
where the isomorphism displayed is the canonical one. This monoidal product is semicartesian. The forgetful functor $\Sigma: M/I \to M$ is strong monoidal, and is universal in the sense of exhibiting the fact that semicartesian monoidal functors and strong monoidal functors form a coreflective sub-bicategory of the bicategory of monoidal categories and strong monoidal functors. (Check this.) 

## Internal logic

The [[internal logic]] of a (symmetric) semicartesian monoidal category is [[affine logic]], which is like [[linear logic]] but permits the [[weakening rule]] (and also the [[exchange rule]], if the monoidal structure is symmetric).

## Properties

### Semicartesian vs. cartesian

In a semicartesian monoidal category, any tensor product of objects $x \otimes y$ comes equipped with morphisms 
$$ p_x : x \otimes y  \to x $$
$$ p_y : x \otimes y \to y$$
given by
$$ x \otimes y \stackrel{1 \otimes e_y}{\longrightarrow} x \otimes I \stackrel{r_x}{\longrightarrow} x $$
and
$$ x \otimes y \stackrel{e_x \otimes 1}{\longrightarrow} I \otimes y \stackrel{\ell_y}{\longrightarrow} y $$
respectively, where $e$ stands for the unique morphism to the terminal object and $r$, $\ell$ are the right and left unitors.  We can thus ask whether $p_x$ and $p_y$ make $x \otimes y$ into the [[product]] of $x$ and $y$.  If so, it is a theorem that $C$ is a cartesian monoidal category.  (This theorem has been observed by Eilenberg and Kelly ([1966](#EilKel66), p.551), but they may not have been the first to note it.) 

Alternatively, suppose that $(C, \otimes, I)$ is a monoidal category equipped with monoidal natural transformations $e_x : x \to I$ and $\Delta_x: x \to x \otimes x$ such that 
$$ x \stackrel{\Delta_x}{\longrightarrow} x \otimes x \stackrel{e_x \otimes 1}{\longrightarrow} I \otimes x \stackrel{\ell_x}{\longrightarrow} x $$
and
$$ x \stackrel{\Delta_x}{\longrightarrow} x \otimes x \stackrel{1 \otimes e_x}{\longrightarrow} x \otimes I \stackrel{r_x}{\longrightarrow} x $$
are identity morphisms.  Then $(C, \otimes, I)$ is a cartesian monoidal category. 

So, suppose $(C, \otimes, 1)$ is a semicartesian monoidal category.  The unique map $e_x : x \to I$ is a monoidal natural transformation.  Thus, if there exists a monoidal natural transformation $\Delta_x: x \to x \otimes x$ obeying the above two conditions, $(C, \otimes, 1)$ is cartesian.  The converse is also true.

The characterization of cartesian monoidal categories in terms of $e$ and $\Delta$, apparently discovered by Robin Houston, is mentioned here:

* John Baez, Universal algebra and diagrammatic reasoning, 2006. [pdf](http://math.ucr.edu/home/baez/universal/)

and as of 2014, Nick Gurski plans to write up the proof in a paper on semicartesian monads.  

### Colax functors

It is well-known that any functor between cartesian monoidal categories is automatically and uniquely [[colax monoidal functor|colax monoidal]]; the colax structure maps are the comparison maps $F(x\times y) \to F x \times F y$ for the cartesian product.  (This also follows from abstract nonsense given that the [[2-monad]] for cartesian monoidal categories is [[colax-idempotent 2-monad|colax-idempotent]].)  An inspection of the proof reveals that this property only requires the domain category to be semicartesian monoidal, although the codomain must still be cartesian.

### Semicartesian operads

The notion of [[semicartesian operad]] is a type of [[generalized multicategory]] which corresponds to semicartesian monoidal categories in the same way that [[operads]] correspond to (perhaps symmetric) monoidal categories and [[Lawvere theories]] correspond to cartesian monoidal categories.  Applications of semicartesian operads include:

* [Generalized operads in classical algebraic topology](http://golem.ph.utexas.edu/category/2009/10/generalized_operads_in_classic.html) (blog post) -- this also uses the above fact about colax functors

* [Characterizing finite measure spaces](http://golem.ph.utexas.edu/category/2011/05/an_operadic_introduction_to_en.html#c038131) (blog comment)

## Related pages

* [[cartesian monoidal category]]

* A [[relevance monoidal category]] is the "dual" of a semicartesian monoidal category, with diagonals but not projections.

## Reference

* {#EilKel66} [[Samuel Eilenberg|S. Eilenberg]], [[Max Kelly|M. G. Kelly]], _Closed Categories_ , pp.421-562 in Eilenberg et al. (eds.), _Proceedings of the Conference on Categorical Algebra - La Jolla 1965_ , Springer Heidelberg 1966.

* [Monoidal Categories with Projections](https://golem.ph.utexas.edu/category/2016/08/monoidal_categories_with_proje.html) (blog discussion)


[[!redirects semicartesian category]]
[[!redirects semi-cartesian category]]
[[!redirects semi-Cartesian category]]
[[!redirects semicartesian monoidal categories]]
[[!redirects semi-cartesian monoidal category]]
[[!redirects semi-cartesian monoidal categories]]
[[!redirects semicartesian categories]]
[[!redirects semi-cartesian categories]]
[[!redirects semi-Cartesian categories]]
