
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Super-Algebra and Super-Geometry
+-- {: .hide}
[[!include supergeometry - contents]]
=--
#### Higher spin geometry
+-- {: .hide}
[[!include higher spin geometry - contents]]
=--
=--
=--

# Contents
* table of contents 
{: toc}

## Definition

Given a [[commutative ring]] $R$ and $R$-[[module]]s $M$ and $N$, an __$R$-[[quadratic function]]__ on $M$ with values in $N$ is a map $q: M \to N$ such that the following properties hold:

* (cube relation) For any $x,y,z \in M$, we have $q(x+y+z) - q(x+y) - q(x+z) - q(y+z) + q(x) + q(y) + q(z) = 0$.
* (homogeneous of degree 2) For any $x \in M$ and any $r \in R$, we have $q(r x) = r^2q(x)$.

A **quadratic $R$-module** is an $R$-module $M$ equipped with a __[[quadratic form]]__: an $R$-quadratic function on $M$ with values in $R$. 

The **Clifford algebra** $Cl(M,q)$ of a quadratic $R$-module $(M,q)$ can be defined as the [[quotient]] of the [[tensor algebra]] $T_R(M)$ by the [[ideal]] generated by the relations $x \otimes x - q(x)$ for all $x \in M$.  

Equivalently, it is the [[initial object]] in the [[category]] whose [[object]]s are pairs $(A,\phi)$ where $A$ is an associative unital $R$-[[associative algebra|algebra]], and $\phi: M \to A$ is an $R$-[[linear map]] satisfying $\phi(x)^2 = q(x) 1_A$ for all $x \in M$, and whose morphisms $(A,\phi)\to (A',\phi')$ are the associative $R$-algebra maps $\chi: A\to A'$ such that $\chi\circ\phi=\phi'$.

## Examples

Examples in low [[rank]] can be calculated easily.  If $M$ is freely generated by a single element $e$, with quadratic form $q(e) = 1$, then $Cl(M,q) = R[e]/(e^2-1)$.  Note that the opposite sign convention is often used in the differential geometry literature, so one may see the assertion that the Clifford algebra of the real line with a positive definite metric is isomorphic to the complex numbers $\mathbb{R}[e]/(e^2+1)$.  Similarly, the Clifford algebra of a negative definite two dimensional real vector space is isomorphic to the (non-split) quaternions in our convention, but one may see the assertion that it is isomorphic to $M_2(\mathbb{R})$.  Complexification removes the difference between positive definite and negative definite, and the two complexified algebras are isomorphic.

Let $M = L \oplus L^\vee$ for $L$ projective of rank $d$ over $R$, and $L^\vee = Hom_R(L,R)$ the dual module.  One can define the canonical quadratic form $q(f+x) = f(x)$ for $f \in L^\vee$ and $x \in L$.  In this case, $Cl(M,q) \cong M_{2^d}(R)$.  In general, the Clifford algebra arising from a nondegenerate form is flat-locally (on $\operatorname{Spec} R$) isomorphic to a matrix algebra (when rank is even) or a direct sum of two matrix algebras (when rank is odd).

If $M$ is a projective $R$-module of rank $d$, then independently of $q$, the Clifford algebra $Cl(M,q)$ is projective of rank $2^d$, and is (noncanonically) isomorphic to $\bigwedge M$ as an $R$-module equipped with a map from $M$.  The Clifford algebra is isomorphic to the exterior algebra (as algebras equipped with $R$-module maps from $M$) if and only if $q = 0$.

If $R$ is the ring of smooth functions on a pseudo-Riemannian manifold $X$, and $M$ is the $R$-module of sections of the tangent bundle, then the metric endows $M$ with a quadratic structure, and one can form the Clifford algebra of the tangent bundle.  

## Properties

### Classification and Relation to matrix algebras
 {#Classification}



#### Over the complex numbers
 {#ClassificationOverTheComplexNumbers}

+-- {: .num_theorem}
###### Theorem

Let $V$ be the [[vector space]] over the [[complex numbers]]
of complex [[dimension]] $d$, equipped with non-degenerate
[[bilinear form]], unique up to [[isomorphism]]. The Clifford algebra 

$$
  Cl_{d}(\mathbb{C}) \coloneqq Cl(V)
$$ 

is  [[isomorphism|isomorphic]], as a complex [[associative algebra]]
to a  [[matrix algebra]] as follows:

$$
  Cl_d(\mathbb{C})
  \simeq
  \left\{
    \array{
       Mat_{2^{\tfrac{d}{2}}}(\mathbb{C}) & for \, d \, even
       \\
       Mat_{2^{\tfrac{d-1}{2}}}(\mathbb{C}) \oplus Mat_{2^{\tfrac{d-1}{2}}}(\mathbb{C}) 
       & for \, d \, odd
    }
  \right.
$$

=--

+-- {: .num_remark}
###### Remark

This is one of the incarnations of [[Bott periodicity]].

=--



#### Over the real numbers
 {#ClassificationOverTheRealNumbers}

We discuss the classification of Clifford algebras over the [[real numbers]] and their relation to [[matrix algebras]] over the real numbers. A key statement is that of the mod-8 [[Bott periodicity]] of this classification (prop. \ref{RealBottPeriodicity} below).

In the following we write

*  $\Cl_{s,t}$ for the real Clifford algebra with 

   * $s$ generators squaring to -1 

   * $t$ generators squaring to +1

* $\mathbb{C}$ for the [[complex numbers]] regarded as an [[associative algebra]] over $\mathbb{R}$;


* $\mathbb{H}$ for the [[quaternions]] regarded as an [[associative algebra]] over $\mathbb{R}$;

* $\mathbb{K}[n] \coloneqq Mat_{n \times n}(\mathbb{K})$ for the [[matrix algebra]] of $n \times n$ matrices with [[coefficients]] in $\mathbb{K}$.

+-- {: .num_prop }
###### Proposition

For low dimensions of real Clifford algebras, there are the following isomorphisms of [[associative algebras]] over $\mathbb{R}$

$$
  Cl_{0,1}
  \simeq
  \mathbb{R} \oplus \mathbb{R}
$$

$$
  Cl_{1,1}
   \simeq
  \mathbb{R}[2]
$$


$$
   Cl_{1,0}
    \simeq
   \mathbb{C}
$$

$$
  Cl_{2,0} \simeq \mathbb{H}
$$

=--

(e. g. [Figueroa-O'Farrill, lemma32](#FigueroaOFarrill))


+-- {: .num_prop #Smooth0TypeIsSheavesOnSmoothMfd}
###### Proposition

For $n,s,t \in \mathbb{N}$ then there are the following [[isomorphisms]] of [[associative algebras]] over $\mathbb{R}$:

$$
  Cl_{n+2,0} \simeq Cl_{0,n} \otimes_{\mathbb{R}} Cl_{2,0}
$$

$$
  Cl_{0,n+2} \simeq Cl_{n,0} \otimes_{\mathbb{R}} Cl_{0,2}
$$

$$
  Cl_{s+1.t+1} \simeq Cl_{s,t} \otimes_{\mathbb{R}} Cl_{1,1}
$$

=--

(e.g. [Lawson-Michelsohn 89, theorem 4.1](#LawsonMichelsohn89), [Figueroa-O'Farrill, lemma 2](#FigueroaOFarrill))

+-- {: .num_prop #Smooth0TypeIsSheavesOnSmoothMfd}
###### Proposition

For $n,n_1, n_2 \in \mathbb{N}$ there are the following [[isomorphisms]] of [[associative algebras]] over $\mathbb{R}$:

* $\mathbb{R}[n_1] \otimes_{\mathbb{R}} \mathbb{R}[n_2] \simeq \mathbb{R}[n_1 n_2]$;

* $\mathbb{R}[n] \otimes_{\mathbb{R}} \mathbb{K} \simeq \mathbb{K}[n]$;

* $\mathbb{C} \otimes_{\mathbb{R}} \mathbb{C} \simeq \mathbb{C} \oplus \mathbb{C}$.

* $\mathbb{C} \otimes_{\mathbb{R}} \mathbb{H} \simeq \mathbb{C}[2]$;

* $\mathbb{H} \otimes_{\mathbb{R}} \mathbb{H} \simeq \mathbb{R}[4]$

=--

(e.g. [Lawson-Michelsohn 89, proposition 4.2](#LawsonMichelsohn89))


Now the incarnation in Clifford algebras of [[Bott periodicity]] over the [[real numbers]] is the following:

+-- {: .num_prop #RealBottPeriodicity}
###### Proposition

For all $n \in \mathbb{N}$ there are [[isomorphisms]] of [[associative algebras]] over $\mathbb{R}$ as follows:

* $Cl_{n+8,0} \simeq Cl_{n,0} \otimes_{\mathbb{R}} Cl_{8,0}$;

* $Cl_{0,n+8} \simeq Cl_{0,n} \otimes_{\mathbb{R}} Cl_{0,8}$.

where

* $Cl_{8,0} \simeq Cl_{0,8} \simeq \mathbb{R}[16]$.

=--

(e.g. [Lawson-Michelsohn 89, theorem 4.3](#LawsonMichelsohn89))

### As a superalgebra

While the [[tensor algebra]] of an $R$-module $M$ has a natural [[integer]] grading, the quadratic relation collapses this to a natural $\mathbb{Z}/2\mathbb{Z}$-grading on $Cl(M,q)$.

$$
  Cl(M,q) = Cl(M,q)^{ev} \oplus Cl(M,q)^{odd}
$$

When $M$ is projective of rank $d$, each homogeneous piece is projective of rank $2^{d-1}$.  When $q$ is nondegenerate, the even part of the Clifford algebra is also flat-locally isomorphic to a matrix ring or a sum of two matrix rings.

One can view the Clifford algebra multiplication as a quantization of the commutative [[super algebra]] $\bigwedge_R M$.

### Relation to exterior algebra (quantization)
 {#AsQuantizedExteriorAlgebra}

For $V$ an [[inner product space]], the [[symbol map]] (see there) constitutes an [[isomorphism]] of the underlying [[super vector space]]s of the Clifford algebra with the [[exterior algebra]] on $V$.

One can understand the Clifford algebra as the [[quantization]] [[Grassmann algebra]] induced from the [[inner product]] regarded as an odd [[symplectic form]].

### Relation to $Spin$ groups

Let $M$ be a projective $R$-module of finite [[rank]], and let $q$ be nondegenerate.  Write $Cl(M,q)^\times$ for the [[group of units]] of the Clifford algebra $Cl(M,q)$.  

The **Clifford group** $\Gamma_{M,q}(R)$ is the subgroup of elements $x$ for which twisted conjugation stabilizes the submodule $M \subset Cl(M,q)$.  Here, twisted conjugation is defined by $y \mapsto x y\alpha(x)^{-1}$, where $\alpha$ is the automorphism of $CL(M,q)$ induced by the $-1$ map on $M$.  Since twisted conjugation by $M$-stabilizing elements amounts to reflection $y \mapsto y - 2\frac{(x,y)}{q(x)}x$, there is a canonical map $\Gamma_{M,q}(R) \to O(M,q)$, and the Clifford group is in fact a central extension of the orthogonal group by $R^\times$.

The Clifford group is made of homogeneous elements in the $\mathbb{Z}/2\mathbb{Z}$-grading, and the subgroup of even elements is a normal subgroup of index two.  One also has a [[spinor]] norm $Q: \Gamma_{M,q}(R) \to R^\times$ on the Clifford group, defined by $Q(x) = x^t x$, where $x \mapsto x^t$ is the anti-involution of the Clifford algebra defined by opposite multiplication in the tensor algebra.

The [[Pin group]] $Pin_{M,q}(R)$ is the group elements of the Clifford group with [[spinor]] norm 1.  The [[Spin group]] $Spin_{M,q}(R)$ is the group of elements in the even subgroup of the Clifford group with [[spinor]] norm 1.

The restriction of the map $\Gamma_{M,q}(R) \to O(M,q)$ to the Pin group may not be surjective, but it is for positive definite real vector spaces.  The kernel is the group $\mu_2(R)$ of elements of $R$ that square to 1.  Similarly, the [[Spin group]] has a map to the special orthogonal group with kernel $\mu_2(R)$, but it may not be surjective in general.

One can use base change to define the groups given above as functors on commutative $R$-algebras.

## Spinors

For nondegenerate [[quadratic forms]] on real vector spaces, [[spinors]]/[[spin representations]] are distinguished linear representations of [[Spin groups]] that are not pulled back from the corresponding special orthogonal groups.  In other words, the central element $-1$ acts nontrivially.  They can be realized as restrictions of representations of the even parts of Clifford algebras.  Since even parts of Clifford algebras are (up to complexification) the sum of one or two matrix rings, their representation theory is quite simple.

The specific nature of spinor representations possible depends on the signature of the vector space modulo 8.  This is a manifestation of Bott periodicity.  One always has a Dirac spinor - the fundamental (spin) representation of the complexified Clifford algebra.  In even dimensions, this splits into two Weyl spinors (called half-spin representations).  One may also have real representations called Majorana spinors, and these may decompose into Majorana-Weyl spinors.

There are infinite dimensional Clifford algebra constructions that appear in conformal field theory.  One may extend the above discussion to topological $R$-modules and continuous quadratic forms, and one obtains canonical central extensions of infinite dimensional groups and algebras by a relative determinant construction.  Semi-infinite wedge spaces are spinor modules for Clifford algebras of quadratic Tate $R$-modules.

## Warnings

There is a difference of sign convention between differential geometers (following Atiyah) and everyone else.

Clifford algebras are often defined using bilinear forms instead of quadratic forms (and one often sees incorrect definitions of quadratic forms in terms of bilinear forms).  Such definitions will yield wrong (or boring) objects when 2 is not invertible.

Special orthogonal groups are often defined as the kernel of the determinant map on the corresponding orthogonal groups, but in characteristic 2, the determinant is trivial, while the Clifford grading (called the Dickson invariant) is not.

The Clifford group is sometimes defined without the twist in the conjugation, and this means the map to the orthogonal group may not be a surjection, and the action on $M$ is by negative reflections.

The spinor norm is sometimes defined with the opposite sign.

Special orthogonal groups over the reals are sometimes defined to be the connected component of the identity in the orthogonal group.  In indefinite signature, this defines an index two subgroup of the special orthogonal group.

Spin groups in signature $(m,n)$ for $m,n \geq 2$ have fundamental groups of order two.  They are simply connected when $m$ or $n$ is at most one. 

## Related concepts

* [[geometric algebra]]

* [[Clifford module]], 

* [[Clifford bundle]]

* [[Clifford module bundle]]

* [[Fierz identity]]

* [[spin geometry]], [[spin group]]

* [[2-Clifford algebra]]

* [[Feynman slash notation]]


## References

Original work includes

* [[William Clifford]], _Applications of Grassmann's extensive algebra_. American Journal of Mathematics 1 (4): 350–358. (1878)doi:10.2307/2369379.

* {#Cartan66} [[Élie Cartan]], _Theory of Spinors_, Dover,  first edition 1966

For some standard material see for instance

* {#LawsonMichelsohn89} [[H. Blaine Lawson]], [[Marie-Louise Michelsohn]], _[[Spin geometry]]_, Princeton University Press (1989) ISBN 0-691-08542-0

* [[Eckhard Meinrenken]], _Clifford algebras and Lie groups_ ([pdf](http://www.math.toronto.edu/mein/teaching/clif_main.pdf))

* {#Lounesto} [[Pertti Lounesto]], _Clifford  Algebras and Spinors_, London Mathematical Society No. 286. Cambridge University Press, second edition, 2001.

* [[Jean Gallier]], _Clifford Algebras, Clifford Groups, and a Generalization of the Quaternions_ ([arXiv:0805.0311](https://arxiv.org/abs/0805.0311))

For a program that promotes the use of Clifford algebra as a good expositional tool in introductory [[mechanics]] see _[[Geometric Algebra]]_.

See also the discussion of [[Majorana spinors]]

* {#FigueroaOFarrill} [[José Figueroa-O'Farrill]], _Majorana spinors_ ([pdf](http://www.maths.ed.ac.uk/~jmf/Teaching/Lectures/Majorana.pdf))



[[!redirects Clifford algebras]]
