
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Geometry
+-- {: .hide}
[[!include higher geometry - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Definition

A __group scheme__ is a [[group object]] in the category of [[schemes]] (or in a category of *some* schemes as for instance that of schemes over a fixed base scheme); in particular a group scheme is a [[group functor]]. As explained at [[group object]] there are two equivalent ways of realizing this:

One way is to define it as a functor $G:C Ring\to Set$ equipped with a transformation $m:G\times G\to G$ satisfying the properties spelled out at [[group object]].

The other way is to define it as a functor $Sch\to Grp$ from the category of schemes to that of (discrete) groups whose composition with the forgetful functor $Grp\to Set$ is representable.


Grothendieck emphasized the study of schemes over a fixed base scheme. Following this idea in the [[functor of points]] formalism, a group scheme over a scheme $X$ is a functor

$$
G: (Sch /X)^{op} \to Grp
$$

A **morphism of group schemes** $f:G\to H$ is a morphism of schemes that is a group homomorphism on any choice of values of points. This is more easily stated by saying that a morphism of group schemes must be a [[natural transformation]] between the [[functor of points]]; i.e. $f$ is required to be a natural transformation of functors with values in the category $Grp$ of groups (instead of with values in Set); an equivalent way to state this is that $f$ needs to satisfy $f m=m(f\times f)$ if $m:G\times G\to G$ denotes the group law on $G$.

This construction generalizes to [[ind-object|ind-schemes]] (as for example [[formal scheme|formal schemes]]) to that of a [[formal group scheme]].


## Overview

Let $k$ be some base field. We start with the **constant group scheme** $E_k$ defined by some classical group $E$ which gives in every component just the group $E$. Next we visit the notion of **étale group scheme**. This is not itself constant but becomes so by scalar extension to the separable closure $k_sep$ of $k$. The importance of étale affine is that the category of them is equivalent to that of [[nLab:Galois module|Galois modules]] by $E\mapsto E \otimes_k k_sep=\cup_{K/k \,sep\,fin} E(K)$

So far these examples ''do nothing'' with the (multiplicative and additive) structure of the ring in which we evaluate our group scheme.
But the next instances do this: We define the **additive-** and the **[[multiplicative group]] scheme** by $\alpha_k: R\mapsto R^+$ and $\mu_k:R\mapsto R^\times$ sending a $k$-ring to to its underlying additive- and multiplicative group, respectively. These have the ''function rings'' $O_k(\alpha_k)=k[T]$ and $O_(\mu_k)=K[T,T^{-1}]$ and since $(O_k\dashv Spec_k):k.Ring\stackrel{Spec_k}{\to} k.Aff$ we note that our basic building blocks $\alpha_k$ and $\mu_k$ are in fact representable $k$-functors aka. **affine group schemes**. We observe that we have $k.Gr(\mu_k,\alpha_k)=0$ and call in generalization of this property any group scheme $G$ satisfying $k.Gr(G,\alpha_k)=0$ **multiplicative group scheme**. (We could have also the idea to call $G$ satisfying $k.Gr(\mu_k,G)=0$ ''additive'' but I didn't see this.)
By some computation of the hom spaces $k.Gr(G,\mu_k)$ involving co- and birings we see that these are again always values of a representable $k$-functor $D(G)(-):=(-).Gr(G\otimes_k (-),\mu_{(-)})$; this functor we call the **[[Cartier dual]] of $G$**. If for example $G$ is a **[[finite group scheme]]** $D(G)$ also is, and moreover $D$ is a contravariant autoequivalence (''duality'') of $k.fin.comm.Grp$; in general it is also a **duality** in some specific sense.
By taking the Cartier dual $D(E_k)$ of a constant group scheme we obtain the notion of a **diagonlizable group scheme**. To justify this naming we compute some value $D(E_k)(R)=hom_{Grp}(E_k\otimes_k R, \mu_R)\simeq hom_{Grp}(E_k,R^\times)\simeq hom_Alg(k[E_k],R)$ where $k[E_k]$ denotes the [[group algebra]] of $E_k$ and the last isomorphism is due to the universal property of group rings; we observe that the last equality tells us that $G=Spec\,k[E_k]$ and recall that a $\zeta\in E_k\subset k[E_k]$ is called a [[nLab:character]] of $G$ (and one calls a group generated by these ''diagonalizable'').
Revisiting the condition $k.Gr(H,\alpha_k)=0$ by which we defined multiplicative group schemes and considering a group scheme $G$ satisfying this condition for all **sub group-schemes** $H$ of $G$ we arrive at the notion of **unipotent group scheme**. By the structure theorem of **decomposition of affine groups** we can proof that $G$ is unipotent iff the **completion of group schemes** (which gives us-by the usual technic of [[nLab:completion]]- a **formal (group) scheme** $\hat X$ if $X$ is a group scheme) of the Cartier dual of $G$, i.e. $\hat D(G)$ is a **connected formal group scheme** also called **local group scheme** since a local group scheme $Q=Spec_k A$ is defined to be the [[nLab:spectrum]] of a local ring; this requirement in turn is equivalent to $Q(K)=hom(A,K)=\{0\}$ hence the first name ''connected''. There is also a connection between connected and étale schemes: For any formal group scheme there is an essentially unique [[nLab:exact sequence]]

$$0\to G^\circ\to G\to \pi_0(G)\to 0\label{connectedetaledecomposition}$$

where $G^\circ$ is connected and $\pi_0(G)$ is étale. Such decomposition in exact sequences we obtain in further cases: $0\to G^{ex}\to G\to G_{ex}\to 0$ where

|$k$-group | $G^{ex}$ | $G_{ex}$ | | |
|-------|-------|-------|-------|--------|
| [[nLab:formal scheme|formal]] | [[nLab:connected object|connected]] | [[étale group scheme|étale]] | | p.34 |
| finite | [[nLab:infinitesimal object|infinitesimal]] | étale | splits if $k$ is perfect |p.35 |
| [[nLab:ring spectrum|affine]] | multiplicative | [[unipotent group scheme|unipotent | splits if $k$ is perfect | p.39 |
| connected  | $G_{red}$ is [[nLab:smooth scheme|smooth]] | $G/G_{red}$ is infinitesimal |p.43 |  |

where a **smooth (group) scheme** is defined to be the spectrum of a finite dimensional (over k) [[nLab:power series]] algebra, a (group) scheme is called **finite (group) scheme** if we restrict in all necessary definitions to $k$-ring which are finite dimensional $k$-[[nLab:vector space|vector spaces]], and a (group) scheme is called **infinitesimal (group) scheme** if it is finite and local. If  moreover $k$ is a perfect field any finite affine $k$-group $G$ is in a unique way the product of four subgroups $G=a\times b\times c\times d$ where $a\in Fem_k$ is a formal étale multiplicative $k$ group, $b\in Feu_k$ is a formal étale unipotent $k$ group, $c\in Fim_k$ is a formal infinitesimal multiplicative $k$ group, and $d\in Fem_k$ is a infinitesimal unipotent $k$ group.

If we now shift our focus to colimits- or more generally to codirected systems of [[finite group schemes]], in particular the notion of **[[p-divisible group]]** is an extensively studied case because the $p$-divisible group $G(p)$ of a group scheme encodes information on the **[[p-torsion]]** of the group scheme $G$. To appreciate the definition of $G(p)$ we first recall that for any group scheme $G$ we have the [[nLab:Frobenius morphism|relative Frobenius morphism]] $F_G:G\to G^{(p)}$ to distinguish it from the absolute Frobenius morphism $F^{abs}_G:G\to G$ which is induced by the Frobenius morphism of the underlying ring $k$. The passage to the relative Frobenius is necessary since in general it is not true that the absolute Frobenius respects the base scheme. Now we define $G[p^n]:=ker\; F^n_G$ where the kernel is taken of the Frobenius iterated $n$-times and the codirected system

$$G[p]\stackrel{p}{\to}G[p^2]\stackrel{p}{\to}\dots \stackrel{p}{\to}G[p^{n}]\stackrel{p}{\to}G[p^{n+1}]\stackrel{p}{\to}\dots$$

is then called the $p$-divisible group of $G$. As **cardinality** (in group theory also called **rank**) of this objects we have $card(G[p^j])=p^{j\cdot h}$ for some $h\in \mathbb{N}$; this $h$ is called the **[[height of a group scheme|height]] of $G$**. Moreover we have (p1) the $G[p^i]$ are finite group schemes (we assumed this by definition), (p2) the sequences of the form $0\to ker\, p^j\xhookrightarrow{\iota_j} ker p^{j+k}\stackrel{p^j}{\to}ker p^k\to 0$ are exact, (p3) $G=\cup_j ker\, p^j\cdot id_G$ and one can show that if we start with any codirected system $(G_i)_{i\in \mathbb{N}}$ satisfying (p1)(p2) we have that $colim_i G_i$ satisfies (p3) and $ker( F^n_G)\simeq G_n$ - in other words the properties (p1)(p2) give an equivalent **alternative definition of $p$-divisible groups** (and (p3) leads some authors to ''identify'' $G$ and $G(p)$). Basic examples of $p$-divisible groups are $(\mathbb{Q}_p/\mathbb{Z}_p)^h_k$ which is (up to isomorphism) the unique example of a constant $p$-divisible group of height $h$ and $A(p)$ where $A$ is a commutative [[nLab:variety]] with a group law (aka. **algebraic group**). $A(p)$ is called **[[nLab:the Barsotti-Tate group of an abelian variety]]**; if the dimension of $A$ is $g$ the height of $A(p)$ is $2g$.
Now, what about decomposition of $p$-divisible groups? We have even one more equivalent **''exactness'' characterization of $p$-divisible formal groups** by: $G$ is $p$-divisible iff in the connected-étale decomposition given by the exact sequence displayed in (1) we have ,($p1^\prime$), $\pi_0(G)(\overline k)\simeq (\mathbb{Q}_p/\mathbb{Z}_p)^r$ for some $r\in \mathbb{N}$ and ,($p2^\prime$), $G^\circ$ is **of finite type** (= the spectrum of a Noetherian ring), smooth, and the kernel of its [[Verschiebung morphism]] (this is the left adjoint the Frobenius morphism) is finite. Of course this characterization of $p$-divisiblity by exact sequences gives rise to propositions on dimensions and subgroups of $p$-divisible groups.

(...)

In cases where $k$ is a field of prime [[nLab:characteristic]] $p$, there is some special $k$-functor which is a group functor and even a ring functor (a $k$-functor equipped with a ring structure) - namely the functor $W:k.Ring. comm\to \lambda.Ring\hookrightarrow Set$ whose image is the category $\Lambda$ of **[[nLab:lambda ring|lambda-rings]]**; the objects $W(R)$ of $\Lambda$ are also called **[[nLab:Witt vectors]]** since they are infinite sequences of elements of $R$ (this justifies at least ''vectors''). $W$ possesses a left adjoint $(V\dasv W)$ forgetting the lambda-structure and the [[couniversal property]] associated to this adjunction states that for a $k$-ring $R$ we have that $W(R)$ is the couniversal object such that all so called **Witt polynomials** $w_n(x_0,\dots x_n):=x_0^{p^n}+p\cdot x_1^{p^{n-1}}+p^2 \cdot x_2^{p^{n-2}}+\dots+p^n\cdot x_n$ are ring homomorphisms. For this special $k$-group $W$ we revisit some construction we have done above for general $k$-groups: we firstly make the eponymous remark that the Verschiebung morphism $V_W(R):(a_1,a_2,\dots,a_n,\dots)\mapsto (0,a_1,a_2,\dots,a_n,\dots)$ is given by shifting (German: Verschiebung) one component to the right. By abstract nonsense we have also Frobenius. An important proposition concerning the ring of Witt vectors is that for a perfect field $k$, $W(k)$ is a **discrete valuation ring**. The next construction we visit with $W(R)$ is **Cartier duality of finite Witt groups** (here we forget that $W(R)$ is even a ring): For this note that the **ring of finite Witt vectors $W_fin(R)$** is an ideal in $W(R)$ and we have Frobenius and Verschiebung also in this truncated case; more precisely we have for each $n$ a Frobenius $F_{W_n}:W_n\to W_n$ where $W_n(R)$ denotes the **ring of Witt vectors of length $n$**. With this notation we find $ker(F^m_{W_n})\simeq D(ker(F^n_{W_n})$.

Since $W(k)$ is a ring we can ask of its modules in general; however there is in particular one $W(k)$-module of interest which is called the **Dieudonné module $M(G)$ of $G$**. It can be defined in two equivalent ways: 1. as a $W(k)$-module $M$ equipped with two endomorphisms of $F$ and $V$ satisfying the ''Witt-Frobenius identities''

(WF1): $FV=VF=p$

(WF2): $Fw=w^{(p)} F$

(WF3): $w V=V w^{(p)}$

or 2. as a left module over the **Dieudonné ring** which is the (noncommutative ring) generated by $W(k)$ and two variables $F$ and $V$ satisfying (WF1)(WF2)(WF3) in which case every element of $D_k$ can uniquely be written as a finite sum

$$\sum_{i\gt 0} a_{-i} V^i + a_0 + \sum_{i\gt 0} a_i F^i$$

(...)



## Examples

* For a field $k$ the terminal $k$-scheme $Sp_k k$ is a group scheme in a unique way.

* An [[affine scheme|affine]] group scheme. Affine group [[variety|varieties]] are called [[linear algebraic group|linear algebraic groups]].

* Complete group varieties are called [[abelian variety|abelian varieties]].

* Given any group $G$, one can form the [[constant group scheme]] $G_X$ over $X$. 

* [[etale group scheme]] is the spectrum of a commutative [[Hopf algebra]]. In this case the multiplication- resp. inversion- reps. unit map are given by [[comultiplication]] reps. [[antipodism]] resp. [[counit]] in the Hopf algebra.


* The functor $\mu:=\mathbb{G}_m$ is a group scheme given by $\mathbb{G}_m(S)=\Gamma(S, \mathcal{O}_S)^\times$. A scheme is sent to the invertible elements of its global functions. This group scheme is called *the multiplicative group scheme*. In context of [[p-divisible group|p-divisible groups]] the kernels of the $k$-group scheme endomorphisms of $\mathbb{G}_m$ defined by $(-)^n:x\mapsto x^n$ for an integer $n$ are of particular interest. These kernels give the group schemes of the $n$-th [[root of unity]].

* [[diagonalizable group scheme]]. Note that the multiplicative group scheme is diagonalizable.

* [[multiplicative group scheme]] also called *group scheme of multiplicative type*. Every diagonalizable group scheme is in particular of multiplicative type.

* The *[[additive group]] scheme* assigns to a ring its additive group. Also here the kernels of the powering-by-n map are of interest. These kernels give the group schemes of the $n$-th [[nilpotent object|nilpotent element]].

* Group schemes can be constructed by [[restriction of scalars]].

* The functor $\alpha:=\mathbb{G}_a$ is a group scheme given by $\mathbb{G}_a(S)=\Gamma(S, \mathcal{O}_S)$ the additive group of the ring of global functions. This group scheme is called *the additive group scheme*.

* [[connected group scheme]] (is synonymous to [[local group scheme]])

* [[unipotent group scheme]] (these are [[Cartier duality|Cartier duals]] of local group schemes)

* the kernel of any group scheme morphism is a group scheme.

* Every [[algebraic group]] is in particular a group scheme.



## Properties


### Cartier duality
(main article: [[Cartier duality]])

Suppose now that $G$ is a finite flat commutative group scheme (over $X$). The __Cartier dual__ of $G$ is given by the functor $G^D(S)=Hom (G\otimes S, \mathbb{G}_m \otimes S)$. The Hom is taken in the category of group schemes over $S$.

For example, $\alpha_p^D\simeq \alpha_p$.

### Dieudonné module
(main article: [[Dieudonné module]])

There are certain correspondences ([Theorem Acu](#thmAcu)--[Theorem Fftc](#thmFftc)) between certain categories of group schemes and certain categories of Dieudonné modules.

+-- {: .num_defn}
###### Definition
A *Dieudonné module* is a module over the [[Dieudonné ring]] $D_k$ of a field $k$ of prime [[characteristic]] $p$.
=--

+-- {: .num_defn}
###### Definition
The Dieudonné ring of $k$ is the ring generated by two objects $F,V$ subject to the relations

$$FV=VF=p$$

$$Fw=w^\sigma F$$

$$w V=V w^\sigma$$

where

$$\sigma:\begin{cases}
W(k)\to W(k)
\\
(w_1,w_2,\dots)\mapsto (w_1^p,w_2^p,\dots)
\end{cases}$$

denotes the endomorphism of the [[Witt ring]] $W(k)$ of $k$ given by raising each component of the [[Witt vectors]] to the $p$-th power; this means that $\sigma$ is component-wise given by the [[Frobenius endomorphism]] of the file $k$.
=--

The Dieudonné ring is a $\mathbb{Z}$-[[graded ring]] where the degree $n$-part is the $1$-[[dimension|dimensional]] [[free object|free module]] generated by $V^{-n}$ if $n\lt 0$ and by $F^n$ if $n\gt 0$

+-- {: .num_theorem #thmAcu}
###### Theorem
([III.5](#Demazure), $Acu_k\simeq Tor_V D_kMod$)

(see also [[Dieudonné module]] for more details concerning this theorem)

Let $k$ be a [[perfect field]] of prime characteristic $p$. Since $k$ is perfect Frobenius is an automorphism.

On the left we have the category of [[affine scheme|affine]] commutative [[unipotent group scheme|unipotent group schemes]]. On the right we have the category of all [[Dieudonné ring|D_k]][[Dieudonné module|-modules]] of $V$-torsion. The (contravariant) equivalence is given by

$$M:\begin{cases}
Acu_k&\to& Tor_V D_kMod
\\
G&\mapsto&colim_n Acu_k(G,W_{nk})
\end{cases}$$

where we recall that how the colimit of the hom space can be multiplied by the generators of the [[Dieudonné ring]].
=--

+-- {: .num_theorem}
###### Theorem
([III.6](#Demazure), $Feu_k\simeq Tor_V D_kMod$)

=--

+-- {: .num_theorem}
###### Theorem
([III.6](#Demazure), $Fiu_k\simeq Tor_F D_kMod$)

=--

+-- {: .num_theorem}
###### Theorem
([III.8](#Demazure), $Torf_p\simeq (fin W(k) Mod,F,V)$)

=--

+-- {: .num_theorem #thmFftc}
###### Theorem
([III.9](#Demazure), $Fftc\simeq \hat D_k Mod_{fin.len.quot}$)

=--

## Related concepts

* [[abelian group scheme]]

* [[dual abelian group scheme]]

* [[spectral group scheme]]

## References

* M. Artin, J. E. Bertin, M. Demazure, P. Gabriel, A. Grothendieck, M. Raynaud, J.-P. Serre, _Schemas en groupes_, i.e. SGA III-1, III-2, III-3

* Michel Demazure, [[Pierre Gabriel|P. Gabriel]], _Groupes algebriques_, tome 1 (later volumes never appeared), Mason and Cie, Paris 1970

* Michel [[Demazure, lectures on p-divisible groups]] [web](http://sites.google.com/site/mtnpdivisblegroupsworkshop/lecture-notes-on-p-divisible-groups){#Demazure}

* W. Waterhouse, _Introduction to affine group schemes_, GTM 66, Springer 1979. 

* D. Mumford, _Abelian varieties_, 1970, 1985.

* J. C. Jantzen, _Representations of algebraic groups_, Acad. Press 1987 (Pure and Appl. Math. vol 131); 2nd edition AMS Math. Surveys and Monog. 107 (2003; reprinted 2007)


[[!redirects group scheme]]
[[!redirects group schemes]]

[[!redirects Cartier dual]]
[[!redirects Cartier duals]]

[[!redirects group schemes]]

[[!redirects height of a group scheme]]
