
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Idempotents
+-- {: .hide}
[[!include idempotents - contents]]
=--
#### Category theory
+--{: .hide}
[[!include category theory - contents]]
=--
=--
=--


# Completions
* table of contents
{:toc}

## Idea

The general idea of completion is that given an object of some sort $C$, we construct from it a larger object, containing $C$ as a subobject, which moreover has certain properties that $C$ might have lacked.  This larger object is then called the _completion_ of $C$ with respect to these properties.


## Completion and idempotence

Outside of category theory (see below), "completion" is usually used mostly for *idempotent* operations.  That is, the completion of a thing with respect to some property is itself *complete* with respect to that property, and the completion process doesn't change an object that is already complete.  From the perspective of [[stuff, structure, property]] this makes sense because we complete with respect to a *property*.  Namely, according to the yoga of SSP, given some ambient category $K$, the subcategory of objects having a property $P$ should be a *full* subcategory, whose inclusion [[functor]] forgets that property.  A "completion" operation is then usually a left (or, occasionally, right) [[adjoint functor|adjoint]] to that inclusion functor, making the category of objects with property $P$ [[reflective subcategory|reflective]] (or coreflective).  Note that a [[full and faithful functor]] with a left adjoint is always [[monadic functor|monadic]] and the monad is [[idempotent monad|idempotent]].

By contrast, when we add *structure* to objects, i.e. we consider an adjoint to a forgetful functor which is faithful but not necessarily full, we usually do not use the word "completion" but rather the word "free".  For example, the category of complete [[metric spaces]] is a full reflective subcategory of the category of metric spaces, and the reflection is called "completion."  By contrast, the forgetful functor from the category of groups to the category of sets has a left adjoint, but we call that left adjoint the "free group on a set" rather than the "completion of a set into a group."

Additionally, we tend to use the term 'completion' only for a [[faithful functor|faithful]] [[reflector]].  Note that the reflector is faithful if and only if the unit of the reflection is [[monomorphism|monic]]; we might even want to require it to be a [[regular monomorphism]].  For example, the left adjoint of the forgetful functor from [[abelian groups]] to groups is called 'abelianisation' and may even be called 'free abelian group on a group' but is not normally called 'abelian completion' or anything like that. (The tendency in such cases is rather to resort to suffixes like "-ification" and "-ization": sheafification, abelianization, localization.) This fits with the intuition that a completion "adds more stuff" to the object we started with in order to "make it complete".


## List of completions

* [[complete space|Cauchy completion]] of a [[metric space]], or more generally a [[uniform space]]

* [[Dedekind completion]] of a [[linear order]] (or sometimes a more general [[preorder]] or [[quasiorder]])

* [[completion of a ring]]

* [[MacNeille completion]] of a [[partially ordered set]]

* [[profinite completion of a group|profinite completion]] of a discrete group 
  +--{: .query}
  Is this a case of profinite completion of a category, i.e., adding cofiltered limits?

  [[Mike Shulman]]: No, I don't think so.  Are you thinking of viewing a group as a one-object groupoid?  The profinite completion of a group is not an ordinary group but a [[profinite group]], which is thus not a category, at least not in the same sense.

  [[Mike Shulman]]: Also, is the unit of this adjunction monic?  Off the top of my head I see no reason for it to be.
  =--

* [[Grothendieck group]] of a cancellative commutative [[monoid]]; group completion of a cancellative monoid

* Field of fractions of an [[integral domain]]

* The [[Stone-Čech compactification]] of a [[Tychonoff space]]

* [[Moore closure]] operators (monads) on posets or preorders, e.g., the subgroup generated by a subset of a group, the ideal generated by a subset of a ring, etc.

+-- {: .query}
David: It's not clear to me when in the 'List of completions' we have examples of enriched category completions: Cauchy completion of a metric space (yes) of a uniform space (no?), Dedekind completion of a linear order (yes for 2-enriched categories?). 

[[Mike Shulman]]: Although orders are 2-enriched categories, Dedekind completion of an order is not a categorical completion, at least not in the sense of adding limits or colimits.  That would be the construction of downsets or ideals.

Cauchy completion of a metric space is, of course, an instance of Cauchy completion of enriched categories.  I believe that Cauchy completion of a uniform space is actually also an instance of a general categorical notion of Cauchy completion, but in the more general setting of an [[equipment]] (namely, the equipment of sets and filters).  See "Categorical interpretation" at [[uniform space]] for a too-brief summary of this point of view.

[[David Corfield]]: so is there are clear-cut distinction of level in all these cases, where we can separate completions of (enriched) categories (equipment) from completions of sets (with properties and structures)?

[[Mike Shulman]]: I think the reason that completion of metric spaces and uniform spaces feels more like the completion of sets (than categories) is that they are basically (enriched) (0,1)-categories.  If the question is where to separate this list from the one below, I would put completions of anything enriched in a preorder up here, and completions of things enriched non-posetally below.
=--


## Free completion and lax-idempotence

The general contrast between "completion" for adding a property and "free" for adding structure applies to operations on [[category|categories]] as well.  For instance, since [[split idempotents]] are preserved by any functor, the 2-category of categories with split idempotents is a full sub-2-category of [[Cat]].  Therefore, it makes perfect sense to call the left adjoint of its inclusion a "completion," in this case the (Set-enriched) [[Cauchy completion]] or [[Karoubi envelope]].  By contrast, the forgetful functor from the 2-category of [[monoidal categories]] to $Cat$ forgets structure, rather than properties, so its left adjoint should be called a "free" construction rather than a "completion."

However, in this case there is an intermediate notion between properties and structure, namely [[property-like structure]].  Intuitively, property-like structure is "structure which, when it exists, is essentially unique" or "a property which is not necessarily preserved by morphisms."  The canonical example is the existence of [[limits]] and [[colimits]] in a category: when they exist they are unique up to unique canonical isomorphism (so that "having limits" is intuitively a property of a category), but not every functor preserves limits, so the forgetful functor from  categories-with-limits to categories is not full.  (Left) adjoints to functors which forget property-like structure are usually called *free completions*.  The monads they induce are not idempotent, but they are often [[lax-idempotent monad|lax-idempotent]] or colax-idempotent.  (For example, when we freely add limits to a category that already had limits, the old limits are no longer limits and the new ones take their place.)

Property-like structure is most common in category theory, but it does occur elsewhere as well.  For instance, a [[monoid]] is a [[semigroup]] with property-like structure: a semigroup has at most one identity element, but that identity element is not necessarily preserved by semigroup homomorphisms.  Thus the adjoining of a new formal identity element to a semigroup (which is not an idempotent operation) might be called its "free completion into a monoid".  Notice that if the original semigroup is already a monoid, then its free completion into a monoid will be a *different* monoid (with a new identity); this shows the distinction between free completion and mere completion.


## List of completions in category theory

### Idempotent completions

The following completions add a *property* in the strictest sense, and as such are idempotent.

* [[Cauchy complete category|Cauchy completion]] of an enriched category: addition of all absolute limits.
* [[exact completion]] of a [[regular category]] (the "ex/reg" completion)
* [[extensive category|extensive]] completion
* [[pretopos]] completion of a [[coherent category]]


### Non-idempotent completions

These completions add a property-like structure, are often lax-idempotent or colax-idempotent.

* [[free cocompletion]]: the [[presheaf category]] of a [[small category]] is its free cocompletion under all small colimits.
* [[free completion]]: the dual (the opposite of the free cocompletion of the opposite).
* Ind-completion: the "free cocompletion under [[filtered colimits]]," consisting of all [[ind-object|ind-objects]].
* Pro-completion: the dual (free completion under cofiltered limits, the opposite of the Ind-completion of the opposite), consisting of all [[pro-objects]].
* [[ideal completion]]: the free cocompletion under filtered colimits of monomorphisms.

Note that these completions take small categories to large categories.  Free completions and cocompletions of large categories can be obtained using categories of [[accessible functor|accessible presheaves]].  However, if we only want to add limits and/or colimits for a given *set* of diagram shapes, the free completion process will preserve smallness.  For example we have:

* the free completion under finite products or coproducts
* the free completions under finite limits or colimits

All these sorts of completions work just as well in an [[enriched category|enriched]] setting, as long as the enriching category $V$ is nice enough ([[locally presentable category|locally presentable]] is certainly enough).

Some other non-idempotent completions:

* The [[reg/lex completion]] and [[ex/lex completion]] of a category with finite limits.


## Non-unique completions
{#nonunique}

The completions above are mostly (all?) [[the|unique in the relevant sense]]: unique up to unique isomorphism for objects of [[groupoids]] (or [[categories]]), more generally with a [[contractible space|contractible]] $\infty$-[[infinity-groupoid|groupoid]] of completions.

However, there are other sorts of completions in mathematics, such as:

*  'The' [[algebraic closure]] of a [[field]] is unique up to isomorphism, but the isomorphism is not unique. This is an example of an [[injective hull]].
*  Every [[model theory|model]] of a [[first-order theory]] may be interpreted as giving a completion of that theory (but not one with a recursively enumerable axiomatisation); every statement that is true in the model is an axiom of the complete theory.  However, this is far from unique.
*  An [[ultrapower]] of a structure may be viewed as an elementary completion (see [[elementary embedding]]), as described by [[Terry Tao]] in [a blog post](http://terrytao.wordpress.com/2010/11/27/nonstandard-analysis-as-a-completion-of-standard-analysis/).

## Related concepts

* [[completion monad]]

* [[completion of a ring]], [[completion of a module]]

* [[analytic completion]]

## References

* {#Sullivan70} [[Dennis Sullivan]], pp.9 in _Localization, Periodicity and Galois Symmetry_ (The 1970 MIT notes) edited by [[Andrew Ranicki]], K-Monographs in Mathematics, Dordrecht: Springer ([pdf](http://www.maths.ed.ac.uk/~aar/surgery/gtop.pdf)) 

* [[Marta Bunge]], _Tightly Bounded Completions_ , TAC **28** no. 8 (2013) pp.213-240. ([pdf](http://www.tac.mta.ca/tac/volumes/28/8/28-08.pdf))

[[!redirects completion]]
[[!redirects completions]]
