* toc
{: toc}

# Definition of Ho(Cat)

**Ho(Cat)** is a name for the [[homotopy category]] of [[Cat]].  That is, $Ho(Cat)$ is the [[category]]

* whose objects are ([[small category|small]]) categories, and
* whose morphisms are [[natural isomorphism]] classes of [[functors]].

This is an instance of a general construction which, given a [[2-category]], or more generally an [[n-category]], produces a [[1-category]] with the same objects and whose morphisms are [[equivalence]] classes of 1-morphisms in the original $n$-category.  Sometimes this is called the 1-[[truncation]] and denoted $\tau_1$.

+--{: .query}
[[David Roberts]]: I would think that $\tau_1(C)$ for a strict 2-category is the underlying 1-category. What is described here could be called the Poincaré category (I think that Benabou's monograph on bicategories has this term). Maybe terminology as developed in the meantime, though.

[[Mike Shulman]]: Well, the uses of "truncation" I've seen always involves quotienting by equivalences, rather than discarding them.  Discarding them only even makes sense in the strict situation (a bicategory has no underlying 1-category) and is an [[evil]] (and not often very useful) thing to do, so it doesn't seem to me worth giving an important name to.  "Poincare category" may also be a name for the same thing, but I prefer "truncation" as more evocative.

[[Beppe Metere]]: If I remember well, Benabou introduces two different constructions related to this discussion: the Poincarè category of a bicategory, where the arrows are connected components of 1-cells, and the classifying category, where the arrows are iso classes of 1-cells. Of course, these two categories coincide when the bicategory is locally groupoidal.
=--

It can also be viewed as an instance of the homotopy category of a [[model category]] (or more generally a [[category with weak equivalences]]).  The category $Ho(Cat)$ as defined above is equivalent to the category obtained from $Cat$ by forcing all [[equivalences of categories]] to be isomorphisms (by [[localization|localizing]]).  This is for the same reason that the category $hTop$ of [[topological spaces]] and [[homotopy]] classes of [[continuous maps]] is equivalent to the category obtained from $Top$ by inverting the homotopy equivalences (namely, the existence of [[cylinder objects]] and/or [[path objects]]).  Indeed, a [[cylinder object]] for a category $C$ is the [[product category]] $C \times I$ where $I$ is the category with two objects 0 and 1 and an isomorphism $0 \to 1$.  It is not difficult to see that an isomorphism of functors is the same as a [[homotopy]] of functors with the respect to the [[canonical model structure]] on $Cat$.

# Subcategories of Ho(Cat)

Some notable full subcategories of $Ho(Cat)$ include

* $Ho(Gpd)$, the homotopy category of the category [[Gpd]] of [[groupoids]].  Note that this is equivalent to the homotopy category of (unbased) [[homotopy 1-types]].
* The category whose objects are [[groups]] and whose morphisms are [[conjugacy class]]es of [[group homomorphism]]s.  This can be identified with the full subcategory of $Ho(Gpd)$ whose objects are the connected groupoids.  This category sometimes arises in the study of [[gerbes]].


# Ho(Cat)-categories

Like the homotopy category of any model category, $Ho(Cat)$ has [[products]] and [[coproducts]], and is in particular a [[cartesian monoidal category]].  Therefore, we can talk about categories [[enriched category|enriched over]] $Ho(Cat)$.  Such a "$Ho(Cat)$-category" consists of

* a collection of objects $x,y,z$
* for each pair of objects, a category $C(x,y)$
* for each object $x$, an objects $id_x\in C(x,x)$
* for each triple of objects, a functor $C(y,z)\times C(x,y)\to C(x,z)$

such that the usual associativity and unit diagrams for an enriched category commute up to isomorphism.  The difference between a $Ho(Cat)$-category and a [[bicategory]] is that in a $Ho(Cat)$-category, *no coherence axioms* are required of the [[associator]] and [[unitor]] isomorphisms; they are merely required to *exist*.  Thus a $Ho(Cat)$-category can be thought of as an "incoherent bicategory."  In particular, any bicategory has an underlying $Ho(Cat)$-category.

Although $Ho(Cat)$-categories are not very useful, there are some interesting things that can be said about them.  For instance:

* Any $Ho(Cat)$-category which is equivalent, as a $Ho(Cat)$-category, to a bicategory, is itself in fact a bicategory.
* Any [[2-functor]] between bicategories which induces an equivalence of underlying $Ho(Cat)$-categories is in fact itself an equivalence of bicategories (or "biequivalence").


# Other limits and colimits {#OtherLimits}

Although $Ho(Cat)$ has products and coproducts, like most homotopy categories it is not well-endowed with other [[limits]].  The following concrete example shows that it (and also $Ho(Gpd)$) fails to have [[pullbacks]].

Consider the [[cospan]]
$$\array{&& \mathbb{Z}/3\\
  && \downarrow^j\\
  \mathbb{Z}/2 & \underset{i}{\to} & S_3}$$
where the two arrows are inclusions of subgroups.  That is, we choose a 2-cycle and a 3-cycle in $S_3$, say $a=(1,2)$ and $b=(1,2,3)$, and identify $\mathbb{Z}/2$ and $\mathbb{Z}/3$ with the subgroups generated by $a$ and $b$ respectively.  Regard these groups as connected groupoids and thus as objects of $Ho(Cat)$, and suppose that this cospan had a pullback
$$\array{P & \overset{f}{\to} & \mathbb{Z}/3\\
  ^g \downarrow && \downarrow^j\\
  \mathbb{Z}/2 & \underset{i}{\to} & S_3}$$
in $Ho(Cat)$ or $Ho(Gpd)$.

Note that for any category $C$, the set $Ho(Cat)(1,C)$ is the set of isomorphism classes of objects in $C$ (where $1$ is the [[terminal category]]).  Therefore, any pullbacks that exist in $Ho(Cat)$ must induce pullbacks of sets of isomorphism classes of objects, and so $P$ must also have only one isomorphism class of objects; i.e. it must be a [[monoid]], regarded as a one-object category.  We choose monoid homomorphisms $P\to \mathbb{Z}/2$ and $P\to \mathbb{Z}/3$ representing $f$ and $g$, respectively.  We also choose a natural isomorphism $\sigma\colon j f \cong i g$, which consists of an element $\sigma\in S_3$ such that $j(f(c)) = \sigma \cdot i(g(c)) \cdot \sigma^{-1}$ for all $c\in P$.

Now let $Q$ be the [[2-pullback]]
$$\array{Q & \overset{h}{\to} & \mathbb{Z}/3\\
  ^k \downarrow & \cong & \downarrow^j\\
  \mathbb{Z}/2 & \underset{i}{\to} & S_3.}$$
Then the objects of $Q$ are the elements of $S_3$, and the morphisms from $x$ to $y$ consist of pairs $(u,v)\in \mathbb{Z}/2 \times \mathbb{Z}/3$ such that $i(u)\cdot x = y \cdot j(v)$.  Since the square defining $Q$ commutes in $Ho(Cat)$, there must be a functor $\ell\colon Q\to P$ such that $f\ell\cong h$  and $g\ell\cong k$.

Now every element of $\mathbb{Z}/2$ or $\mathbb{Z}/3$ is the image of some morphism of $Q$ under $k$ or $h$, respectively.  For instance, $a\in \mathbb{Z}/2$ is the image of $(a,1)\colon 1 \to a$ and $b\in \mathbb{Z}/3$ is the image of $(1,b)\colon b\to 1$.  Therefore, since $h$ and $k$ factor through $f$ and $g$ up to isomorphism, $f$ and $g$ must be surjective as monoid homomorphisms.

Let $c_1$ be such that $f(c_1)=b$.  If $g(c_1)$ is not the identity, let $c=c_1$.  Otherwise $g(c_1)=1$ and there is some $c_2$ with $g(c_2)=a$.  If $f(c_2)$ is not the identity, then let $c=c_2$.  Otherwise $f(c_2)=1$ and let $c = c_1\cdot c_2$.  In either case, neither $f(c)$ nor $g(c)$ is the identity.  Therefore, neither $j(f(c))$ nor $i(g(c))$ is the identity, and moreover $j(f(c))$ is a 3-cycle and $i(g(c))$ is a 2-cycle in $S_3$.  But the element $\sigma$ conjugates $i(g(c))$ to $j(f(c))$, a contradiction.

Since all the categories involved were groupoids (except possibly $P$), the same argument shows that $Ho(Gpd)$ doesn't have pullbacks.  Moreover, basically the same argument, regarding groupoids as connected 1-types, shows that the homotopy category of topological spaces doesn't have pullbacks either (in this case the final contradiction is derived from $\pi_1(P)$ instead of $P$ itself).

## See also

* [[canonical model structure]]

category: category
