> this entry is about the notion of _action_ in algebra (of one algebraic object on another object). For the notion of _[[action functional]]_ in [[physics]] see there.

***

+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Algebra
+--{: .hide}
[[!include higher algebra - contents]]
=--
#### Representation theory
+-- {: .hide}
[[!include representation theory - contents]]
=--
=--
=--

# Actions
* table of contents
{: toc}


## Idea
 {#Idea}

There are various variants of the notion of something _acting_ on something else. They are all closely related.

The simplest concept of an action involves one [[set]], $X$, acting on another set $Y$ and such an action is given by a [[function]] from the [[product]] of $X$ with $Y$ to $Y$

$$
  act\colon X \times Y \to Y
  \,.
$$ 

For fixed $x \in X$ this produces an [[endofunction]] $act(x,-) \colon Y \to Y$ and hence some "transformation" or "action" on $Y$. In this way the whole of $X$ acts on $Y$.

Here $(x\mapsto act(x,-))$ is the _[[currying|curried]]_ function $\widehat{act}\colon X \to Y^Y$ of the original $act$, which maps $X$ to the [[function set|set of]] of [[endofunctions]] on $Y$.  Quite generally one has these two perspectives on actions.

Usually the key aspect of an action of some $X$ is that $X$ itself carries an algebraic structure, such as being a [[group]] (or just a [[monoid]]) or being a [[ring]] or an [[associative algebra]], which is also possessed by $Y^Y$ and preserved by the curried action $\widehat{act}$.  Note that if $Y$ is any set then $Y^Y$ is a monoid, and when $X$ acts on it one calls it an [[MSet|X-set]].  For $Y^Y$ to have a ring/algebra structure, $Y$ must be some sort of [[abelian group]] or [[vector space]] with the action by [[linear functions]]; then one calls the action also a _[[module]]_ or _[[representation]]_.

In terms of the uncurried action $X\times Y\to Y$, the "preservation" condition says roughly speaking that acting consecutively with two elements in $X$ is the same as first multiplying them and then acting with the result:

$$
  act(x_2,act(x_1,y)) = act(x_2\cdot x_1, y)
  \,.
$$

To be precise, this is the condition for a *left action*; a *right action* is defined dually in terms of a map $Y\times X\to Y$.  If $X$ has no algebraic structure, or if its relevant structure is commutative, then there is no essential difference between the two; but in general they can be quite different.

This _action property_ can also often be identified with a [[functor]] property: it characterizes a [[functor]] from the [[delooping]] $\mathbf{B}X$ of the [[monoid]] $X$ to the [[category]] (such as [[Set]])  of which $Y$ is an object.

In this way essentially every kind of [[functor]], [[n-functor]] and [[enriched functor]] may be thought of as defining a generalized kind of action. This perspective on actions is particularly prevalent in [[enriched category theory]], where for instance [[coends]] may be thought of as producing [[tensor products]] of actions in this general functorial sense.

Under the [[Grothendieck construction]] (or one of its variants), this perspective turns into the perspective where an action of $X$ is some [[bundle]] $Y/X$ over $\mathbf{B}X$, whose [[fiber]] is $Y$:

$$
  \array{
    Y &\longrightarrow& Y/X
    \\
    && \downarrow
    \\
    && \mathbf{B}X
  }
  \,.
$$

Here the total space $Y/X$ of this bundle is typically the "weak" [[quotient]] (for instance: [[homotopy quotient]]) of the action, whence the notation. If one thinks of $\mathbf{B}X$ as the [[classifying space]] for the $X$-[[universal principal bundle]], then this bundle $Y/X \to \mathbf{B}X$ is the $Y$-[[fiber bundle]] which is [[associated bundle|associated]] via the action to this universal bundle. For more on this perspective on actions see at _[[∞-action]]_.



## Definitions

### Actions of a group

An **action** of a [[group]] $G$ on an [[object]] $x$ in a [[category]] $C$ is a [[representation]] of $G$ on $x$, that is a group [[homomorphism]] $\rho : G \to Aut(x)$, where $Aut(x)$ is the [[automorphism group]] of $x$.  


As indicated above, a more sophisticated but equivalent definition treats the group $G$ as a category denoted $\mathbf{B} G$ with one object, say $*$.  Then an _action_ of $G$ in the category $C$ is just a [[functor]] 
$$\rho : \mathbf{B} G \to C.$$  
Here the object $x$ of the previous definition is just $\rho(*)$. 


### Actions of a monoid

More generally we can define an _action_ of a [[monoid]] $M$ in the category $C$ to be a functor
$$\rho: \mathbf{B} M \to C $$
where $\mathbf{B} M$ is (again) $M$ regarded as a one-object category.

The _category of actions_ of $M$ in $C$ is then defined to be the [[functor category]] $C^{\mathbf{B} M}$.

### Actions of a category

One can[^2] also define an [[action of a category on a set|action of a category]] $D$ on the category $C$ as a functor from $D$ to $C$, but usually one just calls this a [[functor]].

[^2]: One example of this relatively rare usage is [[William Lawvere]]: _Qualitative Distinctions Between Some Toposes of Generalized Graphs_, Contemporary Mathematics 92 (1989) in which this sense of action is routinely used.

Another perspective on the same situation is: a (small) category is a [[monad]] in the category of [[span]]s in [[Set]]. An action of the category is an algebra for this monad. See [[action of a category on a set]]. 

On the other hand, an action of a [[monoidal category]] (not _in_ a monoidal category, as above) is called an [[actegory]]. This notion can be expanded of course to actions _in_ a [[monoidal bicategory]], where in the case of $Cat$ as monoidal bicategory it specializes to the notion of actegory. 

### Actions of a group object

Suppose we have  a category, $C$, with binary [[product]]s and a [[terminal object]] $*$. There is an alternative way of viewing group actions in [[Set]], so that we can talk about an action of a [[group object]], $G$, in $C$ on an object, $X$, of $C$.

By the adjointness relation between cartesian product, $A\times ?$, and function set, $?^A$, in [[Set]], a group homomorphism

$$\alpha: G\to Aut(X)$$
corresponds to a function

$$act: G\times X\to X$$
which will have various properties encoding that $\alpha$ was a homomorphism of groups:  

$$act(g_1g_2,x) = act(g_1,act(g_2,x))$$

$$act(1,x) = x$$

and these can be encoded diagrammatically.

Because of this, we can **define** an action of a group object, $G$, in $C$ on an object, $X$, of $C$ to be a morphism
$$act: G\times X\to X$$
satisfying conditions that certain diagrams (left to the reader) encoding these two rules, commute.

The advantage of this is that it does not require the category $C$ to have internal automorphism group objects for all objects being considered.

As an example, within the category of [[profinite group]]s, not all objects have automorphism groups for which the natural topology is profinite, because of that profinite group actions are sometimes given in this form or are restricted to actions on objects for which the automorphism group is naturally profinite. 

### Actions of a set

The action of a set on a set was defined above; it consists of a function $act: X\times Y\to Y$.  This can equivalently be represented by a [[quiver]] with $Y$ as its vertices, with its edges labeled by elements of $X$, and such that each vertex has exactly one arrow leaving it with each label.  (This is a sort of "Grothendieck construction".)  It is also the same as a simple (non halting) [[deterministic automaton]], with $Y$ the set of states and $X$ the set of inputs.


That an action is a type of edge labeled quiver can be seen by explicitly giving the product [[projection]] functions, $p_1$ and $p_2$, of $X\times Y$.

$$X\overset{\quad p_1 \quad}{ \leftarrow}X\times Y\underoverset{\quad act \quad}{p_2}{\rightrightarrows}Y$$

The shape of this diagram corresponds to that of an edge labeled quiver:

$$Labels\overset{\quad label \quad}{ \leftarrow}Edges\underoverset{\quad target \quad}{source}{\rightrightarrows}Vertices$$


While the set $X$ has no algebraic structure to be preserved, the action $act$ generates a unique **[[free category]] action** $act^{*}:X^{*}\times Y\to Y$ where $X^{*}$ is the [[free monoid]] on $X$ containing [[path|paths]] of $X$ elements. The monoidal structure of $X^*$ is preserved: two actions in succession is equal to the action of the concatenation of their paths.

$$act^{*}(x^{*}_2,act(x^{*}_1,y)) = act^{*}(x^{*}_2\cdot x^{*}_1, y) $$ 


## Examples

* A [[representation]] is a "linear action".

* In [[symplectic geometry]] one considers [[Hamiltonian actions]].

* In [[topology]]: [[topological G-space]]

  * [[circle action]]

(...)

## Related concepts
 {#RelatedConcepts}

* **action**, [[∞-action]],

  * [[conjugation action]], [[adjoint action]]

  * [[diagonal action]]

  * [[transitive action]], [[free action]], [[regular action]]

* [[coaction]]

* [[representation]], [[∞-representation]]

* [[module]], [[∞-module]]

* [[associated bundle]], [[associated ∞-bundle]]

* [[quotient]], [[quotient stack]], [[quotient type]]

* [[representation theory]], [[invariant theory]]

* [[equivariant homotopy theory]]

  * [[Borel model structure]]


## References

* [[Patrick Morandi]], _Group actions_ ([pdf](http://sierra.nmsu.edu/morandi/notes/groupactions.pdf))

[[!redirects action]]
[[!redirects actions]]
[[!redirects group action]]
[[!redirects group actions]]

[[!redirects left action]]
[[!redirects left actions]]

[[!redirects right action]]
[[!redirects right actions]]
