
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Monoidal categories
+--{: .hide}
[[!include monoidal categories - contents]]
=--
#### Category theory
+--{: .hide}
[[!include category theory - contents]]
=--
=--
=--

#Contents#
* table of contents
{:toc}

##  Idea 

Recall that a [[category]] consists of a collection of [[morphisms]] each having a single [[object]] as source or input, and a single object as target or output, together with laws for composition and identity obeying associativity and identity axioms. A _multicategory_ is like a category, except that one allows multiple inputs and a single output.

Another term for _multicategory_ is _coloured [[operad]]_.


## Definition

### In components

A **multicategory** $C$ consists of

* A collection of _objects_, $C_0$.
* A collection of _multimorphisms_, $C_1$.
* A source map $s: C_1 \to (C_0)*$ to the collection of finite, possibly empty [[list]]s of objects (where $(C_0)*$ is the [[free monoid]] generated by $C_0$), and a target map $t: C_1 \to C_0$. We write $f: c_1, \ldots, c_n \to c$ to indicate the source and target of a multimorphism $f$.
* Identity and composition laws. The identity law is a map $1_{-}: C_0 \to C_1$ where $1_c: c \to c$. The composition law assigns, to each $f: c_1, \ldots, c_n \to c$ together with an $n$-tuple $\langle f_i: \vec{c}_i \to c_i: i = 1, \ldots, n \rangle$, a composite 
$$f \circ (f_1, \ldots, f_n): \vec{c}_1, \ldots, \vec{c}_n \to c$$ 
where the source is obtained by concatenating lists in the evident way.

These operations are subject to [[associativity]] and [[identity]] axioms which the reader can probably figure out, but see for example ([Leinster, page 35 ff.](#Leinster)), for details.

Many people (especially non-category theorists) use the word _multicategory_ or the word _colored [[operad]]_ to mean what we would call a _[[symmetric multicategory]]_ / _[[symmetric operad]]_. These are multicategories equipped with an [[action]] of the [[symmetric group]] $S_n$ on the multimorphisms $c_1, \ldots, c_n \to c$ such that the composition is equivariant with respect to these actions.

### In terms of cartesian monads

An efficient abstract method for defining multicategories and related structures is through the formalism of [[cartesian monads]]. For ordinary categories, one uses the identity monad on [[Set]]; for ordinary multicategories, one uses the [[free monoid]] monad $(-)*: Set \to Set$.  This is a special case of the yet more general notion of [[generalized multicategory]].

We summarize here how the theory applies to the case of a [[cartesian monad]] $T$ on a category with [[pullbacks]]; see [[generalized multicategory]] for the fully general context.

* First, a **$T$-span** from $X$ to $Y$ is a [[span]] $p$ from $T X$ to $Y$, that is, a diagram
$$T X \stackrel{p_1}{\leftarrow} P \stackrel{p_2}{\to} Y$$
A $T$-span is often written as $p: X &#x21F8; Y$.

When $T$ is the free monoid monad on $Set$, a $T$-span from $X$ to itself is called a _multigraph_ on $X$.

* $T$-spans are the 1-cells of a [[bicategory]]. A 2-cell between $T$-spans $e, f: X &#x21F8; Y$ is a 2-cell between ordinary spans from $T X$ to $Y$. To horizontally compose $T$-spans $e: X &#x21F8; Y$ and $f: Y &#x21F8; Z$, take the ordinary span composite of
$$(T X \stackrel{m X}{\leftarrow} T^2 X \stackrel{T e_1}{\leftarrow} T E \stackrel{T e_2}{\to} T Y) \circ (T Y \stackrel{f_1}{\leftarrow} F \stackrel{f_2}{\to} Z)$$
where $m: T^2 \to T$ is the monad multiplication. The identity $T$-span from $X$ to itself is the span
$$T X \stackrel{u X}{\leftarrow} X \stackrel{1_X}{\to} X$$
where $u: I \to T$ is the monad unit. The verification of the bicategory axioms uses the cartesianness of $T$ in concert with the corresponding axioms on the bicategory of spans.

* A _$T$-multicategory_ is defined to be a [[monad]] in the bicategory of $T$-spans.

When $T$ is the free monoid monad on sets, then a $T$-multicategory is a multicategory as defined above.  For more examples and generalizations, see [[generalized multicategory]].


## Properties

### Relation to operads 

A [[nonpermutative operad|nonpermutative]] (or Stasheff-) [[operad]] in [[Set]] may be defined as an ordinary multicategory with exactly one object.  Likewise, a [[symmetric operad]] in any [[symmetric monoidal category]] $V$ is equivalent to a $V$-[[enriched category|enriched]] multicategory with one object.  

More generally, the notion of _multi-colored [[planar operad]]_ is equivalent to that of multicategory, and the notion of _multi-colored [[symmetric operad]]_ is equivalent to that of [[symmetric multicategory]].

Fully generally, for each cartesian monad $T$, there is a corresponding notion of $T$-operad, namely a $T$-multicategory whose underlying $T$-span has the form $1 &#x21F8; 1$.

For example, in Batanin's approach to (weak) $\infty$-[[infinity-category|categories]], a [[globular operad]] is a $T$-operad, where $T$ is the free (strict) $\omega$-[[strict omega-category|category]] monad on the category of [[globular set]]s.

Ordinary (permutative/symmetric) operads, and their generalization to [[symmetric multicategory|symmetric multicategories]], can also be treated in the framework of [[generalized multicategories]], but they require a framework more general than that of cartesian monads.

### Relation to monoidal categories

There is a [[faithful functor]] from [[monoidal categories]] to [[multicategories]], given by forming [[representable multicategories|represented multicategories]].  Conversely, to any multicategory $C$ there is an associated (strict) monoidal category $F(C)$, whose objects (respectively, arrows) are [[lists]] of objects (respectively, arrows) of $C$, and where the tensor product in $F(C)$ is given by concatenation.

## Examples and special cases

See also the examples at _[[operad]]_.

## Related concepts

* [[multimorphism]]

* [[polycategory]]

* [[fibration of multicategories]]

* [[symmetric multicategory]]

* [[generalized multicategory]], [[operad]] 


## References

* [[Tom Leinster]], _Higher operads, higher categories_, London Math. Soc. Lec. Note Series __298__, [math.CT/0305049](http://arxiv.org/abs/math.CT/0305049)
 {#Leinster}


[[!redirects multicategories]]
[[!redirects multicategories]]

[[!redirects pseudomonoidal category]]
