
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Group Theory
+-- {: .hide}
[[!include group theory - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Idea

A __permutation__ is an [[automorphism]] in [[Set]].  More explicitly, a __permutation__ of a [[set]] $X$ is an [[inverse|invertible]] [[function]] from $X$ to itself.


## Definition

The [[group]] of permutations of $X$ (that is the [[automorphism group]] of $X$ in $Set$) is the __symmetric group__ (or __permutation group__) on $X$.  This group may be denoted $S_X$, $\Sigma_X$, or $X!$.  When $X$ is [[the]] [[finite set]] $[n]$ with $n$ elements, then its symmetric group is a [[finite group]], and one typically writes $S_n$ or $\Sigma_n$; note that this group has $n!$ elements.

In [[combinatorics]], one often wants a slight generalisation.  Given a [[natural number]] $r$, an __$r$-permutation__ of $X$ is an [[injective function]] from $[r]$ to $X$, that is a [[list]] of $r$ distinct elements of $X$.  Note that the number of $r$-permutations of $[n]$ is counted by the [[falling factorial]] $n(n-1)\dots(n-r+1)$.  Then an $n$-permutation of $[n]$ is the same as a permutation of $[n]$, and the total number of such permutations is of course counted by the ordinary factorial $n!$.  (That an injective function from $X$ to itself must be invertible characterises $X$ as a [[Dedekind-finite set]].)


## Concrete representations 

### Via string diagrams 

### Via cycle decompositions 

Every permutation $\pi : X \to X$ generates a [[cyclic group|cyclic]] [[subgroup]] $\langle \pi \rangle$ of the symmetric group $S_X$, and hence inherits a [[group action]] on $X$.  The [[orbits]] of this action partition the set $X$ into a disjoint union of cycles, called the **cyclic decomposition** of the permutation $\pi$.

For example, let $\pi$ be the permutation on $[6] = \{0,\dots,5\}$ defined by

$$\pi = \array{0 \mapsto 0 \\ 1 \mapsto 3 \\ 2 \mapsto 4 \\ 3 \mapsto 5 \\ 4 \mapsto 2 \\ 5 \mapsto 1}$$

The domain of the permutation is partitioned into three $\langle\pi\rangle$-orbits 

$$[6] = \{0\} \cup \{1,3,5\} \cup \{2,4\}$$

corresponding to the three cycles

$$0 \underset{\pi}{\to} 0 \qquad
1 \underset{\pi}{\to} 3 \underset{\pi}{\to} 5 \underset{\pi}{\to} 1 \qquad
2 \underset{\pi}{\to} 4 \underset{\pi}{\to} 2$$

Finally, we can express this more compactly by writing $\pi$ in cycle form, as the product $\pi = (0)(1\,3\,5)(2\,4)$.

## Properties

### Conjugacy classes
 {#ConjugacyClasses}


+-- {: .num_prop #ConjugacycClassesOfSymmetricGroupCorrespondToCycleSet}
###### Proposition

Let $n \in \mathbb{N}$ and $\Sigma(n)$ the [[symmetric group]]
on $n$ elements. Then the [[conjugacy classes]] of elements of $\Sigma(n)$, hence of permutations of $n$ elements, correspond to the [[cycle]] structures: two elements are conjugate to each other precisely if they have the same number of distinct cycles of the same length, or in other words if they define the same underlying [[partition]] of $n$.

=--

+-- {: .num_example }
###### Example


For the symmetric group on three elements there are three such classes:

<div>
<div style="float:left;width:30%;margin:10%">
 <div style="padding-bottom:20px">(1 2 3) ~ (1 3 2)</div>
 <div style="padding-bottom:20px">(1 2)(3) ~ (1 3)(2) ~ (1)(2 3)</div>
 <div>(1)(2)(3)</div>
</div>
<div style="float:left;width:20%">
<div>
 <svg width="80" height="40" xmlns="http://www.w3.org/2000/svg" se:nonce="39384" xmlns:se="http://svg-edit.googlecode.com" xmlns:xlink="http://www.w3.org/1999/xlink">
 <desc>Young diagram (3)</desc>
 <g>
  <title>Layer 1</title>
  <rect x="10" y="10" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_1"/>
  <rect x="30" y="10" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_2"/>
  <rect x="50" y="10" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_3"/>
 </g>
 </svg>
</div>
<div>
 <svg width="60" height="60" xmlns="http://www.w3.org/2000/svg" se:nonce="39384" xmlns:se="http://svg-edit.googlecode.com" xmlns:xlink="http://www.w3.org/1999/xlink">
 <desc>Young diagram (2,1)</desc>
 <g>
  <title>Layer 1</title>
  <rect x="10" y="10" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_1"/>
  <rect x="30" y="10" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_2"/>
  <rect x="10" y="30" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_3"/>
 </g>
 </svg>
</div>
<div>
 <svg width="40" height="90" xmlns="http://www.w3.org/2000/svg" se:nonce="39384" xmlns:se="http://svg-edit.googlecode.com" xmlns:xlink="http://www.w3.org/1999/xlink">
 <desc>Young diagram (1,1,1)</desc>
 <g>
  <title>Layer 1</title>
  <rect x="10" y="10" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_1"/>
  <rect x="10" y="30" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_2"/>
  <rect x="10" y="50" width="20" height="20" fill="#ffdddd" stroke="#000000" stroke-width="2" id="svg_39384_3"/>
 </g>
 </svg>
</div>
</div>
<div style="float:left;width:20%">
<img src="https://ncatlab.org/nlab/files/The3SheetedCoveringsOfTheCircle.png" width="100">
</div>
</div>

=--

<div style="width:200px;height:30px"></div>

$\,$

$\,$

$\,$

$\,$

$\,$

$\,$

$\,$

### Relation to the field with one element

One may regard the symmetric group $S_n$ as the [[general linear group]] in dimension $n$ on the [[field with one element]]  $GL(n,\mathbb{F}_1)$.

### Classifying space and universal Thom space
 {#ClassifyingSpaceAndThomSpace}

The [[classifying space]] $B \Sigma(n)$ of the symmetric group on $n$ elements may be presented by $Emb(\{1,\cdots, n\}, \mathbb{R}^\infty)/\Sigma(n)$, the [[Fadell's configuration space]] on $n$ unordered points in $\mathbb{R}^\infty$.


Write $\tau_n$ for the [[rank]] $n$ [[vector bundle]] over this which exhibits the canonical [[action]] of $\Sigma(n)$ on $\mathbb{R}^n$, by permutation of [[coordinates]].

The [[Thom space]] $B \Sigma(n)^{\tau_n}$ of this bundle appears as the cofficients of the [[spectral symmetric algebra]] of the "absolute [[spectral superpoint]]" $Sym_{\mathbb{S}} \Sigma \mathbb{S}$ (see [Rezk 10, slide 4](spectral%20symmetric%20algebra#Rezk10)).


See also ([Hopkins-Mahowald-Sadofsky 94, around def. 2.8](#HopkinsMahowaldSadofsky94))





### Whitehead tower and relation to supersymmetry
 {#WhiteheadTowerAndSupersymmetry}

The [[symmetric groups]] and [[alternating groups]] are the first stages in a restriction of the [[Whitehead tower]] of the [[orthogonal group]] to "finite [[discrete ∞-groups]]" in the sense of [[homotopy type with finite homotopy groups]]. The [[homotopy fibers]] of the stages of the "finite Whitehead tower" are the [[stable homotopy groups of spheres]] ([Epa-Ganter 16](#EpaGanter16)). (See also at _[super algebra -- Abstract idea](super+algebra#AbstractIdea)_ and at _[[Platonic 2-group]]_.)

$$
  \array{   
    && && \vdots
    \\
    && && \downarrow
    \\
    && && \mathbf{B}Fivebrane(n)
    \\
    && \downarrow && \downarrow
    \\
    \mathbf{B}^2 \pi_3 \mathbb{S} 
      &\stackrel{}{\longrightarrow} & 
     \mathbf{B}\mathcal{A}_n &\hookrightarrow& \mathbf{B} String(n)
    \\
    && \downarrow && \downarrow
    \\
    \mathbf{B} \pi_2 \mathbb{S} &\longrightarrow & \mathbf{B} \tilde A_n &\hookrightarrow& \mathbf{B} Spin(n)
    \\
    && \downarrow && \downarrow
    \\
    \pi_1 \mathbb{S} &\longrightarrow& \mathbf{B} A_n &\hookrightarrow& \mathbf{B} SO(n)
    \\
    && \downarrow && \downarrow
    \\
    && \mathbf{B} S_n &\hookrightarrow& \mathbf{B} O(n)
  }
$$

* on the right: the [[delooping|delooped]] [[smooth ∞-group]] [[Whitehead tower]] of the [[orthogonal group]] ([[fivebrane 6-group]] $\to$ [[string 2-group]] $\to$ [[spin group]] $\to$ [[special orthogonal group]] $\to$ [[orthogonal group]]);

* in the middle, its restriction to [[deloopings]] of [[finite groups]] and their universal [[∞-group extensions]] ($\cdots \to $ [[covering of alternating group]] $\to$ [[alternating group]] $\to$ [[symmetric group]])

* on the left the [[homotopy fibers]] of each stage.


Notice that the squares on the right are _not_ [[homotopy pullback]] squares. (The homotopy pullback of the [[string 2-group]] along $\tilde A \hookrightarrow Spin(n)$ is a $\mathbf{B}U(1)$-extension of $\tilde  A$, but here we get the universal _finite_ 2-group extension, by $\mathbb{Z}/24$ instead.

## Examples

* The symmetric group on 4 elements is [[isomorphism|isomorphic]] to the full [[tetrahedral group]] as well as to the orientation-preserving [[octahedral group]].

## Related entries

* [[alternating group]]

* [[signature of a permutation]]

* [[permutation category]]

## References

* {#EpaGanter16} [[Narthana Epa]], [[Nora Ganter]], _Platonic and alternating 2-groups_, ([arXiv:1605.09192](http://arxiv.org/abs/1605.09192))

* {#HopkinsMahowaldSadofsky94} [[Michael Hopkins]], [[Mark Mahowald]], [[Hal Sadofsky]], _Constructions of elements in Picard groups_, Contemporary mathematics, Volume 158, 1994 in [[Eric Friedlander]], [[Mark Mahowald]] (eds.), _Topology and Representation theory_ ([doi:10.1090/conm/158/01454](http://dx.doi.org/10.1090/conm/158/01454))


[[!redirects permutation]]
[[!redirects permutations]]
[[!redirects permutation group]]
[[!redirects permutation groups]]
[[!redirects symmetric group]]
[[!redirects symmetric groups]]
