
# Contents
* automatic table of contents goes here
{:toc}

## Definition

__$Bool Alg$__ is the [[category]] whose [[objects]] are [[boolean algebras]] and whose [[morphisms]] are lattice [[homomorphisms]], that is [[functions]] which preserve finitary [[meets]] and [[joins]] (equivalently, binary meets and joins and the [[top]] and [[bottom]] elements); it follows that the homomorphisms preserve [[negation]].  $Bool Alg$ is a [[subcategory]] of [[Pos]], in fact a [[replete subcategory]] of both [[DistLat]] and [[HeytAlg]].

$Bool Alg$ is given by a finitary [[variety of algebras]], or equivalently by a [[Lawvere theory]], so it has all the usual properties of such categories. As usual, the [[Lawvere theory]] is the category opposite to the category of [[finitely generated object|finitely generated]] [[free object|free]] Boolean algebras.


## Free Boolean algebras 

The free Boolean algebra $Bool(X)$ generated by a finite set $X$ is isomorphic to the _double [[power set]]_ $\mathcal{P}\mathcal{P}X$ of $X$; an element $a$ of $X$ is interpreted as the set of all those [[subsets]] of $X$ to which $a$ belongs, and the boolean algebra operations on the [[intersection]] and [[union]] as usual.

The __free Boolean algebra__ on an arbitrary set $X$ is more complicated; it can be described in several ways. By [[abstract nonsense]], it can be described as a [[filtered colimit]] of finitely generated free Boolean algebras

$$Bool(X) = colim_{S \subseteq\subseteq X} Bool(S)$$ 

(where $\subseteq\subseteq$ indicates a [[finite set|finite subset]]) in the category of Boolean algebras; here the colimit is over the [[directed system]] of finite subsets and inclusions between them. 

A second, more concrete description is 

$$Bool(X) = \mathcal{P}_{fin} \mathcal{P}_{fin} X$$ 

where $\mathcal{P}_{fin}(X)$ denotes the set of [[Dedekind finite set|Dedekind finite]] [[subset]]s of $X$.

However, the Boolean operations are not what one might naively expect. The simplest way of describing the operations might be to consider Boolean algebras as equivalent to [[Boolean ring]]s (where binary addition is given by [[symmetric difference]]), and consider the construction of free Boolean rings by analogy with [[polynomial algebra]] constructions, where one forms the free [[vector space]] generated by a monoid of monomials. 

Thus, in the first place, the monoid $M = \mathcal{P}_{fin} X$ (where the multiplication is given by [[intersection]]) can be seen as the free commutative idempotent monoid (that is the [[free semilattice]]) on $X$. In the second place, 

$$Bool(S) = \mathcal{P}_{fin} M$$ 

is seen as the free $\mathbb{F}_2$-vector space on $M$, where binary addition is given by symmetric difference of two finite subsets of $M$. The multiplication on $Bool(S)$ is inherited from multiplication on $M$, with the help of the distributive law. 

(The naive prescription, where one uses the usual intersection and union on the Boolean algebra $\mathcal{P}_{fin} {|M|}$, is guaranteed to fail because this is an [[atomic Boolean algebra]], whereas the free Boolean algebra on an infinite set $X$ is atomless.) 

A third description comes from Stone duality (see below). 


## Stone duality 
 {#StoneDuality}

Classical [[Stone duality]] comes about as follows. The two-element Boolean algebra can be regarded as a Boolean algebra object $\mathbf{2}$ in the category of [[compact Hausdorff spaces]] $CH$. Thus, for each finitary Boolean algebra operation $\theta\colon \mathbf{2}^n \to \mathbf{2}$, there is a corresponding operation on the representable functor $CH(-, \mathbf{2}): CH^{op} \to Set$ given by 

$$CH(-, \mathbf{2})^n \cong CH(-, \mathbf{2}^n) \stackrel{CH(-, \theta)}{\to} CH(-, \mathbf{2})$$ 

and therefore we obtain a lift 

$$CH(-, \mathbf{2}): CH^{op} \to BoolAlg$$ 

A _[[Stone space]]_ is by definition a totally disconnected compact Hausdorff space. Let $Stone \hookrightarrow CH$ denote the full subcategory of Stone spaces. 

+-- {: .un_thm}
###### Theorem (Stone representation)

The representable functor restricts to an [[equivalence of categories]] $Stone^{op} \to BoolAlg$. 
=-- 

This important theorem can be exploited to give a third description of the free Boolean algebra on a set $X$: 

$$Bool(X) \cong CH(2^X, \mathbf{2})$$ 

where $2$ denotes the 2-element compact Hausdorff space, and $2^X$ the product space $\prod_X 2$. Indeed, the inverse equivalence 

$$BoolAlg^{op} \to Stone$$ 

takes a Boolean algebra $B$ to its [[spectrum]], i.e., the space of Boolean algebra maps $Bool(B, 2)$ (*this* $2$ is the two-element Boolean algebra $\mathbb{Z}_2$!) equipped with the [[Zariski topology]]. Applied to $B = Bool(X)$, we have 

$$BoolAlg(B, 2) \cong Set(X, 2) = 2^X$$ 

where the Zariski topology coincides with the [[product topology]] on $2^X$. By the equivalence, we therefore retrieve $Bool(X)$ as $CH(2^X, \mathbf{2})$. This in turn is identified with the Boolean algebra of [[clopen subset]]s of the generalised [[Cantor space]] $2^X$.

A second description of the inverse equivalence $BoolAlg^{op} \to Stone$ comes about through the yoga of [[ambimorphic object|ambimorphic objects]]. Namely, the Boolean compact Hausdorff space $\mathbf{2}$ can equally well be seen as a [[compact Hausdorff object]] in the category of Boolean algebras. Thus, the representable functor $Bool(-, \mathbf{2}): Bool^{op} \to Set$ lifts canonically to a functor 
$$Bool^{op} \to CH$$ 
and in fact part of the Stone representation theorem is that this factors through the inclusion $Stone \hookrightarrow CH$ as the inverse equivalence $Bool^{op} \to Stone$. In particular this lift determines the topology, providing an description alternative to the description in terms of the Zariski topology (although they are of course the same). 


## In weak foundations

Boolean algebras are less interesting in [[constructive mathematics]], since [[power sets]] are not boolean algebras.  However, they are still a perfectly good algebraic construct, and the explicit construction of free algebras in terms of finite subsets is still correct.  Stone duality also works in constructive mathematics, but it must be done using [[locales]] instead of standard [[topological spaces]].

In [[predicative mathematics]], the explicit construction of free algebras works if we have general [[inductive object]]s; the [[natural numbers object]] alone is not enough.


category: category

[[!redirects BoolLat]]
[[!redirects Bool Lat]]
[[!redirects BoolAlg]]
[[!redirects BoolALg]]
[[!redirects Bool Alg]]
[[!redirects BoolRing]]
[[!redirects Bool Ring]]

[[!redirects free boolean algebra]]
[[!redirects free Boolean algebra]]
[[!redirects free boolean lattice]]
[[!redirects free Boolean lattice]]
[[!redirects free boolean ring]]
[[!redirects free Boolean ring]]

[[!redirects double powerset]]
[[!redirects double power set]]
