
# Bases and subbases
* table of contents
{: toc}

## Idea

For many notions of [[structure]], particularly for [[topological concrete category|topological categories]], one can specify a structure by a _base_ or _subbase_ that generate the structure.  Besides being convenient ways to specify a structure, they may even be necessary when using weak [[foundations]].

+-- {: .num_remark #basevsbasis}
###### Warning

Sometimes one says '[[basis]]' instead of 'base', but I ([[Toby Bartels]]) think that it\'s safest to save the former term for the generating set of a [[free object]] (or an analogous situation), especially in an [[algebraic category]].  Although a basis and a base can both generate something, they tend to do so in very different ways.  (It doesn\'t help that 'bases' is the plural of both, although the pronunciation is different.)
=--

Typically, every structure of an appropriate type is both a base and a subbase for itself, while every base is a subbase.  Bases and subbases can also be characterised independently; every subbase generates a base (which tends to be _saturated_ in some way), while every base (saturated or not) generates a complete structure.


## Examples

### Bases for filters

Recall that a __[[filter]]__ on a [[poset]] $L$ is a [[subset]] $F$ of $L$ such that:

1.  If $x \leq y$ and $x \in F$, then $y \in F$.
2.  Some $x \in F$.
3.  If $x, y \in F$, then for some $z \in F$, $z \leq x, y$.

More generally, any subset $F$ satisfying (2,3) is a __filter base__.

Given a filter base $F$ in a poset, we generate a filter $\overline{F}$ by closing under (1); that is, if $F$ is a filter base on a poset $L$, then
$$ \overline{F} \coloneqq \{ y \;|\; \exists x \in F,\; x \leq y \} $$
is a filter on $L$.

If $L$ is a [[meet]]-[[semilattice]], then we can equivalently define a filter as a subset $F$ such that:

1.  If $x \leq y$ and $x \in F$, then $y \in F$ (same as before).
2.  The [[top element]] $\top \in F$.
3.  If $x, y \in F$, then $x \wedge y \in F$.

Now any subset satisfying (2,3) is a __saturated filter base__, and any subset whatsoever is a __filter subbase__.

Given a filter subbase $F$ in a semilattice, we generate a base $\vec{F}$ by closing under (2,3) in the second list; that is, if $F$ is a filter subbase on a semilattice $L$, then
$$ \vec{F} \coloneqq \{ \bigwedge_{i=1}^n x_i \;|\; x_i \in F \} $$
is a filter base on $L$, which in fact is saturated.  (Note that $\top \in \vec{F}$ follows when $n = 0$.)

Given a filter subbase $F$ in a semilattice, we can generate a filter by first generating a base $\vec{F}$ and then generating a filter $\overline{\vec{F}}$.  Alternatively, we can generate the same filter by closing under (1,2,3) in the first list all at once.  That is, if $F$ is a filter subbase on a semilattice $L$, then
$$ \overline{F} \coloneqq \{ y \;|\; \exists x_1,\ldots,x_n \in F,\; \forall z \leq x_1,\ldots,x_n,\; z \leq y \} $$
is a filter on $L$.  Furthermore, this is the same filter as $\overline{\vec{F}}$.

The [[intersection]] of any family of filters on a semilattice $L$ is a filter; that is, being a filter is a [[Moore closure]] property on subsets of $L$.  The filter generated by a filter subbase $F$ (which is an arbitrary subset of $L$, remember) is the same as the Moore closure of $F$ under this property, that is the intersection of all filters on $L$ that contain $F$.

Unlike filters and filter bases, the concept of filter subbase does not seem to make sense on an arbitrary poset, but only on a semilattice.


### Bases for topologies

Recall that a [[topological space|topology]] on a [[set]] $X$ is a collection $\mathcal{O}$ of [[subsets]] of $X$ such that:

1.  Any [[union]] of elements of $\mathcal{O}$ belongs to $\mathcal{O}$.
2.  $X$ itself belongs to $\mathcal{O}$.
3.  If $U,V \in \mathcal{O}$, then $U \cap V \in \mathcal{O}$.

More generally, any collection $\mathcal{O}$ satisfying (2,3) is a __saturated topological base__, and any collection whatsoever is a __topological subbase__.

A slightly more complicated but equivalent definition of topology is this:

1.  Again, any union of elements of $\mathcal{O}$ belongs to $\mathcal{O}$.
2.  $X$ itself is a union of elements of $\mathcal{O}$.
3.  If $U,V \in \mathcal{O}$, then $U \cap V$ is contained in a union of elements of $\mathcal{O}$.

Now any collection satisfying (2,3) is a __[[basis for a topology|topological base]]__ (not necessarily saturated).

Given a topological subbase $\mathcal{O}$, we generate a base $\vec{\mathcal{O}}$ by closing under (2,3) in the first list; that is, if $\mathcal{O}$ is a topological subbase on a set $X$, then
$$ \vec{\mathcal{O}} \coloneqq \{ \bigcap_{i=1}^n U_i \;|\; U_i \in \mathcal{O} \} $$
is a topological base on $X$, which in fact is saturated.  (Note that $X \in \vec{\mathcal{O}}$ follows when $n = 0$.)

Given a topological base $\mathcal{O}$, we generate a topology $\overline{\mathcal{O}}$ by closing under (1); that is, if $\mathcal{O}$ is a topological base on a set $X$, then
$$ \overline{\mathcal{O}} \coloneqq \{ V \;|\; \forall p \in V,\; \exists U \in \mathcal{O},\; p \in U \subseteq V \} $$
is a topology on $X$.

Given a topological subbase $\mathcal{O}$, we can generate a topology by first generating a base $\vec{\mathcal{O}}$ and then generating a topology $\overline{\vec{\mathcal{O}}}$.  Alternatively, we can generate the same topology by closing under (1,2,3) in the second list all at once.  That is, if $\mathcal{O}$ is a topological subbase on a set $X$, then
$$ \overline{\mathcal{O}} \coloneqq \{ V \;|\; \forall p \in V,\; \exists U_1, \ldots, U_n \in \mathcal{O},\; p \in \bigcap_{i=1}^n U_i \subseteq V \} $$
is a topology on $\mathcal{O}$.  Furthermore, this is the same topology as $\overline{\vec{\mathcal{O}}}$.

As with filters, being a topology is a [[Moore closure]] property, this time on subsets of the [[power set]] $\mathcal{P}X$, and the topology generated by a topological subbase $\mathcal{O}$ is the intersection of all topologies on $X$ that contain $\mathcal{O}$.

Very analogous considerations apply to [[local bases]] for a topology and bases for [[pretopological space|pretopologies]], [[convergence space|convergence structures]], [[gauge space|gauge structures]], [[Cauchy space|Cauchy structures]], etc.


### Bases for uniformities

Uniformities are a little trickier than topologies, at least in the case of subbases.  For now, see the page [[uniform space]] for definitions of base and subbase for a uniformity.


### Bases for $\sigma$-algebras

Recall that a $\sigma$-[[sigma-algebra|algebra]] on a [[set]] $X$ is ...

...


### Bases for Grothendieck coverages

See  [[basis for a Grothendieck topology]].

## General theory

Is there a general theory of bases?  That\'s a good question.  I don\'t know!

Obviously this has something to do with [[Moore closures]] (and hence [[monads]]); generating a structure from a subbase is (often) taking a Moore closure.  But there\'s some particular property of some closure operators that makes the intermediate concept of base work out.


[[!redirects base]]
[[!redirects subbase]]
[[!redirects saturated base]]
