
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Topology
+--{: .hide}
[[!include topology - contents]]
=--
=--
=--

# Topological spaces
* table of contents
{: toc}

## Idea
 {#Idea}

The notion of _topological space_ aims to axiomatize the idea of a _[[space]]_ as a collection of [[points]] that hang together ("[[cohesive topos|cohere]]") in a _[[continuous function|continuous]]_ way.

Some one-dimensional shapes with different topologies: the Mercedes-Benz symbol, a line, a circle, a complete graph with 5 nodes, the skeleton of a cube, and an asterisk (or, if you'll permit the one-dimensional approximation, a starfish). A circle has the same topology as a line segment with a wormhole at its finish which teleports you to its start. You can see this by putting overlapping open intervals on each of the shapes. You'll see that they respond the same way, so they're equivalent in that sense.

The surface of a [[torus]] is also topologically equivalent to the surface of a mug. You can see this by putting open circles or slightly looser loops all over each surface: you'll see that they also respond in the same way. Abstractly, the surface of the mug can be deformed _continuously_ to become the standard torus: the continuous cohesion among the collections of points of the two surfaces is the same.

There is a slight generalization of the notion of topological space to that of a _[[locale]]_, which consists of dropping the assumption that all [[neighbourhoods]] are explicitly or even necessarily supported by points. In this form the definition is quite fundamental and can be naturally motivated from just pure [[logic]] -- as the formal dual of _[[frames]]_ --  as well as, and [[duality|dually]], from [[category theory]] in its variant as [[topos theory]] -- by the notion of _[[(0,1)-toposes]]_. 

Topological spaces are the objects studied in _[[topology]]_. 
By equipping them with a notion of [[weak equivalence]], namely of [[weak homotopy equivalence]], they turn out to support also _[[homotopy theory]]_. 

Topological spaces equipped with extra [[property]] and [[structure]] form the fundament of much of [[geometry]]. For instance a topological space locally isomorphic to a [[Cartesian space]] is a _[[manifold]]_. A topological space equipped with a notion of [[smooth functions]] into it is a [[diffeological space]]. The intersection of these two notions is that of a _[[smooth manifold]]_ on which [[differential geometry]] is based. And so on.


## Definitions
 {#Definitions}

We present first the

* [standard definition](#StandardDefinition)

and then a list of different

* [equivalent definitions](#AlternateDefinitions).

Finally we mention genuine

* [variants of the notion](#Variants).

### Standard definition
 {#StandardDefinition}

+-- {: .num_defn}
###### Definition

A **topological space** is a [[set]] $X$ equipped with a set of [[subsets]] 
$U \subset X$, called the **[[open sets]]**, which are closed under 

1. finite [[intersections]] 
1. arbitrary [[unions]].  

=--

+-- {: .num_remark}
###### Remark

The word 'topology' sometimes means the [[topology|study of topological spaces]] but here it means the collection of open sets in a topological space. In particular, if someone says 'Let $T$ be a topology on $X$', then they mean 'Let $X$ be equipped with the structure of a topological space, and let $T$ be the collection of open sets in this space'.

=--


+-- {: .num_remark}
###### Remark

Since $X$ itself is the intersection of zero subsets, it is open, and since the [[empty set]] $\emptyset$ is the union of zero subsets, it is also open. Moreover, every open subset $U$ of $X$ contains the empty set and is contained in $X$

$$
  \emptyset \subset U \subset X
  \,,
$$

so that the topology of $X$ is determined by a [[poset of open subsets]] $Op(X)$ with [[bottom]] element $\bot = \emptyset$ and [[top]] element $\top = X$. 

Since by definition the elements in this [[poset]] are closed under finite [[meets]] (intersection) and arbitrary [[joins]] (unions), this poset of open subsets defining a topology is a _[[frame]]_, the _[[frame of opens]]_ of $X$.

=--

+-- {: .num_defn}
###### Definition

A [[homomorphisms]] between topological spaces $f : X \to Y$ is a **[[continuous function]]**: 

a [[function]] $f:X\to Y$ of the underlying [[sets]] such that the [[preimage]] of every open set of $Y$ is an open set of $X$.

=--

Topological spaces with continuous maps between them form a [[category]], usually denoted _[[Top]]_.

+-- {: .num_remark}
###### Remark

The definition of [[continuous function]] $f : X \to Y$ is such that it induces a homomorphism of the corresponding [[frames of opens]] the other way around

$$
  Op(X) \leftarrow Op(Y) : f^{-1}
  \,.
$$

And this is not just a morphism of [[posets]] but even of [[frames]].
For more on this see at _[[locale]]_.

=--

### Alternate equivalent definitions
 {#AlternateDefinitions}

There are many equivalent ways to define a topological space.  A non-exhaustive list follows:

* A set $X$ with a [[frame]] of open sets (as above).

* A set $X$ with a co-frame of [[closed sets]] (the complements of the open sets) satisfying dual axioms.

* A set $X$ with any collection of subsets whatsoever, to be thought of as a [[subbase]] for a topology.

* A pair $(X, int)$, where $int\colon P(X) \to P(X)$ is a [[lex functor|left exact]] [[comonad]] on the [[power set]] of $X$ (the "[[interior]] operator").  The open sets are exactly the fixed points of $int$.

* A pair $(X, cl)$ where $cl$ is a [[rex functor|right exact]] [[Moore closure]] operator satisfying axioms dual to those of $int$.  The closed sets are the fixed points of $cl$.

* A [[relational β-module]]; that is, a [[lax algebra]] of the [[monad]] $\beta$ of [[ultrafilters]] on the [[(1,2)-category]] [[Rel]] of sets and [[binary relations]].  More explicitly, this means a set $X$ together with a relation called "[[convergence]]" between ultrafilters and points satisfying certain axioms.  This exhibits it as a special sort of [[generalized multicategory]], and also as a special sort of [[pseudotopological space]].

* A set with a [[convergence relation]] between [[nets]] or [[filters]] (not just ultrafilters) and points, or even between transfinite [[sequences]] and points, satisfying appropriate axioms.


### Variations
 {#Variants}

The definition of topological space was a matter of some debate, especially about 100 years ago. Our definition is due to [[Bourbaki]], so may be called **Bourbaki spaces**.

For some purposes, including [[homotopy theory]], it is important to use [[nice topological spaces]] (such as [[sequential topological spaces]]) and/or a [[nice category of spaces]] (such as [[compactly generated spaces]]), or indeed to directly use a model of $\infty$-[[infinity-groupoid|groupoids]] (such as [[simplicial sets]]).

On the other hand, when doing [[topos theory]] or working in [[constructive mathematics]], it is often more appropriate to use [[locales]] than topological spaces.

Some applications to [[analysis]] require more general [[convergence spaces]] or other generalisations.


## Examples

### Special cases

* [[finite topological space]]

* [[discrete topological space]]

* [[codiscrete topological space]]

* [[cofinite topology]]

* [[order topology]] [[specialization topology]], [[Scott topology]]

* [[compact topological space]]

* [[paracompact topological space]], [[sigma-compact topological space]], [[Lindelöf topological space]]

* [[spectral topological space]]

* [[CW-complex]]

* [[manifold]]

...


### Specific examples

* [[empty space]]

* [[point space]]

* [[Sierpinski space]]

* [[simplex]]

* [[circle]]

* [[Cantor space]]

* [[long line]], [[line with two origins]]

* [[K-topology]]

* [[projective space]], [[real projective space]], [[complex projective space]]

* [[classifying space]]

...

+-- {: .num_example}
###### Example

The [[Cartesian space]] $\mathbb{R}^n$ with its standard notion of open subsets [[topological base|generated from]]: [[unions]] of [[open balls]] $D^n \subset \mathbb{R}^n$.

=--


## Related concepts

* [[separation axioms]]

* [[finer topology]], [[coarser topology]]

* [[first countable topological space]], [[second countable topological space]], [[separable topological space]], [[Hausdorff topological space]], [[topological manifold]]

* [[topological property]]

* [[locale]], [[topos]]

* [[proximity space]], [[uniform space]], [[syntopogenous space]]

* [[quotient topology]], [[quotient topological space]]

* [[subspace topology]], [[topological subspace]]

* [[product topological space]]

* [[effective topological space]], [[equilogical space]]

* [[topological G-space]]

* [[filter space]]

* [[connected topological spaces]], [[simply connected topological space]]

* [[nilpotent topological space]]

* [[fractal]]

## References

See at _[[topology]]_.

[[!redirects topological space]]
[[!redirects topological spaces]]
[[!redirects topological structure]]
[[!redirects topological structures]]
