
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Physics
+--{: .hide}
[[!include physicscontents]]
=--
#### Mathematics
+--{: .hide}
[[!include mathematicscontents]]
=--
=--
=--



#Contents#
* table of contents
{:toc}

## Idea

**Mathematical physics** is a discipline at the interface of [[mathematics]] and [[physics]], concerned with developing mathematical models of physical phenomena and mathematical apparatus arising or needed in such models. It intersects with **theoretical physics** which deals with theoretical arguments in consideration of physical phenomena and the development of models of known and of conjectured physics; theoretical physics is in a sense wider as it deals also with interpretations, non-rigorous and sometimes speculative argument from experiments or from rough comparisons of different models and various experimental data, not entering or forming together a necessarily compatible mathematical entity. For example, the calculations of fitting parameters and adjusting models to complicated experimental data, called the [[phenomenology]] is part of the work of a theoretical physicist, but most such work is not nowadays considered to belong to mathematical physics, unless one is developing a really new mathematical model or tool for such work. 

## History

Historically, there has been some variance as to what exactly is comprised by "mathematical physics", see ([Fadeev 00](#Fadeev00)) for some history. 

In the beginning of the 20th century the term was understood very broadly:

> Not only [[Henri Poincaré ]], but also [[Albert Einstein]], were called mathematical physicists. Newly established theoretical chairs were called chairs of mathematical physics. It follows from the documents in the archives of the Nobel Committee that MP had a right to appear both in the nominations and discussion of the candidates for the Nobel Prize in physics. Roughly speaking, the concept of Mathematical Physics covered theoretical papers where mathematical formulae were used. ([Fadeev 00, p. 1](#Fadeev00))

Also, in the list of [[Hilbert's problems]] of mathematics, the [[Hilbert's sixth problem|sixth problem]] regards the mathematical formulation of physics as one of the core problems in mathematics:

> **6. Mathematical Treatment of the Axioms of Physics.** The investigations on the [[foundations]] of [[geometry]] suggest the problem: To treat in the same manner, by means of [[axioms]], those [[physics|physical sciences]] in which already today [[mathematics]] plays an important part; in the first rank are the [[probability theory|theory of probabilities]] and [[mechanics]].


However, the 1920 and 1930s  the term "mathematical physics" began to be reserved more exclusively for the activity of making precise arguments that are already more or less understood by theoretical physicists informally. The term began to be referred to mathematical tools used in physics or yet more specifically in [[classical physics]] as the theory of [[partial differential equations]] and [[variational calculus]] and in [[quantum physics]] as [[functional analysis]] and [[representation theory]]. 

> One sees the quest for the rigorous mathematical theorems about results which are understood by physicists in their own way. ([Fadeev 00, p. 2](#Fadeev00))

More recently this narrow understanding has been called into question: [Fadeev 00, p. 3](#Fadeev00) writes:

> I consider as the main goal of Mathematical Physics the use of mathematical intuition for the derivation of really new results in the fundamental physics. In this sense, Mathematical Physics and Theoretical Physics are competitors.  Their goals in unraveling the laws of the structure of matter coincide. However, the methods and even the estimates of the importance of the results of work may differ quite significally. 

In a similar spirit of trying to break out of an overly restrictive understanding of the term "mathematical physics" [[Gregory Moore]] has been advocating the alternative term **physical mathematics** for the study of mathematical constructions inspired by models of theoretical physics ([Moore 14](#Moore14)).



Some of the greatest names of mathematical physics have sought a more profound role for it in the belief that very deep mathematical ideas are required to describe nature. For instance, [[Paul Dirac]] expresses such a view here:

> It seems to be one of the fundamental features of nature that fundamental physical laws are described in terms of a mathematical theory of great beauty and power, needing quite a high standard of mathematics for one to understand it. You may wonder: Why is nature constructed along these lines? One can only answer that our present knowledge seems to show that nature is so constructed. We simply have to accept it. One could perhaps describe the situation by saying that God is a mathematician of a very high order, and He used very advanced mathematics in constructing the universe. (Paul Dirac, *The Evolution of the Physicist's Picture of Nature*, Scientific American 1963)

This view led Dirac to advocate the following as a methodology:

>The trend of mathematics and physics towards unification provides the physicist with a powerful new method of research into the foundations of his subject, a method which has not yet been applied successfully, but which I feel confident will prove its value in the future. The method is to begin by choosing that branch of mathematics which one thinks will form the basis of the new theory. One should be influenced very much in this choice by considerations of mathematical beauty. It would probably be a good thing also to give a preference to those branches of mathematics that have an interesting group of transformations underlying them, since transformations play an important role in modern physical theory, both relativity and quantum theory seeming to show that transformations are of more fundamental importance than equations. Having decided on the branch of mathematics, one should proceed to develop it along suitable lines, at the same time looking for that way in which it appears to lend itself naturally to physical interpretation. ([The Relation between Mathematics and Physics](http://www.damtp.cam.ac.uk/events/strings02/dirac/speach.html))

[[Hermann Weyl]] helped develop many of the ingredients of modern mathematical physics, as [[Michael Atiyah]] explains:  

>The past 25 years have seen the rise of gauge theories&#8211;Kaluza-Klein models of high dimensions, string theories, and now M-theory, as physicists grapple with the challenge of combining all the basic forces of nature into one all embracing theory. This requires sophisticated mathematics involving Lie groups, manifolds, differential operators, all of which are part of Weyl's inheritance. There is no doubt that he would have been an enthusiastic supporter and admirer of this fusion of mathematics and physics. No other mathematician could claim to have initiated more of the theories that are now being explored. His vision has stood the test of time. (Michael Atiyah, *Hermann Weyl: 1885-1955*)


>[Weyl's] contemporaries are long since gone and only a few personal reminiscences survive. On the other hand the passage of time makes it easier to assess the long-term significance of Weyl's work, to see how his ideas have influenced his successors and helped to shape mathematics and physics in the second half of the twentieth century. In fact, the last fifty years have seen a remarkable blossoming of just those areas that Weyl initiated. In retrospect one might almost say that he defined the agenda and provided the proper framework for what followed. He made fundamental contributions to most branches of mathematics, and he also took a serious interest in theoretical physics. (Michael Atiyah, *Hermann Weyl: 1885-1955*)

The version of this belief in the necessity of deep mathematics for physics to be found at the $n$Lab is, naturally enough, that higher categories, and in particular cohesive $(\infty, 1)$-toposes, are required. In this regard, see [[higher category theory and physics]], [[geometry of physics]] and [differential cohomology in a cohesive topos](http://ncatlab.org/schreiber/show/differential+cohomology+in+a+cohesive+topos#Subprojects).

## Related entries

* [[theory (physics)]]

* See the related, but disputable notion of [[applied mathematics]]. 


## References and links

* {#Dirac78} [[Paul Dirac]], _The mathematical foundations of quantum theory_, pages 1-8 in A. R. Marlow (ed.) _Mathematical Foundations of Quantum Theory_, Ac. Press 1978

> "One should keep the need for a sound mathematical basis dominating one’s search 
for a new theory. Any physical or philosophical ideas that one has must be adjusted to  fit the mathematics. Not the way round. 

> Too many physicists are inclined to start from some preconceived physical ideas 
and then to try to develop them and ?nd a mathematical scheme that incorporates them.  Such a line of attack is unlikely to lead to success. One runs into difficulties and ?nds no  reasonable way out of them. One ought then to realize that one’s whole line of approach  is wrong and to seek a new starting point with a sound mathematical basis."


* {#Geroch85} [[Robert Geroch]], _Mathematical Physics_, Chicago 1985

  (introduces concepts via [[categories]])

* {#Matolcsi86} [[Tamás Matolcsi]], _A Concept of Mathematical Physics_

  _Models for spacetimes_, Akad&eacute;miai Kiad&oacute;, 1984 ([djvu]( http://szofi.elte.hu/~szaboa/MatolcsiKonyvek/djvu/konyv/spacetime_ocr.djvu))

  _Models in Mechanics_, Akad&eacute;miai Kiad&oacute;, 1986 ([djvu](http://szofi.elte.hu/~szaboa/MatolcsiKonyvek/djvu/konyv/mechanics_ocr.djvu))

* {#Fadeev00} [[Ludwig Faddeev]], _Modern Mathematical Physics: what it should be?_, in Fokos, Grigoryan, Kibble, Zegarlinski (eds) _Mathematical Physics 2000_, World Scientific (2000) ([arXiv:math-ph/0002018](https://arxiv.org/abs/math-ph/0002018))



A historically inclined article is in 

* Wikipedia,  _[Mathematical physics](http://en.wikipedia.org/wiki/Mathematical_physics)_ 

An exposition from the point of view of modern [[gauge theory]] is in 

* {#Freedman93} [[Daniel Freedman]], _Some beautiful equations of mathematical physics_, Dirac Prize lecture, November 1993 ([arXiv:hep-th/9408175](http://arxiv.org/abs/hep-th/9408175))

Some observations from the point of view of [[string theory]] are in

* {#Moore14} [[Gregory Moore]], _[[Physical Mathematics and the Future]]_ (2014)

For an extensive list of literature see

* [[books and reviews in mathematical physics]]

Further related entries include

* [[higher category theory and physics]], [[geometry of physics]]

[[!redirects physical mathematics]]
[[!redirects mathematical physicist]]
[[!redirects mathematical physicists]]