
# The red herring principle
* table of contents
{: toc}

## Idea

The mathematical **red herring principle** is the principle that in [[mathematics]], a "red herring" need not, in general, be either red or a herring.

Frequently, in fact, it is conversely true that all herrings are red herrings.  This often leads to mathematicians speaking of "non-red herrings," and sometimes even to a redefinition of "herring" to include both the red and non-red versions.


## Notes

* Clearly, the term "red herring" here is not to be confused with the usual meaning, which typically refers to a deliberate attempt to divert or throw one off track, as for example a rhetorical tactic for this purpose, or a novelistic device. 

* It should also not be thought that "red herring" as used here signals a pejorative, indicating for example ineptitude or lack of care in naming. For example, it may be that "foo" once meant a "bar", but over time the meaning of "foo" changed, so that while "weak $*$-foo" might seem strange if "foo" is taken in the modern sense, it made much better sense under the older (but mostly forgotten) meaning of "foo". 

Thus, "red herring" as used here is to be interpreted neutrally: it refers to a name of a concept which might throw the reader off-track, by accident as it were. 


## Examples

* A [[manifold with boundary]] is not a [[manifold]].  This leads to the use of "manifold without boundary."

* In [[linear algebra]], an [[associative algebra|algebra]] is usually defined to be associative, so a [[nonassociative algebra]] is not an algebra in this sense.  This leads to the technically redundant use of "associative algebra".  Furthermore, a "nonassociative algebra" *might* happen to be associative; it just doesn\'t *have* to be!

* Similarly, [[noncommutative geometry]] is really about _not necessarily commutative_ or _possibly non-commutative_ geometry. In fact, many tools developed in "non-commutative geometry" are also useful tools in ordinary commutative geometry.

* A [[star-autonomous category|*-autonomous category]] is not an [[autonomous category]], but the reverse is almost true: a *symmetric* autonomous (a.k.a. [[compact closed category|compact closed]]) category is a fairly special case of a $*$-autonomous one.  This red herring is apparently an accident of history: at the time $*$-autonomous categories were invented, "autonomous category" was sometimes used to mean a [[closed monoidal category]], of which $*$-autonomous categories are indeed a special case, but nowadays that usage has mostly disappeared.

* A [[linearly distributive category]] has essentially nothing to do with a [[distributive category]].

* If a [[localizer]] refers to a class of maps in a [[presheaf category]], as it sometimes does, then a [[basic localizer]], being a class of maps in [[Cat]], is not a localizer.

* A [[multivalued function]] is not a [[function]], but a function is a special case of a multivalued function.

* A [[planar ternary ring]] is not a [[ring]].  A general ring is not a planar ternary ring either; their "intersection" is the class of [[division rings]].

Some adjectives are almost universally used as "red herring adjectives," i.e. placing that adjective in front of something makes it *more* general in some way.  Some red herring adjectives almost always have the same meaning, such as "pseudo" and "lax," but others, such as "weak," have different meanings in different contexts.

* A [[weak factorization system]] is not a factorization system, as originally defined, but rather the reverse.  This has led some people to the use of [[orthogonal factorization system]] in place of the classical term "factorization system."

* A [[weak limit]] is not a [[limit]] in a similar way: it satisfies only existence but not uniqueness.

* Originally, [[n-category]] referred only to the strict version, so that a "weak $n$-category" was not an $n$-category.  Nowadays some people (including many authors of the nLab)  are trying to reverse this, so that $n$-category means the weak version, while the strict version needs an adjective added.  Likewise for related concepts such as [[2-limit]] and [[strict 2-limit]].

Sometimes a red herring is only a red herring in degenerate case, perhaps only one case:

* Fixing a [[natural number]] $n$, a [[homogeneous polynomial]] of degree $n$ is almost always a [[polynomial]] of degree $n$, but there is one exception: the [[zero]] polynomial has no degree (or is degree $-1$ or degree $-\infty$, depending on conventions), yet it is homogeneous of any degree.


## Non-examples

Some uses of terminology are similar in some ways, but don't quite fall under the same category.  For instance, in a number of cases mathematicians working in a particular field tend to omit [[dichotomy between nice objects and nice categories|niceness]] adjectives, e.g.:

* The generally accepted *definition* of a [[ring]] does not include commutativity, but in [[algebraic geometry]] and [[commutative algebra]] it is an almost universal convention that all rings are taken to be commutative.  However, almost every book concerning the subject announces its conventions early on.

* Algebraic topologists usually work with a [[convenient category of topological spaces]] rather than the category of all [[topological spaces]], but usually they simply say "space" to mean an object of their chosen convenient category.  Some algebraic topologists (particularly of the MIT school) take this even further and say "space" to mean [[simplicial set]]. In the Chicago school, this is occasionally stretched even further, with "space" meaning [[spectrum]] (although this is arguably more of a joke than a common usage).

These terminological uses can create situations that appear similar to actual red herrings, such as the use of "noncommutative ring" by people who are familiar with using "ring" to mean "commutative ring."  However, since the actual definitions of terms like "ring" and "topological space" is generally accepted to be unchanged (as opposed to the commonly used abbreviations), these are not true red herrings.


### Semi-non-examples

Sometimes, adding an adjective does not destroy the property that the noun has, but the noun now has its property in a different way, e.g.:

* A [[contravariant functor]] from $C$ to $D$ _is_ still a functor, however not from $C$ to $D$, but from $C^{op}$ to $D$ (or equivalently from $C$ to $D^{op}$).

[[!redirects red herring]]
[[!redirects red herring principle]]
[[!redirects the red herring principle]]
