
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Topos Theory
+-- {: .hide}
[[!include topos theory - contents]]
=--
#### Category Theory
+-- {: .hide}
[[!include category theory - contents]]
=--
=--
=--

# Forcing
* table of contents
{: toc}

## Idea

In [[set theory]], **forcing** is a way of "adjoining indeterminate objects" to a [[model]] in order to make certain [[axioms]] [[true]] or [[false]] in a resulting new model.  

The language of forcing is generally used in [[material set theory]]. From the point of view of [[structural set theory]]/[[categorical logic]] it is more or less equivalent to the construction of [[categories of sheaves]] in [[topos theory]] and [[structural set theory]]: here a [[classifying topos]] of a [[theory]] is a "category of sets" that is  "forced" to contain a generic model of the theory.


## An analogy to polynomial rings

There are three ways in which to describe the construction of forcing, which can be explained by analogy to a situation in algebra.  Suppose that we have a [[ring]] $R$ and we want to know what $R$ would be like if it had a nilsquare element, i.e. an $x$ such that $x^2=0$, although we don't know whether $R$ *actually* has any nilsquare elements.  There are several things we could do.

1. We could consider some larger ring $S$ which contains $R$ as a subring, and also contains some nilsquare element $x$, and then study the subring of $S$ generated by $R$ and $x$, using only our knowledge that it contains $R$ and $x$ and that $x$ is nilsquare.

1. We could work formally in the [[theory]] of $R$ with an extra variable $x$ and the axiom that $x^2=0$, avoiding consideration of any new rings at all.

1. We could construct the polynomial ring $R[x]$ and quotient by the ideal $(x^2)$, resulting in the *universal* ring $R[x]/(x^2)$ containing $R$ and also a nilsquare element.

Obviously these are more or less equivalent ways of doing the same thing.  Arguably, most modern mathematicians would find the third the most natural.  It is certainly the most [[category theory|category-theoretic]] and the most in line with the [[nPOV]].

Now suppose instead that we have a model $V$ of [[ZF]] set theory (for instance), and we want to know what $V$ would be like if it contained a set $G$ satisfying some particular properties.  We can likewise take three approaches.

1. We can assume that $V$ sits inside some larger model of ZF, in such a way that there is a set $G$ outside of $V$ and the "model generated by $V$ and $G$" called $V[G]$ satisfies the desired properties.  The $G$ is called a *generic* set for the desired "notion of forcing."  There is an extra wrinkle in this approach in that such a $G$ will not generally exist unless we assume that $V$ is [[countable set|countable]].  But for purposes of independence proofs in [[classical mathematics]], this is no problem, since the downward [[Löwenheim-Skolem theorem]] guarantees that if ZF is consistent, then it has a countable model.

1. We can define a new notion of "truth" for statements about $V$, which is not the same as the old one, and which will usually take values not in ordinary [[truth values]] but in some more complicated [[Boolean algebra]] (or [[Heyting algebra]]), in such a way so that the statement "there exists a $G$ with the desired properties" is "true."  This is called *forcing semantics*.

1. We can construct a new model of set theory out of whole cloth from $V$, rather than trying to find it as a submodel of some assumed larger model.  In material set theory, this construction is usually called a *Boolean valued model* (or a *Heyting valued model* if it is [[constructive mathematics|intuitionistic]]).  In structural set theory, this construction is simply that of the [[topos of sheaves]] on a suitable [[site]], in the model $V$.  The topos of sheaves is moreover *universal* over $V$ such that it contains an [[object]] $G$ satisfying the desired properties in its [[internal logic]]---in other words, it is a [[classifying topos]] of the [[theory]] of such a $G$. See at _[References -- In terms of classifying toposes](#ReferencesInTermsOfClassifyingToposes)_ for more.

Although by analogy, it would seem that a modern perspective should prefer the third approach, most material set theorists still seem to prefer one of the first two.

Before [[Paul Cohen|Cohen]] showed how forcing could give rise to models of ZF(C), [[Abraham Fraenkel|Fraenkel]] introduced the method of [[permutation model]]s (later refined by Mostowski and Specker), which gave models of [[ZFA]], a version of ZF with [[urelements|atoms]]. See for example the [[basic Fraenkel model]].

## Related concepts

* [[double negation topology]]

* [[homotopy type theory FAQ]] -- [What is homotopy type theory? -- For set theorists](http://ncatlab.org/nlab/show/homotopy+type+theory+FAQ)

## References

Exposition is in 

* [[Timothy Chow]], _A beginner's guide to forcing_, Contemp. Math ([arXiv:0712.1320](https://arxiv.org/abs/0712.1320))

Another good introduction is in [Schoenfield 71](#Schoenfield71)

### General


* [[Paul Cohen]], _Set theory and the [[continuum hypothesis]]_, Benjamin, New York 1966

* [[Gonzalo Reyes]], _Typical and generic in a Baire space for relations_, thesis 1967

* [[Abraham Robinson]], _Infinite forcing in model theory_,  in Proc. 2nd Scand. Logic Synp. pp. 317-340, ed. J. E. Fenstad

* Jon Barwise ed. _Handbook of mathematical logic_, 1977, in chapters by Macintyre, Burgess and Keisler

* {#Schoenfield71} J. R. Schoenfield, _Unramified forcing_, pp. 383--395 in: Axiomatic set theory, vol. 1, ed. D. S. Scott, Proc. Symp. Pure Math. __13__ (1971) (([pdf](https://www.math.ucsd.edu/~sbuss/CourseWeb/Math260_2012F2013W/Shoenfield_UnramifiedForcing.pdf)))

* S. Shelah, _Proper and Improper Forcing_ , Perspectives in Math. Logic vol. 5 Springer Heidelberg 1998. ([toc](http://projecteuclid.org/euclid.pl/1235419814#toc))

* [[Paul Cohen]], _The Discovery of Forcing_, Rocky Mountain J. Math.
Volume 32, Number 4 (2002), 1071-1100. ([Euclid](http://projecteuclid.org/euclid.rmjm/1181070010))

* math overflow, what is the generic poset used in forcing really?, [web](http://mathoverflow.net/questions/51187/what-is-the-generic-poset-used-in-forcing-really)

### In terms of sheaves and classifying toposes
 {#ReferencesInTermsOfClassifyingToposes}

Discussion of the interpretation of forcing as the passage to [[classifying toposes]] includes

* {#MakkaiReyes77} [[Michael Makkai]], [[Gonzalo Reyes]], _First Order Categorical Logic_,  Lecture Notes in Mathematics Volume 611, Springer 1977

* {#Skedrov84} Andrej Skedrov, _Forcing and classifying topoi_, Memoirs of the American Mathematical Society 1984; 93 pp

* [[Andreas Blass]], Andrej Skedrov, _Classifying topoi and finite forcing_ ([pdf](http://deepblue.lib.umich.edu/bitstream/handle/2027.42/25225/0000666.pdf;jsessionid=8D65C672D70D8E24A5ACD366C1815921?sequence=1))

* {#Roberts15} [[David Roberts]], _Class forcing and topos theory_, talk at _[Topos at l'IHES](https://indico.math.cnrs.fr/event/747/)_ 2015 ([talk notes pdf](https://www.dropbox.com/s/vk1efw7lsvta80p/Roberts_IHES.pdf?dl=0),  [video recording](https://youtu.be/4AaSySq8-GQ))

On [Skedrov 84](#Skedrov84), [[Peter Johnstone]] writes in his review ([The Journal of Symbolic Logic Vol. 50, No. 3 (Sep., 1985), pp. 852-85]( http://www.jstor.org/stable/2274338 )):

>  Until recently, logicians could have been forgiven for treating topos theory as a closed book, whose applications to logic (however interesting they might appear from the outside) were accessible only to insiders well schooled in the mysteries of category theory $[...]$ $[$ Skedrov's book makes $]$ a very clear case for the advantages of the topos-theoretic approach to forcing namely, that it provides a clear conceptual view of what generic structures really are, as well as a workable mean $[...]$ Although categorical ideas and terminology are inevitably present, they are handled so skilfully that the categoriphobic reader need have few qualms about them $[...]$ Skedrov's work ought to go a long way towards demolishing the wall of incomprehension that has hitherto prevented many logicians from appreciating what topos theory has to offer their subject.

[[!redirects forcing]]