
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Topology
+-- {: .hide}
[[!include topology - contents]]
=--
=--
=--



#Contents#
* table of contents
{:toc}

## Idea 

A [[topological space]] is called _sequentially compact_ if every [[sequence]] of points in that space has a sub-sequence which [[convergence|converges]]. In general this concept neither implies nor is implied by that of actual [[compact space|compactness]], but for some types of [[topological spaces]], such as [[metric spaces]], it is equivalent.

[[compact space|Compactness]] is an extremely useful concept in [[topology]].  The basic idea is that a [[topological space]] is [[compact space|compact]] if it isn't "fuzzy around the edges".

Whilst one can study a topological space by itself, it is often useful to probe it with known spaces.  A common choice for topological spaces, and in particular metric spaces, is to use the natural numbers, and the 1-point compactification of the natural numbers.  This is more traditionally known as studying the topology using sequences and convergent sequences.

Thus one can ask, "Can I detect compactness using probes from $\mathbb{N}$, and $\mathbb{N} \cup \{*\}$?".  The short answer to this is "No", but that just reveals that the question was too restrictive.  Rather, one should ask "What does compactness look like if all I'm allowed to use are probes from $\mathbb{N}$ and $\mathbb{N} \cup \{*\}$?".  The answer to that question is "sequential compactness".

Thus **sequential compactness** is what [[compact space|compactness]] looks like if all one has to test it are sequences.

## Definition 

+-- {: .num_defn #seqcpt}
###### Definition ######
A topological space is **sequentially compact** if every [[sequence]] in it has a [[convergence|convergent]] [[subsequence]].
=--



## Properties 

The following is a list of properties of and pertaining to sequentially compact spaces.


1. For a [[metric space]], the notions of sequential compactness and compactness coincide. See at _[[sequentially compact metric spaces are equivalently compact metric spaces]]_.

2. The [[Eberlein-Smulian theorem|Eberlein–Šmulian theorem]] states that in a [[Banach space]], for a subset with regard to the [[weak topology]], compactness and sequentially compactness are both equivalent to the weaker notion of [[countably compact space|countable compactness]].

3. A [[countable set|countable]] product of sequentially compact spaces is again sequentially compact.

   Let $\{X_k\}$ be a countable family of sequentially compact spaces.  Let $(a_l)$ be a sequence in $\prod X_k$.  For each $m$ we recursively define an infinite subset $A_m \subseteq A_{m-1} \subseteq \mathbb{N}$ with the property that the sequence $(a_l)_{l \in A_m}$ converges when projected down to $\prod_{k=1}^m X_k$.  Let $l_m = \min\{A_l\}$.  Consider the sequence $(a_{l_m})$.  For each $k$, we choose a limit $x_k$ of the projection of $(a_l)_{l \in A_k}$ to $X_k$.  Let $x = (x_k) \in \prod X_k$.  Let $U$ be a neighbourhood of $x$.  Then there is some $n \in \mathbb{N}$ and neighbourhood $U_n \subseteq \prod_{k=1}^n X_k$ of $(x_k)_{k=1}^n$ such that $U$ contains the preimage of $U_n$.  For $m \ge n$, the sequence $(l_m)$ is contained in $A_n$ and so the image of $(a_{l_m})$ converges to $(x_k)_{k=1}^n$.  Hence there is some $r$ such that for $m \ge r$, the projection of $a_{l_m}$ lies in $U_n$.  Hence for $m \ge r$, $a_{l_m} \in U$.  Thus $(a_{l_m})$ converges to $(x_k)$ and so $\prod X_k$ is sequentially compact.

   This shows that the example of a compact space that is not sequentially compact is about as simple as can be.

4. The theorem that a continuous bijection from a compact space to a Hausdorff space is a homeomorphism has a counterpart for sequentially compact spaces.

   +-- {: .num_theorem #SeqCptReg}
   ###### Theorem
   Let $\mathcal{T}_1$ and $\mathcal{T}_2$ be two topologies on a set $X$ such that:

   1. $\mathcal{T}_1 \supseteq \mathcal{T}_2$ (equivalently, the identity map on $X$ is continuous as a map $(X,\mathcal{T}_1) \to (X, \mathcal{T}_2)$)
   2. $\mathcal{T}_1$ is sequentially compact
   3. $\mathcal{T}_2$ is [[completely regular space|completely regular]] and singleton sets are $G_\delta$-[[G-delta set|sets]],

   then $\mathcal{T}_1 = \mathcal{T}_2$.
   =--

   +-- {: .proof}
   ###### Proof
   Let $V \subseteq X$ be such that $V \notin \mathcal{T}_2$.  Then it must be non-empty and there must be a point $v \in V$ such that $V$ is not a neighbourhood of $v$.  As $\mathcal{T}_2$ is completely regular and singleton sets are $G_\delta$ sets, there is a continuous function $g \colon (X, \mathcal{T}_2) \to \mathcal{R}$ such that $g^{-1}(0) = \{v\}$.  Since $V$ is not a neighbourhood of $v$, for each $n \in \mathbb{N}$, the set $g^{-1}(-\frac1n, \frac1n)$ is not wholly contained in $V$.  Thus for each $n$ there is a point $x_n \in X$ such that $x_n \notin V$ and $|g(x_n)| \lt \frac1n$.  As $\mathcal{T}_1$ is sequentially compact, this sequence has a $\mathcal{T}_1$-convergent subsequence, say $(x_{n_k})$ converging to $y$.  Since $g(x_n) \to 0$, $g(x_{n_k}) \to 0$ and thus $g(y) = 0$.  Thus $y = v$ and so $(x_{n_k}) \to v$ in $\mathcal{T}_1$.  As $x_{n_k}
 \notin V$ for all $n_k$, and $v \in V$, it must be the case that $V$ is not a $\mathcal{T}_1$-neighbourhood of $v$.  Hence $V \notin \mathcal{T}_1$.  Thus $\mathcal{T}_1 \subseteq \mathcal{T}_2$, whence they are equal.
   =--

5. The [[image]] of a sequentially compact space $X$ under a continuous map $f: X \to Y$ is also sequentially compact. For suppose $y_n$ is a sequence in $f(X)$, say $y_n = f(x_n)$. Then $x_n$ has a convergent subsequence $x_{n_j}$, converging to $x$ say, and by continuity $y_{n_j} = f(x_{n_j})$ converges to $f(x)$. 


### Relationship to Compactness 

[[compact space|Compactness]] does not imply sequentially compactness, nor does sequentially compactness imply compactness, without further assumptions, see at _[Examples and counter-examples](#Examples)_ below.

In [[metric spaces]] for example both notions coincide, see at [[sequentially compact metric spaces are equivalently compact metric spaces]]. (This is a consequence of the [[Lebesgue number lemma]] and the fact that  [[sequentially compact metric spaces are totally bounded]].)

This is _not_ a contradiction to the statement that compact is equivalent to every [[net]] having a convergent subnet: Given a sequence in a compact space, its convergent _subnet_ need not be a _subsequence_ (see [[net]] for a definition of subnet).

## Examples and counter-examples 
 {#Examples}

A [[metric space]] is sequentially compact precisely if it is [[compact topological space|compact]]. See at _[[sequentially compact metric spaces are equivalently compact metric spaces]]_.

In general neither of these two properties implies the other:

* Examples of a sequentially compact spaces which are not compact are given in in ([Buskes-Rooij 97, example 13.5](#BuskesRooij97), [Patty 08, chapter 4, example 13](#Patty08), [Vermeeren 10, prop. 18](#Vermeeren10)).

* An example of a [[compact topological space]] which is not sequentially compact is given in ([Steen-Seebach 70, item 105](#SteenSeebach70)), recalled at [Vermeeren 10, prop. 17](#Vermeeren10). See at [compact space -- Compact spaces which are not sequentially compact](compact+space#CompactSpacesWhichAreNotSequentiallyCompact).

+-- {: .num_example #ACompactSpaceNotSequentiallyCompact}
###### Example
**(a compact space which is not sequentially compact)**

Consider the [[product topological space]] (with its [[Tychonoff topology]])

$$
  X \coloneqq \underset{[0,1)}{\prod} Disc(\{0,1\})
$$

of copies of the [[discrete space]] on two elements, indexed by the points in the [[half-open interval]]. Since $Disc(\{0,1\})$ is a [[finite topological space|finite]] [[discrete topological space]] it is clearly compact. Therefore the [[Tychonoff theorem]] says that also $X$ is compact.

But here is an instance of a [[sequence]] $x_{(-)}$ in $X$ which does not have a convergent sub-sequence:

By the nature of the [[product]], an element $x \in X$ is a [[tuple]] of elements $\pi_r(x) \in \{0,1\}$ for $r \in [0,1)$. Now for $n \in \mathbb{N}$ define $x_n$ by

$$
  \pi_r(x_n) \coloneqq n\text{th digit in the binary expansion of}\,r
  \,.
$$

Suppose this sequence $(x_n)_{n \in \mathbb{N}}$ had a subsequence $(x_{(n_k)})_{k \in \mathbb{N}}$, converging to some $x_\infty \in X$, hence that for every open neighbourhood $\{x_\infty\} \subset U \subset X$ there were a $k_0 \in \mathbb{N}$ such that $x_{n_{k \geq k_0}} \in U$.

Considering then for each $r \in [0,1)$ the Tychonoff-open subset

$$
  \{ \pi_r(x_\infty) \}
  \times
  \left(
    \underset{r' \in [0,1) \backslash \{r\}}{\prod}
    \{0,1\}
  \right)
$$

this would imply that there were $n_0$ such that

$$
  \pi_r( x_{k_{n \geq n_0}} )
  =
  \pi_r(x_\infty)
$$

hence that the binary expansion of $r$ had the same digit in position $k_n$ for  all $n \geq n_0$. This is clearly not the case for all $r$ (if it is true for some $r$, just change one of these digits to obtain an $r'$ for which it is not), and hence we have a [[proof by contradiction]].


=--



## Related concepts

* [[compact topological space]]

* [[countably compact topological space]]

* [[paracompact topological space]]

* [[locally compact topological space]]

* [[compactly generated topological space]]


## References 

* {#BuskesRooij97} Buskes, van Rooij, _Topological Spaces: From  Distance to Neighbourhood_, Springer 1997

* {#SteenSeebach70} Lynn Steen, J. Arthur Seebach, _Counterexamples in Topology_, Springer-Verlag, New York (1970) 2nd edition,  (1978), Reprinted by Dover Publications, New York, 1995

* {#Patty08} Wayne Patty, _Foundations of Topology_, Jones and Bartlett Publishers (2008)

* {#Vermeeren10} [[Stijn Vermeeren]], _Sequences and nets in topology_, 2010 ([pdf](http://stijnvermeeren.be/download/mathematics/nets.pdf))


See also

* Wikipedia, _[Sequentially compact space](https://en.wikipedia.org/wiki/Sequentially_compact_space)_



[[!redirects sequentially compact space]]
[[!redirects sequentially compact spaces]]

[[!redirects sequentially compact]]
[[!redirects sequential compactness]]


[[!redirects sequentially compact metric space]]
[[!redirects sequentially compact metric spaces]]
