
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Category theory
+-- {: .hide}
[[!include category theory - contents]]
=--
#### Additive and abelian categories
+--{: .hide}
[[!include additive and abelian categories - contents]]
=--
#### Topos Theory
+-- {: .hide}
[[!include topos theory - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Idea

In a [discussion](http://www.mta.ca/~cat-dist/catlist/1999/atcat) with [[Vaughan Pratt]] on the categories mailing list, [[Peter Freyd]] gave a sharp and clever description of the commonalities and differences between [[abelian categories]] and [[topos]]es (or, in the first place, between abelian categories and [[pretopos]]es), by introducing a finitely axiomatized theory of "AT categories". Thus abelian categories and pretoposes are examples of AT categories; underscoring how much these structures have in common, Freyd's theory hews so closely to both of these two basic examples that in fact every AT category splits cleanly as a [[product]] of a pretopos part and an abelian part. 

Here, the properties held in common between abelian categories and pretoposes are all exactness conditions; in the AT set-up, the decisive difference between abelian categories and pretoposes is concentrated solely in the behavior of the [[initial object]] with respect to [[cartesian product]] (being in one case the cartesian monoidal unit, i.e. an element that is universally absorbed into any other, and in the other an absorbing element, i.e. an element that absorbs any other element into itself, aka a zero element or annihilating element). 

There is no research we know of on AT categories. One might say that they were invented by Freyd really for the sole theoretical purpose of demonstrating the commonalities and differences between abelian categories and pretopos categories, not because AT categories are found in nature. Indeed, a "typical" AT category is something of a mythological creature with the head of an abelian lion and the body of a pretopos dragon, and serves no purpose as such, even though pure lions and pure dragons themselves serve a purpose. Some of the axioms, particular axiom "AE" below, seem expressly designed to fuse them together in ad hoc fashion. 

## Definition

Freyd introduces some baseline assumptions on the categories in question: 

* [[finitely complete category|Finite completeness]], 

* Presence of an [[initial object]], 

* Presence of [[pushout|pushouts]] for pairs of [[morphism|arrows]] one of which is [[monomorphism|monic]], 

* Presence of pushouts for [[kernel pair]]s

Each of these assumptions obviously holds in any [[abelian category]] and in any [[pretopos]]. 

+-- {: .num_remark} 
###### Remarks 
If we introduce predicates to express these four baseline assumptions, such as a predicate formula $P(p, q; f, g)$ whose meaning is "$(p, q)$ is a pushout pair for pairs of arrows $(f, g)$", then the remaining AT axioms given below all have a simple logical structure: they can be expressed as [[Horn theory|Horn clauses]] in the language generated by the baseline predicates. The first 8 axioms are in fact universal Horn clauses in these predicates. 

This might look like a side comment for logicians, but it might also signal that Freyd intends to invoke, if pressed for details of proofs, one of a battery of representation theorems, such as the representation theorem for regular categories whose precise formulation is in terms of Horn theories -- see [[Categories, Allegories]] for examples. 

Furthermore, by choosing a *specific* initial object, a specific pullback for each pair of arrows with common target, etc., an AT category can be cast as a model for a certain [[essentially algebraic theory]]. In other words, such "algebraic AT categories" can be internalized in any finitely complete category. 
=-- 

The crucial difference between "abelianness" and "toposness" is concentrated in the following definition: 

+-- {: .num_defn}
###### Definition
Let $0$ be the initial object, and let $\pi_1: 0 \times X \to 0$, $\pi_2: 0 \times X \to X$ be the two product projections. We say $X$ is of **type T** if $\pi_1$ is an isomorphism, and **type A** if $\pi_2$ is an isomorphism.
=--

A pretopos will turn out to be precisely an AT category in which every object is of type T, and an abelian category will turn out to be an AT category where every object is of type A. 

Here then are the AT exactness axioms. Again, each of them is satisfied in every abelian category and in every pretopos, and according to Freyd's thesis, any exactness condition satisfied in both classes of categories is a logical consequence of this set of axioms. Some of Freyd's remarks in his original posting are included in parentheses. 

+-- {: .num_defn}
###### Definition

A category meeting the baseline assumptions above is an **AT category** if the following 8 axioms plus axiom "AE" are satisfied. 

1. The category is an effective [[regular category]]. ("Yes this can be stated as universal Horn conditions on pullbacks and the special pushouts mentioned above.")

1. The arrow $0 \to 1$ is monic. ("Note that it follows that all maps from $0$ are monic.")

1. If $i\colon A \to C$ is monic, then any pushout square 
$$\array{
A & \stackrel{i}{\to} & C \\
\downarrow & & \downarrow \\
B & \stackrel{j}{\to} & D
}$$
is also a pullback, and $j$ is monic. 

1. The functor $0 \times -$ preserves pushouts of kernel pairs, and pushouts of pairs of arrows one of which is monic. 

1. If $f\colon B \to 0 \times C$ is epic and
$$\array{
A & \to & B \\
\downarrow & & \downarrow f \\
0 & \to & 0 \times C
}$$
is a pullback, then it's also a pushout. 

1. In the full subcategory of type T objects, pushouts of pairs of morphisms, one of which is monic, are universal (i.e., stable under pullback). 

1. Define a functor $T$ by the pushout diagram 
$$\array{
0 \times X & \stackrel{\pi_1}{\to} & 0 \\
\pi_2 \downarrow & & \downarrow \\
X & \to & T X
}$$
Then $T$ preserves pullbacks. 

1. Given a morphism $f\colon X \to Y$, if $T f$ and $0 \times f$ are isomorphisms, then so is $f$. 

=--

This is the basic list of exactness assumptions which permit a sharp comparison between pretoposes and abelian categories. From this list alone one can prove that every AT category embeds faithfully in a product of a pretopos and an abelian category. To show that every AT category is _equivalent_ to such a product, Freyd appends the following axiom involving an existential Horn condition: 

+-- {: .num_defn #AxiomAE}
###### Definition
**axiom (AE)** 

For every object $X$, there is a map $\xi\colon T X \to X$ such that 
$$0 \times X \stackrel{\pi_1}{\to} X \stackrel{\xi}{\leftarrow} T X$$ 
is a coproduct diagram, and the canonical map $X \to T X$ is a retraction of $\xi$.  

=--


To bring actual toposes into the picture, Freyd adds some more axioms, but let's first take stock and see what this gives us so far. 


## Basic consequences of the AT axioms

+-- {: .num_prop}
###### Proposition
For any $X$ the unique map $0 \to X$ is monic. 
=--

+-- {: .proof}
###### Proof
By axiom 2, the map $0 \to 1$ is monic. The pullback-preserving functor $- \times X$ preserves monos, so 

$$0 \times X \stackrel{! \times 1_X}{\to} 1 \times X \cong X$$

(which is just the second projection $\pi_2: 0 \times X \to X$) is monic. The unique map $0 \to 0 \times X$ is monic since it has a retraction $\pi_1: 0 \times X \to0$. The result follows. 
=-- 

+-- {: .num_prop}
###### Proposition
Binary coproducts exist. 
=-- 

+-- {: .proof} 
###### Proof
Because we can take the pushout of a pair of monos $0 \to X$, $0 \to Y$. 
=-- 

+-- {: .num_prop}
###### Proposition
Coproducts are disjoint. 
=-- 

+-- {: .proof}
###### Proof
By axiom 3, the two coprojections $i_X \colon X \to X + Y$, $i_Y \colon Y \to X + Y$ are monic, and their pullback is initial. 
=-- 

## Category of type A objects is abelian

In this section we show that the full subcategory of type A objects forms an abelian category. 

+-- {: .num_lemma #tozero}
###### Lemma
An object is of type A if and only if there exists a map to $0$. 
=-- 

+-- {: .proof}
###### Proof
If $X$ is of type A, then we clearly have $X \cong 0 \times X \stackrel{\pi_1}{\to} 0$. Conversely, suppose there exists $p: X \to 0$. Note that since $0 \to 1$ is monic, there is at most one map $Y \to 0$ for any object $Y$. It follows quickly that maps $Y \to X$ are in natural bijective correspondence with maps $Y \to X \times 0$ by composition with $\pi_1: X \times 0 \to X$, so that $\pi_1$ is an isomorphism by the Yoneda lemma.
=--

+-- {: .num_prop #coreflective} 
###### Proposition 
The full subcategory of type A objects is coreflective. 
=-- 

+-- {: .proof} 
###### Proof 
By Lemma \ref{tozero}, the subcategory of type A objects in an AT category $C$ is equivalent to the subcategory $C/0 \hookrightarrow C/1 \simeq C$, which is the category of coalgebras for the functor $A(X) = 0 \times X$. Thus the category of type A objects is comonadic. 
=-- 

+-- {: .num_lemma}
###### Lemma
Objects of type A are closed under binary products, finite coproducts, subobjects, and quotient objects (= cokernels of kernel pairs). 
=-- 

+-- {: .proof}
###### Proof
This follows from the fact that the category of type A objects is the slice category $C/0$. 
=--

Before we prove the next lemma, recall that in a category with zero objects, a **kernel** of an arrow $f: A \to B$ is an equalizer of the pair $f, 0: A \stackrel{\to}{\to} B$. This is the same as a pullback 

$$\array{
K & \to & A \\
\downarrow & & \downarrow f \\
0 & \to & B
}$$

Cokernels are defined dually, and can be formulated dually as certain pushouts. Since pushouts along monos exist, we can take the cokernel of any mono, and in particular the cokernel of any kernel. 

+--{: .num_lemma}
###### Lemma
In the category of type A objects, every mono is the kernel of its cokernel, and every epi is the cokernel of its kernel. 
=--

+-- {: .proof}
###### Proof
Of course, $0$ is a zero object in the category of type A objects. If $i\colon A \to B$ is a mono in the category of type A objects, then the pushout 
$$\array{
A & \stackrel{i}{\to} & B \\
\downarrow & & \downarrow \\
0 & \to & coker(i)
}$$
exists and is also a pullback, by axiom 3, and hence $i$ is the kernel of its cokernel. Now suppose $f: A \to C$ is an epi in the category of type A objects. Since $0 \times C \cong C$, we have an epi $f\colon A \to 0 \times C$. Then, by axiom 5, the pullback 
$$\array{
ker(f) & \to & A \\
\downarrow & & \downarrow f \\
0 & \to & 0 \times C
}$$
is also a pushout, so $f$ is the cokernel of its kernel. 
=--

+-- {: .num_theorem}
###### Theorem
The category of type A objects is an abelian category. 
=--

+-- {: .proof}
###### Proof
Any category with zero objects, binary products and coproducts, and in which every mono is the kernel of its cokernel and every epi is the cokernel of its kernel, is in fact an abelian category. See Freyd-Scedrov, _Categories, Allegories_, 1.598 (p. 95). 
=--


## Category of type T objects is a pretopos

Now we show that the full subcategory of type T objects is a pretopos. It is clear that $0 \times 0 \cong 0$ (since $0 \to 1$ is monic), so $0$ is a type T object. 

+-- {: .num_lemma #exactlyone}
###### Lemma
If $A$ is type A and $T$ is type T, then there exists exactly one map $A \to T$. Type T objects are characterized by this property. 
=-- 

+-- {: .proof}
###### Proof
There is exactly one morphism $A \to 0$. Hence morphisms $A \to T$ are in bijection with maps $A \to 0 \times T \cong 0$, of which there is exactly one. For the second statement, suppose that $X$ has the property that there is exactly one map $A \to X$ for each type A object. Such objects $X$ are closed under products, and $0$ is such an object; therefore $0 \times X$ is such an object. On the other hand, $0 \times X$ is of type A since it projects to $0$. Hence there is at most one morphism $0 \times X \to 0 \times X$, and it follows that $0 \times X \to 0 \to 0 \times X$ is the identity, so that $0 \times X \cong 0$. Thus $X$ is of type T. 
=-- 

+-- {: .num_corollary #strict}
###### Corollary
The initial object $0$ is [[strict initial object|strict]] in the category of type T objects. 
=--

+-- {: .proof}
###### Proof
Given $T$ of type T and $T \to 0$, we know $T$ is type A, and therefore by Lemma \ref{exactlyone} there is exactly one map $T \to T$. Hence $T \to 0 \to T$ is the identity, and of course so is $0 \to T \to 0$. So $T$ is initial. 
=--

+-- {: .num_corollary #closed}
###### Corollary
The full subcategory of objects of type T is closed under products, coproducts, subobjects, and quotient objects.
=--

+-- {: .proof}
###### Proof
Closure under products and subobjects is immediate from Lemma \ref{exactlyone}. Closure under quotients and coproducts follows from axiom 4. 
=--

+-- {: .num_theorem}
###### Theorem
The full subcategory of objects of type T is a pretopos. 
=--

+-- {: .proof}
###### Proof
Corollary \ref{closed} gives finite completeness, coproducts, and quotients of kernel pairs. Axiom 6 gives that in the full subcategory of $T$ objects, pushouts along monos are stable under pullback, and the initial object is stable under pullback in the category of T objects, because it is strict by Corollary \ref{strict}. It follows that coproducts are universal in the category of T objects. They are also disjoint by an earlier result, so the category of T objects is extensive. It is also effective regular by axiom 1, hence a pretopos. 
=-- 


## Splitting into type A and type T objects 

In this section we show that every AT category $C$ is the product of the abelian category $C_A$ of type A objects and the pretopos $C_T$ of type T objects. 

Let us first observe that the coreflector (see Proposition \ref{coreflective}) 

$$0 \times {-}\colon C \to C_A$$ 

is left exact (as all coreflectors are), and 

* Preserves the initial object (by axiom 2), 

* Preserves pushouts of kernel pairs, and pushouts of pairs of arrows one of which is monic (axiom 4), 

* And therefore also preserves coproducts. 

A functor between AT categories which is left exact and which preserves such classes of finite colimits may be called a **morphism of AT categories**. Hence the coreflector is a morphism of AT categories. 

Next let us observe that the subcategory $C_T \hookrightarrow C$ is _reflective_; the reflector is the functor $T$ defined above by means of a suitable pushout. The reflector clearly preserves any colimits that exist, and preserves pullbacks (by axiom 7), so 

$$T\colon C \to C_T$$ 

is also a morphism of AT categories. Therefore we have a morphism of AT categories 

$$F = \langle 0 \times {-}, T \rangle\colon C \to C_A \times C_T$$ 

and now we wish to prove, under a suitable additional axiom (also satisfied by every abelian category and every pretopos), that this is an equivalence. 

+-- {: .num_lemma}
###### Lemma
The functor $F$ is faithful. 
=-- 

+-- {: .proof}
###### Proof
The functor $F$ is left exact and therefore preserves kernels. By axiom 8, $F$ reflects isomorphisms. It follows immediately from these two facts that $F$ is faithful. 
=--

+-- {: .num_remark}
###### Remark

With this result, Freyd's "first task" is complete: any AT category may be faithfully represented in a product of a pretopos and an abelian category. 

=--

At this point we bring in axiom **AE**, def. \ref{AxiomAE}, for its debut appearance. It may be helpful to consider that $T X$ is by definition the [[cokernel]] appearing in the exact sequence 

$$0 \times X \stackrel{\pi_2}{\to} X \to coker(\pi_2)$$ 

and that axiom AE asserts that this exact sequence splits (with splitting $\xi: coker(\pi_2) \to X$), in such a way that $X$ is the coproduct of the end terms. 

+-- {: .num_prop}
###### Proposition
The functor $F$ is full. 
=--

+-- {: .proof}
Suppose given maps $f: 0 \times X \to 0 \times Y$, $g: T X \to T Y$, and contemplate the diagram 
$$\array{
0 \times X & \stackrel{\pi_2}{\to} & X & \to & T X \\
f \downarrow & & & & \downarrow g \\
0 \times Y & \underset{\pi_2}{\to} & Y & \stackrel{\overset{\xi}{\leftarrow}}{\to} & T Y
}$$
Since $X = (0 \times X) + T X$, the two obvious arrows $0 \times X \to Y$, $T X \to Y$ combine to give an arrow $(f, g): X \to Y$. It is straightforward to check that $0 \times (f, g) = f$ (because the functor $0 \times -$ kills the type T summands) and that $T(f, g) = g$. 
=-- 

+-- {: .num_theorem} 
###### Theorem
The functor $F$ is an equivalence. 
=-- 

+-- {: .proof}
###### Proof
All that is left to check is that $F$ is essentially surjective, but this is clear because given a type A object $X$ and a type T object $Y$, we have $0 \times (X + Y) \cong X$ (use axiom 4 plus the fact that $0 \times Y \cong 0$), and 
$$T(X + Y) \cong T X + T Y \cong 0 + T Y \cong Y$$
which completes the proof. 
=--

This completes Freyd's "second task". 


## Topos-theoretic considerations 
 
In order to beef up the type T objects to a topos, Freyd imposes some extra structure on top of the AT axioms. Since it is now the topos axioms that are in the ascendant, I will christen these categories _TA categories_. 

Thus, a **TA category** is an AT category $C$ together with 

* Functions $P, E\colon Ob(C) \to Ob(C)$, 

* Functions $l, r\colon Ob(C) \to Mor(C)$, of the form $l X\colon E X \to P X$, $r X\colon E X \to X$,

* An operation $\Lambda$ which assigns to each pair of morphisms $f\colon R \to Y$, $g\colon R \to X$ (where $R$ and $Y$ are assumed to be type T), a morphism 
$\Lambda(f, g)\colon Y \to P X$. 

This data is to satisfy the following axioms: 

1. $\langle l X, r X \rangle: E X \to P X \times X$ is monic and $P X$, $E X$ are of type T, 

2. The composite of relations  
$$Y \stackrel{\Lambda(f, g)}{\to} P X \stackrel{(l X)^{op}}{\to} E X \stackrel{r X}{\to} X$$ 
is equal to 
$$Y \stackrel{f^{op}}{\to} R \stackrel{g}{\to} X,$$

3. If 
$$\array{
R & \stackrel{g}{\to} & E X \\
f \downarrow & & \downarrow l X \\
Y & \underset{h}{\to} & T X
}$$
is a pullback and $R$ is of type T, then $\Lambda(f, (r X) \circ g) = h$. 

Freyd: "Note that in the full category of type-T objects, $P$ yields
power-objects with $E$, $l$, $r$  naming the universal relations. (The third axiom provides the uniqueness condition.)" 

And: "In any abelian category the only type T object is the zero
object, which forces $P = E = 0$ for abelian categories."

And finally: "It's routine that both $0 \times {-}$ and $T$ preserve the new structure. We can now remove the existential from AE. Define $\xi\colon T X \to X$  as the image of $r X$. The third task is finished with:

1. For every $X$, $0 \times X \to X \stackrel{\xi}{\leftarrow} T X$ is a coproduct diagram." 

_This section is likely to be rewritten and cleaned up._


[[!redirects AT category]]
[[!redirects AT categories]]
[[!redirects AT-category]]
[[!redirects AT-categories]]

[[!redirects TA category]]
[[!redirects TA categories]]
[[!redirects TA-category]]
[[!redirects TA-categories]]