
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Model category theory
+--{: .hide}
[[!include model category theory - contents]]
=--
#### Topology
+--{: .hide}
[[!include topology - contents]]
=--
#### Homotopy theory
+--{: .hide}
[[!include homotopy - contents]]
=--
=--
=--

#Contents#
* table of contents
{:toc}

## Idea

Philosophically, [[model category|model structures]] allow one to [[localization|localize]] a [[category]] at a particular collection of [[category with weak equivalences|weak equivalences]], which one would like to formally invert.  

For [[topological space]]s, there are two natural candidates for the collection $W$ of weak equivalences: 

1. the [[weak homotopy equivalence]]s 

1. and the [[homotopy equivalence]]s.  

Both of these have accompanying model structures.  Interestingly, these two model structures can also be combined to form what's known as the _mixed_ model structure.

All of these model structures exist not only on the category of all topological spaces, but also on most [[convenient categories of topological spaces]].  Using a nice category instead is sometimes important, such as if we want the model structure to be [[monoidal model category|monoidal]].


## Definition

### Classical Quillen Model Structure
  {#QuillenModelStructure}

The first, and most prevalent, [[model category]] structure on [[Top]], called the _[[classical model structure on topological spaces]]_ ([Quillen67, II.3](#Quillen67)) has

* weak equivalences are the [[weak homotopy equivalences]];

* fibrations are the [[Serre fibrations]], maps which have the [[right lifting property]] with respect to all inclusions of the form $i_0 : D^n \hookrightarrow D^n \times I$ that include the $n$-disk as $D^n \times \{0\}$.

* cofibrations are the "[[retracts]] of [[relative cell complexes]]".

  
This is a [[cofibrantly generated model category]]. The cofibrations $C$ are generated by the set of [[boundary]] inclusions $S^{n-1} \hookrightarrow D^n$ for all $n \in \mathbb{N}$ in the sense that they are the smallest saturated class containing these morphisms. As a consequence, of Quillen's [[small object argument]], all cofibrations have the form described above, where a [[relative cell complex]] is a [[transfinite composition|transfinite composite]] of [[pushouts]] of [[coproducts]] of these generating maps.

This model structure is sometimes called the **[[Quillen model structure on topological spaces]]** or **$q$-model structure** on [[Top]].



### Hurewicz (or Strøm) Model Structure
 {#StromModelStructure}

A second model structure has 

* weak equivalences are the [[homotopy equivalences]];

* fibrations are the **[[Hurewicz fibration]]s**, which are defined to be maps that have the right lifting property with respect to _all_ inclusions $i_0 : A \hookrightarrow A \times I$ for any topological space $A$. 

* cofibrations are determined by these classes and are called the **closed [[Hurewicz cofibration]]s**.

This model structure is sometimes called the **Hurewicz model structure**, since it uses Hurewicz fibrations and cofibrations, or also the $h$-model structure, where $h$ can stand for either "Hurewicz" or "homotopy equivalence."  However, it is also sometimes called the [[Strøm model structure]], since it was first proven to exist by [[Arne Strøm]].

### Mixed Model Structure

From the definitions, [[Hurewicz fibration]]s are necessarily [[Serre fibration]]s. It is well-known that [[homotopy equivalence]]s are [[weak homotopy equivalence]]s. If we write $(C_1, F_1, W_1)$ for the classes of the first model structure and $(C_2, F_2, W_2)$ for the classes of the second, we have $W_2 \subset W_1$ and $F_2 \subset F_1$. 

In general given two model structures with these inclusions, we get a third **[[mixed model structure]]** $(C_m, F_2, W_1)$ where the cofibrations $C_m$ are determined by the other two classes.

On topological spaces, this model structure has 

* weak equivalences the [[weak homotopy equivalence]]s 

* fibrations the [[Hurewicz fibration]]s; 

*  cofibrant spaces (the [[m-cofibrant space]]s) are precisely those spaces that are homotopy equivalent to [[CW complex]]es.

## Properties

### Restriction to convenient categories of topological spaces
 {#OnNiceTopologicalSpaces}

For the discussion of the [[homotopy theory]] given by the model structure on topological spaces, it is necessary or at least useful to pass to [[convenient categories of topological spaces]].

+-- {: .num_defn}
###### Definition

Write

* $kTop \hookrightarrow Top$ for the [[full subcategory]] of [[k-spaces]];

* $CGTop \hookrightarrow Top$ for the full subcategory of [[compactly generated spaces]].

=--

+-- {: .num_prop}
###### Proposition

There is a [[model category]] structure $kTop_{Quillen}$ on $kTop$ in which a morphism is a cofibration, fibration or weak equivalence, respectively, precisely if it is so under the inclusion $kTop \hookrightarrow Top$. And this inclusion is the [[left adjoint]] in a [[Quillen equivalence]]

$$
  Top_{Quillen} \stackrel{\overset{}{\hookleftarrow}}{\underset{}{\to}}
  kTop_{Quillen}
  \,.
$$

=--

This appears for instance as ([Hovey, theorem 2.4.23](#Hovey))


+-- {: .num_prop}
###### Proposition

There is a [[model category]] structure $CGTop_{Quillen}$ on $CGTop$ in which a morphism is a cofibration, fibration or weak equivalence, respectively, precisely if it is so under the inclusion $CGTop \hookrightarrow Top$. And this inclusion is the [[right adjoint]] in a [[Quillen equivalence]]

$$
  CGTop_{Quillen} \stackrel{\overset{w}{\leftarrow}}{\underset{}{\hookrightarrow}}
  kTop_{Quillen}
  \,.
$$

=--

Notice that $Top_{Quillen}$ is _not_ a [[monoidal model category]], because $Top$ itself is not ([[cartesian closed category|cartesian]]) [[closed monoidal category|closed]].

+-- {: .num_prop}
###### Proposition

Both $kTop_{Quillen}$ and $CGTop_{Quillen}$ are [[symmetric monoidal category|symmetric]] [[monoidal model categories]].

=--

This appears as ([Hovey, prop. 4.2.11](#Hovey)).

+-- {: .num_prop}
###### Proposition

In fact $CGTop_{Quillen}$ is a [[cartesian closed model category]].
(see e.g [Berger-Moerdijk 03](#BergerMoerdijk03))

=--


### Relation between $Top_{Quillen}$ and $sSet_{Quillen}$

The [Quillen model structure](#QuillenModelStructure) $Top_{Qullen}$ is [[Quillen equivalence|Quillen equivalent]] to the standard (Quillen) [[model structure on simplicial sets]] via the total [[fundamental infinity-groupoid|singular complex]] and [[geometric realization]] functors.

$$
  (\vert-\vert \dashv Sing)
  : 
  Top_{Quillen} 
    \stackrel{\overset{|-|}{\leftarrow}}{\underset{Sing}{\to}} 
  sSet_{Quillen}
  \,.
$$

Since the standard [[model structure on simplicial sets]] is a [[presentable (infinity,1)-category|presentation]] of the [[(∞,1)-category]] [[∞Grpd]] of [[∞-groupoid]]s realized as [[Kan complex]]es, this identifies topological spaces with [[∞-groupoid]]s in an [[(∞,1)-category|(∞,1)-categorical]] sense. Notably it says that every $\infty$-groupoid is, up to equivalence, the [[fundamental ∞-groupoid]] of some topological space.

This statement is called the [[homotopy hypothesis]] (which here is a theorem). See there for more details.

### Relation between $Top_{Quillen}$ and $Top_{Strom}$

The identity functor constitutes a [[Quillen adjunction]]

$$
  (Id \dashv Id)
   : 
   Top_{Strom}
    \stackrel{\leftarrow}{\to}
   Top_{Quillen}
$$

between the [Quillen model structure](#QuillenModelStructure) and the [Strom model structure](#StromModelStructure) on $Top$. Here $Top_{Strom} \to Top_{Quillen}$ is the [[Quillen adjunction|right Quillen functor]].

## Related concepts

* [[homotopical structure on C*-algebras]]

## References 

The original "Quillen" or "q-" model structure is due to

* {#Quillen67} [[Dan Quillen]], chapter II, section 3 of _Homotopical algebra_, Lecture Notes in Mathematics __43__, Springer-Verlag 1967, iv+156 pp.

An expository, concise and comprehensive writeup is in

* [[Philip Hirschhorn]], _The Quillen model category of topological spaces_, 2015 ([arXiv:1508.01942](http://arxiv.org/abs/1508.01942))

Standard textbooks references include 

* {#Hovey} [[Mark Hovey]] _Model categories_ 

* Hirschhorn _Model categories and their localizations_.

* [[Kate Ponto]], [[Peter May]], section 17 of _More concise algebraic topology_ ([pdf](http://www.maths.ed.ac.uk/~aar/papers/mayponto.pdf))

For the "Hurewicz," "Strøm," or "h-" model structure:

* [[Arne Strøm]], _The homotopy category is a homotopy category_, Archiv der Mathematik 23 (1972)

For the "mixed" or "m-" model structure:

* Michael Cole, _Mixing model structures_, Topology Appl. 153 no. 7 (2006) [doi](http://dx.doi.org/10.1016/j.topol.2005.02.004).

The generalization to the [[model structure on topological operads]] is due to 

* {#BergerMoerdijk03} [[Clemens Berger]], [[Ieke Moerdijk]], _Axiomatic homotopy theory for operads_, Comment. Math. Helv. Vol. 78 (2003), no. 4 ([arXiv:math/0206094](http://arxiv.org/abs/math/0206094))
 


[[!redirects model category of topological spaces]]

[[!redirects model structures on topological spaces]]
[[!redirects model structures on Top]]

