
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Algebra
+--{: .hide}
[[!include higher algebra - contents]]
=--
#### Monoidal categories
+--{: .hide}
[[!include monoidal categories - contents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}

## Idea

The **symmetric algebra** $S V$ of a vector space is the [[free object|free]] [[commutative algebra]] over $V$.  

This construction generalizes to [[group representations]], [[chain complexes]], [[vector bundles]], [[coherent sheaves]], and indeed objects in any [[symmetric monoidal category|symmetric monoidal]]  [[linear category|linear categories]] with enough [[colimit|colimits]], where the tensor product distributes over those colimits (as in a [[2-rig]]).


## Explicit definition

We begin with the construction for vector spaces and then sketch how to generalize it.

### For vector spaces

Suppose $V$ is a [[vector space]] over a [[field]] $K$.  Then the **symmetric algebra** $S V$ is generated by the elements of $V$ using these operations:

*  addition and scalar multiplication
*  an associative binary operation $\cdot$

subject to these identities:

*  the identities necessary for $S V$ to be an [[associative algebra]]
*  the identity $v \cdot w = w \cdot v$ for all $v \in V$.

It then follows that $S V$ is a [[graded algebra]]
where $S^p V$ is spanned by $p$-fold products, that is, elements of the form 

$$v_1 \cdot \cdots \cdot v_p $$

where $v_1, \dots, v_p \in V$.  Clearly $S V$ is also [[commutative algebra|commutative]].

The symmetric algebra of $V$ is also denoted $Sym V$.   It is also called the **polynomial algebra**.  However we should carefully distinguish between polynomials _in_ the elements of $V$, which form the algebra $S V$, and polynomial functions _on_ the vector space $V$, which form the algebra $S(V^*)$.    In quantum physics, a similar construction for Hilbert spaces is known as the [[Fock space]].

### In general

More generally, suppose $C$ is any [[symmetric monoidal category]] and $V \in C$ is any object.  Then we can form the [[tensor power|tensor powers]] $V^{\otimes n}$.  If $C$ has countable coproducts we can form the [[coproduct]] 

$$  T V = \bigoplus_{n \ge 0} V^{\otimes n} $$

(which we write here as a [[direct sum]]), and if the tensor product distributes over these coproducts, $T V$ becomes a [[monoid]] object in $C$, with multiplication given by the obvious maps

$$   V^{\otimes p} \otimes V^{\otimes q} \to V^{\otimes (p+q)} $$

This monoid object is called the [[tensor algebra]] of $V$.

The [[symmetric group]] $S_n$ acts on $V^{\otimes n}$, and if $C$ is a [[linear category]] over a [[field]] of [[characteristic]] zero, then we can form the symmetrization map 

$$  p_A : V^{\otimes n} \to V^{\otimes n} $$

given by

$$ p_A = \frac{1}{n!} \sum_{\sigma \in S_n} \sigma $$

This is an [[idempotent]], so if idempotents split in $C$ we can form its [[cokernel]], called the $n$th **symmetric tensor power** or **symmetric power** $S^n V$.  The coproduct

$$  S V = \bigoplus_{n \ge 0} S^n V $$

becomes a monoid object called the **symmetric algebra** of $V$.

If $C$ is a more general sort of symmetric monoidal category, then we need a different construction of $S^n V$.  For example, if $C$ is a symmetric monoidal category with finite colimits, we can simply define $S^n V$ to be the [[coequalizer]] of the action of the symmetric group $S_n$ on $V^{\otimes n}$.  And if $C$ also has countable coproducts, we can define 

$$  S V = \coprod_{n \ge 0} S^n V $$

Then, if the tensor product distributes over these colimits (as in a [[2-rig]]), $S V$ will become a [[internalization|commutative monoid object]] in $C$.  In fact, it will be the _free_ commutative monoid object on $V$, meaning that any morphism in $C$

$$ V \to A \, , $$

where $A$ is a commutative monoid, factors uniquely as the obvious morphism

$$ V \to S V $$

followed by a morphism of commutative monoids

$$ S V \to A  \, ,$$

as in this commutative triangle:

$$ \array {
     &          & S V \\
     & \nearrow &                 & \searrow \\
   V &          & \longrightarrow &          & A
} $$

## Examples

+-- {: .num_example #SymmetricAlgebraInCoChainComplexes}
###### Example
**(symmetric algebra in [[chain complexes]] is [[differential graded-commutative algebra]])**

Let the ambient [[category]] be the [[category of cochain complexes]] over a [[ground field]] of [[characteristic zero]], regarded as a [[symmetric monoidal category]] via the [[tensor product of chain complexes]].

Then for $(V^\bullet, d)$ a [[cochain complex]], the symmetric algebra

$$
  Sym\left( (V^\bullet, d) \right)
  \;\in\; CMon( Ch^\bullet, \otimes )
$$

is the [[differential graded-commutative algebra]] whose underlying [[graded algebra]] is the [[graded-commutative algebra]] on $V^\bullet$, and whose [[differential]] is the original $d$, extended, uniquely, as a graded [[derivation]] of degree +1.

=--


## Properties

+-- {: .num_prop #CochainCohomologyOfSymmetricAlgebraOnCochainComplex}
###### Proposition

Let the ambient [[category]] be the [[category of cochain complexes]] over a [[ground field]] of [[characteristic zero]], regarded as a [[symmetric monoidal category]] via the [[tensor product of chain complexes]] and consider the [[differential graded-commutative algebra]] $Sym((V^\bullet,d))$ free on a cochain complex $(V^\bullet,d)$ from example \ref{SymmetricAlgebraInCoChainComplexes}. 

Then the [[cochain cohomology]] (of the [[forgetful functor|underlying]] cochain complex) of $Sym((V^\bullet,d))$ is the graded symmetric algebra on the [[cochain cohomology]] of $(V^\bullet,d)$:

$$
  H^\bullet\left( 
    Sym\left((V^\bullet,d)\right)
  \right)
  \;\simeq\;
  Sym\left( H^\bullet(V^\bullet,d) \right)
  \,.
$$

=--

See also [this MO discussion](https://mathoverflow.net/a/91243/381).


+-- {: .proof}
###### Proof

The symmetric algebra is equivalently the [[quotient]] of the [[tensor algebra]] by the [[symmetric group]] [[action]]. In [[characteristic zero]] this is equivalently [[invariants]] of the [[symmetric group]] [[action]], because here $V^G \to V \to V_G$ is a [[linear isomorphism]]:

$$
  Sym( (V^\bullet,d) )
  \;\simeq\;
  \underset{k \in \mathbb{N}}{\bigoplus}
   \left( (V^\bullet,d)^{\otimes_k}\right)^{\Sigma_k}
$$

We compute:

$$
  \begin{aligned}
    H^\bullet
    left(
      Sym( (V^\bullet,d) )
    \right)
    & \simeq
    H^\bullet\left(
      \underset{k \in \mathbb{N}}{\oplus}
       \left( (V^\bullet,d)^{\otimes_k}\right)^{\Sigma_k}
    \right)
  \end{aligned}
$$


Here the second-but-last step uses that for [[finite groups]] in [[characteristic zero]], taking [[invariants]] is compatible with passing to [[cochain cohomology]] ([this prop.](invariant#TakingInvariantsForFiniteGroupCommutesWithTaingHomologyInCharZero)):

The last step is the [[Künneth theorem]] for [[ordinary homology]] over a [[field]] ([this prop.](Künneth+theorem#InordinaryHomology)).


=--

## Related concepts

* [[symmetric algebra spectrum]]

## References

* [[Stacks Project]], [Tag 00DM](http://stacks.math.columbia.edu/tag/00DM).

* [[Bourbaki]], _Algèbre_, chap. III, § 6.

The [[symmetric algebra spectrum]] of the [[sphere spectrum]], and its structure as a [[Hopf ring spectrum]] is discussed in

* [[Neil Strickland]], [[Paul Turner]], _Rational Morava $E$-theory and $D S^0$_, Topology Volume 36, Issue 1, January 1997, Pages 137-151 ([pdf](http://hopf.math.purdue.edu/Strickland-PTurner/rme.pdf))


[[!redirects symmetric algebra]]
[[!redirects symmetric algebras]]
[[!redirects symmetric power]]
[[!redirects symmetric powers]]
[[!redirects symmetric tensor power]]
[[!redirects symmetric tensor powers]]

[[!redirects symmetric product]]
[[!redirects symmetric products]]

[[!redirects symmetric tensor algebra]]
[[!redirects symmetric tensor algebras]]
