#Contents#
* automatic table of contents goes here
{:toc}

## Definition 

By removing structure and properties from the notion of [[canonical hypergroup|hypergroup]], a **hypermonoid** is a set equipped with an associative multivalued multiplication. There are several equivalent ways of making this more precise: 

* A _hypermonoid_ is a monoid $M$ in the monoidal [[Pos]]-enriched category of sets and total ([[entire relation|entire]]) relations, where the tensor product of sets is cartesian product and the tensor product of relations $R: A \to B$, $S: C \to D$ is defined by the truth-value assignment 
$$(R \times S)((a, c), (b, d)) = R(a, b) \wedge S(c, d)$$ 
The unit $u: 1 \to M$ is assumed to be a well-defined relation (therefore a function). 

* A _hypermonoid_ is a $\mathbf{2}$-enriched [[promonoidal category]] structure on a discrete poset $S$, whose prounit is a singleton and whose promultiplication $S \times S \to P S$ takes values in $P_+(S)$ (nonempty subsets); 

* A _hypermonoid_ is a structure of [[quantale]] on a power set $P(S)$, whose unit is a singleton and where the quantale multiplication $\cdot$ satisfies $T \cdot U \neq \bot$ whenever $T, U \neq \bot$. 

(In the opinion of one of the article authors ([[Todd Trimble]]), one may legitimately ask what is the mathematical gain in restricting to total relations and in the condition that the unit is functional. Lifting these restrictions, one obtains the simpler notion of quantale.) 

## Examples 

### Special types

Analogous to how ordinary [[monoid]]s refine to [[group]]s and to [[ring]]s, hypermonoids refine to 

* [[hypergroup]]s 

* and [[hyperring]]s.

See there for more examples.

### Specific examples

#### Boolean Hecke algebra of a Coxeter group 

Let $W$ be a finite Coxeter group. A [[Coxeter group]] is _by definition_ a group presentation, generated by elements $s_1, \ldots, s_n$ and subject to relations of the form 

$$(s_i s_j)^{m_{i j}} = 1$$ 

where $m_{i j}$ is a collection of integers specified by a Coxeter diagram or Coxeter matrix, assumed symmetric and with $m_{i i} = 1$. We may rewrite the presentation as 

$$s_{i}^{2} = 1, \qquad s_i s_j \ldots = s_j s_i \ldots$$ 

where the words on either side of the second equation alternate between $s_i$ and $s_j$ and have length $m_{i j}$. 

The Boolean [[Hecke algebra]] of a Coxeter group $W$ is a quantale whose underlying sup-lattice is $P W$, and whose quantalic multiplication is uniquely determined by a hypermonoid structure which satisfies 

$$\{s_i\} \cdot \{s_i\} = \{s_i, 1\}, \qquad s_i s_j \ldots = s_j s_i \ldots$$ 

and described as follows: 

* If $w$ is a reduced word $s_{i_1} s_{i_2} \ldots s_{i_k}$, then the hypermonoid product $\prod_j s_{i_j}$ is $\{[w]\}$ where $[w]$ is the value of $w$ in $W$; 

* Given a generator $s$ and a reduced word $w = w' s$ in the Coxeter group presentation, define $\{[w]\} \cdot \{s\} = \{[w' s], [w']\}$. 

It may be shown that this recipe gives a well-defined map $W \times W \to P(W)$ that gives a hypermonoid structure. 

This description appears to depend on combinatorial technicalities of Coxeter groups, but it can be made more conceptual if the Coxeter group $W$ is seen as arising from a BN-pair. A [[BN-pair]] (see also references below) is given by a simple [[algebraic group]] $G$, a Borel subgroup $B$, and a normalizer $N$ of a maximal torus $T$ for which $T = B \cap N$ and $G = B N$, satisfying some conditions. The corresponding Boolean Hecke algebra may be defined to be the quantale whose elements are $G$-equivariant sup-preserving maps 

$$P(G/B) \to P(G/B)$$ 

where the quantale multiplication is composition. As a sup-lattice, this quantale is isomorphic to $P(B\backslash G/B)$, the power set of the set of [[double cosets]] $B g B$. According to the general theory of BN-pairs, the double cosets are in bijection with the elements of a Coxeter group $W$ given by $N/T$; the bijection is given by the well-defined map 

$$W \to B \backslash G/B: w \mapsto B w B$$

Hence $P(W) \cong P(B\backslash G/B)$ as sup-lattices, but the algebra structure on $P(B \backslash G/B)$ can be regarded as a deformation of the group algebra structure. The unit is the singleton $\{B e B\}$. 

#### Other examples 

Hecke algebras are a [[deformation theory|deformation]] of the Coxeter group algebra. Under certain conditions, other deformations of group or monoid algebras of monoids $M$ can be exploited to yield hypermonoids. 

For example, if the multiplication table of such a deformation is given by equations 

$$g_i g_j = \sum_k a_{i j}^{k} g_k$$ 

where all the $a_{i j}^k$ are nonnegative rational numbers of which at least one is nonzero for each pair $i, j$, then we may obtain a hypermonoid by replacing each positive $a_{i j}^{k}$ by $1$ and interpreting the sum as a join in the Boolean algebra $P(M)$. This procedure may be termed "Booleanization". For example, in the case of Hecke algebras, we have 

$$s_{i}^{2} = \frac{q-1}{q} s_i + \frac1{q}$$ 

and if the parameter $q$ is specialized to positive integer values (e.g., powers of primes), one may apply Booleanization to obtain the Boolean Hecke algebra. 

In general the principle is this: if the structure coefficients $a_{i j}^{k}$ belong to a [[rig]] $A$, so that we have a deformation $A[M]_d$ of a monoid rig, and if one is provided with a rig homomorphism $p: A \to\mathbf{2} = (\{0, 1\}, + = \vee, \cdot = \wedge)$ then there is a Booleanized hypermonoid structure defined by the composite 

$$M \times M \stackrel{mult}{\to} A[M]_d \cong A \otimes_A A[M]_d \stackrel{p \otimes_A 1}{\to} \mathbf{2} \otimes_A A[M]_d \cong \mathbf{2}[M]_d \hookrightarrow P(M)$$ 

For instance, there is a unique rig homomorphism $p: \mathbb{Q}_+ \to \mathbf{2}$ from the rig of nonnegative rational numbers. 

## References 

* [[Todd Trimble]],  _[Notes on BN-pairs and Boolean Hecke algebras](http://math.ucr.edu/home/baez/trimble/BN-pairs_and_Boolean_Hecke_algebras.html)_  (2005) 


[[!redirects hypermonoids]]