
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Topos Theory
+-- {: .hide}
[[!include topos theory - contents]]
=--
#### Topology
+-- {: .hide}
[[!include topology - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Idea and motivation

A _locale_ is, intuitively, like a [[topological space]] that may or may not have enough [[points]] (or even any points at all).  It contains things we call [[open subspaces]] but there may or may not be enough points to distinguish between open subspaces.  An open subspace in a locale can be regarded as conveying a bounded amount of information about the (hypothetical) points that it contains.

For example, there is a locale of all [[surjections]] from [[natural numbers]] (thought of as forming the [[discrete space]] $N$) to [[real numbers]] (forming the [[real line]] $R$): the _[[locale of real numbers]]_.  This local has no points, since there are no such surjections, but it contains many nontrivial open subspaces; these open subspaces are generated by a family parametrised by $n\colon N$ and $x\colon R$; the basic open associated to $n$ and $x$ may be described as $\{f\colon N \twoheadrightarrow R \;|\; f(n) = x\}$.

Every topological space can be regarded as a locale (with some lost information if the space is not [[sober space|sober]]). The locales arising this way are the _[[topological locale|topological]]_ or _spatial_ locales.  Conversely, every locale induces a topology on its set of points, but sometimes a great deal of information is lost; in particular, there are many different locales whose set of points is [[empty set|empty]].

One motivation for locales is that since they take the notion of open subspace as basic, with the points (if any) being a derived notion, they are exactly what is needed to define [[sheaves]].  The notion of sheaf on a topological space only refers to the open subspaces, rather than the points, so it carries over word-for-word to a definition of sheaves on locales.  Moreover, passage from locales to their [[toposes]] of sheaves is a [[full and faithful functor]], unlike for topological spaces.

Another advantage of locales is that they are better-behaved than topological spaces in alternative [[foundations of mathematics]], including mathematics without the [[axiom of choice]], more generally [[constructive mathematics]], or mathematics [[internalization|internal]] to an arbitrary [[topos]].  For example, constructively the topological space $[0,1]$ need not be [[compact space|compact]], but the _locale_ $[0,1]$ is always compact (in a suitable sense).  It follows that the locale $[0,1]$, and hence also the locale $R$ of real numbers, is not necessarily spatial.  When it fails to be spatial, because there are "not enough real numbers," the locale or real numbers is generally a better-behaved object than the topological space of real numbers.


## Definitions

Recall that a **[[frame]]** $A$ is a [[partial order|poset]] with all [[join|joins]] and all finite [[meet|meets]] which satisfies the _infinite distributive law_:
$$ x \wedge (\bigvee_i y_i) = \bigvee_i (x\wedge y_i) .$$
A **frame [[homomorphism]]** $\phi\colon A\to B$ is a function which preserves finite meets and arbitrary joins.  Frames and frame homomorphisms form a [[category]] [[Frm]].

Note: By the [[adjoint functor theorem]] (AFT) for posets, a frame also has all meets (at least assuming that it is a [[small set]], or more generally that we allow [[predicative mathematics|impredicative quantification]] over it), but a frame homomorphism need not preserve them.  Similarly, by the AFT, a frame is automatically a [[Heyting algebra]], but again a frame homomorphism need not preserve the [[Heyting implication]].

By definition, the [[category]] [[Locale]] of **locales** is the [[opposite category|opposite]] of the category of frames
$$
  Locale \coloneqq Frm^{op}
  \,.
$$
That is, a locale $X$ "is" a frame, which we often write as $O(X)$ and call "the frame of open subspaces of $X$", and a **[[continuous map]]** $f\colon X \to Y$ of locales is a frame homomorphism $f^*\colon O(Y) \to O(X)$. If you think of a frame as an algebraic structure (a [[lattice]] satisfying a completeness condition), then this is an example of the [[duality]] of [[space and quantity]].

It is also possible to think of a continuous map $f\colon X \to Y$ as a map of [[posets]] $f_*\colon O(X) \to O(Y)$: a [[function]] that preserves all [[meets]] (and therefore is [[monotone function|monotone]] and has a [[left adjoint]] $f^*\colon O(Y) \to O(X)$) and such that the left adjoint $f^*$ preserves all finite meets.  This has the arrow pointing in the "right" direction, at the cost of a less direct definition.  (In [[predicative mathematics]], we must explicitly add into this definition that $f_*$ has a left adjoint; compare the definition of [[geometric morphism]] one level up.)

This category is naturally enhanced to a [[2-category]]:
+-- {: .num_defn}
###### Definition

The [[2-category]] [[Locale]] has

* as [[objects]] $X$ [[frames]] $O(X)$;

* as [[morphisms]] $f\colon X \to Y$ frame homomorphisms $f^*\colon O(Y) \to O(X)$;

* a unique [[2-morphism]] $f \Rightarrow g$ whenever for all $U \in O(Y)$ we have $f^*(U) \leq g^*(U)$.
=--
(See for instance [Johnstone, C1.4, p. 514](#Johnstone).)

Since [[parallel morphisms|parallel]] $2$-morphisms are equal, this [[2-category]] is in fact a [[(1,2)-category]]: a [[Poset]]-[[enriched category]].


## Subsidiary notions
{#Subsidiaries}

### Open and closed subspaces

Given a locale $X$, the elements of the frame $O(X)$ are traditionally thought of as being the [[open subspaces]] of $X$ and are therefore called the __opens__ (or __open subspaces__, __open parts__, or __open sublocales__) of $X$.  However, one may equally well view them as the [[closed subspaces]] of $X$ and call them the __closeds__ (or __closed subspaces__, __closed parts__, or __closed sublocales__) of $X$.  When viewed as closed subspaces, the [[opposite relation|opposite]] containment relation is used; thus $O(X)$ is the __frame of opens__ of $X$, while the [[opposite poset]] $O(X)^{op}$ is the __coframe of closeds__ of $X$.

An open subspace may be thought of as a potentially *verifiable* property of a hypothetical point of the space $X$.  Thus we may verify the [[intersection]] of two open subspaces by verifying both properties, and we may verify the [[union]] of any family of open subspaces by verifying at least one of them; but it may not necessarily make sense to verify the intersection of infinitely many open subspaces, because this would require us to do an infinite amount of work.  (The [[meet]] of an arbitrary family of open subspaces does exist, but the construction is impredicative, and it does not match the meet within the lattice of all subspaces.)

[[de Morgan duality|Dually]], a closed subspace may be thought of as a potentially *refutable* property.  Thus we may refute the union of two closed subspaces by refuting both of them, and we may refute the intersection of any family of closed subspaces by refuting at least one of them; but it may not necessarily make sense to refute the union of infinitely many closed subspaces.  (Again, the [[join]] of an arbitrary family of closed subspaces does not work right.)

If one views an element of $O(X)$ as a [[subspace]] of $X$, one usually means to view it as an open subspace, but we have seen that one may also view it as a closed subspace.  This is given by two different maps (one covariant and a frame homomorphism, one contravariant and a coframe homomorphism) from $O(X)$ to the lattice of all subspaces of $X$.  See [[sublocale]] for further discussion.


### Points

As a locale, the __abstract [[point]]__ is the locale $q$ whose frame of opens is the frame of [[truth values]] (classically $\{\bot \lt \top\}$).  This is the [[terminal object]] in $Locale$, since we must have (for $f\colon X \to 1$) $f^*(\top) = \top_X$ and $f^*(\bot) = \bot_X$ (and most generally $f^*(p) = \bigvee \{\top_X \;|\; p\}$, since $p = \bigvee \{\top \;|\; p\}$).

Given a locale $X$, a __concrete [[point]]__ of $X$ may be defined in any of the following equivalent ways:

1.  A point of $X$ is a [[continuous map]] $f\colon 1 \to X$;
2.  Unravelling this in terms of $f^*\colon O(X) \to O(1)$ and viewing this as a [[characteristic function]], a point of $X$ is a [[completely prime filter]] in $O(X)$;
3.  Unravelling (1) in terms of $f_*\colon O(1) \to O(X)$, which classically (using [[excluded middle]]) is determined by $f_*(\bot)$, a point of $X$ is a [[prime element]] of $O(X)$.

Definition (3) is simpler than (2), being an element of $O(X)$ satisfying a finitary condition rather than a subset of $O(X)$ satisfying an infinitary condition.  However, it doesn\'t work in [[constructive mathematics]], which provides much (but by no means all) of the motivation for studying locales.


## Properties

### Categories of internal locales
 {#CategoryOfLocales}

+-- {: .num_prop}
###### Proposition

The category [[Locale]]$(E)$ of locales [[internalization|internal to]] a [[topos]] $E$ is equivalent to the category of [[localic geometric morphisms]] $Sh_{E}(\Sigma) \to E$ in [[Topos]].

$$
  Locale(E) \simeq (Topos/E)_{loc}
  \,.
$$
=--

See [[localic geometric morphism]] for more.


+-- {: .num_prop}
###### Proposition

For every locale $X$, the category $Locale(Sh(X))$ of locales internal to the [[sheaf topos]] over $X$ is equivalent to the [[overcategory]] $Locale/X$

$$
  \mathcal{I}\colon Locale/X \stackrel{\simeq}{\to} Locale(Sh(X)) 
  \,.
$$
=--

This appears as [Johnstone, theorem C1.6.3](#Johnstone).

+-- {: .num_prop}
###### Proposition

For every morphism of locales $f\colon Y \to X$ the [[sheaf topos]] $Sh(Y)$ is equivalent as a topos over $Sh(X)$ to the topos $Sh_{Sh(X)}(\mathcal{I}(Y))$ of internal sheaves over the internal locale $\mathcal{I}(Y) \in Sh(X)$

$$
  Sh(Y) \simeq Sh_{Sh(X)}(\mathcal{I}(Y))
  \,.
$$
=--

This appears as [Johnstone, scholium C1.6.4](#Johnstone).



### Relation to topological spaces
 {#RelationToTopologicalSpaces}

Every [[topological space]] $X$ has a [[frame of opens]] $O(X)$, and therefore gives rise to a locale $X_L$.  For every [[continuous function]] $f\colon X \to Y$ between topological spaces, the [[preimage|inverse image]] map $f^{-1}\colon O(Y) \to O(X)$ is a frame homomorphism, so $f$ induces a continuous map $f_L\colon X_L \to Y_L$ of locales.  Thus we have a [[functor]] 

$(-)_L\colon$ [[Top]] $\to$ [[Loc|Locale]].

Conversely, if $X$ is any locale, we define a **[[point]]** of $X$ to be a [[continuous map]] $1 \to X$.  Here $1$ is the [[terminal object|terminal]] locale, which can be defined as the locale $1_L$ corresponding to the terminal space.  Explicitly, we have $O(1) = P(1)$, the [[powerset]] of $1$ (the initial frame, the set of [[truth values]], which is $2$ classically or in a [[Boolean topos]]).  Since a frame homomorphism $O(X) \to P(1)$ is determined by the preimage of $1$ (the [[true]] truth value), a point can also be described more explicitly as a _[[completely prime filter]]_: an upwards-closed subset $F$ of $O(X)$ such that $X \in F$ ($X$ denotes the [[top element]] of $O(X)$), if $U,V \in F$ then $U \cap V \in F$, and if $\bigcup_i U_i \in F$ then $U_i \in F$ for some $i$.

The elements of $O(X)$ induce a [[topological structure|topology]] on the set of points of $X$ in an obvious way, thereby giving rise to a topological space $X_P$.  Any continuous map $f\colon X \to Y$ of locales induces a continuous map $f_P\colon X_P \to Y_P$ of spaces, so we have another functor 

$(-)_P\colon Locale \to Top$.

One finds that $(-)_L$ is [[left adjoint]] to $(-)_P$.

In fact, this is an [[idempotent adjunction]]:

+-- {: .num_prop #TopLocAdjunction}
###### Proposition

The categories [[Top]] of [[topological spaces]] and [[Loc|Locale]] of locales are related by an [[idempotent adjunction]].

$$
  (
    (-)_L \dashv (-)_P
  )
  \colon
  Top
  \;
    \underoverset
      {\underset{(-)_P}{\longleftarrow}}
      {\overset{(-)_L}{\longrightarrow}}
      {\bot}  
  \;
  Locale
  \,.
$$

=--

This appears for instance as ([MacLaneMoerdijk, theorem IX.3 1](#MacLaneMoerdijk)) or as ([Johnstone, lemma C.1.2.2](#Johnstone)).

Therefore the [[adjunction]] restricts to an [[equivalence of categories|equivalence]] between the fixed subcategories on either side.  

+-- {: .num_defn}
###### Definition

A [[topological space]] $X$ with $X \cong X_{L P}$ is called **[[sober space|sober]]**.

A locale with $X \cong X_{P L}$ is called **[[spatial locale|spatial]]** or **topological**; one also says that it has **enough points**.
=--

see also MO [here](http://math.stackexchange.com/a/1904289/58526)

+-- {: .num_cor}
###### Corollary

The [[adjunction]] from prop. \ref{TopLocAdjunction} exhibits [[sober topological spaces]] as a [[coreflective subcategory]] of [[Locale]]

$$
  (
    (-)_L \dashv (-)_P
  )
  \colon
  SoberTop
    \underoverset
      {\underset{(-)_P}{\leftarrow}}
      {\overset{(-)_L}{\hookrightarrow}}
      {\bot}
  Locale
$$

and this restricts to an 
[[equivalence of categories]] between the [[full subcategory]] of locales with enough points, and that of [[sober topological spaces]].
=--

This appears for instance as ([MacLaneMoerdijk, corollary IX.3 4](#MacLaneMoerdijk)).

Consequently, we often identify a sober topological space and the corresponding topological locale.


### Relation to toposes -- localic reflection
 {#RelationToToposes}

The notion of [[Grothendieck topos]] can be seen as a [[categorification]] of the notion of locale, by relating both notions to the notion of [[total category|lex totality]]: 

+-- {: .num_prop} 
###### Proposition

A [[poset]] $P$ is a [[frame]] if and only if the [[Yoneda embedding]]

$$
  y \colon P \to \mathbf{2}^{P^{op}}
$$ 
has a [[exact functor|left exact]] [[left adjoint]]. (Here the poset $\mathbf{2}$ of [[truth values]] is the base of enrichment for posets seen as [[enriched categories]].) 
=--

The analogous result for toposes involves a bit of 
[[set theory]]: under [[ZFC]] plus the existence of a [[strong inaccessible cardinal]] $\kappa$, the foundational assumption of MacLane in _[[Categories for the Working Mathematician]]_, call a category _[[moderate category|moderate]]_ if its set of morphisms has size $\kappa$. For example, $Set$ is moderate.

+-- {: .num_prop}
###### Proposition 
([Street](#Street)) 

A moderate [[locally small category]] $C$ is a [[Grothendieck topos]] if and only if the [[Yoneda embedding]] 
$$y \colon C \to Set^{C^{op}}$$ 
has a [[left exact functor|left exact]] [[left adjoint]]. 
=--

These results emphasize frames/toposes as algebras, where the morphisms are left exact left adjoints. The [[right adjoints]] to such morphisms are called [[geometric morphism|geometric morphisms]], and emphasize locales/toposes as [[spaces]]. This analogy, which plays an important but mostly tacit role in [Joyal and Tierney](#JT), can be developed further along the following lines. 

The [[frame of opens]] $O(X)$ corresponding to a locale $X$ is naturally a [[site]]:

+-- {: .num_defn}
###### Definition

Given a locale $X$, with [[frame of opens]] $O(X)$, say that a family of [[morphisms]] $\{U_i \to U\}$ in $O(X)$ is a [[cover]] if $U$ is the [[join]] of the $U_i$:

$$
  U = \vee_i U_i
  \,.
$$
=--

+-- {: .num_prop}
###### Proposition

This defines a [[coverage]] on $O(X)$ and hence makes it a [[site]].
=--

See for instance ([MacLaneMoerdijk, section 5](#MacLaneMoerdijk)).

+-- {: .num_defn}
###### Definition

For $X$ a locale, write
$$
  Sh(X) \coloneqq Sh(O(X))
$$
for the [[sheaf topos]] over the category $O(X)$ equipped with the above canonical structure of a [[site]].
=--

Write [[Topos]] for the category of [[Grothendieck toposes]] and [[geometric morphisms]].

+-- {: .num_prop}
###### Proposition

This construction defines a [[full and faithful functor]] $Sh(-) : $ [[Locale]] $\to$ [[Topos]].
=--

This appears for instance as [MacLaneMoerdijk, section IX.5 prop 2](#MacLaneMoerdijk).

+-- {: .num_defn}
###### Definition

A topos in the [[image]] of $Sh(-)\colon Locale \to Topos$ is called a _[[localic topos]]_.
=--

+-- {: .num_prop}
###### Proposition

The functor $Sh(-)\colon Locale \to Topos$ has a [[left adjoint]] 
$$
  L\colon Topos \to Locale
$$
given by sending a [[topos]] $\mathcal{E}$ to the locale that is formally dual to the [[frame]] of [[subobjects]] of the [[terminal object]] of $\mathcal{E}$:
$$
  O(L(\mathcal{E})) \coloneqq Sub_{\mathcal{E}}(*)
  \,.
$$
=--

This appears for instance as [MacLaneMoerdijk, section IX.5 prop 3](#MacLaneMoerdijk).

The functor $L$ here is also called **localic reflection**.

In summary this means that locales form a [[reflective subcategory]] of [[Topos]]:
$$ 
  Locale \stackrel{\overset{L}{\leftarrow}}{\hookrightarrow}
  Topos
  \,.
$$

In fact this is even a genuine [[full sub-2-category]]: 
+-- {: .num_prop}
###### Proposition

For all $X,Y \in $ [[Locale]] the [[2-functor]] $Sh\colon$ [[Locale]] $\to$ [[Topos]] induces an [[equivalence of categories]]
$$
  Sh\colon Locale(X,Y) \stackrel{\simeq}{\to} Topos(Sh(X), Sh(Y))
  \,.
$$
=--

This appears as ([Johnstone, prop. C1.4.5](#Johnstone)).

+-- {: .num_prop}
###### Proposition

The [[poset of subobjects]] $Sub_{\mathcal{E}}(*)$ of the terminal object of $\mathcal{E}$ is equivalent to the full [[subcategory]] $\tau_{\leq -1}(\mathcal{E})$ of $\mathcal{E}$ on the $(-1)$-[[truncated]] objects of $E$:
$$
  Sub_{\mathcal{E}}(*) \simeq \tau_{\leq -1} \mathcal{E}
  \,.
$$
=--

+-- {: .proof}
###### Proof

A [[(-1)-truncated]] sheaf $X$ is one whose values over any object are either the [[(-2)-groupoid|singleton set]], or the [[empty set]]

$$
  X(X) \in \{*, \emptyset\} = \subset Set
  \,.
$$

A [[monomorphism]] of [[sheaves]] is a [[natural transformation]] that is degreewise a monomorphism of sets (an [[injection]]). Therefore the [[subobjects]] of the [[terminal object|terminal]] sheaf (that assigns the singleton set to every object) are precisely the sheaves of this form.
=--

We may think of a [[frame]] as a [[Grothendieck (0,1)-topos]]. Then localic reflection is reflection of [[Grothendieck toposes]] onto $(0,1)$-toposes and is given by $(-1)$-truncation: for $X$ a locale, $Sh(X)$ the corresponding [[localic topos]] and $\mathcal{E}$ any Grothendieck topos we have a natural equivalence
$$
  Gr1Topos( \mathcal{E},  Sh X) \simeq Gr(0,1)Topos(\tau_{\leq -1} \mathcal{E}, O(X))
$$
which is
$$
  \cdots \simeq Frame(O(X), Sub_{\mathcal{E}}(*))
  \simeq
  Locale(L \mathcal{E} , X)
  \,.
$$

This is a small part of a pattern in [[higher topos theory]], described at [[n-localic (∞,1)-topos]].


## Examples

* [[the locale of real numbers]]

* [[Cantor space]]



## Related concepts

* The notion of locale may be identified with that of a [[Grothendieck topos|Grothendieck]] [[(0,1)-topos]]. See [[Heyting algebra]] for more on this.

* An [[ionad]] is to a [[topological space]] as a [[Grothendieck topos]] is to a [[locale]].

* A [[group object]] [[internalization|internal]] to locales or an [[internal groupoid]] in locales is a [[localic group]] or [[localic groupoid]], respectively. 

There is also a notion of [[internal locale]], see also [[internal site]].


* [[topological space]], [[topological locale]]

* [[ionad]]

* [[topos]]

* [[profinite space]], [[profinite reflection]]

* [[localic homotopy theory]]

## References 

An introduction to and survey of the use of locales instead of topological spaces ("[[point-free topology]]") is in

* {#Johnstone83} [[Peter Johnstone]], _The point of pointless topology_ ,  Bull. Amer. Math. Soc. (N.S.) Volume 8, Number 1 (1983), 41-53. ([Bulletin AMS](http://www.ams.org/bull/1983-08-01/S0273-0979-1983-15080-2/home.html), [Euclid](http://projecteuclid.org/euclid.bams/1183550014))

This is, in its own words, to be read as the trailer for the book

*  [[Peter Johnstone]], _[[Stone Spaces]]_, Cambridge Studies in Advanced Mathematics __3__, Cambridge University Press 1982. xxi+370 pp. [MR85f:54002](http://www.ams.org/mathscinet-getitem?mr=698074), reprinted 1986.


that develops, among other things, much of standard [[topology]] entirely with the notion of locale used in place of that of [[topological space]]s. See [[Stone Spaces]] for details.

Other textbook accounts include

* [[Francis Borceux]], volume 3, chapter 1 of _[[Handbook of Categorical Algebra]]_, 

* {#Johnstone} [[Peter Johnstone]], part C (volume 2) _[[Elephant|Sketches of an elephant: a topos theory compendium]]_.
 
* {#MacLaneMoerdijk} [[Saunders MacLane]], [[Ieke Moerdijk]], _[[Sheaves in Geometry and Logic]]_


* Jorge Picado, Aleš Pultr, _Frames and Locales.  Topology without points_, Birkhäuser (2012)

and

* [[Steve Vickers]], _Topology via logic_, Cambridge University Press (1989)

where the latter develops topology from the point of view of its [[internal logic]].

An introductory survey is

* Jorge Picado, Aleš Pultr, Anna Tozzi, _Locales_ , pp.49-101 in Pedicchio&Tholen (eds.), _Categorical Foundations_ , CUP 2004. ([draft](http://www.mat.uc.pt/~picado/publicat/Chapter2.pdf))

See also

* [[eom]], _[Locale](https://www.encyclopediaofmath.org/index.php/Locale)_




Lex totality is the subject of an article of Street, 

* {#Street} [[Ross Street]], _Notions of Topos_, Bull. Australian Math. Soc. 23 (1981), 199-208. 


The connection between locales and toposes via lex totality plays a tacit role throughout the influential monograph 

* {#JT} [[André Joyal]] and [[Myles Tierney]], _An Extension of the Galois Theory of Grothendieck_, Memoirs of the American Mathematical Society 51 (1984). 



[[!redirects locale]]
[[!redirects locales]]

[[!redirects internal locale]]
[[!redirects internal locales]]

[[!redirects localic reflection]]
[[!redirects localic reflections]]

[[!redirects locale theory]]