## Definition ## 

A **(graded) quadratic algebra** is an $\mathbb{N}$-graded algebra $A$ which as a [[graded algebra]] admits a presentation 

$$A \cong T(V)/I$$ 

where $T(V)$ is the [[tensor algebra]] of a finite-dimensional [[vector space]] $V$ of degree 1, and $I$ is a ideal generated by a space $R \subseteq V \otimes V$ of homogeneous elements of degree 2 in $T(V)$. Observe that $V$ and $R$ are uniquely determined by $A$: $V = A_1$, and if $I$ is the kernel of the canonical algebra map $T(A_1) \to A$, then $R = I_2$. It is often convenient to identify quadratic algebras with such pairs $(V, R)$. 

A morphism of quadratic algebras is just a morphism as graded algebras. Alternatively, a morphism of quadratic algebras $f: A \to B$ determines and is determined by a linear map $f_1: A_1 \to B_1$ such that $(f \otimes f)(R_A) \subseteq R_B$. 

## Examples 

1. The tensor algebra $T(V)$ ($V$ finite-dimensional) is of course quadratic. 

1. The [[symmetric algebra]] $S(V)$ is quadratic. 

1. The [[Grassmann algebra]] $\Lambda(V)$ is quadratic. 

1. Extrapolating from the first three examples, a [[Koszul algebra]] is quadratic. 

1. For many examples of [[quantum group|quantum groups]], for example quantum $GL_2$, the underlying algebra is quadratic. See the reference by Manin for further examples. 

## Quadratic dual and Manin's monoidal products 

If $(V, i: R \hookrightarrow V \otimes V)$ defines a quadratic algebra, its **quadratic dual** is defined by the pair $(V^*, R^\perp)$, where $R^\perp$ is the kernel of the composite 

$$V^* \otimes V^* \cong (V \otimes V)^* \stackrel{i^*}{\to} R^*$$ 

In the literature where it commonly appears, the dual of a quadratic algebra $A$ is usually denoted $A^!$. There is a canonical isomorphism $A \cong A^{!!}$. It was first observed by Yuri Manin that this is the duality operator for a [[star-autonomous category|$*$-autonomous]] structure on the category of quadratic algebras: 

* The monoidal product of $(V, R_A)$ and $(W, R_B)$ is defined by $(V \otimes W, \sigma(R_A \otimes R_B)$ where $\sigma$ refers to the canonical interchange isomorphism 
$$V \otimes V \otimes W \otimes W \cong V \otimes W \otimes V \otimes W$$ 
(writing as if the tensor product were strict, as justified by Mac Lane's coherence theorem). Manin's notation for this is $A \bullet B$. The monoidal unit is the free algebra on one generator in degree 1. 

* The dual monoidal product, denoted $A \circ B$, may be defined by the formula 
$$A \circ B = (A^! \bullet B^!)^!$$ 
Up to coherent isomorphism, this may be more explicitly defined by the pair $(V \otimes W, \sigma(R_A \otimes 1_{W \otimes W}) + \sigma(1_{V \otimes V} \otimes R_B))$. 

(To see this last more clearly, observe that for finite-dimensional $V$, the mapping 

$$(-)^\perp: Sub(V) \to Sub(V^*)$$ 

is a [[Galois connection|Galois correspondence]], and hence a bijection that takes meets to joins and joins to meets. Now the meet of $\sigma(R_{A}^\perp \otimes 1_{W^* \otimes W^*})$ and $\sigma(1_{V^* \otimes V^*} \otimes R_{B}^\perp)$ is $\sigma(R_{A}^\perp \otimes R_{B}^\perp)$. Applying $(-)^\perp$ to this, one obtains the join of $\sigma(R_A \otimes 1_{W \otimes W})$ and $\sigma(1_{V \otimes V} \otimes R_B$ which is $\sigma(R_A \otimes 1_{W \otimes W}) + \sigma(1_{V \otimes V} \otimes R_B$.) 

+-- {: .un_thm} 
######Theorem
There is a natural isomorphism $QAlg(A \bullet B, C) \cong QAlg(A, B^! \circ C)$. 
=-- 

+-- {: .proof}
######Proof 
A preliminary comment is that the aforementioned Galois correspondence is induced by the equivalence 

$$\frac{X \subseteq Y^\perp}{\langle X, Y \rangle = 0}$$ 

where $X \subseteq V^*$, $Y \subseteq V$ are subspaces and $\langle -, - \rangle: V^* \otimes V \to k$ is the usual pairing to the ground field $k$. 

Let $(U, R_A)$, $(V, R_B)$, $(W, R_C)$ define the quadratic algebras, and suppose that $f: U \otimes V \to W$ and $g: U \to V^* \otimes W$ correspond to one another under the adjunction 

$$Vect_k(U \otimes V, W) \cong Vect_k(U, V^* \otimes W)$$ 

Now $f$ induces a (unique) graded algebra map $A \bullet B \to C$ iff $f(R_A \otimes R_B) \subseteq R_C$, which is true iff $\langle f(R_A \otimes R_B), R_{C}^\perp \rangle = 0$ iff $\langle g(R_A), R_B \otimes R_{C}^\perp \rangle = 0$ iff $g(R_A) \subseteq (R_B \otimes R_{C}^\perp)^\perp$. This is true iff $g$ induces a (unique) graded algebra map $A \to B^! \circ C$. 
=-- 

This result may be effectively summarized by saying that the category of quadratic algebras carries a [[star-autonomous category]] structure, i.e., a [[closed monoidal category|closed symmetric monoidal category]] structure equipped with a dualizing object $D$, i.e., an object for which the double dual embedding $\delta_A: A \to [[A, D], D]$ is a natural isomorphism. The monoidal unit is the polynomial algebra $k[x]$, and the dualizing object $D$ is $k[x]^! = k[\varepsilon]/(\varepsilon^2)$, the [[Grassmann algebra|algebra of Grassmann numbers]]. We then have $A^! \cong [A, D]$ for any quadratic algebra $D$. 

## References ## 

Y. Manin, _Some remarks on Koszul algebras and quantum groups_, Annales de l'institut Fourier, 37 no. 4 (1987), p. 191-205 [(pdf)](http://archive.numdam.org/ARCHIVE/AIF/AIF_1987__37_4/AIF_1987__37_4_191_0/AIF_1987__37_4_191_0.pdf)