
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Graph theory
+-- {: .hide}
[[!include graph theory - contents]]
=--
=--
=--

#Contents#
* table of contents
{:toc}

## Idea

A _ribbon graph_ (also called _fat graph_ ) is a (typically finite and connected) [[graph]] equipped with a cyclic ordering on the half edges incident to each vertex. 

To each ribbon graph, one can associate an [[orientation|oriented]] [[surface]] with [[boundary]] by replacing edges by thin oriented rectangles (ribbons) and vertices by disks, and pasting rectangles to disks according to the chosen cyclic orders at the vertices. (For some illustrations of this, see [Mulase-Penkava](#MulPen).) 

## Definition

The following definition of an ordinary [[graph]] (allowing loops and multiple edges) is not the standard one used for ordinary graphs, but is easily seen to be equivalent to it, while being the right starting point for describing ribbon graphs.

+-- {: .num_defn}
###### Definition

A **[[graph]]** is a quadruple $(V, H, s, i)$, where

* $V$ is a [[set]], called the **set of vertices**;

* $H$ is a [[set]], called the **set of half-edges**

* $s : H \to V$ is a [[function]], thought of as sending each half-edge to the vertex that it is _incident_ on;

* $i : H \to H$ is a [[involution|involutive]] [[function]] without fixed points, thought of as sending each half-edge to its other half.

The set of [[cycle]]s of $i$ is the set $E$ of full edges.

A [[homomorphism]] of graphs is a pair of [[function]]s $V_1 \to V_2$ and $H_1 \to H_2$ commuting with the $i$- and $s$-maps.

=--

An edge is a *loop* if its constituent half-edges are incident on the same vertex. 

+-- {: .num_defn}
###### Definition

A **fat graph** or **ribbon graph** is a graph $(V,H,i,s)$ equipped with a [[bijection]] $\sigma : H \to H$ whose [[cycle]]s correspond to the sets $s^{-1}(v)$ of half-edges incident on vertices $v \in V$. 

=--

This means that on all sets $s^{-1}(v)$ of jointly incident half-edges there is induced a cyclic ordering.  When drawing ribbon graphs on paper this cyclic ordering is identified with the ordering induced from the standard orientation of the plane.

Note that this definition (which appears in [Igusa 02](#Igusa02)) is essentially equivalent to that of an oriented [[combinatorial map]], except that the usual definition of combinatorial map does not make the set $V$ and the function $s : H \to V$ explicit, instead identifying vertices with the cycles of $\sigma$.  Under this style of definition, the extra condition (often assumed) that the underlying graph be connected corresponds to the condition that the group generated by the permutations $i$ and $\sigma$ acts [[transitive action|transitively]] on the set of half-edges $H$.


### Boundary of a fat graph

+-- {: .num_defn}
###### Definition

Write 

$$
  \partial : FatGraph \to Graph
$$

for the [[functor]] -- called the **boundary graph functor** -- that sends a fat graph $\Gamma = (V, H, s, i, \sigma)$ to the graph

$$
  \partial \Gamma = \left(
     \coprod_{v \in V} \coprod_{h \in s^{-1}(v)} \{v_h\},\,
     \coprod_{h \in H} \{h_0, h_1\},\,
     s_{\partial_\Gamma},\,
     i_{\partial_\Gamma}
  \right)
$$

with $s_{\partial \Gamma}$ given by 

$$
  s_{\partial \Gamma}(h_0) = v_h
$$

$$
  s_{\partial \Gamma}(h_1) = \sigma(v_h)
$$

and $i_{\partial \Gamma}$ given by

$$
  i_{\partial \Gamma}(h_0) = i(h)_1
$$

$$
  i_{\partial \Gamma}(h_1) = i(h)_0
  \,.
$$


=--

+-- {: .num_prop}
###### Proposition

The set of [[boundary]] components of $\Sigma_\Gamma$ is naturally identified with the [[cycle]]s of $\sigma \circ i : H \to H$, or equivalently with the cycles of $i \circ \sigma$.

=--

Write $S : FatGraph \to Graph$ for the evident [[forgetful functor]] sending fat graphs to their underlying graph.

+-- {: .num_prop}
###### Proposition/Definition

There is a [[natural transformation]]

$$
  c : \partial \to S
$$

from the boundary graph functor to the forgetful functor -- called the **collapse map**, whose components morphism on a fat graph $\Gamma$ sends on vertices

$$
  v_h \mapsto s(h)
$$

and on half-edges

$$
  h_{0,1} \mapsto h
  \,.
$$

=--


### Further constructions

Given any edge $e$ in a graph $\Gamma$, 
we can collapse it to a new graph $\Gamma/e$ by merging the two vertices
containing the edge and removing both half edges.  

A forest $F$ (disjoint union of trees) spans a graph $\Gamma$ if it contains all of its vertices. One can collapse $\Gamma$ to $\Gamma/F$ by collapsing each tree to a separate vertex. Then the edges in $\Gamma/F$ are the edges of $\Gamma$ which do not lie in any tree in $F$; the vertices of $\Gamma/F$ correspond to the sets of leaves of the component trees of $F$.  

A morphism of graphs $\Gamma_0\to\Gamma_1$ is defined as an isomorphism $\Gamma_0/F\to\Gamma_1$ where $F$ is a spanning forest of $\Gamma_0$. Morphisms of such graphs are both epi and mono. 

For  a ribbon graph, the set of leaves of any tree inherits a cyclic order. Thus $\Gamma/F$ has a canonical structure a ribbon graph. This makes the following definition possible: A morphism of ribbon graphs is the morphism of underlying graphs which respects the ordering on the vertices; i.e.  $\Gamma_0/F\to\Gamma_1$ is an isomorphism of ribbon graphs. Every endomorphism of a ribbon graph is an automorphism and for any two ribbon graphs $\Gamma$ and $\Gamma'$, the set $Aut(\Gamma)$ acts freely on $Hom(\Gamma,\Gamma')$ on the right and $Aut(\Gamma')$ acts freely on $Hom(\Gamma,\Gamma')$ from the left. 

Let $\mathcal{Fat}$ denote the category of ribbon graphs and ribbon automorphisms. Strebel proved that the geometric realization $|\mathcal{Fat}|$ of the category of ribbon graphs decomposes into a direct sum of classifying spaces of all [[mapping class group]]s $M^s_g$ 

$$
|\mathcal{Fat}| = \coprod_{g,s} BM^s_g
$$

$M^s_g$ is a mapping class group of a surface of genus $g$ with $s$ punctures. Alternatively, one can instead of the geometric realization take a moduli space of ribbon graphs with metric. A **metric** on a ribbon graph is a positive real valued function on the set of edges. 


## Properties

For the following we represent a fat graph by

* a set $V$ of vertices;

* a set $H$ of half-edges;

* a source map $s : H \to V$;

* an involution $i :  H \to H$ which sends each half-edge to its partner half-edge;

* an permutation $\sigma : H \to H$ which gives the cyclic order on the edges.


### Geometric realization

For $\Gamma$ a fat graph, write $\Sigma_\Gamma$ for the [[surface]] that it defines.



+-- {: .num_prop}
###### Proposition

The [[genus]] of $\Sigma_\Gamma$ is

$$
  g = \frac{1}{2}
   \left(
     2 - \vert V\vert + \vert E\vert - \vert boundary components\vert
   \right)
  \,.
$$

=--

+-- {: .num_prop}
###### Proposition

For every surface $S$ with boundary, there is a fat graph $\Gamma$ and a [[homeomorphism]]

$$
  S \stackrel{\simeq}{\to}  \Sigma_\Gamma
  \,.
$$

=--

### Moduli space of surfaces / classifying spaces of mapping class groups

Write $FatGraph^c_3$ for the [[full subcategory]] of fat graphs on the connected fat graphs for which every vertex has valence at least 3. Write $\vert FatGraph^c_3 \vert \in $ [[Top]] for the [[geometric realization]] of this [[category]]. For $\Sigma$ a [[surface]], write $\Gamma_Sigma$ for its [[mapping class group]] and $B \Gamma_\Sigma$ for the corresponding [[classifying space]].

+-- {: .num_theorem}
###### Theorem

There is a [[weak homotopy equivalence]]

$$
  \vert FatGraph^c_3 \vert \simeq
  \coprod_{[\Sigma]} B \Gamma_\Sigma
  \,,
$$

where on the right thr coproduct ranges over isomorphism classes of orientable, closed 2-dimensional manifolds with $n \geq 1$ marked points, except those for which $(g,n) = (0,1)$ or  $(g, n) = (0,2)$.

=--

In various guises this theorem has been proven by [Costello](#Costello), [Kontsevich92](#Kontsevich92), [Igusa02](#Igusa02), [Penner](#Penner), [Strebel](#Strebel).

The restriction to valence $\geq 3$ can be dropped:

+-- {: .num_theorem}
###### Theorem

There is a [[weak homotopy equivalence]]

$$
  \vert FatGraph^c \vert \simeq
  B U(1) \coprod B U(1) \coprod_{[\Sigma]} B \Gamma_\Sigma
  \,,
$$

where again on the right the [[coproduct]] ranges over [[isomorphism class]]es of orientable, closed 2-dimensional manifolds with $n \geq 1$ marked points, except those for which $(g,n) = (0,1)$ or  $(g, n) = (0,2)$. The two extra copies of $B U(1)$ corespond to these two exceptional cases.

=--

This has been shown in ([Godin](#Godin)). One of the $B U(1)$-summands is also produced in ([Igusa02](#Igusa02)). A detailed complete proof appears as ([Kupers, theorem 3.59](#Kupers)).


## Related concepts

* [[graph]]

* [[directed graph]]

  * [[directed n-graph]]

* **ribbon graph**

* [[topological map]]

* [[combinatorial map]]

## References

Original references include

* {#Kontsevich92}[[Maxim Kontsevich]], _Intersection theory on the moduli space of curves and the matrix Airy function_ , Commun.
Math. Phys. (1992), no. 147, 1-23.
 
* {#Igusa02}[[Kiyoshi Igusa]], _Higher Franz Reidemeister torsion_ , IP Studies in Advanced Mathematics, American Mathematical
Society, 2002.

* {#Igusa04}[[Kiyoshi Igusa]], _Graph cohomology and Kontsevich cycles_, Topology __43__ (2004), n. 6, p. 1469-1510, [MR2005d:57028](http://www.ams.org/mathscinet-getitem?mr=2005d:57028), [doi](http://dx.doi.org/10.1016/j.top.2004.03.004)


* {#Strebel}K. Strebel, _Quadratic Differentials_, Springer, Berlin, 1984, [MR86a:30072](http://www.ams.org/mathscinet-getitem?mr=86a:30072)

* {#Penner}R. C. Penner, _The decorated Teichmüller space of punctured surfaces_, Commun. Math. Phys. __113__ (2) (1987) 299--339. [MR89h:32044](http://www.ams.org/mathscinet-getitem?mr=89h:32044)

* John Harer, _The cohomology of the moduli space of curves_, Lec. Notes in Math. __1337__, p. 138–221. Springer, Berlin, 1988.

* {#MulPen}M. Mulase, M. Penkava, _Ribbon graphs, quadratic differentials on Riemann surfaces, and algebraic curves defined over_ $\overline{\mathbb{Q}}$. Mikio Sato: a great Japanese mathematician of the twentieth century.  Asian J. Math. __2__ (1998),  no. 4, 875--919. ([pdf](http://arxiv.org/pdf/math-ph/9811024v2.pdf)) 

* [[Maxim Kontsevich]], _Feynman diagrams and low-dimensional topology_, First European Congress of Mathematics, 1992, Paris, vol. II, Progress in Mathematics __120__, Birkhäuser (1994), 97–121, [pdf](http://www.ihes.fr/~maxim/TEXTS/Feynman%20%20diagrams%20and%20low-dimensional%20topology.pdf)

* Ib Madsen, Michael Weiss, _The stable moduli space of Riemann surfaces: [[Mumford's conjecture]]_,  Ann. of Math. (2) __165__ (2007), no. 3, 843--941, [MR2009b:14051](http://www.ams.org/mathscinet-getitem?mr=2009b:14051), [doi](http://dx.doi.org/10.4007/annals.2007.165.843)

* J. Conant, K. Vogtmann, _On a theorem of Kontsevich_, [math.QA/0208169](http://arxiv.org/abs/math/0208169)

* Gabriele Mondello, _Riemann surfaces, ribbon graphs and combinatorial classes_, [pdf](http://www1.mat.uniroma1.it/people/mondello/ricerca/papers/ober-definitive.pdf) [arxiv](http://arxiv.org/abs/0705.1792)

* {#Godin}[[Veronique Godin]], _Higher string topology operations_ (2007)([arXiv:0711.4859](http://arxiv.org/abs/0711.4859))

A survey is in chapter 3 of 

* [[Sander Kupers]], _String topology operations_ MSc thesis (2011)

Some discussion is at

* MathOverflow: [why does ribbon graph cohomology compute cohomology of mapping class group](http://mathoverflow.net/questions/51978/why-does-ribbon-graph-cohomology-compute-cohomology-of-mcg)

[[!redirects ribbon graphs]]

[[!redirects fat graph]]
[[!redirects fat graphs]]