
> For the concept in [[category theory]] see at _[[exponential object]]_.

***

+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Arithmetic
+--{: .hide}
[[!include arithmetic geometry - contents]]
=--
=--
=--



# Exponential maps
* table of contents
{: toc}

## Idea

The exponential [[function]] of classical [[analysis]] given by the [[series]],
\[ \label{series} \exp x \coloneqq \sum_{i = 0}^{\infty} \frac{x^i}{i!} ,\]
is the solution of the [[differential equation]]
$$ f' = f $$
with initial value $f(0) = 1$.

This classical function is defined on the [[real line]] (or the [[complex plane]]).  To generalise it to other [[manifolds]], we need two things:

*  by its nature, the argument of the function should be a [[tangent vector]]; so in the classical function $\mathbb{R} \to \mathbb{R}$, the [[source]] $\mathbb{R}$ is really the [[tangent space]] to the [[target]] $\mathbb{R}$ at the point $\exp 0 = 1$.
*  We need a [[covariant derivative]] to tell us what $f'$ means.

So in the end we have, for any [[point]] $p$ on a [[differentiable manifold]] $M$ with an [[affine connection]] $\Del$, a map $\exp_p\colon T_p M \to M$, which is defined at least on a [[neighbourhood]] of $0$ in the [[tangent space]] $T_p M$.

Note that $p$ here comes from the initial value $\exp_p 0 = p$; we usually take $p = 1$ when we work in a [[Lie group]], but otherwise we are really generalising the classical exponential function $x \mapsto p \exp x$; every solution to $f' = f$ takes this form.

Classically, there are some other functions called 'exponential'; given any nonzero real (or complex) number $b$, the map $x \mapsto b^x$ (or even $x \mapsto p\, b^x$) is also an exponential map.  Using the [[natural logarithm]], we can define $b^x$ in terms of the natural exponential map $\exp$:
$$ b^x \coloneqq \exp (x \ln b) .$$
So while $b$ is traditionally called the 'base', it is really the number $\ln b$ that matters, or even better the operation of multiplication by $\ln b$.  This operation is an [[endomorphism]] of the real line (or complex plane), and every such endomorphism takes this form for some nonzero $b$ (and some branch of the natural logarithm, in the complex case).  So we see that this generalised exponential map is simply the [[composite]] of the natural exponential map after a linear endomorphism.


## Definition

See also at _[[flow of a vector field]]_.

### With respect to an affine connection

Let $M$ be a [[differentiable manifold]], let $\Del$ be an [[affine connection]] on $M$, and let $p$ be a [[point]] in $M$.  Then by the general theory of [[differential equations]], there is a unique [[maximal partial function|maximally]] defined [[partial function]] $\exp_p$ from the [[tangent space]] $T_p M$ to $M$ such that:

*  $\Del \exp_p = \exp_p$ and
*  $\exp_p(0) = 1$.

This function is the __natural exponential map on $M$ at $p$ relative to $\Del$__.  We have $\exp_p\colon U \to M$, where $U$ is some [[neighbourhood]] of $0$ in $T_p M$.  If $M$ is [[complete manifold|complete]] (relative to $\Del$), then $U$ will be all of $T_p M$.

Let $M$ be a [[Riemannian manifold]] (or a [[pseudo-Riemannian manifold]]) and let $p$ be a point in $M$.  Then $M$ may be equipped with the [[Levi-Civita connection]] $\Del_{lc}$, so we define the __natural Riemannian exponential map on $M$ at $p$__ to be the natural exponential map on $M$ at $p$ relative to $\Del_{lc}$.


Given any [[endomorphism]] $\phi\colon T_p M \to T_p M$, we can also consider the __exponential map on $M$ at $p$ relative to $\Del$ with logarithmic base $\phi$__, which is simply $x \mapsto \exp_p \phi(x)$.  We say 'logarithmic base' since a classical exponential function with base $b$ corresponds to an exponential function whose logarithmic base is multiplication by $\ln b$.


### Via geodesics

Recall that a [[geodesic]] is a [[curve]] on a manifold whose [[velocity]] is constant (as measured along that curve relative to a given affine connection).  Working naïvely, we may write
$$ \gamma' = v ,$$
pretend that this is a differential equation for a function $\gamma\colon \mathbb{R} \to \mathbb{R}$, and take the solution
$$ \gamma(t) = p \exp t x ,$$
where $p$ is given by the initial value $\gamma(0) = p$.  We recognise this as being, morally, $\exp_p t x$.  This suggests (although we need more work for a proof) the following result:

Let $M$ be a [[differentiable manifold]], let $\Del$ be an [[affine connection]] on $M$, and let $p$ be a [[point]] in $M$.  Given a [[tangent vector]] $x$ at $p$, there is a unique [[maximal geodesic]] $\gamma$ on $M$ tangent to $x$ at $p$.  If $\gamma(1)$ is defined (which it will be whenever $M$ is [[complete manifold|complete]] and may be in any case), we have $exp_p x = \gamma(1)$.  In any case, we have $\exp_p (t x) = \gamma(t)$ for sufficiently small $t$.





## In Lie groups {#exp_of_Lie_groups}

Note: this section is under repair. 

The classical exponential function $\exp \colon \mathbb{R} \to \mathbb{R}^*$ or $\exp \colon \mathbb{C} \to \mathbb{C}^*$ satisfies the fundamental property: 

+-- {: .num_prop} 
###### Proposition 
The function $\exp \colon \mathbb{C} \to \mathbb{C}^*$ is a homomorphism taking addition to multiplication: 
$$\exp(x + y) = \exp(x) \cdot \exp(y)$$ 
=-- 

+-- {: .proof} 
###### Proof 
A number of proofs may be given. One rests on the combinatorial [[binomial theorem|binomial identity]]  

$$(x + y)^n = \sum_{j + k = n} \frac{n!}{j! k!} x^j y^k$$ 

(which crucially depends on the fact that multiplication is [[commutative monoid|commutative]]), whereupon 

$$\array{
\sum_{n \geq 0} \frac{(x+y)^n}{n!} & = & \sum_{n \geq 0} \sum_{j + k = n} \frac1{j!} \frac1{k!} x^j y^k \\
 & = & (\sum_{j \geq 0} \frac{x^j}{j!}) \cdot (\sum_{k \geq 0} \frac{y^k}{k!}) \\ 
 & = & \exp(x) \cdot \exp(y)
}$$

An alternative proof begins with the observation that $f = \exp$ is the solution to the system $f' = f$, $f(0) = 1$. For each $y$, the function $g_1 \colon x \mapsto f(x) f(y)$ is a solution to the system $g' = g$, $g(0) = f(y)$, as is the function $g_2 \colon x \mapsto f(x + y)$. Then by uniqueness of solutions to ordinary differential equations (over connected domains; see, e.g., [here](http://en.wikipedia.org/wiki/Picard%E2%80%93Lindel%C3%B6f_theorem)), $g_1 = g_2$, i.e., $f(x + y) = f(x)f(y)$ for all $x, y$.[^fine] 
=-- 

[^fine]: A previous edit offered even more detail: "An alternative proof begins with the premise that each solution of the ordinary differential equation $g' = 0$ is locally constant. Suppose $c$ is a complex number. As $\exp' = \exp$, we find that $(\exp(x) \exp(c - x))' = \exp(x) \exp(c - x) + \exp(x) (-\exp(c-x)) = 0$. Hence, by the premise and the connectedness of the domain of $\exp$ (either ${\mathbb{R}}$ or ${\mathbb{C}}$), we obtain $\exp(x)\exp(c - x) = \exp(0)\exp(c)$. The initial condition $\exp(0) = 1$ then yields $\exp(x)\exp(c - x) = \exp(c)$. The result follows by setting $c = x + y$." 

Let $M$ be [[Lie group]] and let $\mathfrak{g}$ be its [[Lie algebra]] $T_1 M$, the tangent space to the [[identity element]] $1$.  Then $M$ may be equipped with the canonical left-invariant connection $\Del_l$ or the canonical right-invariant connection $\Del_r$.  It turns out that the natural Riemannian exponential maps on $M$ at $1$ relative to $\Del_l$ and $\Del_r$ are the same; we define this to be the __natural Lie exponential map on $M$ at the identity__, denoted simply $\exp$.  Several nice properties follow:

*  $\exp$ is defined on all of $\mathfrak{g}$.
*  $\exp \colon \mathfrak{g} \to G$ is a [[smooth map]]. 
*  If $\rho \colon \mathbb{R} \to \mathfrak{g}$ is a smooth homomorphism from the additive group $\mathbb{R}$ (i.e., if $\rho$ is an $\mathbb{R}$-linear map, uniquely determined by specifying $X = \rho(1)$), then $\exp \circ \rho_X \colon \mathbb{R} \to G$ is a smooth homomorphism. 
*  For $X, Y \in \mathfrak{g}$, if $[X, Y] = 0$, then the restriction of $\exp \colon \mathfrak{g} \to G$ to the subspace spanned by $X$ and $Y$ is a smooth homomorphism to $G$. In particular, $\exp \colon \mathfrak{g} \to G$ is a homomorphism if $\mathfrak{g}$ is abelian (e.g., if $G$ is a commutative Lie group). 
*  $\exp$ is [[surjection|surjective]] (a [[regular epimorphism]]) if $G$ is [[connected space|connected]] and [[compact space|compact]] (and also in some other situations, such as the classical cases where $G$ is $]0,\infty[$ or $\mathbb{C} \setminus \{0\}$). See [this post](https://terrytao.wordpress.com/2011/06/25/two-small-facts-about-lie-groups/) by Terence Tao, Proposition 1; see also the first comment which indicates an alternative proof based on the fact that [[maximal tori]] in $G$ are all conjugate to one another. Note also that the exponential map might not be surjective if the compactness assumption is dropped, as in the case of $G = SL_2(\mathbb{R})$ or $SL_2(\mathbb{C})$, both of which are connected; see [here](http://math.stackexchange.com/questions/643216/non-surjectivity-of-the-exponential-map-to-sl2-mathbbc) for instance. 
*  If $G$ is [[compact space|compact]], then it may be equipped with a [[Riemannian metric]] that is both left and right invariant (see Tao's post linked in the previous remark); then the Lie exponential map is the same as the Riemannian exponential map at $1$.
*  If $G$ is a [[matrix Lie group]], then $\exp$ is given by the classical series formula (eq:series).

(to be expanded on) 


## Logarithms

A __[[logarithm]]__ is a [[local section]] of an exponential map.

## Related concepts

* [[pane wave]]

* [[flow of a vector field]]

* [[Euler number]], [[e]]

* [[logarithm]]

* [[Euler's formula]]

* [[exponential exact sequence]]

* [[Hamiltonian flow]]

* [[exponential modality]]

## References

* wikipedia [exponential map (Lie theory)](https://en.wikipedia.org/wiki/Exponential_map_%28Lie_theory%29), [derivative of the exponential map](https://en.wikipedia.org/wiki/Derivative_of_the_exponential_map), [exponential map (Riemannian geometry)](https://en.wikipedia.org/wiki/Exponential_map_(Riemannian_geometry))
* Springer [[eom]]: [exponential mapping](https://www.encyclopediaofmath.org/index.php/Exponential_mapping)

An extensive treatment for the general exponential map for an affine connection, for exponential map for Riemannian manifolds and the one for Lie groups is

* Sigurdur Helgason, Differential geometry, Lie groups and symmetric spaces

Specifically for Lie groups, a different detailed treatment of the exponential map is in 

* [[M M Postnikov]], _Lie groups and Lie algebras_, Geometry V

Some nice historical notes are in

* Wilfried Schmid, _Poincare and Lie groups_, Bull. Amer. Math. Soc. 6:2, 1982 [pdf](http://www.ams.org/journals/bull/1982-06-02/S0273-0979-1982-14972-2/S0273-0979-1982-14972-2.pdf)

[[!redirects exponential map]]
[[!redirects exponential maps]]
[[!redirects exponential function]]
[[!redirects exponential functions]]


[[!redirects exponent]]
[[!redirects exponentiation]]
[[!redirects exponential]]
[[!redirects exponentials]]

[[!redirects exponential series]]


