
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Knot theory
+-- {: .hide}
[[!include knot theory - contents]]
=--
=--
=--

# Vassiliev knot invariants
* tic
{: toc}

## Idea ##

The space of knots in $\mathbb{R}^3$ (or $S^3$) is an open submanifold of the [[smooth loop space]].  Knot invariants are locally constant functions on this manifold.  The complement of the space of knots is called the [[discriminant]] and consists of all [[singular knots]].

If we consider those singular knots with only a finite number of double points, we can build a [[cubical complex]] from this data.  The vertices in the complex are labelled by the isotopy classes of knots, and more generally the $n$-cubes by the isotopy classes of singular knots with $n$ double points (and a few other technical pieces of information).  The boundary operator resolves a double crossing either upwards or downwards according to the orientation at the crossing.

A **Vassiliev invariant** is simply a cubical morphism from this complex to an abelian group that vanishes above a certain degree.

## Definition ##

One does not need the language of cubical complexes to _define_ Vassiliev invariants.  Rather, there is a general method whereby a [[knot invariant]] can be extended to all [[singular knots]] with only finitely many double points (and no other singularities) using the [[Vassiliev skein relations]].


+-- {: .num_definition #vinv}
###### Definition
A **Vassiliev invariant** of degree (or order) $\le n$ is a knot invariant whose extension to singular knots (with double points) vanishes on all singular knots with more than $n$ double points.
=--

As is standard, it is of degree $n$ if it is of degree $\le n$ but not $\le n - 1$.  Vassiliev invariants are also called **finite type invariants**.


## Remarks ##

The degree of Vassiliev invariants defines a filtration on the space of knots (and more particularly, on the [[algebra of knots]]).  Two knots are $n$-equivalent if all the Vassiliev invariants of degree $\le n$ agree on them.  In particular, a knot that is $n$-equivalent to the unknot is said to be $n$-trivial.

## Properties ##

A function which is constant on nonsingular knots may be extended to a Vassiliev invariant of degree 0 by applying the [[Vassiliev skein relations]], and conversely, any Vassiliev invariant of degree 0 must be constant on nonsingular knots.  Likewise, any Vassiliev invariant of degree 1 must be constant on nonsingular knots.

## Chord diagrams and weight systems ##

Any singular knot $f : S^1 \to \mathbb{R}^3$ with $n$ distinct double points $x_1,\dots,x_n \in \mathbb{R}^3$ gives rise to a [[chord diagram]] of order $n$, consisting of the circle $S^1$ with a chord connecting each pair of points $f^{-1}(x_1), \dots, f^{-1}(x_n)$.

The importance of this construction for singular knots comes from the fact that any finite type invariant determines a function on chord diagrams:

+-- {: .un_thm}
######Theorem 
Let $v$ be a Vassiliev invariant of degree $\le n$.  Then the value of $v$ on a singular knot with $n$ distinct double points depends only on the chord diagram of the knot, and not on the knot itself.
=-- 

Conversely, one can ask which functions on chord diagrams come from finite type invariants.  The answer is that Vassiliev invariants (of degree $\le n$) can essentially be identified with _weight systems_ (of order $n$), which are functions on chord diagrams (of order $n$) satisfying two properties called the "1-term relation" (or "framing independence") and the "4-term relation": see Theorem 1 of [Bar-Natan](#Bar-Natan) (or Theorem 6.2.13 of [Lando & Zvonkin](#LandoZvonkin)).

## Examples ##

1. The $n$th coefficient of the Conway polynomial is a Vassiliev invariant of order $\le n$.

## Related concepts ## 

* [[knot theory]]
* [[Jones polynomial]]
* [[Kontsevich integral]]
* [[singularity]] 

## References ##


* [[V. A. Vassiliev]], _Complements of discriminants of smooth maps: topology and applications_, Amer. Math. Soc. 1992. 
* {#Bar-Natan} [[Dror Bar-Natan]], On the Vassiliev knot invariants, _Topology_ 34 (1995), 423-472. ([html](http://www.math.toronto.edu/~drorbn/papers/OnVassiliev/))
* There is a huge online bibliography on Vassiliev invariants maintained by [[Dror Bar-Natan]] and Sergei Duzhin [here](http://www.pdmi.ras.ru/~duzhin/VasBib/Long).
* S. Chmutov, S. Duzhin, J. Mostovoy, _Introduction to Vassiliev knot invariants_, [arxiv/1103.5628](http://arxiv.org/abs/1103.5628)
* Wolframworld [Vassiliev invariant](http://mathworld.wolfram.com/VassilievInvariant.html)

See also Chapter 6 of

* {#LandoZvonkin} Sergei K. Lando and Alexander K. Zvonkin, _Graphs on Surfaces and Their Applications_, Springer, 2004.

category: geometry, topology
[[!redirects Vassiliev knot invariant]]
[[!redirects Vassiliev invariants]]
[[!redirects Vassiliev finite type invariants]]
[[!redirects Vassiliev finite type invariant]]
[[!redirects Vassiliev finite-type invariants]]
[[!redirects Vassiliev finite-type invariant]]
[[!redirects finite type invariants]]
[[!redirects finite type invariant]]
[[!redirects finite-type invariants]]
[[!redirects finite-type invariant]]