# Books in algebraic geometry

We should limit to books which we can really recommend, either by their special content, approach or pedagogical value. Historically fine but outdated books are in a separate historical section below. The outstanding surveys may be added to the lists if they are not too specialized to minor directions: the subfields may be covered in separate lists. See also MathOverflow discussions [best-algebraic-geometry-text-book-other-than-hartshorne](http://mathoverflow.net/questions/2446/best-algebraic-geometry-text-book-other-than-hartshorne), [life-after-hartshorne-the-book](http://mathoverflow.net/questions/61515/life-after-hartshorne-the-book-not-the-person). To orient in the basic standard terminology, the wikipedia's [Glossary of algebraic geometry](https://en.wikipedia.org/wiki/Glossary_of_algebraic_geometry) is decent.

* table of contents
{: toc}


## Introductory level but excellent textbooks

* [[Miles Reid]], _Undergraduate algebraic geometry_, London Math. Soc. Student Texts __12__
* [[Joe Harris]], _Introductory algebraic geometry_ (varieties) 
* [[Igor Shafarevich]], _Basic algebraic geometry_ (varieties and schemes)
* [[Shigeru Mukai]], _An introduction to invariants and moduli_, Cambridge Studies in Adv. Math. __81__ 
* [[William Fulton]], _Algebraic curves. An introduction to algebraic geometry_, 3rd ed. 2008 (varieties)
* [[James Milne|J. S. Milne]], _Algebraic geometry_, 2017 [pdf](http://www.jmilne.org/math/CourseNotes/AG.pdf)

## Schemes, standard sources

* [[Robin Hartshorne]], _Algebraic geometry_, Springer
* Qing Liu, _Algebraic geometry and arithmetic curves_, 592 pp. Oxford Univ. Press 2002 
* D. Eisenbud, J. Harris, _The geometry of schemes_, Springer Grad. Texts in Math.
* [[David Mumford]], _Red book of varieties and schemes_ (cf. also unfinished sequel notes for the later part of Mumford's course, coauthored with Oda, [ch. 1-6 pdf](http://www.math.upenn.edu/~chai/624_08/mumford-oda_chap1-6.pdf), [ch. 7-8 pdf](http://www.math.upenn.edu/~chai/624_08/mumford-oda_chap7-8.pdf))
* Amnon Neeman, _Algebraic and analytic geometry_, London Math. Soc. Lec. Note Series __345__ 
* M. Demazure, P. Gabriel, _Groupes algebriques_, tome 1 (later volumes never appeared), Mason and Cie, Paris 1970 
* Ravi Vakil's Stanford [course notes](http://math.stanford.edu/~vakil/0708-216)
* William Fulton, _Intersection theory_, Springer 1984
* Ulrich Görtz, Torsten Wedhorn, _Algebraic geometry I. Schemes with examples and exercises_, Advanced Lectures in Mathematics. Vieweg + Teubner, Wiesbaden, 2010. viii+615 pp. [Springerlink book](http://www.springerlink.com/content/kt5u74/#section=748613&page=1)

## Grothendieck school sources

* [[EGA]]
* [[SGA]]
* [[FGA]], [[FGA explained]]
* R. Hartshorne, _Residues and duality_
* A. Grothendieck et al. _Dix exposes sur la cohomologie des schemas_, North Holland, Amsterdam, 1968.

## Background in commutative algebra

* M. Atiyah, I. G. Macdonald, _Introduction to commutative algebra_, 1969, 1994
* H. Matsumura, _Commutative algebra_, 2 vols.; see also the online summary notes by D. Murfet, [Matsumura.pdf](http://therisingsea.org/notes/Matsumura.pdf), [Matsumura-Part2.pdf](http://therisingsea.org/notes/Matsumura-Part2.pdf)
* D. Eisenbud, _Commutative algebra: with a view toward algebraic geometry_, Grad. Texts in Math. 150, Springer-Verlag 1995. 
* James Milne, _A primer of commutative algebra_, (online notes in progress) [webpage](http://www.jmilne.org/math/xnotes/ca.html), [pdf](http://www.jmilne.org/math/xnotes/CA.pdf)

## Algebraic groups/group schemes; Fourier-Mukai transform 

* William C. Waterhouse, _Introduction to affine group schemes_, GTM 66, Springer 1979
* [[Armand Borel]], _Linear algebraic groups_, Springer GTM, 2 editions
* Tonny A. Springer, _Linear algebraic groups_, Progress in Mathematics, 9 (2nd ed.), BBirkhäuser Boston 1998, [MR1642713](http://www.ams.org/mathscinet-getitem?mr=1642713)
* [[David Mumford]], _Abelian varieties_, Oxford Univ. Press 1970
* A. Polishchuk, _Abelian varieties, theta functions and the Fourier transform_, Cambridge Univ. Press 2003
* [[M. Demazure]], [[P. Gabriel]], _Groupes algebriques_, tome 1 (later volumes never appeared), Mason and Cie, Paris 1970 -- has functor of points point of view (listed also under scheme theory); for review see
Bull. London Math. Soc. (1980) 12 (6): 476-478, [doi](http://dx.doi.org/10.1112/blms/12.6.476b) 
* SGA III
* J. S. Milne, _Abelian varieties_, course notes, [pdf](http://www.jmilne.org/math/CourseNotes/AV.pdf)
* [[Daniel Huybrechts]], _Fourier-Mukai transforms in algebraic geometry_, Oxford Mathematical Monographs. 2006. 307 pages.
* André Weil, _Courbes algébriques et variétés abéliennes_, Paris: Hermann 1971
* C. Bartocci, Ugo Bruzzo, D. Hernandez Ruiperez, _Fourier-Mukai and Nahm transforms in geometry and mathematical physics_, Progress in Mathematics __276__, Birkhauser 2009.

## Complex-analytic approach

* P. Griffiths, J. Harris, _Principles of algebraic geometry_
* Phillip A. Griffiths, _Introduction to algebraic curves_
* [[Daniel Huybrechts]], _Complex geometry - an introduction_, Springer (2004). Universitext. 309 pages.
* [[Donu Arapura]], _Algebraic geometry over the complex numbers_, Springer Universitext 223, 329 pp.

## Mori program and birational geometry

* János Kollár, Shigefumi Mori, _Birational geometry of algebraic varieties_, 
With the collaboration of C. H. Clemens and A. Corti. Translated from the 1998 Japanese original. Cambridge Tracts in Math. 134 (1998), viii+254 pp. 
* Kenji Matsuki, _Introduction to the Mori program_, Universitext. Springer 2002. xxiv+478 pp. [MR2002m:14011](http://www.ams.org/mathscinet-getitem?mr=1875410)
* Herbert Clemens, János Kollár, Shigefumi Mori, _Higher-dimensional complex geometry_, Astérisque __166__ (1988), 144 pp. (1989). 

## Arithmetic aspects

* Goro Shimura, _Abelian varieties with complex multiplication and modular functions_, Princeton Univ. Press 1997
* Dale Husemöller, _Elliptic curves_, Graduate Texts in Mathematics. 111 (2nd ed.). Springer 2004, ISBN 0-387-95490-2. 
* Anthony Knapp, _Elliptic curves_, Math Notes. 40. Princeton University Press 1992
* Neal Koblitz, _Introduction to elliptic curves and modular forms_, Graduate Texts in Mathematics. __97__ (2nd ed.). Springer-Verlag 1993
* Joseph H. Silverman, _The Arithmetic of Elliptic Curves_, Graduate Texts in Math. __106__, Springer 1986; _Advanced Topics in the Arithmetic of Elliptic Curves_ Graduate Texts in Mathl. __151__, Springer 1994.
* J. H. Silverman, John Tate, _Rational Points on Elliptic Curves_, Springer 1992.
* [[Gerd Faltings]], _Lectures on arithmetic Riemann-Roch theorem_, Annals of Math. Studies __127__, Princeton Univ. Press 1992
* S. Bosch, W. Lütkebohmert, M. Raynaud, _Néron models_, Ergebnisse der Mathematik und ihrer Grenzgebiete, Springer 1990. x+325 pp. [MR91i:14034](http://www.ams.org/mathscinet-getitem?mr=1045822)

## Cohomology theories for schemes

* J. S. Milne, _Etale cohomology_, Princeton Univ. Press 1980, [gbooks](http://books.google.com/books?id=uAT4T4BXC50C&lpg=PP1&dq=milne%20etale%20cohomology)
* P. Berthelot, A. Ogus, _Notes on crystalline cohomology_, Princeton Univ. Press 1978. vi+243, ISBN0-691-08218-9
* ...list basic literature on [[motive]]s 
* [[Marc Levine]], _Mixed motives_, Math. Surveys and Monographs __57__, Amer. Math. Soc.  1998, free [pdf](http://www.ams.org/online_bks/surv57/surv57.pdf)
* F. Hirzebruch, _Topological methods in algebraic geometry_


## Modern extensions of scheme theory

These are advanced books or long foundational expositions.

* D. Knutson, _Algebraic spaces_, Springer 1971
* [[Ofer Gabber]], Lorenzo Ramero, _Almost ring theory_, arxiv and published
* [[Jacob Lurie]], _Derived algebraic geometry_, several issues, arxiv
* [[Bertrand Toen]], [[Gabrielle Vezzosi]], HAG and DAG
* [[Nikolai Durov]], _A new approach to Arakelov geometry_, arxiv
* something basic on log schemes, e.g. from Kato/Ogus/Olsson


## Algorithmic and computational methods

Things like Groebner bases, combinatorical methods with toric varieties etc. 

* David A. Cox, John B. Little, Don O'Shea, _Ideals, varieties, and algorithms_


## Historically important but now outdated

While many of these fine books are still pleasure for some readers, they do not capture the modern viewpoint and have maybe too old notation to be regularly used. But one should be aware of them, and of sometimes unique material exposed there. 

* W. V. D. Hodge, Daniel Pedoe, _Methods of algebraic geometry_, 3 vols. (see review by Coxeter in Bull. Amer. Math. Soc. __55__, 3, part 1 (1949), 315-316, [euclid](http://projecteuclid.org/euclid.bams/1183513548))
* F. Severi, Vol. I (1942): Serie, sistemi d'equivalenza e correspondenze algebriche sulle varieta algebriche. Vol. I I (1958) and I I I (1959): Geometria dei sistemi algebrici sopra una superficie e sopra una varieta algebrica.

category: reference

[[!redirects books in algebraic geometry]]
[[!redirects book in algebraic geometry]]
[[!redirects books on algebraic geometry]]
[[!redirects book on algebraic geometry]]
[[!redirects algebraic geometry books]]
[[!redirects algebraic geometry book]]
