
# The epistemic logics $T$ and $T_{(m)}$
* table of contents
{:toc}

## Idea

The flavor of _[[modal logic]]_ called $T$ is [[propositional logic]] equipped with a single [[modality]] usually written ''$\Box$" subject to the rules that for all [[propositions]] $p, q \colon Prop$ we have

1. $\Box K \colon \Box(p \to q) \to (\Box p \to \Box q)$ ([[K modal logic]])

1. $\Box T \colon \Box p \to p$ (T modal logic)

Often one considers adding one more axiom:

* $\Box 4 \colon \Box p \to \Box \Box p$. ([[S4 modal logic]]).

In some applications especially in Artificial Intelligence,  $\Box p$ is interpreted as representing a statement that some (fixed) 'agent' knows the proposition $p$. It is then a short step to handling the idea of knowledge in a [[knowledge in a multiagent system|multiagent system]] where there may be $m$ different 'agents'.  In that setting, $\Box_i p$ interprets as 'agent $i$ knows that $p$'.  This leads to modelling of the passage of the interchange of information between neighbours, e.g. we might have three agents and the proposition that 'agent 2 knows that agent 3 does not know $p$'. 


The [[the logic K(m)|basic epistemic logics]], $K$ and $K_{(m)}$, do not reflect much of our intuition of 'knowledge'.  The $K$-axiom merely says that, if an agent knows $\phi$ and also that agent knows $\phi\to \psi$, then the agent knows $\psi$.  There are a series of additional axioms proposed as being appropriate for knowledge, (although, it seems, each has their supporters and detractors!)  These are called $T$, $(4)$, and $B$ (and please don't ask why, ... each has its own history).


## The axioms $T_i$

This is found in two equivalent forms

* $p\to M_i p$

and 

* $K_i p\to p$.

The first interprets as _if $p$ is true, then agent $i$ considers it possible_ and the second as _atomic statements known by agent $i$ are  true_ .


## The logics $T$ and $T_{(m)}$

These logics are generated by $K$ (resp. $K_{(m)}$) and the axiom $T$, (resp. axioms $T_i$ for each $i = 1,\ldots m$.


## Semantics

First looking in the monomodal case, suppose that we have a frame $\mathfrak{F} = (W,R)$ then

+-- {: .un_prop}
###### Proposition

$\mathfrak{F}\models T$ if and only if $\mathfrak{F} \models  \forall w\in W,\; R w w$.
=--

So the frames that support models for the logic $T$ are exactly the reflexive frames.
+-- {: .un_proof}
###### Proof

Suppose $\mathfrak{F}$ is a reflexive frame and take an arbitrary valuation $V$ on $\mathfrak{F}$ and a state $w$ in $\mathfrak{F}$ so that $(\mathfrak{F},V),w\models p$. We use the first form of $T$ above, and have to prove that $M p$ holds at $w$, i.e., that $p$ holds at some state 'accessible' from $w$, but as $R$ is reflexive, $w$ is accessible from itself, ... .

For the converse, we will suppose $R$ is not reflexive, so there is some state, $w \in W$ which is not $R$-related to itself. We will falsify the formula $T$ if we can find a valuation $V$ and a state $v$ such that $p$ holds at $v$ but $M p$ does not. (Recall the semantics of $M$: $\mathfrak{M},w \models M \phi$ if and only if, for some $v \in W$ such that $ R w v$, $\mathfrak{M},v \models \phi$.)

We need a state with this property and we only know about one namely $w$, so that is the obvious to try! We need a valuation such that 1) $w\in V(p)$ and 2) $\{x\in W\mid R w x\}\cap V(p)= \empty$. If we set $V(p) = \{w\}$ this works since $w$ is not related to itself. (Other values of $V$ are irrelevant.) If $w$ has no $R$-successors, then we are finished since clearly in that case, $\neg(w \models M \phi)$, so suppose that $v$ is any $R$-successor of $w$, i.e., $R w v$, then $w\neq v$, so $\neg(v\models p)$, hence $\neg(w\models M p)$ as required.$\blacksquare$
=--


[[!redirects the logic T(m)]]
[[!redirects The logic T(m)]]
[[!redirects T(m)]]

[[!redirects T modal logic]]
