
# Contents
* table of contents
{: toc}

## Idea

A 'PROP' --- an abbreviation of 'products and permutations category' --- is a [[symmetric monoidal category]] generated by a single [[object]], used to describe a given sort of algebraic structure.  One can think of PROPs as a variant of [[Lawvere theory|Lawvere theories]] suitable for non[[cartesian monoidal category|cartesian]] contexts.  In this respect they are similar to [[operad|operads]].  However, they are more general, because they can be used to describe operations with many outputs as well as many inputs.


## Definition


+-- {: .num_defn }
###### Definition
A **PROP** is a strict [[symmetric monoidal category]] where every object is of the form 

$$x^{\otimes n} = x \otimes x \otimes \cdots \otimes x$$ 

for a single object $x$ and $n \ge 0$.
=--

There is also a notion of colored PROP akin to [[colored operads]]. One way to define a colored PROP is as a certain kind of [[symmetric monoidal category]] (see Remark 2.2.14 of [Yau](#Yau)):

+-- {: .num_defn }
###### Definition

A **colored PROP** with set of colors $\mathfrak{C}$ is a strict stymmetric monoidal category $(P,\odot)$ whose [[monoid]] of objects is freely generated by $\mathfrak{C}$.

=-- 

+-- {: .num_defn }
###### Definition

A **morphism of PROPs** $\phi:Q\to T$ is just a strict symmetric monoidal functor that takes the generators for the objects of $Q$ to the generators of the objects of $T$. Equivalently, a morphism of PROPs is a pair of functions:  one from the colors of $Q$ to the colors of $T$, $\phi_c\colon Col(Q)\to Col(T)$, and for each pair of finite list of colors $\vec{x}=\{x_1,\ldots,x_n\}$ and $\vec{y}=\{y_1,\ldots,y_m\}$ in $Col(Q)$, a function $\phi_m\colon Q(\vec{x},\vec{y})\to T(\phi_c(\vec{x}),\phi_c(\vec{y}))$. The two functions $\phi_c$ and $\phi_m$ are of course required to preserve compositions, units and symmetries.
=--

Thus there is a **category of PROPs**. For more on this category, as well as some its properties, see [HR1](#HR1). 



+-- {: .num_defn }
###### Definition

Given a PROP $T$ and a symmetric monoidal category $C$, a [[symmetric monoidal functor]]

$$F : T \to C$$

is called an **algebra** or **model** of $T$ in $C$.  The category of algebras of $T$ in $C$, say $Alg(T,C)$, has

* symmetric monoidal functors $F : T \to C$ as objects,
* [[symmetric monoidal natural transformation|symmetric monoidal natural transformations]] as morphisms.

=--

Note that all of the above definitions can be [[enriched category|enriched]] over a [[symmetric monoidal category]] which yields the notion of enriched PROPs. For instance, we can have [[simplicially enriched category|simplicial]] and [[topologically enriched category|topological]] PROPs where the sets of morphisms are [[simplicial sets]] or [[topological spaces]]. 

##Model Structure on Simplicial PROPs

First, in the case that we are working only with simplicial PROPs with a fixed set of colors (or, in other words, PROPs whose free monoids of objects all have the same generators), we have the following theorem of [HR2](#HR2):

+-- {: .num_prop}
###### Proposition

There is a cofibrantly generated model structure on the category of simplicial PROPs with a fixed set of colors in which a morphism of simplicial PROPs $\phi:Q\to T$ is a weak equivalence (resp. fibration) if for each simplicial set of morphisms the induced map $Q(\vec{x},\vec{y})\to T(\vec{x},\vec{y})$ is also a weak equivalence (resp. fibration).
=--

Recall now that simplicial PROPs admit an obvious forgetful functor to [[categories]] that factors through [[simplicial categories]]. Denote this functor by $\pi_0\colon sPROP\to Cat$. Using this notation, we have (again from [HR2](#HR2)):

+-- {: .num_prop}
###### Proposition

There is a cofibrantly generated model structure on the category of all simplicial PROPs where a morphism of PROPs $\phi\colon Q\to T$ is a weak equivalence (resp. fibration) if:

* the induced morphism of mapping complexes $\phi_m\colon Q(\vec{x},\vec{y})\to T(\phi_c(\vec{x}),\phi_c(\vec{y}))$ is a weak equivalence (resp. [[Kan fibration]]) of simplicial sets, and

* the functor $\pi_0\colon\pi_0Q\to \pi_0T$ is a weak equivalence (resp. [[isofibration]]) of categories. 

=--

Note that the model structure on simplicial PROPs is _not_ the model structure on gets by lifting the model structure of [[(infinity,1)-operad|simplicial operads]] along the free forgetful adjunction between simplicial operads and simplicial PROPs. 


## Examples

### Bialgebras 

A perhaps paradigmatic example is that there is a $Vect$-enriched prop whose algebras are bialgebras. It should be observed here that there is no $Vect$-enriched [[operad]] (or cooperad) whose algebras are bialgebras, so this is a genuine example that illustrates a gain in generality of props over operads. 

See [Pirashvili](#Pirashvili) for some more details on this prop. 


### Endomorphism PROP

Given a set of colors $\mathfrak{C}$ and a [[closed category|closed]] [[symmetric monoidal category]] $E$ with a chosen collection of objects $\mathbf{X}=\{X_c\}_{c\in\mathfrak{C}}$, there is an  $E$-enriched PROP $End_{\mathbf{X}}$ with morphism $E$-mapping spaces $End_{\mathbf{X}}(\{X_i\},\{Y_j\})=E(\otimes_i X_i,\otimes_j Y_j)$.  


## Relation to Polycategories

Every PROP defines a [[polycategory]]; see there for more. PROPs can compose along many objects at once, whereas polycategories compose along a single object.

## Related concepts

* [[PRO]]
* [[polycategory]]
* [[properad]]
* [[dioperad]]

## References

* Wee Liang Gan, _Koszul Duality for Dioperads_, [(arXiv:0201074v2)](http://arxiv.org/abs/math/0201074). 
{#Gan}

* {#HR1} [[Philip Hackney]] and [[Marcy Robertson]], _On the Category of PROPs_, [arXiv:1207.2773v2](http://arxiv.org/pdf/1207.2773v2.pdf).

* {#HR2} [[Philip Hackney]] and [[Marcy Robertson]], _The Homotopy Theory of Simplicial PROPs_, [arXiv:1209.1087](http://arxiv.org/pdf/1209.1087.pdf).


*  [[Steve Lack]], _[Composing PROPs](http://www.tac.mta.ca/tac/volumes/13/9/13-09abs.html)_, [[TAC]] 13 (2004), No. 9, 147--163.

* Teimuraz Pirashvili, *On the PROP corresponding to bialgebras*, http://arxiv.org/abs/math/0110014. ([link](http://arxiv.org/abs/math/0110014)) 

* {#Yau} [[Donald Yau]], _Higher Dimensional Algebras via Colored PROPs_, [(arXiv:0809.2161v1)](http://arxiv.org/pdf/0809.2161v1.pdf).




[[!redirects PROP]]
[[!redirects PROPs]]
[[!redirects prop]]
[[!redirects props]]
