
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Variational calculus
+--{: .hide}
[[!include variational calculus - contents]]
=--
#### Physics
+--{: .hide}
[[!include physicscontents]]
=--
=--
=--


#Contents#
* table of contents
{:toc}

## Idea
 {#Idea}

What is commonly called _Noether's theorem_ or _Noether's first theorem_ is a [[theorem]] due to [[Emmy Noether]] ([Noether 1918](#Noether1918)) which makes precise and asserts that to every continuous [[symmetry of the Lagrangian]] [[physical system]] ([[prequantum field theory]]) there is naturally associated a [[conservation law]] stating the conservation of a [[charge]] ([[conserved current]]) when the [[equations of motion]] hold. 

For instance the [[time]]-translation invariance of a [[physical system]] equivalently means that the quantity of [[energy]] is conserved, and the [[spacetime|space]]-[[translation group|translation]] invariant of a physical system means that [[momentum]] is preserved.

The original and still most common formulation of the theorem is in terms of [[variational calculus]] applied to a [[local action functional]]. A modern version of this formulated properly in terms of the [[variational bicomplex]] we discuss below in 

* _[Lagrangian version -- In terms of the variational bicomplex](#InTermsOfTheVariationalBicomplex)_

There is another formulation of the same physical content, but using the formalism of [[symplectic geometry]] of [[phase spaces]]. In this formulation of [[physics]] the relation between [[symmetries of the Lagrangian]] and [[charges]]/[[conserved currents]] happens to be built deep into the formalism in terms of [[Hamiltonian flows]] generated by the [[Poisson bracket]] with a [[Hamiltonian]] function. Accordingly, in this powerful formalism Noether's theorem becomes almost a tautology. This we discuss in 

* _[Hamiltonian/symplectic version -- In terms of moment maps](#HamiltonianNoetherTheorem)_.


## Lagrangian version 
 {#InTermsOfTheVariationalBicomplex}

Here we formulate Noether's theorem for [[local action functional]] in terms of the [[variational bicomplex]] and the [[covariant phase space]].



### Simple schematic idea
 {#LagrangianVersionSimpleSchematicIdea}

Before coming to the precise and general formulation, we indicate here schematically the simple idea which underlies Noether's first theorem (in its original Lagrangian version).

Consider a [[local Lagrangian]] $L$ and assume for simplicity
that it depends only on the first [[derivatives]] $\nabla \phi$ (the [[gradient]]) of the [[field (physics)|fields]] $\phi$, hence

$$
  L \colon \phi \mapsto L(\phi, \nabla \phi)
  \,.
$$

(We write $\nabla \cdot (-)$ in the following for the [[divergence]].)

Then the [[variational derivative]] of $L$ by the fields is

$$
  \begin{aligned}
    \delta L
    & = 
    \left(\frac{\delta}{\delta \phi} L\right)  \delta \phi
    +
    \left(\frac{\delta}{\delta \nabla \phi} L\right) \cdot \nabla \delta \phi
    \\
    & =
    \left(
      \frac{\delta}{\delta \phi} L
      -
      \nabla \cdot \left(\frac{\delta}{\delta \nabla\phi}L\right)
    \right)
    \cdot (\delta \phi)
    + 
    \nabla \cdot \left( \left(\frac{\delta }{\delta \nabla \phi} L\right)
    \delta \phi
   \right)        
  \end{aligned}
  \,,
$$

where in the second step the total derivative was introduced via the [[product rule]] of [[differentiation]] $f (\nabla g) = -(\nabla f) g + \nabla (f g)$.

From this law for the variation of the Lagrangian, one derives both the [[Euler-Lagrange equation|Euler-Lagrange]] [[equations of motion]] as well as Noether's theorem by making different assumptions and setting different terms to zero:

1. Demanding that the variation $\delta \phi$ vanishes on some [[boundary]] of [[spacetime]] implies that the rightmost term in the above equation disappears in the variation $\delta S = \delta \int L$ of the [[action functional]] (by the [[Stokes theorem]]) and hence demanding that $\delta S = 0$ under variation that vanishes on the boundary is equivalent to demanding the [[Euler-Lagrange equation]]

   $$
      \frac{\delta}{\delta \phi} L
      -
      \nabla \cdot \left(\frac{\delta}{\delta \nabla\phi}L\right)
    = 0
    \,.
   $$

1. On the other hand, assuming that for given $\delta \phi$ the variation $\delta L $ vanishes when these equations of motion hold -- hence assuming that $\delta \phi$ is an _[[on-shell]] [[symmetry of the Lagrangian|symmetry]]_ of $L$ -- is equivalent to assuming that the above expression is zero even without the left term, hence that

  $$
    \nabla \cdot 
    \left(\left(\frac{\delta }{\delta \nabla\phi} L\right) \delta \phi\right)    
     = 0
    \,.
  $$

  This is the statement of _Noether's theorem_. The object

  $$
    p_\phi \delta \phi
    \coloneqq
    \left(\frac{\delta }{\delta \nabla \phi} L\right) \delta \phi
  $$

  (here $p_\phi$ is the [[canonical momentum]] of the [[field (physics)|field]] $\phi$) is called the _[[Noether current]]_ and the above says that this is ([[on-shell]]) a  [[conserved current]] precisely if $\delta \phi$ is a [[symmetry of the Lagrangian]].

This is at least the way that Noether's theorem has been introduced and is often considered. But this formulation is more restrictive than is natural. Namely it is unnatural to demand of a symmetry that it leaves the Lagrangian entirely invariant, $\delta L = 0$:
 
{#WeakSymmetrySchematicIdea} More generally for the symmetry to be a symmetry of the [[action functional]] $\int L$ over a [[closed manifold]] it is sufficient that the Lagrangian changes by a [[divergence]], $\delta L = \nabla \cdot \sigma$, for some term $\sigma$. 

(This is really a sign of a [[higher gauge symmetry]], where the symmetry holds only up to a [[homotopy]] $\sigma$. It happens for instance for the gauge-coupling term in the [[Wess-Zumino-Witten model]] because the WZW term is not strictly invariant under [[gauge transformations]], but instead transforms by a total derivative. See at _[conserved current -- In higher prequantum geometry](conserved+current#InHigherPrequantumGeometry)_).

In this more general case the above [[conservation law]] induced by the "weak" symmetry becomes

$$
  \nabla \cdot
  \left(
    p_\phi \delta \phi - \sigma
  \right)
  = 0
  \,.
$$

(This may be regarded as the [[Legendre transform]] of $\sigma$.)


### Formulation via the variational bicomplex
 {#LagrangianVersionFormalContext}

Let $X$ be a [[spacetime]] of [[dimension]] $n$, $E \to X$ a [[field bundle]], $Jet(E) \to X$ its [[jet bundle]] and write

$$
  \Omega^{\bullet,\bullet}(Jet(E)), (d = d_H + d_V)
$$ 

the corresponding [[variational bicomplex]] with $d_V$ being the vertical and $d_H$ the horizontal [[de Rham differential]].


+-- {: .num_prop #VariationOfTheLagrangian}
###### Proposition

For $\mathbf{L} \in \Omega^{n,0}(Jet(E))$ a [[local Lagrangian]] we have a unique decomposition of its [[de Rham differential]]

$$
  d L = d_V L = \mathbf{E} - d_H \Theta
$$

such that $\mathbf{E}$ is a [[source form]] -- the [[Euler-Lagrange form]] of $\mathbf{L}$ -- and for some $\Theta \in \Omega^{n-1,0}(j_\infty E)$.

=--

+-- {: .num_defn}
###### Definition

The _dynamical [[shell]]_ $\mathcal{E} \hookrightarrow Jet(E)$ is the [[zero locus]] of $\mathbf{E}$ together with its differential consequences.

The [[covariant phase space]] of the Lagrangian is the [[zero locus]]

$$ 
  \{\phi \in \Gamma(E) | \mathbf{E}(j_\infty \phi) = 0\}  
$$

that solves the [[Euler-Lagrange equation|Euler-Lagrange]] [[equations of motion]].

For $\Sigma \subset X$ any [[compact topological space|compact]] $(n-1)$-dimensional [[submanifold]], 

$$
  \delta \theta \coloneqq \delta \int_\Sigma \Theta
$$

is the [[presymplectic structure]] on [[covariant phase space]].


=--


+-- {: .num_defn #Symmetry}
###### Definition

An **infinitesimal variational [[symmetry of the Lagrangian|symmetry]]** of $\mathbf{L}$ is a [[vertical vector field]] $v$ such that 

$$
  \mathcal{L}_v \mathbf{L} = d_H \sigma_v
$$

(with $\mathcal{L}_v$ denoting the [[Lie derivative]]) for some

$$
  \sigma_v \in \Omega^{n-1,0}(Jet(E))
  \,.
$$

=--

+-- {: .num_remark}
###### Remark

By [[Cartan's magic formula]] and since $v$ is assumed vertical while $L$ is horizontal, this is equivalent to 

$$
  \iota_{v} d_V \mathbf{L} = d_H \sigma_v
  \,.
$$

=--

+-- {: .num_defn #ConservedCurrent}
###### Definition

A **[[conserved current]]** is an element

$$
  j \in \Omega^{n-1, 0}(Jet(E))
$$

which is horizontally closed on the dynamical shell

$$
  (d_H\, j)|_{\mathcal{E}} = 0
  \,.
$$

=--

With the above notions and notation, **Noether's theorem** states:

+-- {: .num_theorem #NoetherTheoremViaVariationalBicomplex}
###### Theorem

For $v \in T_v(j_\infty E)$ an infinitesimal variational symmetry according to def. \ref{Symmetry}, then 

$$
  j_v \coloneqq \sigma_v - \iota_v \Theta
$$

is a [[conserved current]], def. \ref{ConservedCurrent}.

=--

+-- {: .proof}
###### Proof

By prop. \ref{VariationOfTheLagrangian} and def. \ref{Symmetry} we have

$$
  \begin{aligned}
    d_H (\sigma_v - \iota_v \Theta)
    & =
    \iota_v d_V \mathbf{L} + \iota_v d_H \Theta
    \\
    & = \iota_v \mathbf{E}
  \end{aligned}
  \,.
$$

=--

+-- {: .num_remark}
###### Remark

A symmetry of the [[Lepage form]] 

$$
  \rho \coloneqq \mathbf{L} + \Theta
  \,.
$$

would be defined with the full differential $d = d_V + d_H$:

$$
  \mathcal{L}_v \rho = d (\sigma_v + \kappa_v)
  \,,
$$

where $\sigma$ is horizontal and $\kappa$ is vertical. 
Decomposing the result into horizontal and vertical components, 
then for vertical $v$ this is equivalent to the pair of equations

$$
  \left\{
    \array{
       \iota_v \mathbf{E} & = d_H (\sigma_v - \iota_v \Theta) 
       \\
       \iota_v \omega & = d_H \kappa_v + d_V \sigma_v 
    }
  \right.
$$

The first one expresses the conserved current corresponding to $v$ as in 
theorem \ref{NoetherTheoremViaVariationalBicomplex}, the second constrains $v$ to be a [[Hamiltonian vector field]] with respect to the presymplectic current.

=--


## Hamiltonian/symplectic version -- In terms of moment maps 
 {#HamiltonianNoetherTheorem}

### In traditional symplectic geometry

In [[symplectic geometry]] the analog of Noether's theorem is the statement that the [[moment map]] of a [[Hamiltonian action]] which preserves a given time evolution is itself conserved by this time evolution.

Souriau called this _the symplectic Noether theorem_, sometimes it is called the _Hamiltonian Noether theorem_. A review is for instance in ([Butterfield 06](#Butterfield06)).

Let $(X,\omega)$ be a [[symplectic manifold]] and let $\mathbb{R} \to \mathfrak{Poisson}(X,\omega)$ be a [[Hamiltonian action]] with [[Hamiltonian]] $H \in C^\infty(X)$, thought of as the time evolution of a [[physical system]] with [[phase space]] $(X,\omega)$.

Then let $G$ be a [[Lie group]] with [[Lie algebra]] $\mathfrak{g}$ and let $\mathfrak{g} \to \mathfrak{Poisson}(X,\omega)$ be a [[Hamiltonian action]] with [[Hamiltonian]]/[[moment map]] 
$\Phi \in C^\infty(X,\mathfrak{g}^\ast)$. We say this preserves the (time evolution-)Hamiltonian $H$ if for all $\xi \in \mathfrak{g}$ the [[Poisson bracket]] between the two vanishes, 

$$
  \delta_\xi H \coloneqq  \{\Phi(\xi), H\} = 0
  \,.
$$

In this situation now the statement of Noether's theorem is that the generators $\Phi(\xi)$ of the symmetry are preserved by the time evolution 

$$
  \frac{d}{d t} \Phi^\xi = 0
  \,.
$$

In this symplectic formulation this is immediate, because

$$
  \frac{d}{d t}\Phi^\xi = \{H,\Phi^\xi\} = - \{\Phi^\xi, H\} = 0
  \,,
$$

by the above assumtion that $H$ is preserved. Hence the "Hamiltonian Noether theorem" is all captured already by the very notion of [[Hamiltonian action]] and the  statement that the [[Poisson bracket]] is skew-symmetric (is a [[Lie algebra]] bracket).

Specifically, if one has a global [[polarization]] of $(X,\omega)$ with [[canonical coordinates]] $\{q^i\}$ and [[canonical momenta]] $\{p_i\}$ and if the symmetry action is on the canonical coordinates (on configuration space), then for $v_\xi$ the [[vector field]] corresponding to the generator $\xi$ the moment map is 

$$
  \Phi^\xi = p_i (v_\xi)^i
  \,.
$$

On the right this is the term in the form in which the conserved quantity obtained from the Nother theorem is traditionally written
(using that given a [[Lagrangian]] $L$ we have $p_i = \frac{\delta L}{\delta (\dot q^i)}$).


## Examples

### Energy-momentum current

* [[energy-momentum tensor]] -- see at _[[geometry of physics -- A first idea of quantum field theory]]_ [this example](geometry+of+physics+--+A+first+idea+of+quantum+field+theory#ScalarFieldEnergyMomentum)

### Dirac current

* [[Dirac current]] -- see at [[geometry of physics -- A first idea of quantum field theory]] [this example](geometry+of+physics+--+A+first+idea+of+quantum+field+theory#DiracCurrent)



## Related concepts

* [[conservation law]]

* [[conserved current]]

* [[charge]]

* [[moment map]]

## References
 {#References}

The original article is

* {#Noether1918} [[Emmy Noether]], _Invariante Variationsprobleme_ Nachrichten der K&#246;niglichen Gesellschaft der Wissenschaften zu  G&#246;ttingen, Math. Phys. Kl, 235 (1918). ([gdz](http://gdz.sub.uni-goettingen.de/dms/load/img/?PID=GDZPPN00250510X))
 

Lecture notes include

* _Chapter 7, Noether's theorem_ ([pdf](http://www-physics.ucsd.edu/students/courses/fall2010/physics110a/LECTURES/CH07.pdf))

* M&#225;ximo Ba&#241;ados, Ignacio A. Reyes, _A short review on Noether's theorems, gauge symmetries and boundary terms, for students_ ([arXiv:1601.03616](http://arxiv.org/abs/1601.03616)) 

A comprehensive exposition of both the Lagrangian and the Hamiltonian version of the theorem is in 

* {#Butterfield06} [[Jeremy Butterfield]], _On symmetry and conserved quantities in classical mechanics_, in _Physical Theory and its Interpretation_,
The Western Ontario Series in Philosophy of Science Volume 72, 2006, pp 43-100(2006) ([[ButterfieldNoether.pdf:file]])
 

Textbook accounts include

* [[Yvette Kosmann-Schwarzbach]], _Les th&#233;or&#232;mes de Noether:
invariance et lois de conservation au XXe si&#232;cle : avec une traduction de l'article original, "Invariante Variationsprobleme"_, Editions Ecole Polytechnique, 2004 ([pdf](http://www.math.cornell.edu/~templier/junior/The-Noether-theorems.pdf))

* {#VinogradovKrasilshchik99} [[Alexandre Vinogradov]], I. S. Krasilshchik (eds.) _Symmetries and Conservation Laws for Differential Equations of Mathematical Physics_, vol. 182 of Translations of Mathematical Monographs. American Mathematical Society, Providence, RI, 1999. ([pdf](ftp://softbank.iust.ac.ir/MathBooks/V/Vinogradov%20-%20Symmetries%20and%20Conservation%20Laws%20for%20Differential%20equations%20of%20mathematical%20physics.pdf))

For 1-parameter groups of symmetries in classical mechanics, the formulation and the proof of [[Noether's theorem]] can be found in the monograph 

* [[Vladimir Arnold]], _Mathematical methods of classical mechanics_

For more general case see for instance the books by [[Peter Olver]].

The Hamitlonian Noether theorem is also reviewed in a broader context of mathematical physics as theorem 7.3.2 in 

* [[Frédéric Paugam]], _Towards the mathematics of quantum field theory_ ([pdf](http://www.math.jussieu.fr/~fpaugam/documents/Towards-the-maths-of-QFT.pdf))


Discussion in the context of the [[variational bicomplex]] includes

* {#BarnichBrandt01} [[Glenn Barnich]], [[Friedemann Brandt]], _Covariant theory of asymptotic symmetries, conservation laws and central charges_, Nucl.Phys.B633:3-82,2002 ([arXiv:hep-th/0111246](http://arxiv.org/abs/hep-th/0111246))

Discussion of a generalization to [[discrete groups]] of symmetries includes

* Anthony Ashton, _Conservation laws and non-Lie symmetries for linear PDEs_, Journal of Non-linear Mathematical Physics, 2013 ([web](http://www.tandfonline.com/doi/pdf/10.2991/jnmp.2008.15.3.5))

The example of conserved currents in [[Chern-Simons theory]] is discussed around (5.381) on p. 925 of

* Vladimir Ivancevic, Tijana Ivancevi, _Applied differential geometry: a modern introduction_

and also in

* M. Francaviglia, M. Palese, E. Winterroth, _Locally variational invariant field equations and global currents: Chern-Simons theories_, Communications in Matheamtical Physics 20 (2012) ([pdf](http://cm.osu.cz/sites/default/files/contents/20-1/cm020-2012-1_13-22.pdf))

and for [[higher dimensional Chern-Simons theory]] in 

* G.Giachetta, L.Mangiarotti, G.Sardanashvily, _Noether conservation laws in higher-dimensional Chern-Simons theory_, Mod. Phys. Lett. A18 (2003) 2645-2651 ([arXiv:math-ph/0310067](http://arxiv.org/abs/math-ph/0310067))

A formalization of Noether's theorem in [[cohesive homotopy type theory]] is discussed in sections  "2.7 Noether symmetries and equivariant structure" and "3.2 Local observables, conserved currents and higher Poisson bracket homotopy Lie algebras" of 

* {#Schreiber13} [[Urs Schreiber]], _[[schreiber:Classical field theory via Cohesive homotopy types]]_ (2013)


A formalization of invariance of Lagrangians in [[parametricity|parametric]] [[dependent type theory]] is discussed in

* [[Robert Atkey]], _From Parametricity to Conservation Laws, via Noether's Theorem_, talk at _[Principles of Programming Languages (POPL) 2014](http://popl.mpi-sws.org/2014/index.html)_  ([pdf article](http://bentnib.org/conservation-laws.pdf), [web slides](http://bentnib.org/posts/2014-01-29-popl-slides.html), [pdf slides](http://bentnib.org/docs/conservation-laws-20140124.pdf))



[[!redirects Noether's theorems]]

[[!redirects Noether theorem]]
[[!redirects Noether theorems]]

[[!redirects symplectic Noether theorem]]
[[!redirects symplectic Noether theorems]]

[[!redirects symplectic Noether's theorem]]
[[!redirects symplectic Noether's theorems]]


[[!redirects Hamiltonian Noether theorem]]
[[!redirects Hamiltonian Noether theorems]]


[[!redirects Hamiltonian Noether's theorem]]
[[!redirects Hamiltonian Noether's theorems]]

