+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Cohomology
+--{: .hide}
[[!include cohomology - contents]]
=--
#### Homological algebra
+--{: .hide}
[[!include homological algebra - contents]]
=--
=--
=--

#Contents#
* table of contents
{:toc}

## Idea

A _Künneth theorem_ is a statement relating the [[homology]] or [[cohomology]] of two objects $X$ and $Y$ with that of their [[product]] $X \times Y$. 

In good situations it identifies the (co)homology of a product with the tensor product of the (co)homologies: $H^\bullet(X \times Y, E) \simeq H^\bullet(X,E) \otimes H^\bullet(Y,E)$. But in general this simple relation receives corrections by [[Tor]]-groups.

## Statement

### In ordinary homology
 {#InOrdinaryHomology}

We discuss the Künneth theorem in [[ordinary homology]]. 

Let $R$ be a [[ring]] and write $\mathcal{A} = R$[[Mod]] for its [[category]] of [[modules]]. 
(For instance $R = \mathbb{Z}$ the [[integers]], in which case $ \mathbb{Z} Mod \simeq$ [[Ab]] is the category of [[abelian groups]]. )

For $N_1, N_2 \in R Mod$ two [[modules]], write $N_1 \otimes N_2 \in R Mod$ for their [[tensor product of modules]]. Similarly for $C_\bullet, C'_\bullet \in Ch_\bullet(R Mod)$ two [[chain complexes]] of $R$-modules, write $(C \otimes_R C')_\bullet$ for their [[tensor product of chain complexes]]. Finally write $Tor^R_1(N_1,N_2)$ for the first [[Tor]]-module of $N_1$ with $N_2$.

We discuss the Künneth theorem over $R$ in stages, starting with important special cases and then passing to more general statements.


1. [Over a field](#InOrdinaryHomologyOverAField)

1. [Over a principal ideal domain](#OverAPrincipalIdealDomain)

1. [Over a general ring](#OverGeneralRings)

All these versions hold for chain homology and tensor products of general chain complexes. But under the [[Eilenberg-Zilber theorem]] all these statements apply directly in particular to the [[singular homology]] of [[topological spaces]] and their products. This is discussed below in 

* [For singular homology of products of topological spaces](#InOrdinaryHomologyForTopologicalSpaces)

#### Over a field
 {#InOrdinaryHomologyOverAField}

Let $R = k$ be a [[field]].

+-- {: .num_theorem #InordinaryHomology}
###### Theorem

For $R = k$ a [[field]], given two [[chain complexes]] of $k$-[[vector spaces]] $C_\bullet,C'_\bullet \in Ch_\bullet(k Vect)$, for each $n \in \mathbb{N}$ there is an [[isomorphism]]

$$
   \oplus_k \left(
     H_k\left(C_\bullet\right) \otimes_k H_{n-k}\left(C'_\bullet\right)
   \right)
     \stackrel{\simeq}{\to}
   H_n\left(
     C_\bullet \otimes_k C'_\bullet
   \right)
$$  

between the [[chain homology]] of the [[tensor product of chain complexes]] and the [[tensor product of abelian groups]] of chain homologies.

=--

For a proof see the proof of theorem \ref{InordinaryHomology} below, of which this is a special case.


#### Over a principal ideal domain
 {#OverAPrincipalIdealDomain}

Let now $R$ be a [[ring]] which is a [[principal ideal domain]]. This may be a [[field]] as above, or for instance it may be the ring $R = \mathbb{Z}$ of [[integers]], in which case $R$-modules are equivalently just [[abelian groups]].

+-- {: .num_theorem #InordinaryHomology}
###### Theorem

For $R$ a [[principal ideal domain]], given a [[chain complex]] $C_\bullet \in Ch_\bullet(R Mod)$ of [[free modules]] over $R$ and given any other chain complex $C'_\bullet \in Ch_\bullet(R Mod)$, then for each $n \in \mathbb{N}$ there is a [[short exact sequence]] of the form

$$
   0 
    \to 
   \oplus_k \left(
     H_k\left(C_\bullet\right) \otimes_R H_{n-k}\left(C'_\bullet\right)
   \right)
     \to 
   H_n\left(
     C_\bullet \otimes_R C'_\bullet
   \right)
     \to 
   \oplus_k
     Tor_1^R\left(H_k\left(C_\bullet\right), H_{n-k-1}\left(C'_\bullet\right)\right)
     \to 
   0
  \,.
$$  

=--

This appears for instance as ([Hatcher, theorem 3B.5](#Hatcher)).

+-- {: .num_remark }
###### Remark

In the special case that $C'$ is concentrated in degree 0, this is the [[universal coefficient theorem]] in ordinary homology.

=--

+-- {: .num_remark }
###### Remark

In particular if all the [[Tor]]-groups on the right vanish, then the theorem asserts an [[isomorphism]]

$$
   \oplus_k \left(
     H_k\left(C_\bullet\right) \otimes_R H_{n-k}\left(C'_\bullet\right)
   \right)
     \stackrel{\simeq}{\to}
   H_n\left(
     C_\bullet \otimes_R C'_\bullet
   \right)
  \,.
$$  

This is the case (assuming the [[axiom of choice]]) notably if $R$ is a [[field]] (since every module over a field is a [[free module]] -- every  [[vector space]] has a [[basis of a free module|basis]] -- and every free module is a [[flat module]]).

=--

+-- {: .proof}
###### Proof 
**of theorem \ref{InordinaryHomology}**

Notice that since $C_k$ is assumed to be free, hence a [[direct sum]] of $R$ with itself, since the [[tensor product of modules]] distributes over direct sums, and since [[chain homology]] respects direct sums, we have

\[
  \label{A}
  H_n(C_k \otimes_R C') 
   \simeq
  C_k \otimes_R H_{n-k}(C'_\bullet)
  \,. 
\]

First consider now the special case that all the [[differentials]] of $C_\bullet$ are [[zero morphism|zero]], so that $H_k(C_\bullet) = C_k$. In this case (eq:A) yields $H_n(C_k \otimes_R C') \simeq H_k(C_\bullet) \otimes_R H_{n-k}(C'_\bullet)$ and therefore

$$
  \begin{aligned}
    H_n(C \otimes_R C')
    &\simeq
    H_n(\oplus_k C_k \otimes_R C' ))
    \\
    & \simeq 
    \oplus_k H_n( C_k \otimes_R C' )
    \\
    & \simeq
    \oplus_k H_k(C_\bullet) \otimes_R H_{n-k}(C'_\bullet)
  \end{aligned}
  \,.
$$

Since $H_k(C) = C_k$ is a [[free module]] by assumption, it has no [[Tor]]-terms (by the discussion there) and hence this is the statement to be shown.

Now let $C_\bullet$ be a general chain complex of free modules. Notice that for each $n$ the [[cycle]]-[[chain]]-[[boundary]]-[[short exact sequence]]

$$
  0 \to Z_{n-k} \hookrightarrow C_{n-k} \stackrel{\partial_{n-k-1}}{\to} B_{n-1} \to 0
$$

[[split exact sequence|splits]] due to the assumption that $C_n$ is a [[free module]], and hence (as discussed at _[[split exact sequence]]_) that it exhibits a [[direct sum]] decomposition $C_n \simeq Z_n \oplus B_{n-1}$. Since the [[tensor product of modules]] distributes over direct sum, it follows that tensoring with any $C'_k$ yields another [[short exact sequence]]

$$
  0   
   \to 
  Z_{n-k} \otimes_R C'_k 
   \to
  C_{n-k} \otimes_R C'_k
    \to
  B_{n-k-1} \otimes_R C'_k
    \to
  0
  \,.
$$

This means that if we regard the graded modules $Z_\bullet$ and $B_\bullet$ of chains and of boundaries as chain complexes with zero-differentials, then we have a short exact sequence of chain complexes

$$
  0 \to Z_\bullet \otimes_R C'_\bullet \to C_\bullet \otimes_R C'_\bullet \to B_{\bullet-1}\otimes_R C'_\bullet  \to 0
  \,.
$$

This induces its [[homology long exact sequence]] of the form

$$
  \cdots
   \to 
  H_n( Z \otimes_R C')
   \to
  H_n( C \times_R C' )
   \to
  H_{n-1}( B \otimes_R C' )
   \to
  H_{n-1}( Z \otimes_R C' )
   \to
  \cdots
  \,.
$$

Here the terms involving the complexes $B$ and $Z$ of boundaries and cycles may be evalutated, since these have zero differentials, via the special case discussed at the beginning of this proof to yield the [[long exact sequence]]

$$
  \cdots
  \stackrel{i_n \otimes_R C'}{\to}
  \oplus_k ( Z_k \otimes_R H_{n-k}(C') )
  \to 
  H_n(C \otimes_R C')
  \to 
  \oplus_{k}( B_k \otimes_R H_{n-k-1}(C') )
   \stackrel{i_{n-1}}{\to}
  \oplus_k ( Z_k \otimes_R H_{n-k-1}(C') )
   \to  
   \cdots
  \,,
$$

where $i_n \coloneqq H_n(i \otimes C')$ is the morphism induced from the inclusion $i \colon B_\bullet \hookrightarrow Z_\bullet$ of boundaries into cycles.

This means that by quotienting out an image on the left and a kernel on the right, we obtain a [[short exact sequence]]

$$
  0 
   \to 
  coker(i_n) 
   \to 
  H_n(C \otimes_R C')
   \to 
  ker(i_{n-1})
   \to 
  0
  \,.
$$

Since the [[tensor product of modules]] is a [[right exact functor]] it commutes with the [[cokernel]] on the left, as does the formation of [[direct sums]], and so we have

$$
  coker\left( \oplus_k \left(
   B_k \otimes_R H_{n-k}(C')
   \stackrel{i_k \otimes H_{n-k}\left(C'\right)}{\to}
   Z_k \otimes_R H_{n-k}\left(C'\right)
  \right)\right)
  \simeq
  \oplus_k \left(
    \left(
      coker\left(B_k \stackrel{i_k}{\to} Z_k\right)
      \otimes_R
      H_{n-k}(C')
    \right)
  \right) 
  \simeq
  \oplus_k
  \left(
    H_k\left(C\right) \otimes_R H_{n-k}\left(C'\right)
  \right)
  \,.
$$

This is the left term in the short exact sequence to be shown. For the right term the analogous argument does not quite go through, because tensoring is not in addition a [[left exact functor]], in general. The failure to be so is precisely measured by the [[Tor]]-module: 

Notice that by the assumption that $C_n$ is free and using the fact (discussed at _[[principal ideal domain]]_) that over our $R$ the submodules $B_n, Z_n \hookrightarrow C_n$ are themselves free modules, the defining [[short exact sequence]] $0 \to B_n \stackrel{i_n}{\to} Z_n \to H_n(C) \to 0$ exhibits a [[projective resolution]] of $H_n(C)$.  Therefore by definition of [[Tor]] we have

$$
  Tor_1(H_k(C), H_{n-k}(C'))
  \simeq
  ker\left(
   i_k \otimes H_{n-k}(C')
  \right)
  \,.
$$

This identifies the term on the right of the exact sequence to be shown.

=--

#### Over general rings
 {#OverGeneralRings}

For $R$ any ring, there is a [[spectral sequence]] converging to the homology of the tensor product, whose second page involves all the [[Tor]]-modules: the _[[Künneth spectral sequence]]_ 

$$
  E_{p,q}^2 
   \coloneqq
  \oplus_{k_1 + k_2 = q}
  Tor_p^{R Mod}( H_{k_1}(C), H_{k_2}(C'))
  \Rightarrow
  H_{p+q}(C \otimes C')
$$

(...)

For instance ([Williams, section 4.2](#Williams)).

### In ordinary cohomology

+-- {: .num_prop #KunnethInOrdinaryCohomology}
###### Proposition

Let $R$ be a [[ring]] and let $X,Y$ be topological spaces. If $H^k(Y,R)$ is a finitely generated [[free module]] over $R$, then the comparison map (cross product)

$$
  H^\bullet(X,R)
  \otimes_R
  H^\bullet(Y,R)
   \longrightarrow
  H^\bullet(X\times Y, R)
$$

is an isomorphim.

=--

(e.g. [Hatcher, theorem 3.15](#Hatcher))

In more generality: ([Spanier, section 5.5, theorem 11](#Spanier))

### In Generalised cohomology theories 

The Künneth theorem for [[generalised cohomology theories]] is a special case of the [[universal coefficient theorem]].  Let $E$ be a [[ring spectrum]], $X$ and $Y$ two [[spectra]].  Then we define a new [[cohomology theory]] as the $E$-[[module spectrum]] $G \coloneqq F(Y, E)$ where $F(-,-)$ is the [[function spectrum]] (that is, the [[internal hom]] in the category of [[spectra]]).  The ([[reduced cohomology|reduced]]) cohomology of $X$ in this cohomology theory is thus given by:

$$
G^*(X) = [X,F(Y,E)] = [X \wedge Y,E] = E^*(X \wedge Y)
$$

A [[universal coefficient theorem]] gives a way of computing $G^*(X)$ from knowledge of $E^*(X)$ and $G^*(pt)$.  In this case, $G^*(pt) = E^*(Y)$ so our initial data is $E^*(X)$ and $E^*(Y)$.

For more details, see the page on the _[[universal coefficient theorem]]_.

## Examples

### For singular homology of products of topological spaces
 {#InOrdinaryHomologyForTopologicalSpaces}


All of these statements have their analogs for [[singular homology]] of [[topological spaces]] $X , Y \in $ [[Top]]: by the [[Eilenberg-Zilber theorem]] there is a [[quasi-isomorphism]]

$$
  C_\bullet(X \times Y)
  \simeq_{qi}
  C_\bullet(X) \otimes C_\bullet(Y)
$$

between the [[singular chain complex]] of the [[product space]] and the [[tensor product of chain complexes]] of the separate singular chain complexes. Hence in particular there are isomorphisms of [[singular homology]]

$$
  H_n(X \times Y) \simeq 
  H_n(C_\bullet(X) \otimes C_\bullet(Y))
  \,.
$$

Using this in the above statements of the Künneth theorem yields directly the Künneth theorem for singular homology of topological spaces.



## Related concepts

* [[Eilenberg-Zilber theorem]]

## References

### In ordinary (co)homology

The original articles are

* H. Künneth, _Über die Bettischen Zahlen einer Produktmannigfaltigkeit_ Math. Ann. , 90 (1923) pp. 65–85

* H. Künneth, _Über die Torsionszahlen von Produktmannigfaltigkeiten_ Math. Ann. , 91 (1924) pp. 125–134

Textbook accounts include

* {#Spanier} [[Edwin Spanier]], _Algebraic topology_

Lecture notes include

* Rob Thompson, _Products and the Künneth theorem_ ([pdf](http://math.hunter.cuny.edu/~rthompso/topology_notes/chapter%20nine.pdf))

Section [3.B](http://www.math.cornell.edu/~hatcher/AT/ATch3.4.pdf) of 

* {#Hatcher} [[Allen Hatcher]], _[Algebraic topology](http://www.math.cornell.edu/~hatcher/AT/ATpage.html)_
 

Section 4.2 in 

* [[Brandon Williams]], _Spectral sequences_ ([pdf](http://www.math.sunysb.edu/~mbw/notes/orals/Spectral%20Sequences.pdf))
 {#Williams}

* [[James Milne]], section 22 of _[[Lectures on Étale Cohomology]]_

### In generalized (co)homology

* [[Stefan Schwede]], part II, section 6.2 of _[[Symmetric spectra]]_ (2012)

See also the corresponding references at _[[universal coefficient theorem]]_.

In the context of [[parameterized spectra]]

* {#MaySigurdsson06} [[Peter May]], J. Sigurdsson, section 22.7 of _[[Parametrized Homotopy Theory]]_, 2006



[[!redirects Künneth formula]]

[[!redirects Kuenneth theorem]]
[[!redirects Kuenneth formula]]
[[!redirects Kunneth theorem]]
[[!redirects Kunneth formula]]
[[!redirects Künneth isomorphism]]

[[!redirects Künneth theorem for complexes]]