+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Monoidal categories
+--{: .hide}
[[!include monoidal categories - contents]]
=--
#### Category theory
+--{: .hide}
[[!include category theory - contents]]
=--
#### Higher category theory
+--{: .hide}
[[!include higher category theory - contents]]
=--
=--
=--

# String diagrams
* table of contents
{: toc}

## Overview

_String diagrams_ are a graphical calculus for expressing operations in a [[monoidal category]]. The idea is roughly to think of objects in a monoidal category as "strings" and a morphism from one tensor product to another as a node which the source strings enter and the target strings exit. Further structure on the monoidal category is encoded in geometrical properties on these strings. For instance

* putting strings next to each other denotes the monoidal product, and having no string at all denotes the unit;

* braiding strings over each other corresponds to &#8211; yes, the [[braided monoidal category|braiding]] (if any);

* bending strings around corresponds to dualities on [[dualizable object]]s (if any).

Many operations in monoidal categories that look rather unenlightening in symbols become very obvious in string diagram calculus, such as the [[trace]]: an output wire gets bent around and connects to an input.



## Variations

There are many additional structures on monoidal categories, or similar structures, which can usually be represented by encoding further geometric properties.  For instance:

* in monoidal categories which are _[[ribbon category|ribbon categories]]_ the strings from above behave as if they have a small transversal extension which makes them behave as ribbons. Accordingly, there is a _twist_ operation in the axioms of a ribbon category and graphically it corresponds to twisting the ribbons by 360 degrees.

* in a [[traced monoidal category]], the trace can be represented by bending an output string around to connect to an input, even though if the objects are not dualizable the individual "bends" do not represent anything.

* in monoidal categories which are _[[spherical category|spherical]]_ all strings behave as if drawn on a sphere.

* in a [[hypergraph category]], the string diagrams are labeled [[hypergraphs]].

* string diagrams can be extended to represent [[monoidal functors]] in several ways.  One nice way is described in [these slides](http://web.science.mq.edu.au/~mmccurdy/cms2010talk.pdf), and can also be done with "3D regions" as drawn [here](http://golem.ph.utexas.edu/category/2010/08/the_geometry_of_monoidal_fibra.html#c034428).

* there is also a string diagram calculus for [[bicategories]], which extends that for monoidal categories regarded as one-object bicategories.  Thus, the strings now represent 1-cells and the nodes 2-cells, leaving the two-dimensional planar regions cut out by the strings to represent the 0-cells.  This makes it manifest that in general, string diagram notation is _Poincar&#233; dual_ to the [[globe|globular]] notation: where one uses $d$-dimensional symbols, the other uses $(2-d)$-dimensional symbols.

* string diagrams for bicategories can be generalized to string diagrams for [[double categories]] and [[proarrow equipments]] by distinguishing between "vertical" and "horizontal" strings.

* Similarly, one can [[categorification|categorify]] this to "[[surface diagrams]]" for [[3-categories]] (including [[monoidal bicategories]]) and so on; see for instance [[toddtrimble:Surface diagrams|here]].

* As explained [here](http://sbseminar.wordpress.com/2007/07/12/the-operadic-periodic-table/), in the presence of certain levels of duality it may be better to work with diagrams on cylinders or spheres rather than in boxes. This relates to [[planar algebras]] and [[canopolis|canopolises]]. 

* A string diagram calculus for [[monoidal fibrations]] can be obtained as a generalization of C.S. Peirce's "existential graphs."  The ideas are essentially contained in ([Brady-Trimble 98](#BradyTrimble98)) and developed in ([Ponto-Shulman 12](#PontoShulman12)), and was discussed [here](http://golem.ph.utexas.edu/category/2010/08/the_geometry_of_monoidal_fibra.html).

* String diagrams for [[closed monoidal categories]] (see also at _[[Kelly-Mac Lane graph]]_) are similar to those for [[autonomous categories]], but a bit subtler, involving "boxes" to separate parts of the diagram.  They were used informally by Baez and Stay [here](#BaezQG06) and [here](#Rosetta), but can also be done in essentially the same way as the [[proof nets]] used in [[intuitionistic logic|intuitionistic]] [[linear logic]]; see [Lamarche](#Lamarche08).

* Proof nets for [[classical mathematics|classical]] [[linear logic]] similarly give string diagrams for [[*-autonomous categories]], or more generally [[linearly distributive categories]]; see [Blute-Cockett-Seely-Trimble](#BCST).

See the article by Selinger below for more examples.


## See also

* [[sharing graph]]

* [[surface diagram]]

* [[Kelly-Mac Lane diagram]]

* [[proof net]]

* [[Feynman diagram]]

* [[linguistics|natural language syntax]]

## References

### Introductory material

* [[John Baez]], QG Seminar Fall 2000 ([web](http://math.ucr.edu/home/baez/qg-fall2000/)), Winter 2001 ([web](http://math.ucr.edu/home/baez/qg-winter2001/)), Fall 2006 ([web](http://math.ucr.edu/home/baez/qg-fall2006/index.html#computation)).

* John Baez and Mike Stay, _Physics, Topology, Logic and Computation: A Rosetta Stone_, [arXiv](http://arxiv.org/abs/0903.0340)

* The Catsters (Simon Willerton), _String diagrams_ ([YouTube](http://www.youtube.com/view_play_list?p=50ABC4792BD0A086))

The higher dimensional string diagrams ("zoom complexes" ([Kock-Joyal-Batanin-Mascari 07](#KockJoyalBataninMascari07))) used for presenting [[opetopes]] in the context of [[opetopic type theory]] are introduced in 

* [[Eric Finster]], _Opetopic Diagrams 1 - Basics_ ([video](http://www.youtube.com/watch?v=OANwLohwJqk))

* [[Eric Finster]], _Opetopic Diagrams 2 - Geometry_ ([video](http://www.youtube.com/watch?v=E7OvuA1jRKM))

### Software

* [[Globular]] is a web-based proof assistant for finitely-presented semistrict globular higher categories. It allows one to formalize higher-categorical proofs in finitely-presented n-categories and visualize them as string diagrams. 

### Original articles 
 {#OriginalArticles}

[[Günter Hotz]] introduced "plane nets" (=string diagrams) and their categories in his 1965 habilitation thesis. This seems to be the first formal definition of string diagrams in the literature.

String diagrams appeared first in [[Max Kelly]] and Laplaza's paper on [[coherence theorem for monoidal categories|coherence for compact closed categories]]

* [[Max Kelly]] and M. L. Laplaza, _Coherence for compact closed categories_. Journal of Pure and Applied Algebra, 19:193&#8211;213, 1980.

+-- {: .query}
Where in Kelly-Laplaza do string diagrams appear?  I can't find any picture of a string diagram in the paper.  Perhaps they are described somewhere in the text, but I can't see it.
=--

and again in [[Ross Street]]'s work with [[André Joyal]] in the mid-80's:

* [[Andre Joyal]] and [[Ross Street]], _The geometry of tensor calculus I_, Advances in Math. 88 (1991) 55-112; MR92d:18011.  ([pdf](http://tqft.net/other-papers/Geometry%20of%20Tensor%20Calculus%20-%20Joyal%20&%20Street.pdf))

* [[Andre Joyal]] and [[Ross Street]], _The geometry of tensor calculus II_.  ([pdf](http://www.math.mq.edu.au/~street/GTCII.pdf).

An early amplification of the use of string-diagram notation as an alternative for the traditional index-calculus for [[tensors]] is due to  [[Roger Penrose]]. 

* [[Roger Penrose]], _Applications of negative dimensional tensors_ , in Combinatorial Mathematics and its Applications, Academic Press (1971) ([pdf](http://www2.math.uic.edu/~kauffman/Penrose.pdf))

Probably [[David Yetter]] was the first (at least in public) to write them  with "coupons" (a term used by [[Nicolai Reshitikhin]] and [[Turaev]] a few months later) to represent maps
which are not inherent in the (braided or symmetric compact closed) monoidal structure. See also these:

* [[Peter Freyd]], [[David Yetter]], _Braided compact closed categories with applications to low dimensional topology_ Advances in Mathematics, 77:156&#8211;182, 1989.

* [[Peter Freyd]] and [[David Yetter]], _Coherence theorems via knot theory_. Journal of Pure and Applied Algebra, 78:49&#8211;76, 1992.

* [[David Yetter]], _Framed tangles and a theorem of Deligne on braided deformations of tannakian categories_ In M. Gerstenhaber and [[Jim Stasheff]] (eds.) _Deformation Theory and Quantum Groups with Applications to Mathematical Physics_, Contemporary Mathematics 134, pages 325&#8211;349. Americal Mathematical Society,
1992.

For more on the history of the notion see the bibliography in ([Selinger 09](#Selinger)).

### Surveys

* [[Peter Selinger]], _A survey of graphical languages for monoidal categories_ ([arXiv:0908.334](http://arxiv.org/abs/0908.3347))
 {#Selinger}

* [[Ross Street]], [Low dimensional topology and higher-order categories](http://www.mta.ca/~cat-dist/CT95Docs/LowDim.ps) -- talks about surface diagrams and includes some pictures (PS version only).

* Ross Street, "Categorical structures" -- discusses string diagrams for bicategories.

* Some philosophical discussion is given in section 10.4 of [[David Corfield]], _Towards a Philosophy of Real Mathematics_, CUP, 2003.


### Details

String diagrams for [[monoidal categories]] are discussed in

* [[Andre Joyal]] and [[Ross Street]], _The geometry of tensor calculus I_, Advances in Math. 88 (1991) 55-112; MR92d:18011.  ([pdf](http://tqft.net/other-papers/Geometry%20of%20Tensor%20Calculus%20-%20Joyal%20&%20Street.pdf))

* [[Andre Joyal]] and [[Ross Street]], _The geometry of tensor calculus II_.  ([pdf](http://www.math.mq.edu.au/~street/GTCII.pdf).

* [[Andre Joyal]] and [[Ross Street]], _Planar diagrams and tensor algebra_, available [here](http://www.math.mq.edu.au/~street/PlanarDiags.pdf).


For [[1-categories]] in 

* [[Dan Marsden]], _Category Theory Using String Diagrams_, ([arXiv:1401.7220](https://arxiv.org/abs/1401.7220)).

(therein: many explicit calculations, colored illustrations, avoiding the common practice of indicating 0-cells by non-filled circles)

For [[traced monoidal categories]] in

* [[Andre Joyal]], [[Ross Street]] and [[Dominic Verity|Verity]], _Traced monoidal categories_.

*  David I. Spivak, Patrick Schultz, Dylan Rupel, _String diagrams for traced and compact categories are oriented 1-cobordisms_, [arxiv](https://arxiv.org/abs/1508.01069)

For [[closed monoidal categories]] in

* [[John Baez]], Quantum Gravity Seminar - Fall 2006.  &lt;http://math.ucr.edu/home/baez/qg-fall2006/index.html#computation&gt;
 {#BaezQG06}

* [[John Baez]] and [[Mike Stay]], *Physics, Topology, Logic and Computation: A Rosetta Stone*, [arxiv](https://arxiv.org/abs/0903.0340)
 {#Rosetta}

* Francois Lamarche, *Proof Nets for Intuitionistic Linear Logic: Essential nets*, 2008 [pdf](http://hal.inria.fr/docs/00/34/73/36/PDF/prfnet1.pdf)
 {#Lamarche08}

For [[linearly distributive categories]] in 

* [[Richard Blute]] and [[Robin Cockett]] and [[R.A.G. Seely]] and [[Todd Trimble]], *Natural deduction and coherence for weakly distributive categories.
 {#BCST}

For [[indexed monoidal categories]] in

* {#BradyTrimble98} Geraldine Brady, [[Todd Trimble]], _[[A string diagram calculus for predicate logic]]_ (1998)

* {#PontoShulman12} [[Kate Ponto]], [[Michael Shulman]], _Duality and traces for indexed monoidal categories_, Theory and Applications of Categories, Vol. 26, 2012, No. 23, pp 582-659 ([arXiv:1211.1555](http://arxiv.org/abs/1211.1555))

The generalization of string diagrams to one dimension higher is discussed in

* [[Todd Trimble]], _[Surface diagrams](/toddtrimble/published/Surface+diagrams)_

* [[John Barrett]], [[Catherine Meusburger]], [[Gregor Schaumann]], _Gray categories with duals and their diagrams_, available [here](http://arxiv.org/abs/1211.0529).

The generalization to arbitrary dimension in terms of [[opetope|opetopic]] "zoom complexes" is due to 

* {#KockJoyalBataninMascari07} [[Joachim Kock]], [[André Joyal]], [[Michael Batanin]], [[Jean-François Mascari]], _Polynomial functors and opetopes_ ([arXiv:0706.1033](http://arxiv.org/abs/0706.1033)) 

Discussion for [[double categories]] and [[2-category equipped with proarrows|pro-arrow equipments]] is in 

* {#Myers16} David Jaz Myers, _String Diagrams For Double Categories and (Virtual) Equipments_ ([arXiv:1612.02762](https://arxiv.org/abs/1612.02762))

See also at _[[opetopic type theory]]_.


[[!redirects string diagram]]
[[!redirects string diagrams]]
[[!redirects circuit diagram]]
[[!redirects circuit diagrams]]
[[!redirects graphical calculus]]
