
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Modalities, Closure and Reflection
+-- {: .hide}
[[!include modalities - contents]]
=--
=--
=--


# Contents #
* table of contents 
{: toc}

## Idea 

The concept of *matroid*, due to Hassler Whitney, is fundamental to [[combinatorics]], giving several different ways of encoding/defining and presenting a general notion of "independence", e.g., [[linearly independent subset|linear independence]] in a [[vector space]], algebraic independence in a [[field extension]], etc. 

There is also a similar concept of an [[oriented matroid]]; every oriented matroid has an underlying matroid. 

## Definitions 

+-- {: .num_defn} 
###### Definition 
A **matroid** on a set $X$ is a [[Moore closure|closure operator]] $cl: P(X) \to P(X)$ satisfying the _exchange axiom_: if $a \in cl(S \cup\{b\}) \cap \neg cl(S)$, then $b \in cl(S \cup\{a\}) \cap \neg cl(S)$. 
=-- 

Usually when combinatorialists speak of matroids as such, $X$ is taken to be a [[finite set]]. A typical example is $X$ some finite subset of a vector space $V$, taking $cl(S) \coloneqq X \cap Span(S)$ for any $S \subseteq X$. 

Under this definition, a subset $S \subseteq X$ is _independent_ if there is a strict inclusion $cl(T) \subset cl(S)$ for every strict inclusion $T \subset S$ (this is the same as requiring $x \notin cl(S\setminus \{x\})$ for every $x \in S$). Again under this definition, $S$ is a _basis_ if $cl(S) = X$ and $S$ is independent. A _hyperplane_ is a closed subset $S$ (meaning $cl(S) = S$) that is maximal among proper closed subsets of $X$. It is possible to axiomatize the notion of matroid by taking bases as the primitive notion, or independent sets as the primitive notion, or hyperplanes as the primitive notion, etc. -- Rota (after Birkhoff) speaks of _cryptomorphism_ between these differing definitions. Much of the power and utility of matroid theory comes from this multiplicity of definitions and the possibility of moving seamlessly between them; for example, a matroid structure might be easy to detect from the viewpoint of one definition, but not from another. 

+-- {: .num_prop #dim1} 
###### Proposition 
Any two bases of a matroid $X$ have the same [[cardinality]], provided that one of them is finite.  
=-- 

The cardinality of such a basis is called of course the _dimension_ of the matroid. Clearly then a finite matroid has a well-defined dimension. 

+-- {: .proof} 
###### Proof 
First, suppose $A$ is an independent set and $B$ is a finite basis, and suppose there are subsets $A_0 \subseteq A, B_0 \subseteq B$ such that $A_0 \cup B_0$ is a basis. We claim that for each $a \in A \setminus A_0$, there exists $b \in B_0$ such that $A_0 \cup \{a\} \cup (B_0 \setminus \{b\})$ is a basis. For, let $C \subseteq B_0$ be of minimum cardinality such that $a \in cl(A_0 \cup C)$; we know $C$ must be inhabited since $a \notin cl(A \setminus \{a\}) \supseteq cl(A_0)$; clearly $C \cap A_0 = \emptyset$. So let $b$ be an element of $C$. Since by minimality of $C$ we have  

$$a \in cl(A_0 \cup (C \setminus \{b\}) \cup \{b\}) \cap \neg cl(A_0 \cup (C \setminus \{b\})),$$ 

it follows from the exchange axiom that $b \in cl(A_0 \cup (C \setminus \{b\}) \cup \{a\})$. Thus $b \in cl(A_0 \cup (B_0 \setminus \{b\}) \cup \{a\})$, whence 

$$cl(A_0 \cup (B_0 \setminus \{b\}) \cup \{a\}) = cl(A_0 \cup B_0 \cup \{a\}) = X$$ 

so that $D \coloneqq A_0 \cup (B_0 \setminus \{b\}) \cup \{a\}$ "spans" $X$. Also $D$ is independent: if $x \in D$ and $x \neq a$, then 

$$cl(D \setminus \{x\}) \subseteq cl((A_0 \cup B_0) \setminus \{x\})$$ 

with neither side containing $x$ since $A_0 \cup B_0$ is independent; whereas if $x = a$ and supposing to the contrary that $a \in cl(D \setminus \{a\}) = cl((A_0 \cup (B_0 \setminus \{b\}))$, we conclude $A_0 \cup (B \setminus \{b\})$ has the same span as $D$. Since $D$ already spans, $b \in cl(A_0 \cup (B_0 \setminus \{b\}))$, again impossible since $A_0 \cup B_0$ is independent. This proves the claim. 

Again assuming $A$ independent and $B$ is a finite basis, now we show that $card(A) \leq card(B)$, which will finish the proof. Let $n = card(B)$, and suppose on the contrary that there are distinct elements $a_1, \ldots, a_{n+1} \in A$. Set $A_0 = \emptyset$ and $B_0 = B$. Applying the claim above inductively, we have that $\{a_1, \ldots, a_i\} \cup (B \setminus \{b_1, \ldots, b_i\})$ is a basis for $1 \leq i \leq n$, so in particular $\{a_1, \ldots, a_n\}$ spans $X$. Hence $a_{n+1} \in cl(\{a_1, \ldots, a_{n}\})$, contradicting the independence of $A$. 
=-- 

## Examples 

Vector spaces, algebraic closures, graphs, restrictions, localizations, ... 

* A *graphic matroid* is a matroid $M$ derived from a [[simple graph]] by taking the underlying set of $M$ to be the set of edges $E$, and taking as independent sets of $M$ those $S \subseteq E$ such that the edges of $S$ (and their incident vertices) form a [[forest]], i.e., a graph without cycles.  

* If $M$ is a (finite) matroid, then the *matroid dual* $M^\ast$ of $M$ has the same underlying set as $M$, and where a basis in $M^\ast$ is precisely the complement of a basis of $M$. It follows that $M^{\ast\ast} \cong M$ (this is even an equality according to the definition). 

## Model-theoretic geometry 

Essentially the very same notion arises in model theory, except instead of being called a matroid it is called a "pregeometry" or "geometry", and in contrast to combinatorialists, model theorists usually mean _infinite_ matroids. The notion arises in the study of geometry of strongly minimal sets, with applications to stability theory (part of Shelah's classification theory). 

+-- {: .num_defn} 
###### Definition 
A _pregeometry_ is a (possibly infinite) matroid (given by a set $X$ equipped with a closure operator $cl$) that is _finitary_: for all $S \subseteq X$, if $x \in cl(S)$ then $x \in cl(S_0)$ for some finite subset $S_0 \subseteq S$. A **geometry** is a pregeometry such that $cl(\emptyset) = \emptyset$ and $cl(\{x\}) = \{x\}$ for every $x \in X$. 
=-- 

(See also [[geometric stability theory]].) 

The language of independence, spanning, and basis carry over as before. A maximal independent set spans (i.e., is a basis), and maximal independent sets exist according to [[axiom of choice|Zorn's lemma]]. Again we have a notion of dimension by the following proposition. 

+-- {: .num_prop #welldefined} 
###### Proposition 
In a pregeometry $(X, cl)$, any two bases have the same cardinality. 
=-- 

+-- {: .proof} 
###### Proof 
We already [proved this](#dim1) in the case where the pregeometry has a finite basis. Otherwise, if $A$ is independent and $B$ is an infinite basis, then 

$$A = A \cap X = A \cap \bigcup_{B_0 \subseteq B\; finite} cl(B_0) = \bigcup_{B_0 \subseteq B\; finite} A \cap cl(B_0)$$ 

where the second equality follows from the finitary condition. Since each summand $A \cap cl(B_0)$ has cardinality less than that of $B_0$ by independence of $A$ (noting that $B_0$ is a basis of $cl(B_0)$), the union on the right has cardinality bounded above by $card(B)$. From $card(A) \leq card(B)$ it follows that any two bases have the same cardinality. 
=-- 


## Combinatorial optimization 


## Mnev's theorem 

Mnëv's universality theorem says that any [[semialgebraic set]] in $\mathbb{R}^n$ defined over integers is stably equivalent to the realization space of some oriented matroid. 

## Categories of matroids 

To be written, possibly with some original research. 

## References 

* wikipedia [matroid](http://en.wikipedia.org/wiki/Matroid), [Mnëv's universality theorem](http://en.wikipedia.org/wiki/Mnev%27s_universality_theorem), [oriented matroid](http://en.wikipedia.org/wiki/Oriented_matroid)
* Hassler Whitney, _On the abstract properties of linear dependence_, American Journal of Mathematics (The Johns Hopkins University Press) 57 (3): 509–533, 1935, [jstor](http://jstor.org/stable/2371182), [MR1507091](http://www.ams.org/mathscinet-getitem?mr=1507091)
* J. Oxley, _What is a matroid_, [pdf](http://www.math.lsu.edu/~oxley/survey4.pdf)
* James G. Oxley, _Matroid theory_, Oxford Grad. Texts in Math. 1992, 2010
* some papers on Coxeter matroids [html](http://www.math.ufl.edu/~white/cox.html)
* MathOverflow question [Mnëv's universality corollaries, quantitative versions](http://mathoverflow.net/questions/72154/mnevs-universality-corollaries-quantitative-versions) 
* Eric Katz, Sam Payne, _Realization space for [[tropical geometry|tropical]] fans_, [pdf](http://users.math.yale.edu/~sp547/pdf/Realization-spaces.pdf)
* Nikolai E. Mnev, _The universality theorems on the classification problem of configuration varieties and convex polytopes varieties_, pp. 527-543, in "Topology and geometry: Rohlin Seminar." Edited by O. Ya. Viro. Lecture Notes in Mathematics, __1346__, Springer 1988; _A lecture on universality theorem_ (in Russian) [pdf](http://club.pdmi.ras.ru/~panina/9.pdf)
* Talal Ali Al-Hawary, _Free objects in the category of geometries_, [pdf](http://www.emis.de/journals/HOA/IJMMS/Volume26_12/770.pdf)
* Talal Ali Al-Hawary, D. George McRae, _Toward an elementary axiomatic theory of the category of LP-matroids_, Applied Categorical Structures __11__: 157–169, 2003, [doi](http://dx.doi.org/10.1023/A:1023557229668)
* Hirokazu Nishimura, Susumu Kuroda, _A lost mathematician, Takeo Nakasawa: the forgotten father of matroid theory_ 1996, 2009
* William H. Cunningham, _Matching, matroids, and extensions_, Math. Program., Ser. B __91__: 515–542 (2002) [doi](http://dx.doi.org/10.1007/s101070100256)
* L. Lovász, _Matroid matching and some applications_, J. Combinatorial Theory B __28__, 208–236 (1980)
* A. Björner, M. Las Vergnas, B. Sturmfels, N. White, G.M. Ziegler,  _Oriented matroids_, Cambridge Univ. Press 1993, 2000, [view at reslib.com](http://reslib.com/book/Oriented_Matroids)
* Matthew Baker, _Matroids over hyperfields_, [arxiv/1601.01204](http://arxiv.org/abs/1601.01204)
* David Marker, _Model Theory: An Introduction_, Graduate Texts in Math. 217, Springer-Verlag New York, 2002. 
* Tom Braden, Carl Mautner, _Matroidal Schur algebras_, [arxiv/1609.04507](http://arxiv.org/abs/1609.04507)
* P. S. Kung, _A Source Book in Matroid Theory_, Birkhäuser, Boston, 1986.

[[!redirects matroids]] 
[[!redirects pregeometry]]
[[!redirects pregeometries]]