
# MV algebras
* table of contents
{: toc}

## Idea

An MV-algebra  is an algebraic structure which models Luzasiewicz multivalued logic, and  the fragment of that calculus which deals with the basic logical connectives "and", "or", and "not", but in a multivalued context.


## Definitions

An MV-algebra consists of

* a non-empty set, $A$;

* a binary operation, $\oplus$, on $A$;

* a unary operation, $\neg$, on $A$; and a constant, $0$, such that


1. $\langle A, \oplus, 0\rangle$ is a commutative [[monoid]];

1. $\neg\neg x =  x$ for all $x \in A$;

1. $x\oplus \neg 0 = \neg 0$ for all $x\in A$; and 

1. $\neg(\neg x\oplus y)\oplus y = \neg(\neg y\oplus x)\oplus x$ for all $x, y$ in $A$.



The last axiom is more difficult to interpret but is clarified by some examples.


+-- {: .num_example}
###### Example

Let $A = [0,1]$ be the unit interval.  Define

$$x\oplus y = min(1,x+y)$$

$$\neg x = 1-x.$$

This gives a commutative monoid easily enough and the double negation and absorption axioms are easy to check. Finally the last axiom divides into two cases: $x \lt y$ and $y \lt x$ and only one of these needs checking!

=--


+-- {: .num_example}
###### Example 

Any [[Boolean algebra]] defines a MV-algebra with $\oplus = \vee$, and $\neg$ being the complement operation. The expressions in the last axiom evaluate to $x\vee y$.

=-- 

## Properties 

Define $x \odot y \coloneqq \neg (\neg x \oplus \neg y)$, and define $x \Rightarrow y \coloneqq \neg x \oplus y$. 

+-- {: .un_prop}
######Proposition 1
Each MV algebra carries a lattice structure, where the join and meet operations are defined by 

$$x \vee y = (x \odot \neg y) \oplus y$$ 

$$x \wedge y = x \odot (\neg x \oplus y)$$ 

and where $0$ and $1 = \neg 0$ are the bottom and top elements. 
=-- 

Let $\leq$ be the partial ordering for the lattice structure, where $x \leq y$ if $x = x \wedge y$. 

+-- {: .un_prop} 
######Proposition 2
Each MV algebra is a [[residuated lattice]], i.e., a closed monoidal poset, where the monoidal product is $\odot$ and 
$$x \odot y \leq z \qquad iff \qquad x \leq y \Rightarrow z.$$
In particular, for all elements $x$ and $y$ we have $1 = y \Rightarrow y$, $1 \Rightarrow y = y$, and $x \leq (x \Rightarrow y) \Rightarrow y$. 
=-- 

In fact, an MV algebra is a $\ast$-[[star-autonomous category|autonomous]] poset, where $\neg x = x \Rightarrow 0$. 

+-- {: .un_prop}
######Proposition 3 
The equational variety of MV algebras is a [[Mal'cev variety]], where the Mal'cev operation is defined by 

$$t(x, y, z) = ((x \Rightarrow y) \Rightarrow z) \wedge ((z \Rightarrow y) \Rightarrow x).$$  

In other words, $t(x, y, y) = x = t(y, y, x)$. 
=-- 

+-- {: .un_thm}
######Completeness theorem
The variety of MV algebras is generated by $[0, 1]$ with its standard MV algebra structure. Consequently, an identity holds for all MV algebras if and only if it holds in $[0, 1]$. 
=-- 


##References

*  D. Mundici, _MV-algebras, a short tutorial_, available [here](http://www.matematica.uns.edu.ar/IXCongresoMonteiro/spanish.htm#cursos).

A recent preprint is

* [[Mark Lawson]], [[Philip Scott]], _AF inverse monoids and the structure of countable MV-algebras_, [ArXiv 1408.1231v2](http://arxiv.org/abs/1408.1231)