
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Foundations
+-- {: .hide}
[[!include foundations - contents]]
=--
#### $(0,1)$-Category theory
+--{: .hide}
[[!include (0,1)-category theory - contents]]
=--
#### Type theory
+-- {: .hide}
[[!include type theory - contents]]
=--
=--
=--

# Axiom schemes of separation
* table of contents
{: toc}

## Idea

In [[set theory]], the __axiom scheme of separation__ aka __specification__ states that, given any [[set]] $X$ and any [[property]] $P$ of the [[elements]] of $X$, there is a set
$$ \{ X | P \} = \{ a \in X \;|\; P(a) \} $$
consisting precisely of those elements of $X$ for which $P$ holds:
$$ a \in \{ X | P \} \;\leftrightarrow\; a \in X \;\wedge\; P(a) .$$
Note that $\{X|P\}$ is a [[subset]] of $X$.

It is important to specify what language $P$ can be written in.  This connects the axiom to [[logic]] and the [[foundations of mathematics]].  Arguably, [[first-order logic]] developed in order to explain the meaning of [[Ernst Zermelo]]\'s axiom of separation (although Zermelo himself disagreed with the interpretation that this gave).  Separation is (usually) given as an axiom *scheme* because there is one axiom for each way to state a property in the language.  (We also allow parameters in $P$.)


## Statements

From weaker to stronger:

*  For __bounded separation__ aka __restricted separation__ aka __$\Delta_0$-separation__, $P$ must be written in the language of first-order set theory and all [[quantifications]] must be guarded by a set: of the form $\forall x \in A$ or $\exists x \in A$ for some set $A$.

*  For __limited separation__ aka __$\Delta_0^{\mathcal{P}}$-separation__, $P$ must be written in the language of first-order set theory and all quantifications must be guarded by a set or a [[power class]]: of the form $\forall x \in A$, $\exists B \subseteq A$, etc.  Limited separation trivially implies bounded separation, while bounded separation implies limited separation if [[power sets]] exist.

*  For __full separation__ aka simply __separation__, $P$ must be written in the language of first-order set theory, but otherwise anything goes; in a [[class theory]], $P$ must be guarded by a class.  Full separation trivially implies limited separation.

*  For __large separation__, $P$ must be written in the language of first-order class theory; of course, this only makes sense *in* a class theory.  The difference in strength between the class theories $MK$ and $NBG$ is precisely that the former has large separation but the latter does not.

*  Separation is sometimes called __restricted comprehension__; for __full comprehension__ aka simply __comprehension__, no set $X$ needs to be given ahead of time.  Full comprehension was proposed by [[Gottlob Frege]], but leads to [[Russell's paradox]].  However, full comprehension can sometimes be allowed if the ambient logic is nonclassical, such as [[linear logic]] or [[paraconsistent logic]].

*  For __stratified comprehension__, no set $X$ is given, but $P$ is restricted to stratified formulas, in which each [[variable]] $x$ can be given a consistent [[natural number]] $\sigma(x)$ (its stratification) such that $x \in y$ appears in the formula only if $\sigma(y) = \sigma(x) + 1$.  This is used in [[Van Quine]]\'s [[New Foundations]].


## In structural set theory

Set theory is usually given in [[material set theory|material]] form, with a language based on a global membership relation $\in$, and we have implicitly followed this above.  However, separation makes sense also in [[structural set theory]] (although full comprehension does not, except in a structural class theory with a [[class of all sets]], where it again leads to paradox).  The conclusion of the axiom is the existence of a set
$$ \{ X | P \} = \{ a\colon X \;|\; P(a) \} $$
and an [[injection]] $i_P\colon \{X|P\} \to X$ such that
$$ \exists b\colon S,\; a = i_P(b) \;\leftrightarrow\; P(a) .$$
Note that $\{X|P\}$, equipped with $i_P$, is a [[subset]] of $X$ in the structural sense.

The structural axioms can of course be stated even in a material set theory, where they are actually weaker than the corresponding material axioms; however, the material axioms follow (as usual) from the structural axioms using [[axiom of replacement|restricted replacement]], which is quite weak (and also follows from the material form of bounded separation).

If a structural set theory is given by stating axioms for the [[category of sets]], then restricted separation amounts to the property that this category is a [[Heyting category]].  If it is an [[elementary topos]], then since it satisfies the power set axiom, this implies limited separation as well.  Full separation is somewhat less natural to state category-theoretically, but the combination of full separation with the structural [[axiom of collection]] is equivalent to saying that the category of sets is [[autological category|autological]].


## In hyperdoctrines

### Lawvere's definition
 {#LawvereDefinition}

[[Lawvere]] gives a definition ([Lawvere70, p. 12-13](#Lawvere70)) of comprehension in [[hyperdoctrines]].

+-- {: .num_defn #LawvereianComprehension}
###### Definition

Let $p \colon E \to B$ be a [[bifibration]] over the category $B$, and assume that each [[fibre]] $E_X$ of $E$ has a [[terminal object]] $T_X$.  For any [[morphism]] $t \colon Y \to X$ in $B$, define the _image_ $im t$ of $t$ to be the pushforward ([[dependent sum]]) $t_! T_Y$.  This gives rise to a functor $im \colon B/X \to E_X$ for each $X$.  Then $E$ is said to _have comprehension_, or to satisfy the _comprehension schema_, if each image functor has a [[right adjoint]] $\{-\} \colon E_X \to B/X$.

=--

+-- {: .num_remark}
###### Remark

This means that for each $P \in E_X$ there is a morphism $i_P \colon \{ P \} \to X$ in $B$ such that there is a [[bijection]] between commuting triangles $t = i_P \circ t'$ in $B$ and morphisms $im t \to P$ in $E_X$.  Lawvere calls the morphism $\{P\} \to X$ the _[[extension (semantics)|extension]]_ of $P$, so that one could say that $E$ satisfies the comprehension schema if the extensions of all predicates exist.

=--

### Ehrhard's reformulation

Notice that, in the above situation, morphisms $\im t \to P$ in $E_X$ are in bijection with morphisms $T_Y \to t^* P$ in $E_Y$, and that these are the same as morphisms $T_Y \to P$ in the total category $E$ that lie over $t$.  This leads to an alternative formulation of the definition, originally considered by [Ehrhard 1988](#Ehrhard88) (see also [Jacobs 1993](#Jacobs93), [Jacobs 99](#Jacobs99)). If the fibres $E_X$ have terminal objects, then there is a ([[fully faithful]]) functor $B \to E$ that sends $X$ to $T_X$, and this is in fact right adjoint to the projection $E \to B$.  Comprehension in the sense above is equivalent to the existence of a further right adjoint to this terminal-object functor (and in fact this version does not require pushforwards in $E$).

The implication from [Lawvere's definition](#LawvereDefinition) to Ehrhard's is clear.  Conversely, if a fibration $p \colon E \to B$ satisfies the Ehrhard definition, then there is a bijection between morphisms $T_Y \to P$ in $E$ and morphisms $Y \to \{P\}$ in $B$.  One must then show that the composite of this last with the canonical $\{P\} \to X$ (given by $p$ applied to the counit $T_{\{P\}} \to P$) is equal to $p$ applied to the morphism $Y \to \{P\}$, thus giving a morphism in $B/X$ of the right sort.  But in fact the morphism $Y \to \{P\}$ is unique with the property that applying the functor $T_{-}$ and composing with the counit gives the morphism $T_Y \to P$, by the counit's universal property, and applying $p$ to this commuting triangle in $E$ produces the required one in $B$.

### Examples

#### Subsets

The tautological example which is useful to see what the abstract [definition by Lawvere](#LawvereDefinition) axiomatizes is the following.

Let $B = $[[Set]] be the category of sets and for $X$ a [[set]] let $E_X$ be the [[poset]] of [[subsets]] of $X$, regarded as the [[propositions]] about elements in $X$. Then comprehension exists and is given by sending a subset of $X$ regarded as an object of $E_X$ (hence regarded as a proposition) to the same subset, but now regarded as a [[monomorphism]] in [[Set]] into $X$.

More generally, the same construction works for the posets of subobjects in any [[regular category]].

#### Presheaves

There is a functor $Cat_1^{op} \to CAT_1$, from the [[large category|large]] [[Cat|1-category of categories]] and functors to the '[[very large category|very large]]' 1-category of large categories and functors, that sends a category $C$ to the [[category of presheaves]] $[C^{op}, Set]$  on $C$, and a functor $F \colon C \to D$ to the pullback functor $F^* \colon [D^{op}, Set] \to [C^{op}, Set]$.  These pullback functors have left and right adjoints given by [[Kan extension]].

[Lawvere 70](#Lawvere70) shows that this fibration has comprehension, with the [[extension (semantics)|extension]] of a presheaf given by its [[category of elements]] together with the canonical projection from this to the base category.

#### In dependent linear type theory
 {#ExamplesDependentLinearTypeTheory}

If the [[hyperdoctrine]] has [[linear type theories]]/[[symmetric monoidal categories]] as fibers, then it is more natural to consider in def. \ref{LawvereianComprehension} not the [[terminal object]] in some fiber (if any) but the [[tensor unit]] (which of course happens to be the terminal object in the case of [[cartesian monoidal category|cartesian monoidal]]) fibers.

In this case then the image functor in def. \ref{LawvereianComprehension} is 

$$
  \Sigma_X \;\colon\; (Y \stackrel{f}{\to} X) \mapsto \underset{f}{\sum} 1_Y 
  \,.
$$

If this has a [[right adjoint]] $R_X$, hence if we have linear comprehension according to def. \ref{LawvereianComprehension}, then the induced [[comonad]]

$$
  !_X \coloneqq \Sigma_X \circ R_X
$$

is (the [[dependent type theory|dependent]] version of) the canonical [[categorical semantics|categorical interpretation]] of the [[!-modality]] of [[linear logic]]. See at _[dependent linear type theory --  The canonical co-modality](http://ncatlab.org/nlab/show/dependent+linear+type+theory#TheCanonicalComodality)_ for more.

### The comprehensive factorization system

If the extension functors $E_X \to B/X$ are [[fully faithful]], then together they make $E$ into a 'fibrewise [[reflective subcategory|reflective]]' subfibration of the codomain fibration of $B$, which is a reflective subfibration if the image functors preserve pullbacks.  (See [[stable factorization system]].)

Call a morphism of the form $\{P\} \to X$ a _subtype inclusion_.  Every morphism $t \colon Y \to X$ of $B$ factors through one such by means of the unit $\eta_t$ of the adjunction $im \dashv \{-\}$:
$$
\array{
  Y & & \overset{\eta_t}{\to} & & \{ im t \} \\
  & \mathllap{t}\searrow & & \swarrow\mathrlap{i_t} & \\
  & & X & &
}
$$
This gives rise to an [[orthogonal factorization system]] precisely when each $\eta_t$ is [[orthogonal]] to all subtype inclusions.
It is shown by [(Carboni et. al., section 2.12)](#Carboni97) that this holds if and only if subtype inclusions are closed under composition.

For the subobject fibration of a regular category, this gives the usual ([[regular epimorphism|regular epi]], [[monomorphism|mono]]) factorization system, while for the fibration of presheaves over $Cat$ it gives the factorization of a functor into a [[final functor]] followed by a [[discrete fibration]].  (See also [[michaelshulman:comprehensive factorization]] for a description of the latter as a [[factorization system in a 2-category]].)


## Axiom or axiom scheme?

Although usually presented as an axiom scheme, in many cases, all instances of separation follow from finitely many special cases (which can then be packaged into a single axiom, using [[and|conjunction]], although this is probably pointless).  This is the case, for example, in [[ETCS]] (a structural set theory that satisfied bounded separation) and [[NBG]] (a material class theory that satisfies full separation).  In [[type theory|type-theoretic]] foundations of mathematics, separation is usually invisible, but again some form (generally only bounded) can again be proved from a few specific axioms or constructions.


## Relation to the axiom of replacement

Full separation follows from the [[axiom of replacement]] and the principle of [[excluded middle]] (along with the axiom of the [[empty set]]).  Therefore, the axiom is often left out entirely of a description of [[ZFC]] (the usually accepted foundation of mathematics).  In versions of set theory for [[constructive mathematics]], however, we often have replacement but only bounded or limited separation, and in any case separation must be listed explicitly.

## References

### General

(...)

### In hyperdoctrines

* [[Lawvere]], F. W. _Equality in hyperdoctrines and comprehension schema as an adjoint functor_.  In A. Heller, ed., _Proc. New York Symp. on Applications of Categorical Algebra_, pp. 1--14.  AMS, 1970. ([[LawvereComprehension.pdf:file]])
 {#Lawvere70}

* [[Lawvere]], F. W. _Metric spaces, generalized logic and closed categories_ Rend. Sem. Mat. Fis. Milano, 43:135–166 (1973). Reprints in Theory and Applications of Categories, No. 1 (2002) pp 1-37 ([tac](http://www.tac.mta.ca/tac/reprints/articles/1/tr1abs.html))
 {#Lawvere73}

* [[Thomas Ehrhard]]. A Categorical Semantics of Constructions. LICS 1988. ([pdf](https://www.irif.univ-paris-diderot.fr/~ehrhard/pub/categ-sem-constr.pdf))
 {#Ehrhard88}

* [[Bart Jacobs]]. Comprehension categories and the semantics of type dependency. _Theoretical Computer Science_ 107:2 (1993), pp. 169-207.
 {#Jacobs93}

* [[Bart Jacobs]].  _Categorical Logic and Type Theory_.  Elsevier, 1999.
 {#Jacobs99}

* [[Finn Lawler]], section "Tabulation and comprehension" in _[[finnlawler:thesis outline|Fibrations of predicates and bicategories of relations]]_ (2014)

* Carboni, Janelidze, Kelly, Paré. _On localization and stabilization for factorization systems_.  Applied Categorical Structures, 1997.
 {#Carboni97}

### In linear logic

Full comprehension (a.k.a. "naive set theory") in the context of logic without the [[contraction rule]] is discussed in:

* Grishin, V. N., "Predicate and set theoretic calculi based on logic without contraction rules" (Russian), _Izvestiya Akademii Nauk SSSR Seriya Matematicheskaya_, 45(1): 47 – 68, 1981. English translation in Math. USSR Izv., 18(1): 41 – 59, 1982. ([math-net.ru](http://www.mathnet.ru/php/archive.phtml?wshow=paper&jrnid=im&paperid=1547&option_lang=eng))

* [[Jean-Yves Girard]], Light Linear Logic, _Information and Computation_, 14(3):123-137, 2003. ([pdf.gz](http://iml.univ-mrs.fr/~girard/LLL.pdf.gz))
* [[Kazushige Terui]], Light Affine Set Theory: A Naive Set Theory of Polynomial Time, _Studia Logica: An International Journal for Symbolic Logic_, Vol. 77, No. 1 (Jun., 2004), pp. 9-40. ([jstor](http://www.jstor.org/stable/20016605)) ([pdf](http://www.kurims.kyoto-u.ac.jp/~terui/lastfin.pdf)).  See also Terui's slides, [Linear Logic and Naive Set Theory (Make our garden grow)](http://www.kurims.kyoto-u.ac.jp/~terui/summer3.pdf)

category: foundational axiom

[[!redirects comprehension]]

[[!redirects comprehension schema]]

[[!redirects comprehension scheme]]
[[!redirects comprehension schemes]]

[[!redirects axiom of separation]]
[[!redirects axioms of separation]]
[[!redirects axiom scheme of separation]]
[[!redirects axiom schemes of separation]]
[[!redirects axiom schema of separation]]
[[!redirects axiom schemas of separation]]
[[!redirects axiom schemata of separation]]

[[!redirects axiom of specification]]
[[!redirects axioms of specification]]
[[!redirects axiom scheme of specification]]
[[!redirects axiom schemes of specification]]
[[!redirects axiom schema of specification]]
[[!redirects axiom schemas of specification]]
[[!redirects axiom schemata of specification]]

[[!redirects axiom of comprehension]]
[[!redirects axioms of comprehension]]
[[!redirects axiom scheme of comprehension]]
[[!redirects axiom schemes of comprehension]]
[[!redirects axiom schema of comprehension]]
[[!redirects axiom schemas of comprehension]]
[[!redirects axiom schemata of comprehension]]

[[!redirects bounded separation]]
[[!redirects axiom of bounded separation]]
[[!redirects axioms of bounded separation]]
[[!redirects axiom scheme of bounded separation]]
[[!redirects axiom schemes of bounded separation]]
[[!redirects axiom schema of bounded separation]]
[[!redirects axiom schemas of bounded separation]]
[[!redirects axiom schemata of bounded separation]]

[[!redirects restricted separation]]
[[!redirects axiom of restricted separation]]
[[!redirects axioms of restricted separation]]
[[!redirects axiom scheme of restricted separation]]
[[!redirects axiom schemes of restricted separation]]
[[!redirects axiom schema of restricted separation]]
[[!redirects axiom schemas of restricted separation]]
[[!redirects axiom schemata of restricted separation]]

[[!redirects limited separation]]
[[!redirects axiom of limited separation]]
[[!redirects axioms of limited separation]]
[[!redirects axiom scheme of limited separation]]
[[!redirects axiom schemes of limited separation]]
[[!redirects axiom schema of limited separation]]
[[!redirects axiom schemas of limited separation]]
[[!redirects axiom schemata of limited separation]]

[[!redirects full separation]]
[[!redirects axiom of full separation]]
[[!redirects axioms of full separation]]
[[!redirects axiom scheme of full separation]]
[[!redirects axiom schemes of full separation]]
[[!redirects axiom schema of full separation]]
[[!redirects axiom schemas of full separation]]
[[!redirects axiom schemata of full separation]]

[[!redirects large separation]]
[[!redirects axiom of large separation]]
[[!redirects axioms of large separation]]
[[!redirects axiom scheme of large separation]]
[[!redirects axiom schemes of large separation]]
[[!redirects axiom schema of large separation]]
[[!redirects axiom schemas of large separation]]
[[!redirects axiom schemata of large separation]]

[[!redirects restricted comprehension]]
[[!redirects axiom of restricted comprehension]]
[[!redirects axioms of restricted comprehension]]
[[!redirects axiom scheme of restricted comprehension]]
[[!redirects axiom schemes of restricted comprehension]]
[[!redirects axiom schema of restricted comprehension]]
[[!redirects axiom schemas of restricted comprehension]]
[[!redirects axiom schemata of restricted comprehension]]

[[!redirects full comprehension]]
[[!redirects axiom of full comprehension]]
[[!redirects axioms of full comprehension]]
[[!redirects axiom scheme of full comprehension]]
[[!redirects axiom schemes of full comprehension]]
[[!redirects axiom schema of full comprehension]]
[[!redirects axiom schemas of full comprehension]]
[[!redirects axiom schemata of full comprehension]]

[[!redirects stratified comprehension]]
[[!redirects axiom of stratified comprehension]]
[[!redirects axioms of stratified comprehension]]

[[!redirects axiom scheme of stratified comprehension]]
[[!redirects axiom schemes of stratified comprehension]]
[[!redirects axiom schema of stratified comprehension]]
[[!redirects axiom schemas of stratified comprehension]]
[[!redirects axiom schemata of stratified comprehension]]

[[!redirects comprehension rule]]
[[!redirects comprehension rules]]