
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Type theory
+-- {: .hide}
[[!include type theory - contents]]
=--
=--
=--

# Contractible types
* table of contents
{: toc}

## Idea

In [[homotopy type theory]], the notion of **contractible [[type]]** is an internalization of the notion of [[contractible space]] / [[(-2)-truncated]] object.

Contractible types are also called of **[[h-level]] $0$**. They represent the notion _[[true]]_ in homotopy type theory.


## Definition

We work in [[intensional type theory|intensional]] [[type theory]] with [[dependent sums]], [[dependent products]], and [[identity types]], 

+-- {: .num_defn}
###### Definition

For $X$ a [[type]], let

$$
  isContr(X) \coloneqq \sum_{x\colon X} \prod_{y\colon X} (y=x)
$$

be the [[dependent sum]] in one [[variable]] $x : X$ over the [[dependent product]] on the other [[variable]] $y \colon X$ of the $x,y$-[[dependent type|dependent]] [[identity type]] $(x = y)$.

We say that $X$ is a **contractible type** if $isContr(X)$ is an [[inhabited type]].

=--

+-- {: .num_remark}
###### Remark

In [[propositions as types]] language, this can be pronounced as "there exists a point $x\colon X$ such that every other point $y\colon X$ is equal to $x$."  

Under the [[homotopy theory|homotopy-theoretic]] interpretation, it should be thought of as the type of *contractions* of $X$ --- since the dependent product describes *continuous* functions, the paths from $y$ to $x$ depend continuously on $y$ and thus exhibit a contraction of $X$ to $x$.

=--

+-- {: .num_prop}
###### Proposition

A provably [[equivalence in homotopy type theory|equivalent]] definition is
the [[product type]] of $X$ with the [[isProp]]-type of $X$:

$$
  isContr(X) \coloneqq X \;\times\; isProp(X) 
  \,.
$$

=--

(Here of course we have to use a definition of [[isProp]] which doesn't refer to $isContr$).  

+-- {: .num_remark}
###### Remark

This now says that $X$ is contractible iff $X$ is [[inhabited type|inhabited]] and an [[h-proposition]].

=--

## Properties

+-- {: .num_prop}
###### Proposition


For any type $A$, the type $isContr(A)$ is an [[h-proposition]].  In particular, we can show $isContr(A) \to isContr(isContr(A))$: if a type is contractible, then its space of contractions is also contractible.

=--


+-- {: .num_prop}
###### Proposition

A type is contractible if and only if it is [[equivalence in homotopy type theory|equivalent]] to the [[unit type]].

=--



## Categorical semantics
 {#CategoricalSemantics}

We discuss the [[categorical semantics]] of contractible types.

Let $\mathcal{C}$ be a [[locally cartesian closed category]] with [[categorical semantics of homotopy type theory|sufficient structure]] to intepret all the above type theory.  This means that $C$ has a [[weak factorization system]] with [[stable path objects]], and that [[acyclic cofibrations]] are preserved by pullback along fibrations between fibrant objects.  (We ignore questions of [[coherence]], which are not important for this discussion.)

In this [[categorical semantics]], the interpretation of a type $\vdash A : Type$ is a [[fibrant object]] $[\vdash A : Type]$, which for short we will just write $A$. The interpretation of the [[identity type]] $x,y : A \vdash (x = y) : Type$ is as the [[path space object]] $A^I \to A \times A$.
The interpretation of $isContr(A)$ is the object obtained by taking the [[dependent product]] of the [[path space object]] along one [[projection]] $p_2 : A\times A\to A$ and then forgetting the remaining morphism to $A$.

$$
  [isContr(A)]
  \;\;
  =
  \;\;
  \array{
    \prod_{p_2} A^I
    \\
    \downarrow
    \\
    A
    \\
    \downarrow
    \\
    *
  }
  \,.
$$

The interpretation $[\hat a : isContr(A)]$ of a [[term]] of $isContr(A)$ is precisely a morphism $\hat a : * \to \prod_{p_2} A^I$.

+-- {: .num_prop}
###### Proposition

Let $\mathcal{C}$ be a [[type-theoretic model category]]. Write $[isContr(A)]$ for the [[categorical semantics|interpretation]] of $isContr(A)$ in $\mathcal{C}$. Then:

Global points $* \to [isContr(A)]$ in $\mathcal{C}$ are in bijection with [[contraction]] [[right homotopies]] of the object $A$, hence to [[diagrams]] in $\mathcal{C}$ of the form

$$
  \array{
    A &\stackrel{\eta}{\to}& A^I
    \\
    & {}_{\mathllap{(id, const_a)}}\searrow & \downarrow
    \\
    && A \times A
  }
  \,,
$$

where $const_a$ is a morphism of the form $A \to * \stackrel{a}{\to} A$ and where $A^I$ is the [[path space object]] of $A$ in $\mathcal{C}$.

=--

+-- {: .proof}
###### Proof

Given a global point $\hat a : * \to \prod_{p_2} A^I$, write $a : * \to A$ for the corresponding composite

$$
  \array{
     * &\stackrel{\hat a}{\to} & \prod_{p_2} A^I
     \\
     &{}_{\mathllap{a}}\searrow & \downarrow
     \\
     && A
  }
  \,.
$$

in $\mathcal{C}$. This is an element in the [[hom set]] $\mathcal{C}_{/A}(a, \prod_{p_2} A^I)$ of the [[slice category]] over $A$. By the ([[base change]] $\dashv$ [[dependent product]])-[[adjunction]] this is equivalently an element in $\mathcal{C}_{/A \times A}( p_2^* a, A^I )$.

Notice that the pullback $p_2^* a$ is the left morphism in

$$
  \array{
    A &\to& *
    \\
    {}^{\mathllap{(id,const_a)}}\downarrow && \downarrow^{\mathrlap{a}}
    \\
    A \times A &\stackrel{p_2}{\to}& A 
  }
  \,.
$$

Therefore a morphism $p_2^* a \to  A^I$ in $\mathcal{C}_{/A \times A}$ is
equivalently in $\mathcal{C}$ a diagram of the form

$$
  \array{
    A &&\stackrel{\eta}{\to}&& A^I
    \\
    & {}_{\mathllap{(id,const_a)}}\searrow && \swarrow
    \\
    && A \times A
  }
  \,.
$$

This is by definition a [[contraction]] right [[homotopy]] of $A$.


=--

+-- {: .num_remark}
###### Remark

Thus if $isContr(A)$, then 
$A\to 1$ is a (right) [[homotopy equivalence]], and hence (since $A$ is [[fibrant]]) an [[acyclic fibration]].

Conversely, if $\mathcal{C}$ is a [[model category]], $A$ and $1$ are cofibrant, and $A\to 1$ is an acyclic fibration, then $A\to 1$ is a right homotopy equivalence, and hence $isContr(A)$ has a global element.  Thus, in most cases, the existence of a global element of $isContr(A)$ (which is unique up to homotopy, since $isContr(A)$ is an [[h-proposition]]) is equivalent to $A\to 1$ being an acyclic fibration.

More generally, we may apply this locally.  Suppose that $A\to B$ is a fibration, which we can regard as a dependent type
$$x\colon B \vdash A(x)\colon Type.$$
Then we have a dependent type
$$x\colon B \vdash isContr(A(x))\colon Type$$
represented by a fibration $isContr(A)\to B$.  By applying the above argument in the [[slice category]] $\mathcal{C}/B$, we see that (if $\mathcal{C}$ is a model category, and $A$ and $B$ are cofibrant) $isContr(A)\to B$ has a [[section]] exactly when $A\to B$ is an acyclic fibration.

We can also construct the type
$$\prod_{x\colon B} isContr(A(x))$$
in global context, which has a global element precisely when $isContr(A)\to B$ has a section.  Thus, a global element of this type is also equivalent to $A\to B$ being an acyclic fibration.

=--

## Related concepts

[[!include homotopy n-types - table]]

* [[isEquiv]]

* **isContr**

* [[isProp]]

* [[contractible space]], [[contractible chain complex]]

## References

[[Coq]]-code for contractible types is at

* [HoTT repository](https://github.com/HoTT/HoTT/blob/master/Coq/Contractible.v)





[[!redirects contractible type]]
[[!redirects contractible types]]
[[!redirects h-level 0]]
[[!redirects h-level 0 type]]
[[!redirects (-2)-truncated type]]
[[!redirects (-2)-truncated types]]
[[!redirects type of contractions]]
[[!redirects h-contractible type]]
[[!redirects isContr]]
