
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Homological algebra
+-- {: .hide}
[[!include homological algebra - contents]]
=--
#### Duality
+-- {: .hide}
[[!include duality - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Idea

A _dual vector space_ is a [[dual in a closed category]] of [[vector spaces]] (or similar [[algebraic structures]]).

Of course, this is a very restricted notion of [[space]]; but for spaces in [[geometry]], one usually uses the [[duality between space and quantity]] and speaks of the [[spectrum]] (not 'dual space') of an [[algebra]].  In [[homotopy theory]], there are also [[Spanier-Whitehead dual]]s; and there are other notions of dual space in [[physics]].


## Definitions

Let $K$ be a [[field]] (or any [[commutative ring|commutative]] [[rig]]), and let $V$ be a [[vector space]] (or [[module]]) over $K$.

+-- {: .num_defn}
###### Definition
The __dual space__ or __dual module__ of $V$ is the vector space $V^*$ of [[linear functionals]] on $V$.  That is, $V^*$ is the [[internal hom]] $[V,K]$ (thinking of $K$ as a vector space over itself: a [[line]]).
=--

More generally, let $K$ and $L$ be [[rings]] (or [[rigs]]) *not* assumed commutative, and let $V$ be a $K$-$L$-[[bimodule]].

+-- {: .num_defn}
###### Definitions
The __left dual module__ of $V$ is the right $K$-module $^*V$ of left $K$-module [[homomorphisms]] from $V$ to $K$.  The __right dual module__ of $V$ is the left $L$-module $V^*$ of right $L$-module homomorphisms from $V$ to $L$.
=--

Now let $V$ be a [[topological vector space]] over the [[ground field]] $K$.

+-- {: .num_defn #LinearDualOfATopologicalVectorSpace}
###### Definitions
**(linear dual of a topological vector space)**

Let $V$ be a [[topological vector space]] over the [[ground field]] $K$.

The __dual space__ of $V$ is the topological vector space $V^*$ of [[continuous linear functionals]] on $V$, equipped with the [[weak-star topology|weak-* topology]] (meaning the [[initial topology]] generated by the elements of $V$, viewed as themselves linear functionals on $V^*$).

=--

In principle, there is no conflict among these definitions, the most general case (so far) being a topological bimodule over two topological rigs; the non-topological cases simply involve [[discrete spaces]].  In practice, however, some complications are possible:

*  If the rig $K$ is an [[associative algebra|algebra]] over another rig $L$, then any $K$-module $V$ is also an $L$-module, but the dual as a $K$-module is different from the dual as an $L$-module.  So one may speak of the __$K$-dual__ or the __dual over $K$__.

*  A topological vector space $V$ has an [[underlying]] discrete vector space, and these have different duals.  So one speaks of the __topological dual__ and the __algebraic dual__ (respectively).  If $V$ is considered with several different topologies (say called 'weak' and 'strong'), then one may speak of the __weak dual__ and the __strong dual__ (etc).

Logically, these duals take place in different [[categories]], which are related by various [[functors]]; the objects whose duals are being taken should not be conflated.  In practice, however, these objects are identified, so the duals must be distinguished.


## Transpose maps

The operation $V \mapsto V^*$ extends to a [[contravariant functor]].

+-- {: .num_defn}
###### Definition (transpose map)
The [[dual linear map]] or __transpose map__ of a [[linear map]] $A\colon V\to W$, is the linear map $A^* = A^T\colon W^*\to V^*$, given by
$$ \langle{A^*(w), v}\rangle = \langle{w, A(v)}\rangle $$
for all $w$ in $W^*$ and $v$ in $V$.
=--

+-- {: .num_remark}
###### Remark

This functor is, of course, the [[representable functor]] represented by $K$ as a vector space over itself (a [[line]]).

=--

+-- {: .num_remark}
###### Remark

This construction is the notion of [[dual morphism]] applied in the [[monoidal category]] [[Vect]] with its [[tensor product]] monoidal structure.

=--


## Dual bases

If $B$ is any [[basis]] of $V$, then we can sometimes turn $B$ into a basis $B^*$ of the dual space $V^*$.

We will begin with the definition of what *might* be the dual basis, cautioning that it is not always a basis:

+-- {: .num_defn}
###### Definition (dual basis)
Treating the basis $B$ as a [[family]] $(b_i)$ with index set $I$, the __dual basis__ $B^*$ is the family $(b^i)$ (with the same index set) such that
$$ b^i(b_j) = \delta^i_j $$
(the [[Kronecker delta]]).
=--

Since $B$ is a basis of $V$, this formula defines $b^i$ for each index $I$, so $B^*$ exists; but in general there is no reason why $B^*$ should be a basis of $V^*$.  However, if $V$ has [[finite set|finite]] [[dimension]], then $B^*$ is a basis of $V^*$. If $V$ is a [[Hilbert space]], and $B$ is a basis of $V$ in the Hilbert space sense (i.e., $B$ is a linearly independent set whose span is topologically dense in $V$), then also $B^*$ is a basis of the dual Hilbert space $V^*$. 

This is related to but different from the sort of [[dual basis]] applicable generally to [[projective modules]].


## Double duals

The __[[double dual]]__ of $V$ is simply the dual of the dual of $V$.  There is a [[natural transformation]] from $V$ to its double dual:
$$ \hat{x}(\lambda) = \lambda(x) ,$$
for $x$ in $V$, $\lambda$ in $V^*$, and consequently $\hat{x}$ in $V^{**}$.

The space $V$ is called __[[reflexive Banach space|reflexive]]__ if this natural transformation is an [[isomorphism]].  The reflexive spaces include all finite-dimensional vector spaces or modules over [[fields]] or [[division rings]], as well as all [[Hilbert spaces]], the [[Lebesgue spaces]] $L^p$ over a [[localizable measure|localisable measure space]] for $1 \lt p \lt \infty$, and others.


## Dual spaces as dual objects

A dual vector space is a [[dual object]] in the [[monoidal category]] [[Vect]] equipped with its [[tensor product]] monoidal structure.

In general, the duality between $V$ and $V^*$ does *not* make $Vect$ into a [[monoidal category with duals]].  However, if we restrict to spaces of [[F-finite|finite]] [[dimension]], then we get a [[compact category]]; finite-dimensional [[Hilbert spaces]] form a $\dagger$-[[dagger-compact category|compact category]], which is very nice indeed.


## Examples


+-- {: .num_example #DualityBetweenVectorsAndCovectors}
###### Example
**(duality between [[vectors]] and [[covectors]])**

* [[tensor|Tensors]] in finite-dimensional [[differential geometry]] make heavy use of the duality between [[tangent spaces]] and [[cotangent spaces]].  That [[infinite-dimensional manifold|infinite-dimensional differential geometry]] is much harder is largely because this duality is no longer perfect.

=--


+-- {: .num_example #VonNeumannAlgebras}
###### Example
**([[von Neumann algebras]])

A [[von Neumann algebra]] (abstractly) is precisely a $C^*$-[[C-star-algebra|algebra]] whose underlying [[Banach space]] is the dual space of some (other) Banach space.  One may equivalently *define* a von Neumann algebra as a Banach space together with a $C^*$-algebra structure on its dual space (except that the [[morphisms]] go the other way, so one is more directly defining a noncommutative [[measurable space]], along the lines of [[noncommutative geometry]]).

=--


+-- {: .num_example #SpacesOFDistributionsAsDualVectorSpaces}
###### Example
**(spaces of [[distributions]])**

The standard [[topological space|topology]] on the spaces $\mathcal{D}'$ of [[distributions]] is the dual space topology according to def. \ref{LinearDualOfATopologicalVectorSpace}. 

(e.g. [Hörmander 90, p. 38](#Hoermander90))

=--

See _[[Riesz representation theorem]]_ for more examples from [[functional analysis]].


## Related concepts

* [[dual space]]

* [[dual vector bundle]]

## References

Discussion in the context of [[distributions]] includes

* {#Hoermander90} [[Lars Hörmander]], section 2.1 of _The analysis of linear partial differential operators_, vol. I, Springer 1983, 1990


[[!redirects dual vector space]]
[[!redirects dual vector spaces]]

[[!redirects dual module]]
[[!redirects dual modules]]

[[!redirects left dual module]]
[[!redirects left dual modules]]
[[!redirects right dual module]]
[[!redirects right dual modules]]

[[!redirects dual topological vector space]]
[[!redirects dual topological vector spaces]]
[[!redirects dual Banach space]]
[[!redirects dual Banach spaces]]
[[!redirects dual Hilbert space]]
[[!redirects dual Hilbert spaces]]

[[!redirects alebraic dual space]]
[[!redirects alebraic dual spaces]]
[[!redirects alebraic dual]]
[[!redirects alebraic duals]]

[[!redirects topological dual space]]
[[!redirects topological dual spaces]]
[[!redirects topological dual]]
[[!redirects topological duals]]

[[!redirects linear dual]]
[[!redirects linear duals]]



