##Idea

Simplification of linear equations uses the 'elementary moves' such as adding a multiple of one equation to another. These 'moves' have analogues in the matrix approach where an elementary move on the corresponding set of linear equations is mirrored by multiplication by elementary matrices. We did not specify over what ring we were working, and the group of elementary matrices will depend on that, but some of the relations between the 'elementary moves' are more universal and these are encoded in the presentation of the _Steinberg group_.  

##The presentation

Let $R$ be an associative ring with 1.  Recall that the ($n^{th}$ unstable) _Steinberg group_, $St_n(R)$, has generators, $x_{ij}(a)$, labelling the _elementary matrices_, $e_{ij}(a)$, having

$$ e_{ij}(a)_{k, l} = \left\{ \begin{array}{ll}
1 & if     k = l\\
a & if    (k, l) = (i, j), a \in R\\
0 &  otherwise,\end{array}\right.$$


and relations

St1  $x_{i,j}(a)x_{i,j}(b) =  x_{i,j}(a + b)$;

St2  $[ x_{i,j}(a),x_{k,\ell }(b)] = \left\{ \begin{array}{ll}
      1 & if    i \neq \ell, j\neq k,\\
      x_{i,\ell}(ab) & i \neq \ell, j = k
\end{array}\right.$

and in which all indices are positive integers less than or equal to $n$.

###Stable and unstable

The terminology _$n^{th}$ unstable_ is to make the contrast with the group $St(R)$, the stable version. The unstable version, $St_n(R)$, models universal relations satisfied by the $n\times n$ elementary matrices, whilst, in $St(R)$, the indices, $i$, $j$, $k$ etc. are not constrained to be less than or equal to $n$. 

There is an inclusion of $St_n(R)$ into $St_{n+1}(R)$ given by the obvious inclusion on the generating sets. The 'union' of the sequence of these groups is $St(R)$.


##Elementary matrix groups

The subgroup of $GL(R)$ generated by the elementary matrices is denoted $E(R)$. In looking at the structure on elementary matrices we have a series of more minor results before a very neat result due to [[Henry Whitehead]].

**Lemma**
If $i,j, k$ are distinct positive integers, then 

$$e_{ij}(a) = [e_{ik}(a),e_{kj}(1)].$$

The proof is just calculation.  This then makes the following obvious.

**Proposition**

For $n\geq 3$, $E_n(R)$ is a [[perfect group]], i.e., 

$$[E_n(R),E_n(R)]= E_n(R).$$


 Continuing with the properties of $E(R)$, let $M = (m_{ij})$ be any $n\times n$ matrix over $R$.  (It is not assumed to be invertible.)

We note that in $G\ell_{2n}(R)$,
$$\left(\begin{array}{cc}
I_n&M\\0&I_n
\end{array}\right)= \prod_{i=1}^n\prod_{j=1}^n e_{i, j+n}(m_{ij}),$$
so this is in $E_{2n}(R)$.  Similarly $\left(\begin{array}{cc}
I_n&0\\M&I_n
\end{array}\right)\in E_{2n}(R)$.

Next, let $M \in G\ell_n(R)$ and note

$$\left(\begin{array}{cc}
M&0\\0&M
\end{array}\right)= \left(\begin{array}{cc}
I_n&0\\M^{-1}-I_n&I_n
\end{array}\right)\left(\begin{array}{cc}
I_n&I_n\\0&I_n
\end{array}\right)\left(\begin{array}{cc}
I_n&0\\M-I_n&I_n
\end{array}\right)\left(\begin{array}{cc}
I_n&-M^{-1}\\0&I_n
\end{array}\right)$$
(as is easily verified).  We thus have 
$$\left(\begin{array}{cc}
M&0\\0&M
\end{array}\right)\in E_{2n}(R),$$
hence it is a product of commutators.


**Lemma**
If $M,N\in G\ell_n(R)$, then

$$\left(\begin{array}{cc}
[M,N]&0\\0&I_n
\end{array}\right)= \left(\begin{array}{cc}
M&0\\0&M^{-1}
\end{array}\right)\left(\begin{array}{cc}
N&0\\0&N^{-1}
\end{array}\right)\left(\begin{array}{cc}
(NM)^{-1}&0\\0&NM
\end{array}\right),$$

so is in $E_{2n}(R)$.

Passing to the stable groups, we get the famous _Whitehead lemma_:

**Proposition
$$[G\ell(R),G\ell(R)] = E(R).$$

##$K_1(R)$
The first algebraic $K$-group of the ring $R$ is $G\ell(R)^{ab}$, the [[abelianization]] of the stable general linear group of $R$.  By the above Whitehead lemma this is also $G\ell(R)/E(R)$.


##The covering properties of $St(R)$.

The Steinberg relations are modelled on observed relations amongst the elementary matrices, so sending $x_{ij}(a)$ to $e_{ij}(a)$ defines an epimorphism $St(R)\to E(R)$.

This is a [[universal central extension]] and its kernel is [[Milnor's K2]].

##Syzygies for the Steinberg group

These are discussed in

* M. M. Kapranov and M. Saito, _Hidden Stasheff polytopes in algebraic K-theory and in the space of Morse functions_, Higher homotopy structure in topology and mathematical physics (Poughkeepsie, N.Y. 1996), Contemporary Mathematics, vol. 227, AMS, 1999, pp. 191 – 225.

