
# Higher generation by subgroups
* table of contents
{: toc}

## Idea

(This is partially an account of the paper by Abels and Holz (1993) listed in the references below. It is augmented with some simple examples and discussion.)

For a [[group]] $G$ and a family, $\mathcal{H}$, of [[subgroups]] of $G$, consider the [[nerve]] of the covering of the set of elements of $G$ by the [[cosets]] $H g$, for $H\in \mathcal{H}$.  Although this is a Čech nerve (and thus we have an established notation for nerves as in [[Čech method]]), we will denote it $N(\mathfrak{H})$ as in the source.

*  The group $G$ is generated by the union of the subgroups $H$ in $\mathcal{H}$ if and only if $N(\mathfrak{H})$ is connected.

*  The group $G$ is the coproduct of the subgroups, amalgamated along their intersections, if and only if $N(\mathfrak{H})$ is simply connected.

The point of the article is to explore the consequences of the  higher connectivity of $N(\mathfrak{H})$, corresponding to 'higher generation by the subgroups', but, from the nPOV, perhaps the real questions are to ask in what way does the homotopy type of $N(\mathfrak{H})$ influence the properties of $G$.

The techniques used include the bar resolution construction and homotopy colimits. There are applications to Tits systems and to [[buildings]].


## The nerve of a family of subgroups

We start with a group, $G$, and a family, $\mathcal{H} = \{H_i\mid i\in I\}$ of subgroups of $G$.  Each subgroup, $H$, determines a family of right cosets, $H_g$, which cover the _set_, $G$.  Of course, these partition $G$, so there are no non-trivial intersections between them.  If we use _all_ the right cosets, $H_ig$, for _all_ the $H_i$ in $\mathcal{H}$, then, of course, we expect to get non-trivial intersections.


Let $\mathfrak{H} = \coprod_{i\in I}H_i\backslash G= \{ H_i g\mid H_i\in \mathcal{H}\},$
where the $g$ is more as an indicator of right cosets than strictly speaking  an index. This is the family of all right cosets of subgroups in $\mathcal{H}$.  This covers $G$ and we write $N(\mathfrak{H})$ for the corresponding simplicial complex, which is the _nerve_ of this covering.  


More formally:

+-- {: .un_defn}
###### Definition

Let $G$ be a group and $\mathcal{H}$ a family of subgroups of $G$.  Let $\mathfrak{H}$ denote the corresponding covering family of right cosets, $H_ig$, $H_i \in \mathcal{H}$. (We will write $\mathfrak{H} = \mathfrak{H}(G,\mathcal{H})$ or even $\mathfrak{H} = (G,\mathcal{H})$, as a shorthand as well.) The _nerve_ of $\mathfrak{H}$ is the [[simplicial complex]], $N(\mathfrak{H})$, whose vertices are the cosets, $H_ig$, $i \in I$, and where a non-empty finite family, $\{H_ig_i\}_{i\in J}$, is a simplex if it has non-empty intersection.
=--

+-- {: .un_example}
###### Examples

1. If $\mathcal{H}$ consists just of one subgroup, $H$, then $\mathfrak{H}$ is just the set of cosets, $H\backslash G$ and $N(\mathfrak{H})$ is 0-dimensional, consisting just of 0-simplices / vertices.


2. If $\mathcal{H} = \{H_1,H_2\}$, (and $H_1$ and $H_2$ are not equal!), then any right $H_1$ coset, $H_1g$, will intersect some of the right $H_2$-cosets, for instance, $H_1g\cap H_2g$ always contains $g$.  The nerve, $N(\mathfrak{H})$, is a bipartite graph, considered as a simplicial complex. (The number of edges will depend on the sizes of $H_1$, $H_2$ and $H_1\cap H_2$, etc.) It is just a graphical way of  illustrating the intersections of the cosets, a sort of intersection diagram.

As a specific very simple example, consider:

*  $S_3 \equiv ( a,b : a^3=b^2=(ab)^2=1)$, (so $a$ denotes, say, the 3-cycle $(1 2 3)$ and $b$, a transposition $(1 2)$).  

     *  Take $H_1 = \langle a \rangle = \{1, (1 2 3), (1 3 2)\}$, yielding two cosets $H_1$ and $H_1b$.  

     *  Similarly take $H_2 = \langle b\rangle = \{1, (1 2)\}$ giving cosets $H_2$, $H_2a$ and $H_2a^2$.  

The covering of $S_3$ is then $\mathfrak{H} =  \{H_1,H_1b,H_2,H_2a,H_2a^2\}$, and the nerve is a complete [[bipartite graph]] on $2+3$-vertices.
=--

## $n$-generating families

+-- {: .un_defn}
###### Definition

A family, $\mathcal{H}$, of subgroups of $G$ is called __$n$-generating__ if the nerve, $N(\mathfrak{H})$, of the corresponding coset covering is [[n-connected space|(n-1)-connected]], i.e., $\pi_i N(\mathfrak{H}) = 0$ for $i\lt n$.
=--

Rephrasing and extending comments made earlier, we have 
+--{: .un_proposition}
######Proposition
There are isomorphisms:

   (a) $\pi_0N(\mathfrak{H}) \cong G/\langle\bigcup H_j\rangle;$

   (b) $\pi_1N(\mathfrak{H}) \cong Ker(\underset{\cap}{\sqcup} \mathcal{H}\to G).$
=--



+-- {: .un_example}
###### Examples


1.  Keeping in the case where $\mathcal{H} = \{H_1,H_2\}$, so two subgroups of $G$ then we have that $\underset{\cap}{\sqcup} \mathcal{H}\to G$ is an isomorphism if and only if $N( \mathfrak{H})$ is a [[tree]].  This gives one of the basic types of a [[graph of groups]]. In more generality, if $\mathcal{H} = \{H_1,\ldots ,H_n\}$ then there is a [[complex of groups]] associated with $N( \mathfrak{H})$.

1.  A more complex family of  examples of the above situation occurs in algebraic K-theory. This has the general linear group, $G\ell _n(R)$, of invertible $n\times n$ matrices together with a family of subgroups corresponding to lower triangular matrices, .... but with some subtleties involved.  

     *  Let  $R$ be an associative ring, and now let $\sigma$ be a partial order  on $\{1,\ldots,n\}$. If $i$ is less that $j$ in the partial order $\sigma$, it is convenient to write $i\stackrel{\sigma}{\lt} j$. (Note that this means that some of the elements may only be related to themselves and hence are really not playing a role in such a $\sigma$.) We will write $PO(n)$ for the set of partial orders of $\{1,\ldots,n\}$.


      * We say an $n\times n$ matrix, $A = (a_{ij})$ is _$\sigma$-triangular_ if, when $i\stackrel{\sigma}{\leq} j$ is false, $a_{ij}=0$, and all diagonal entries, $a_{ii}$ are $1$.

      *   We let $T_n^\sigma(R)$ be the subgroup of $G\ell_n(R)$ formed by the $\sigma$-triangular matrices and then look at all such subgroups for all $n$, considering the stable general linear group $G\ell(R)$ as the colimit of the nested sequence of all the $G\ell_n(R)$, take $G = G\ell(R)$. Considering the family,  $\mathcal{H}$, of all the $T_n^\sigma(R)$, form the corresponding nerve, $N(\mathfrak{H})$.  This space has the same homotopy type as the Volodin model for [[algebraic K-theory]], since it is the Čech nerve of the covering $\mathfrak{H}$, whilst the Vietoris nerve of that covering is the [[Volodin model]].

=--
## References

* [[H. Abels]] and S. Holz, _Higher generation by subgroups_, J. Alg, 160, (1993), 311--341.
