
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Yoneda lemma
+--{: .hide}
[[!include Yoneda lemma - contents]]
=--
#### Geometry
+--{: .hide}
[[!include higher geometry - contents]]
=--
=--
=--



#Contents#
* table of contents
{:toc}

## Idea

A **classifying space** for some sort of data refers to a [[space]] (or a more general object), usually written $\mathcal{B}(data)$, such that maps $X\to \mathcal{B}(data)$ correspond to data over $X$.

The classical example is the classifying space $\mathcal{B}G$ of a [[group]] $G$, which has the property that there is a bijection between [[homotopy]] classes of maps $X\to \mathcal{B}G$ and isomorphism classes of $G$-[[bundle|bundles]] over $X$.  (In fact, one can jack this up to an equivalence of [[groupoid|groupoids]] or $\infty$-[[infinity-groupoid|groupoids]].)  Various improvements of this are possible which classify bundles with extra structure or [[fibration|fibrations]].

Categorically, the corresponding statement is that [[Grothendieck fibrations]] over a [[category]] $X$ correspond to [[pseudofunctors]] $X^{op}\to Cat$.  Thus $Cat$ is the "classifying space for categories."  Similarly, discrete fibrations over $X$ correspond to [[functors]] $X^{op}\to Set$.

To see the connection between the two, consider the case when $X$ is a groupoid and we restrict the fibers of the fibration to be isomorphic to a given set $F$.   Then the functor $X^{op}\to Set$ must land in the subcategory of $Set$ consisting of just the [[automorphisms]] of $F$, which is the one-object groupoid corresponding to the [[automorphism group]] $Aut(F)$.  If we further restrict the automorphisms appearing to preserve some given structure on $F$, so that they lie in some smaller group $G$, then the "classifying space" will be the one-object groupoid corresponding to $G$.  Under the [[homotopy hypothesis]], groupoids correspond to [[homotopy 1-types]], and the one-object groupoid of a group $G$ corresponds precisely to the usual topological classifying space $\mathcal{B}G$ (in fact, this is one _construction_ of $\mathcal{B}G$).  For this reason, $\mathbf{B}G$ is often used to denote that one-object groupoid; see the [[delooping hypothesis]] and the discussion at [[category algebra]].

The phrase "classifying space" is also sometimes used for the realization of the nerve of any category, although it is more complicated to say what exactly this space "classifies."  (One answer is "torsors modulo concordance.")

## Examples


### For principal bundles

For $G$ a [[topological group]] there is a classifying space $B G \in$ [[Top]] for topological $G$-[[principal bundle]]s, hence a space such that for $X$ any sufficiently nice topological space there is a [[natural isomorphism]]

$$
  G Bund(X)_0 \simeq \pi_0 Top(X, B G)
$$

between the set of [[isomorphism]] classes of $G$-[[principal bundle]]s on $X$ and the set of [[homotopy]]-classes of [[continuous function]]s $X \to B G$.

This space may be constructed as follows:

write $\mathbf{B}G \in Top^{\Delta^{op}}$ for the [[simplicial topological space]] obtained as the [[nerve]] of the one-object [[topological groupoid]] associated to $G$, the simplicial space given by

$$
  (\mathbf{B}G)_n = G^{\times n}
$$ 

whose face maps are induced by the product operation on $G$ and whose degeneracy maps are induced from the unit map.

If $G$ is [[well-pointed simplicial topological group|well-pointed]], then the [[geometric realization of simplicial topological spaces]] of $G$ is a model for the [[homotopy type]] of the classifying space

$$
  B G \simeq \vert \mathbf{B}G\vert
  \,.
$$

For more details on this construction see the section <a href="http://ncatlab.org/nlab/show/geometric+realization+of+simplicial+topological+spaces#ClassifyingSpaces">classifying spaces</a> at [[geometric realization of simplicial topological spaces]].

As discussed there, too, this construction generalizes to more general [[simplicial topological group]]s and classifying spaces for their [[principal ∞-bundle]]s.

### For orthogonal and unitary principal bundles
 {#ForOrthogonalAndUnitaryPrincipalBundles}

#### Idea

For $G = O(n)$ the [[orthogonal group]] and
$G = U(n)$ the [[unitary group]], there are standard realizations of the corresponding classifying spaces as [[direct limits]] of [[Grassmannian]] spaces. 

Let $V_n(\mathbb{R}^q)$ be the [[Stiefel manifold]] of [[orthonormal basis|orthonormal]] $n$-frames in the [[Cartesian space]] $\mathbb{R}^q$. Its points are $n$-[[tuples]] of orthonormal [[vectors]] in $\mathbb{R}^q$, and it is topologized as a [[subspace topology|subspace]] of $(\mathbb{R}^q)^n$,
or, equivalently, as a subspace of $(S^{q-1})^n$. It is a [[compact space|compact]] [[manifold]]. 

Let $G_n(\mathbb{R}^q)$ be the [[Grassmannian]] of $n$-planes in $\mathbb{R}^q$. Its points are the n-dimensional subspaces
of $\mathbb{R}^q$. Sending an $n$-tuple of orthonormal vectors to the $n$-plane they span gives
a surjective function $V_n(\mathbb{R}^q) \to G_n(\mathbb{R}^q)$, and we topologize $G_n(\mathbb{R}^q)$ as a [[quotient topology|quotient]] space of $V_n(\mathbb{R}^q)$. It too is a compact manifold. 

The standard inclusion of $\mathbb{R}^q$ in $\mathbb{R}^{q+1}$ induces inclusions
$V_n(\mathbb{R}^q) \hookrightarrow V_n(\mathbb{R}^{q+1})$ and $G_n(\mathbb{R}^q) \hookrightarrow G_n(\mathbb{R}^{q+1})$. We define $V_n(\mathbb{R}^\infty)$ and $G_n(\mathbb{R}^\infty)$ to be the unions of the $V_n(\mathbb{R}^q)$ and $G_n(\mathbb{R}^q)$, with the topology of the union. 

Then $G_n(\mathbb{R}^\infty)$ is a model for the classifying space $B O(n)$.


#### Definitions

In the following we take [[Top]] to denote [[compactly generated topological spaces]]. For these the [[Cartesian product]] $X \times (-)$ is a [[left adjoint]] and hence preserves [[colimits]].


+-- {: .num_defn #StiefelManifold}
###### Definition

For $n, k \in \mathbb{N}$ and $n \leq k$, then the $n$th **real [[Stiefel manifold]]** of $\mathbb{R}^k$ is the [[coset]] [[topological space]].

$$
  V_n(\mathbb{R}^k) \coloneqq O(k)/O(k-n)
  \,,
$$

where the [[action]] of $O(k-n)$ is via its canonical embedding $O(k-n)\hookrightarrow O(k)$.

Similarly the $n$th **complex Stiefel manifold** of $\mathbb{C}^k$ is

$$
  V_n(\mathbb{C}^k) \coloneqq U(k)/U(k-n)
  \,,
$$

here the [[action]] of $U(k-n)$ is via its canonical embedding $U(k-n)\hookrightarrow U(k)$.

=--

+-- {: .num_defn #RealAndComplexGrassmannian}
###### Definition

For $n, k \in \mathbb{N}$ and $n \leq k$, then the $n$th **real [[Grassmannian]]** of $\mathbb{R}^k$ is the [[coset]] [[topological space]].

$$
  Gr_n(\mathbb{R}^k) \coloneqq O(k)/(O(n) \times O(k-n))
  \,,
$$

where the [[action]] of the [[product group]] is via its canonical embedding $O(n)\times O(k-n) \hookrightarrow O(n)$ into the [[orthogonal group]].

Similarly the $n$th **complex [[Grassmannian]]** of $\mathbb{C}^k$ is the [[coset]] [[topological space]].

$$
  Gr_n(\mathbb{C}^k) \coloneqq U(k)/(U(n) \times U(k-n))
  \,,
$$

where the [[action]] of the [[product group]] is via its canonical embedding $U(n)\times U(k-n) \hookrightarrow U(n)$ into the [[unitary group]].


=--

+-- {: .num_example #RealComplexProjectiveSpaceAsGrassmannian}
###### Example

* $Gr_1(\mathbb{R}^{n+1}) \simeq \mathbb{R}P^n$ is [[real projective space]] of [[dimension]] $n$.

* $Gr_1(\mathbb{C}^{n+1}) \simeq \mathbb{C}P^n$ is [[complex projective space]] of [[dimension]] $n$.


=--


+-- {: .num_prop #ProjectionFromStiefelManifoldToGrassmannianIsFiberBundle}
###### Proposition

For all $n \leq k \in \mathbb{N}$, the canonical [[projection]] from the real [[Stiefel manifold]] (def. \ref{StiefelManifold}) to the [[Grassmannian]] is a $O(n)$-[[principal bundle]]

$$
  \array{
    O(n) &\hookrightarrow& V_n(\mathbb{R}^k)
    \\
    && \downarrow 
    \\
    && Gr_n(\mathbb{R}^k)
  }
$$

and the projection from the complex Stiefel manifold to the Grassmannian us a $U(n)$-[[principal bundle]]:

$$
  \array{
    U(n) &\hookrightarrow& V_n(\mathbb{C}^k)
    \\
    && \downarrow 
    \\
    && Gr_n(\mathbb{C}^k)
  }
  \,.
$$

=--

+-- {: .proof}
###### Proof

By ([this cor.](coset#QuotientProjectionForCompactLieSubgroupIsPrincipal) and [this prop.](coset#ProjectionOfCosetsIsFiberBundleForClosedSubgroupsOfCompactLieGroup)).

=--
 
+-- {: .num_defn #EOn}
###### Definition

By def. \ref{RealAndComplexGrassmannian} there are canonical inclusions 

$$
  Gr_n(\mathbb{R}^k) \hookrightarrow Gr_n(\mathbb{R}^{k+1})
$$ 

and

$$
  Gr_n(\mathbb{C}^k) \hookrightarrow Gr_n(\mathbb{C}^{k+1})
$$ 

for all $k \in \mathbb{N}$. The [[colimit]] (in [[Top]], see [there](Top#UniversalConstructions)) over these inclusions is denoted

$$
  B O(n) \coloneqq \underset{\longrightarrow}{\lim}_k Gr_n(\mathbb{R}^k)
$$

and

$$
  B U(n) \coloneqq \underset{\longrightarrow}{\lim}_k Gr_n(\mathbb{C}^k)
  \,,
$$

respectively.

Moreover, by def. \ref{StiefelManifold} there are canonical inclusions 

$$
   V_n(\mathbb{R}^k) \hookrightarrow V_n(\mathbb{R}^{k+1})
$$ 

and

$$
  V_n(\mathbb{C}^k) \hookrightarrow V_n(\mathbb{C}^{k+1})
  \,,
$$ 

respectively, that are compatible with the $O(n)$-[[action]] and the $U(n)$-action, respectively. The [[colimit]] (in [[Top]], see [there](Top#UniversalConstructions)) over these inclusions, regarded as equipped with the induced [[action]], is denoted

$$
  E O(n) \coloneqq \underset{\longrightarrow}{\lim}_k V_n(\mathbb{R}^k)
$$

and

$$
  E U(n) \coloneqq \underset{\longrightarrow}{\lim}_k V_n(\mathbb{C}^k)
  \,,
$$

respectively. The inclusions are in fact compatible with the bundle structure from prop. \ref{ProjectionFromStiefelManifoldToGrassmannianIsFiberBundle}, so that there are induced projections

$$
  \left(
  \array{
    E O(n)
    \\
    \downarrow
    \\
    B O(n) 
  }
  \right)
  \;\;
   \simeq
  \;\;
  \underset{\longrightarrow}{\lim}_k
  \left(
    \array{
       V_n(\mathbb{R}^k)
       \\
       \downarrow
       \\
       Gr_n(\mathbb{R}^k)
    }
  \right)
$$

and

$$
  \left(
  \array{
    E U(n)
    \\
    \downarrow
    \\
    B U(n) 
  }
  \right)
  \;\;
   \simeq
  \;\;
  \underset{\longrightarrow}{\lim}_k
  \left(
    \array{
       V_n(\mathbb{C}^k)
       \\
       \downarrow
       \\
       Gr_n(\mathbb{C}^k)
    }
  \right)
  \,,
$$

respectively. These are the standard models for the **[[universal principal bundles]]** for $O$ and $U$, respectively. The corresponding [[associated bundles|associated]] [[vector bundles]]

$$
 E O(n) \underset{O(n)}{\times} \mathbb{R}^n
$$

and

$$
 E U(n) \underset{U(n)}{\times} \mathbb{C}^n
$$

are the corresponding **[[universal vector bundles]]**.


=--

Since the [[Cartesian product]] $O(n)\times (-)$ in [[compactly generated topological spaces]] preserves [[colimits]], it follows that the colimiting bundle is still an $O(n)$-[[principal bundle]]

$$
  \begin{aligned} 
    (E O(n))/O(n)
    &
    \simeq
    (\underset{\longrightarrow}{\lim}_k V_{n}(\mathbb{R}^k))/O(n)
    \\
    & \simeq 
    \underset{\longrightarrow}{\lim}_k (V_n(\mathbb{R}^k)/O(n))
    \\
    & \simeq
    \underset{\longrightarrow}{\lim}_k Gr_n(\mathbb{R}^k)
    \\
    & \simeq B O(n)
  \end{aligned}
$$

and anlogously for $E U(n)$.

As such this is the standard presentation for the $O(n)$-[[universal principal bundle]]. Its base space $B O(n)$ is the corresponding _classifying space_.


+-- {: .num_defn #InclusionOfBOnIntoBOnPlusOne}
###### Definition

There are canonical inclusions

$$
  Gr_n(\mathbb{R}^k)
  \hookrightarrow
  Gr_{n+1}(\mathbb{R}^{k+1})
$$

and

$$
  Gr_n(\mathbb{C}^k)
  \hookrightarrow
  Gr_{n+1}(\mathbb{C}^{k+1})
$$

given by adjoining one coordinate to the ambient space and to any subspace. Under the colimit of def. \ref{EOn} these induce maps of classifying spaces

$$
  B O(n) \longrightarrow B O(n+1)
$$

and

$$
  B U(n) \longrightarrow B U(n+1)
  \,.
$$

=--

+-- {: .num_defn #WhitneySumMapOnClassifyingSpaces}
###### Definition

There are canonical maps

$$
  Gr_{n_1}(\mathbb{R}^{k_1})
  \times
  Gr_{n_2}(\mathbb{R}^{k_2})  
  \longrightarrow
  Gr_{n_1 + n_2}(\mathbb{R}^{k_1 + k_2})
$$

and

$$
  Gr_{n_1}(\mathbb{C}^{k_1})
  \times
  Gr_{n_2}(\mathbb{C}^{k_2})  
  \longrightarrow
  Gr_{n_1 + n_2}(\mathbb{C}^{k_1 + k_2})
$$


given by sending ambient spaces and subspaces to their [[direct sum]].

Under the colimit of def. \ref{EOn} these induce maps of classifying spaces

$$
  B O(n_1) \times B O(n_2)
  \longrightarrow
  B O(n_1 + n_2)
$$

and

$$
  B U(n_1) \times B U(n_2)
  \longrightarrow
  B U(n_1 + n_2)
$$

=--


#### Properties

+-- {: .num_prop #CWComplexStructure}
###### Proposition

The real [[Grassmannians]] $Gr_n(\mathbb{R}^k)$ and the complex Grassmannians $Gr_n(\mathbb{C}^k)$ of def. \ref{RealAndComplexGrassmannian} admit the structure of [[CW-complexes]]. Moreover the canonical inclusions

$$
  Gr_n(\mathbb{R}^k)
  \hookrightarrow
  Gr_n(\mathbb{R}^{k+1})
$$

and

$$
  Gr_n(\mathbb{C}^k)
  \hookrightarrow
  Gr_n(\mathbb{C}^{k+1})
$$

are subcomplex incusions (hence [[relative cell complex]] inclusions).

Accordingly there is an induced CW-complex structure on the [[classifying spaces]] $B O(n)$ and $B U(n)$ (def. \ref{EOn}).

=--

A proof is spelled out in ([Hatcher, section 1.2 (pages 31-34)](#Hatcher)). 

+-- {: .num_prop}
###### Proposition

The [[Stiefel manifold]] $V_n(\mathbb{R}^k)$ from def. \ref{StiefelManifold} admits the structure of a [[CW-complex]].

=--

e.g. ([James 59, p. 3](Stiefel+manifold#James59), [James 76, p. 5 with p. 21](Stiefel+manifold#James76), [Blaszczyk 07](Stiefel+manifold#Blaszczyk07))

(And I suppose with that cell structure the inclusions $V_n(\mathbb{R}^k) \hookrightarrow V_n(\mathbb{R}^{k+1})$ are subcomplex inclusions.) 



+-- {: .num_prop }
###### Proposition

The [[Stiefel manifold]] $V_n(\mathbb{R}^k)$ (def. \ref{StiefelManifold}) is [[n-connected topological space|(k-n-1)-connected]].

=--

+-- {: .proof}
###### Proof

Consider the [[coset]] [[quotient]] [[projection]]

$$
  O(k-n)
    \longrightarrow
  O(k)
    \longrightarrow
  O(k)/O(k-n) 
    = 
  V_n(\mathbb{R}^k)
  \,.
$$

Since the orthogonal groups is compact ([prop.](orthogonal+group#OrthogonalGroupIsCompact)) and by [this corollary](coset#QuotientProjectionForCompactLieSubgroupIsPrincipal) the projection $O(k)\to O(k)/O(k-n)$ is a [[Serre fibration]]. Therefore there is induced the [[long exact sequence of homotopy groups]] of this [[fiber sequence]], and by [this prop.](orthogonal+group#InclusionOfOnIntoOkIsnMinus1Equivalence) it has the following form in degrees bounded by $n$:

$$
  \cdots
    \to
  \pi_{\bullet \leq k-n-1}(O(k-n))
    \overset{epi}{\longrightarrow}
  \pi_{\bullet \leq k-n-1}(O(k))
    \overset{0}{\longrightarrow}
  \pi_{\bullet \leq k-n-1}(V_n(\mathbb{R}^k))
    \overset{0}{\longrightarrow}
  \pi_{\bullet-1 \lt k-n-1}(O(k))
    \overset{\simeq}{\longrightarrow}
  \pi_{\bullet-1 \lt k-n-1}(O(k-n))
    \to
  \cdots
  \,.
$$

This implies the claim. (Exactness of the sequence says that every element in $\pi_{\bullet \leq n-1}(V_n(\mathbb{R}^k))$ is in the kernel of zero, hence in the image of 0, hence is 0 itself.)


=--

Similarly:

+-- {: .num_prop }
###### Proposition

The complex [[Stiefel manifold]] $V_n(\mathbb{C}^k)$ (def. \ref{StiefelManifold}) is [[n-connected topological space|2(k-n)-connected]].

=--

+-- {: .proof}
###### Proof

Consider the [[coset]] [[quotient]] [[projection]]

$$
  U(k-n)
    \longrightarrow
  U(k)
    \longrightarrow
  U(k)/U(k-n) 
    = 
  V_n(\mathbb{C}^k)
  \,.
$$

By prop. \ref{UnitaryGroupIsCompact} and by [this corollary](coset#QuotientProjectionForCompactLieSubgroupIsPrincipal) the projection $U(k)\to U(k)/U(k-n)$ is a [[Serre fibration]]. Therefore there is induced the [[long exact sequence of homotopy groups]] of this [[fiber sequence]], and by prop. \ref{InclusionOfUnitaryGroupnIntoUnitaryGroupnPlusIneIsnMinus1Equivalence} it has the following form in degrees bounded by $n$:

$$
  \cdots
    \to
  \pi_{\bullet \leq 2(k-n)}(U(k-n))
    \overset{epi}{\longrightarrow}
  \pi_{\bullet \leq 2(k-n)}(U(k))
    \overset{0}{\longrightarrow}
  \pi_{\bullet \leq 2(k-n)}(V_n(\mathbb{C}^k))
    \overset{0}{\longrightarrow}
  \pi_{\bullet-1 \lt 2(k-n)}(U(k))
    \overset{\simeq}{\longrightarrow}
  \pi_{\bullet-1 \lt 2(k-n)}(U(k-n))
    \to
  \cdots
  \,.
$$

This implies the claim. 


=--



+-- {: .num_cor #EOnIsWeaklyContractible}
###### Corollary

The colimiting space $E O(n) = \underset{\longrightarrow}{\lim}_k V_n(\mathbb{R}^k)$ from def. \ref{EOn} is [[weakly contractible topological space|weakly contractible]].

The colimiting space $E U(n) = \underset{\longrightarrow}{\lim}_k V_n(\mathbb{C}^k)$ from def. \ref{EOn} is [[weakly contractible topological space|weakly contractible]].


=--

+-- {: .num_prop #HomotopyGroupsOfBOnThoseOfOnShifted}
###### Proposition

The [[homotopy groups]] of the classifying spaces $B O(n)$ and $B U(n)$ (def. \ref{EOn}) are those of the [[orthogonal group]] $O(n)$ and of the [[unitary group]] $U(n)$, respectively, shifted up in degree: there are [[isomorphisms]]

$$
  \pi_{\bullet+1}(B O(n))
    \simeq
  \pi_\bullet O(n)
$$

and

$$
  \pi_{\bullet+1}(B U(n))
    \simeq
  \pi_\bullet U(n)
$$

(for homotopy groups based at the canonical basepoint).

=---

+-- {: .proof}
###### Proof

Consider the sequence

$$
  O(n)
    \longrightarrow
  E O(n)
    \longrightarrow
  B O(n)
$$

from def. \ref{EOn}, with $O(n)$ the [[fiber]]. Since (by [this prop.](coset#ProjectionOfCosetsIsFiberBundleForClosedSubgroupsOfCompactLieGroup)) the second map is a [[Serre fibration]], this is a [[fiber sequence]] and so it induces a [[long exact sequence of homotopy groups]] of the form

$$
  \cdots
    \to
  \pi_\bullet(O(n))
    \longrightarrow
  \pi_\bullet(E O(n))
    \longrightarrow
  \pi_\bullet(B O(n))
    \longrightarrow
  \pi_{\bullet-1}(O (n))
   \longrightarrow
  \pi_{\bullet-1}(E O(n))
    \to
  \cdots
  \,.
$$

Since by cor. \ref{EOnIsWeaklyContractible} $\pi_\bullet(E O(n))= 0$, exactness of the sequence implies that 

$$
  \pi_\bullet(B O(n))
   \overset{\simeq}{\longrightarrow}
  \pi_{\bullet-1}(O (n))
$$

is an isomorphism.

The same kind of argument applies to the complex case.

=--


+-- {: .num_prop #SphereFibrationOverInclusionOfClassifyingSpaces}
###### Proposition

For $n \in \mathbb{N}$ there are [[homotopy fiber sequences]]

$$
  S^n
    \longrightarrow 
  B O(n)
    \longrightarrow
  B O(n+1)
$$

and

$$
  S^{2n+1}
    \longrightarrow 
  B U(n)
    \longrightarrow
  B U(n+1)
  \,,
$$

exhibiting the [[n-sphere]] ($(2n+1)$-sphere) as the [[homotopy fiber]] of the canonical maps from def. \ref{InclusionOfBOnIntoBOnPlusOne}.

This means that there is a replacement of the canonical inclusion $B O(n) \hookrightarrow B O(n+1)$ (induced via def. \ref{EOn}) by a [[Serre fibration]]

$$
  \array{
     B O(n) &\hookrightarrow& B O(n+1)
     \\
     {}^{\mathllap{{weak \, homotopy} \atop equivalence}}\downarrow  & \nearrow_{\mathrlap{Serre \, fib.}}
     \\
     \tilde B O(n)
  }
$$

such that $S^n$ is the ordinary [[fiber]] of $B O(n)\to \tilde B O(n+1)$, and analogously for the complex case.

=--

+-- {: .proof}
###### Proof

Take $\tilde B O(n) \coloneqq (E O(n+1))/O(n)$. 

To see that the canonical map $B O(n)\longrightarrow (E O(n+1))/O(n)$ is a [[weak homotopy equivalence]] consider the [[commuting diagram]]

$$
  \array{
    O(n) &\overset{id}{\longrightarrow}& O(n)
    \\
    \downarrow && \downarrow
    \\
    E O(n) &\longrightarrow& E O(n+1)
    \\
    \downarrow && \downarrow
    \\
    B O(n) &\longrightarrow& (E O(n+1))/O(n)
  }
  \,.
$$

By [this prop.](coset#ProjectionOfCosetsIsFiberBundleForClosedSubgroupsOfCompactLieGroup) both bottom vertical maps are [[Serre fibrations]] and so both vertical sequences are [[fiber sequences]]. By prop. \ref{HomotopyGroupsOfBOnThoseOfOnShifted} part of the induced morphisms of [[long exact sequences of homotopy groups]] looks like this

$$
  \array{
    \pi_\bullet(B O(n))
    &\overset{}{\longrightarrow}&
    \pi_\bullet( (E O(n+1))/O(n) )
    \\
    {}^{\mathllap{\simeq}}\downarrow && \downarrow^{\mathrlap{\simeq}}
    \\
    \pi_{\bullet-1}(O(n))
    &\overset{=}{\longrightarrow}&
    \pi_{\bullet-1}(O(n))
  }
  \,,
$$

where the vertical and the bottom morphism are isomorphisms. Hence also the to morphisms is an isomorphism.

That $B O(n)\to \tilde B O(n+1)$ is indeed a [[Serre fibration]] follows again with [this prop.](coset#ProjectionOfCosetsIsFiberBundleForClosedSubgroupsOfCompactLieGroup), which gives the [[fiber sequence]]

$$
  O(n+1)/O(n)
    \longrightarrow
  (E O(n+1))/O(n)
    \longrightarrow
  (E O(n+1))/O(n+1)
  \,.
$$

The claim in then follows since ([this exmpl.](coset#nSphereAsCosetSpace))

$$
  O(n+1)/O(n) \simeq S^n
  \,.
$$

The argument for the complex case is of the same form, concluding now with the identification ([this exmpl.](unitary+group#nSphereAsUnitaryCosetSpace))

$$
  U(n+1)/U(n) \simeq S^{2n+1}
  \,.
$$


=--

#### Classification of bundles

+-- {: .num_prop }
###### Proposition

For $X$ a [[paracompact topological space]], the operation of [[pullback]] of the [[universal principal bundle]] $E O(n) \to B O(n)$ from def. \ref{EOn} along [[continuous functions]] $f \colon X \to B O(n)$ eastblishes a [[bijection]]

$$
  [X, B O(n)]
   \underoverset{iso}{f \mapsto f^\ast E O(n)}{\longrightarrow}
  O(n) Bund/_\sim
$$

between [[homotopy classes]] of functions from $X$ to $B O(n)$ and isomorphism classes of $O(n)$-[[principal bundles]] on $X$.

=--

A full proof is spelled out in ([Hatcher, section 1.2, theorem 1.16](#Hatcher))


### For symmetric principal bundles

* the _unordered_ [[Fadell's configuration space]] of $n$ points in $\mathbb{R}^\infty$ is a model for the classifying space $B \Sigma(n)$ of the [[symmetric group]] $\Sigma(n)$;

* the _ordered_ configuration space of $n$ points, equipped with the canonical $\Sigma(n)$-[[action]], is a model for the $\Sigma(n)$-[[universal principal bundle]].


### For crossed complexes

We discuss here classifying spaces of [[crossed complex]]es.

The notion of classifying space should be regarded in general terms as giving a functor 

$$  \mathcal{B} :(algebraic data) \to (topological data).$$

Composition with a forgetful functor $U: (topological data) \to (topological spaces) $ gives a [[classifying space]]. In such cases one would also like a homotopically defined functor 

$$ \Xi: (topological data) \to (algebraic data) $$

such that 

1. $\Xi \circ \mathcal{B}$ is equivalent to the identity; 

1. $\Xi$ preserves certain colimits (Generalised [[van Kampen theorem]]) allowing some calculation;

1. there are notions of homotopy for both types of data leading to a bijection of homotopy classes for some $X$ 

$$[X,U\mathcal{B}C] \cong [\Xi X_*, C].$$

This happens for the algebraic data of crossed complexes and the topological data of filtered spaces, when $X$ is a CW-complex, and $\Xi$ is the fundamental crossed complex of a filtered space. Thus in this case the classifying space does classify homotopy classes of maps, and more work is needed to sort out the data over $X$ which this classifies (gerbes?). 

However $\mathcal{B}C$ is in this case defined by a nerve construction which generalises that for groupoids, and can also be applied to topological crossed crossed complexes, giving a simplicial space. 

+--{: .query}
[[Mike Shulman|Mike]]: I don't really get any intuition from that.  There might be lots of functors from "algebraic data" to "topological data" but it seems to me that only particular sorts of them deserve the name "classifying space."  Can you say more specifically what sorts of functors you have in mind, and relate it to the more basic ideas that I am familiar with?  What do these classifying spaces classify?

[[Ronnie Brown|Ronnie]] What I am trying to characterise is that higher categories carry structure such as a filtration by lower dimensional higher categories, or, for multiple structures, a multiple filtration. Thus one expects a classifying space to inherit this extra structure. Conversely, the construction of an infinity-groupoid from a space might depend on this extra structure. 

So I spent 9 years trying to construct a _strict_ homotopy double groupoid of a space, yet Philip Higgins and I did this overnight in 1974 when we tried the simplest relative example we could think of: take homotopy classes of maps from a square to $X$ which take the edges to a subspace $X_1$ and the vertices to a base point $x_0$. Then the filtered case took another 4 years or so to complete. 

Then Loday constructed a [[cat-n-group]] from an n-cube of spaces, published in 1982. Its multi-nerve  is an $(n+1)$-simplicial set, whose realisation is $(n+1)$-filtered. 

A strict homotopy double groupoid of a Hausdorff space has been constructed but this needs a subtle notion of [[thin element|thin]] homotopy.

Of course the filtration for a group is not so apparent, but it is more clear that  [[groupoids]]  carry structure in dimension 0 and 1, and hence are useful for representing non connected homotopy 1-types, and their identifications in dimension 0, as explained in the first edition (1968) of my Topology book.   

The intuition for the [[higher homotopy van Kampen theorem]] is that you need _structure in all  dimensions from 0 to n _to get colimit theorems in dimension n, because in homotopy, low dimensional identifications, even in dimension 0,  usually effect high dimensional homotopy information. In effect, the [[higher homotopy van Kampen theorem]] is about gluing [[homotopy n-types]]. 

_Mike_: Thanks, that is helpful.
=--

Some such constructions arise from generalisations of the [[Dold-Kan correspondence]], with values in [[simplicial sets]]. For example, from a [[crossed complex]] $C$ one obtains a simplicial  set $Nerve(C)$ which in dimension $n$ is $Crs(\Pi(\Delta^n_*),C)$. The geometric realisation $\mathcal{B}C$ of this is canonically filtered by the skeleta of $C$, so $\mathcal{B}$ is really a functor to [[filtered spaces]]. This ties in with the functor $\Pi$ which goes in the opposite direction. But note that there is a different filtration of the space $\mathcal{B}C$ since it is a CW-complex, and so $\Pi$ of this filtration gives a free crossed complex. 

Special cases of crossed complexes are [[groupoids]], and so we get the classifying space of a groupoid; and similarly of a [[crossed module]]. 

A crossed module is equivalent to a category object in groups, and so a nerve of this can be constructed as a bisimplicial set. The geometric realisation of this is naturally bifiltered, in several ways!

In considering what is desirable for a [[fundamental infinity-groupoid]] one should bring the notion of classifying space, and its inherited structure, into account. 

### For simplicial groups

The $\bar W(-)$-construction (see [[simplicial group]] and [[groupoid object in an (∞,1)-category]]) which gives the classifying space functor for [[simplicial group]]s and simplicially enriched groupoids is given in the entry on [[simplicial group|simplicial groups]].  It provides a good example of the above as the W-bar functor is right adjoint to the [[Dwyer-Kan loop groupoid]] functor and induces an equivalence of homotopy categories between that of simplicial sets and that of simplicially enriched groupoids.
The simplicial sets here are playing the role of 'topological data'.


## Properties


### For classical Lie groups

Let $O(n)$ be the [[orthogonal group]] and $U(n)$ the [[unitary group]] in real/complex [[dimension]] $n$, respectively.

+-- {: .num_prop #CWComplexStructure}
###### Proposition

The real [[Grassmannians]] $Gr_n(\mathbb{R}^k)$ and the complex Grassmannians $Gr_n(\mathbb{C}^k)$ admit the structure of [[CW-complexes]]. Moreover the canonical inclusions

$$
  Gr_n(\mathbb{R}^k)
  \hookrightarrow
  Gr_n(\mathbb{R}^{k+1})
$$

are subcomplex incusion (hence [[relative cell complex]] inclusions).

Accordingly there is an induced CW-complex structure on the classifying space

$$
  B O(n) \simeq \underset{\longrightarrow}{\lim}_k Gr_n(\mathbb{R}^k)
  \,.
$$

=--

A proof is spelled out in ([Hatcher, section 1.2 (pages 31-34)](#Hatcher)).



+-- {: .num_prop #}
###### Proposition

The classifying spaces $B O(n)$ are [[paracompact spaces]].

=--

An early source of this statement is ([Cartan-Schwartz 63, exposé 5](#CartanSchwartz63)). It follows for instance by prop. \ref{CWComplexStructure} the fact that every [[CW-complex]] is paracompact.



## Moduli spaces 

The notion of **[[moduli space]]** is closely related to that of classifying space, but has some subtle differences. See there for more on this.

## Related concepts

* **classifying space**, [[classifying stack]], [[moduli space]], [[moduli stack]], [[derived moduli space]], [[Kan-Thurston theorem]]

  * [[Milnor classifying space]]

  * [[numerable bundle]]

  * [[acyclic group]]

* [[classifying topos]]

* [[universal principal bundle]], [[universal principal ∞-bundle]]

* [[subobject classifier]]

* [[classifying morphism]]

## References

Original accounts include

* {#CartanSchwartz63} [[Henri Cartan]], [[Laurent Schwartz]], _Le théoréme d'Atiyah-Singer_ Séminaire 1963/1964. New York:  Benjamin 1967. 
 
Textbook accounts on classifying spaces for [[vector bundles]] include

* {#Kochmann96} [[Stanley Kochmann]], section 1.3 of of _[[Bordism, Stable Homotopy and Adams Spectral Sequences]]_, AMS 1996

* {#May} [[Peter May]], chapter 23 of _A concise course of algebraic topology_ ([pdf](http://www.math.uchicago.edu/~may/CONCISE/ConciseRevised.pdf))

* {#Hatcher} [[Alan Hatcher]], section 1.2 of _Vector bundles and K-theory_ ([web](https://www.math.cornell.edu/~hatcher/VBKT/VBpage.html))

* [[Dale Husemoeller]], [[Michael Joachim]], [[Branislav Jurčo]], [[Martin Schottenloher]], _[[Basic Bundle Theory and K-Cohomology Invariants]]_, 
Lecture Notes in Physics, Springer 2008 ([pdf](http://www.mathematik.uni-muenchen.de/~schotten/Texte/978-3-540-74955-4_Book_LNP726corr1.pdf))
 
 
A discussion more from the point of view of [[topos theory]] is in

* [[Ieke Moerdijk]], _Classifying spaces and classifying topoi_, Lecture Notes in Math. 1616, Springer-Verlag, New York, 1995.

Discussion of [[universal principal bundles]] over their classifying spaces is in 

* Stephen Mitchell, _Universal principal bundles and classifying spaces_ ([pdf](http://www-math.mit.edu/~mbehrens/18.906/prin.pdf))

Discussion of characterization of principal bundles by rational [[universal characteristic classes]] and torsion information is in the appendices of 

* Igor Belegradek, Vitali Kapovitch, _Obstructions to nonnegative curvature and rational homotopy theory_ ([arXiv:math/0007007](http://arxiv.org/abs/math/0007007))

* Igor Belegradek, _Pinching, Pontrjagin classes, and negatively curved vector bundles_ ([arXiv:math/0001132](http://arxiv.org/abs/math/0001132))

Discussion of classifying spaces in the context of [[measure theory]] is in 

* {#Marin17} Ivan Marin, _Measure theory and classifying spaces_ ([arXiv:1702.01889](https://arxiv.org/abs/1702.01889))



[[!redirects classifying spaces]]
