
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Model theory
+-- {: .hide}
[[!include model theory - contents]]
=--
=--
=--

#Contents#
* table of contents
{:toc}

## Idea 

Stability theory, also referred to a classification theory, is a means to determine whether the isomorphism types of a given sort of [[structure in model theory|structure]] can be classified by means of intelligible invariants of the structure. It was largely created by Saharon Shelah. 

The basic idea is that for quite general classes of algebraic objects, one can prove what Shelah calls a "structure/nonstructure theorem": either the isomorphism types are classifiable by a smallish number of invariants, or they are hopelessly wild in some sense, e.g., an arbitrary structure can be encoded set-theoretically in some isomorphism type of the class. An example of the "structure" case is the theory of [[algebraically closed fields]], whose isomorphism types can be classified according to characteristic and [[transcendence degree]]. An example of the "nonstructure" case is the family of linear orderings, where a proliferation of complicated linear orders can be constructed by various set-theoretic means. 

In very rough outline, stability theory analyzes good (or "stable") notions of "free amalgams" $M_3 = M_1 \cup_{M_0} M_2$ where $M_0 \subset M_1$, $M_0 \subset M_2$ are substructures. In the "good" (structure) case, it is possible to analyze models by a series of free amalgams of small models, with the series indexed by a well-founded tree. Otherwise, if the class of algebraic objects does not admit a suitably good notion of free amalgam, we have a "bad" (nonstructure) case which permits arbitrarily wild models to be constructed. 

## Definitions 

(For the time being we are recording some definitions without any effort to motivate them. That should come later.) 

For now we will be interested in [[complete theory|complete theories]] $\mathbf{T}$ over a countable [[signature (in logic)|signature]]. Let $\mathbf{M}$ be a [[theory|model]] of $\mathbf{T}$ with underlying set $M$. Let $A \subseteq M$ be a subset, and let $Def_A(M^n)$ be the [[Boolean algebra]] of subsets of $M^n$ that are definable by a formula in $\mathbf{T}$ with parameters in $A$. 

Recall that an [[ultrafilter]] in a Boolean algebra $B$ is the set of elements that get mapped to the top element $1$ under some Boolean algebra homomorphism $\phi: B \to \mathbf{2}$; alternatively, we could define an ultrafilter as such a homomorphism. 

+-- {: .num_defn} 
###### Definition 
The _space of complete $n$-types_ over $A$ is the [[Stone space]] $S_n^{\mathbf{M}}(A)$ of ultrafilters in the Boolean algebra $Def_A(M^n)$. Such an ultrafilter is called a complete $n$-type. More generally, an $n$-type is a [[filter]] in $Def_A(M^n)$. 
=-- 

+-- {: .num_prop} 
###### Proposition 
Suppose $i: M \to N$ is an [[elementary embedding]] from $\mathbf{M}$ to $\mathbf{N}$. Then $i$ induces an isomorphism $S_n^{\mathbf{M}}(A) \cong S_n^{\mathbf{N}}(i(A))$. 
=-- 

+-- {: .proof} 
###### Proof 
It is enough to show $i$ induces an isomorphism $Def_A(M^n) \to Def_A(N^n)$. As a Boolean algebra, $Def_A(M^n)$ is the Boolean quotient of formulas with $n$ free variables $\phi(\bar{x}, \bar{a})$ modulo the equivalence relation $E(\phi, \psi) \coloneqq \phi \Leftrightarrow \psi$ is satisfied in $\mathbf{M}$. By elementary equivalence, $\mathbf{M} \models E(\phi, \psi)(\bar{x}, \bar{a})$ iff $\mathbf{N} \models E(\phi, \psi)(\bar{x}, i(\bar{a}))$, as desired. 
=-- 

+-- {: .num_defn} 
###### Definition 
A complete type is _realized_ by a point $\bar{a} \in M^n$ if it is of the form 

$$Def_A(M^n) \hookrightarrow P(M^n) = \mathbf{2}^{M^n} \stackrel{eval_{\bar{a}}}{\to} \mathbf{2}$$ 

by restricting a principal ultrafilter generated by a point $\bar{a} \in M^n$. Such a type is denoted $tp(\bar{a}/A)$. 
=-- 

+-- {: .num_defn} 
###### Definition 
For an infinite cardinal $\kappa$, a model $\mathbf{M}$ is called _$\kappa$-saturated_ if for every $A \subseteq M$ with ${|A|} \lt \kappa$, any complete $n$-type is realized in $\mathbf{M}$. 
=-- 

+-- {: .num_defn} 
###### Definition 
For an infinite cardinal $\kappa$, the theory $\mathbf{T}$ is _$\kappa$-stable_ if for every model $\mathbf{M} \models \mathbf{T}$ and $A \subseteq M$ with ${|A|} = \kappa$, we have ${|S_n^{\mathbf{M}}(A)|} = \kappa$. A structure $\mathbf{M}$ of a countable language is called $\kappa$-stable if the complete theory $Th(\mathbf{M})$ is $\kappa$-stable. 
=-- 

 

## Related concepts

* [[geometric stability theory]]

## References

* [[M. Makkai]], _A survey of basic stability theory, with particular emphasis on orthogonality and regular types_, Israel J. Math. __49__, n.1-3 (1984), 181-238, [doi](http://dx.doi.org/10.1007/BF02760649)

* John T. Baldwin, _Fundamentals of stability theory_, Perspectives in Math. Logic vol. 12 Springer Heidelberg 1988. ([toc](http://projecteuclid.org/euclid.pl/1235414194#toc))

* Steven Buechler, _Essential Stability Theory_ , Perspectives in Math. Logic vol. 4  Springer Heidelberg 1996. ([toc](http://projecteuclid.org/euclid.pl/1235420888#toc))

* Gregory L. Cherlin, Review of _Fundamentals of stability theory_, Bull. AMS, Vol. 20 No. 2 (April 1989), 185-190. 
