

+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Complex geometry
+--{: .hide}
[[!include complex geometry - contents]]
=--
#### Differential geometry
+--{: .hide}
[[!include synthetic differential geometry - contents]]
=--
=--
=--



#Contents#
* automatic table of contents goes here
{:toc}

## Idea

_Generalized complex geometry_ is the study of the geometry of [[symplectic Lie n-algebroid|symplectic Lie 2-algebroid]] called [[standard Courant algebroid]]s $\mathfrak{c}(X)$ (over a [[smooth manifold]] $X$). 

This geometry of symplectic Lie 2-algebroids turns out to unify, among other things, [[complex geometry]] with [[symplectic geometry]]. This unification notably captures central aspects of [[T-duality]].

## Definition
 {#Definition}

### On a vector space

Let $V$ be a [[dimension|finite dimensional]] [[vector space]] over the [[real numbers]].

Recall that a _[[complex structure]]_ on $V$ is a [[linear map]]

$$
  J : V \to V
$$

such that $J \circ J = - id_V$. And a [[symplectic structure]] on $V$ is equivalently a linear [[isomorphism]]

$$
  \omega : V \to V^*
$$

such that

$$
  \omega^* = - \omega
  \,,
$$

where $V^*$ denotes the [[dual vector space]] and $\omega^*$ the dual linear map.

The following definition may be thought of as combining these two concepts.

+-- {: .num_defn}
###### Definition

A **generalized complex structure** on $V$ is a [[linear map]]

$$
  \mathcal{J} : V \oplus V^* \to V \oplus V^*
$$

(an [[endomorphism]] of the [[direct sum]] of $V$ with its [[dual vector space]])

such that it is both

1. a [[complex structure]] on $V \oplus V^*$ in that $\mathcal{J}^2 = - id$;

1. a [[symplectic structure]] on $V \oplus V^*$ in that $\mathcal{J}^* = - \mathcal{J}$.

=--

The following shows that this is indeed a joint generalization of complex and symplectic structures.

+-- {: .num_example}
###### Examples

Let $J : V \to V$ be an ordinary complex structure on $V$. Then the linear endomorphism of $V \oplus V^*$ defined by [[matrix calculus]] as

$$
  \mathcal{J}_j := 
  \left(
    \array{
       -J & 0
       \\
       0 & J^*
    }
  \right)
$$

is a generalized complex structure on $V$.

Similarly, let $\omega : V \to V^*$ be an ordinary symplectic structure on $V$. then the endomorphism

$$
  \mathcal{J}_\omega :=
  \left(
    \array{
      0 & - \omega^{-1}
      \\
      \omega & 0
    }
  \right)
$$

is a generalized complex structure on $V$.

=--

### On a manifold

A generalized complex structure on a manifold is a generalized complex structure on the fibers of the [[generalized tangent bundle]].

(...)

### In terms of reduction of the structure group

A generalized complex structure on $V \oplus V^*$ is equivalently a [[reduction of the structure group]] along the inclusion

$$
  U(n,n) \hookrightarrow O(2n,2n)
  \,,
$$

where the left hand is identified as $U(n,n) = O(2n,2n) \cap GL(2n, \mathbb{C})$ ([Gualtieri, prop. 4.6](#Gualtieri)).

The analog of this with the unitary group replaced by the orthogonal group yields _[[type II geometry]]_.

## Properties

One finds (as described at [[standard Courant algebroid]]) that

* choices of sub-[[Lie algebroid]]s of $\mathfrak{c}(X)$ encode (almost) **[[Dirac structure]]s** and -- after [[complexification]] -- **generalized [[complex structure]]s**;

* choices of [[section]]s of the canonical morphism $\mathfrak{c}(X) \to T X$ to the [[tangent Lie algebroid]]s encode **generalized Riemannian metrics**: pairs consisting of a (possibly [[pseudo-Riemannian metric|pseudo]]-)[[Riemannian metric]] and a [[differential form|2-form]].

  In applications in [[string theory]], this encodes the field of [[gravity]] and the [[Kalb–Ramond field]], respectively. (There are also proposals for how the [[dilaton]] field appears in this context.)

In components these are structures found on the [[vector bundle]]

$$
  T X \oplus T^* X
  \,,
$$

the [[direct sum]] of the [[tangent bundle]] with the cotangent bundle of $X$. 

Generalized complex geometry thus generalizes and unifies

* [[complex geometry]],
* [[symplectic geometry]], and
* [[Riemannian geometry]].

It was in particular motivated by the observation that this provides a natural formalism for describing [[T-duality]].

## Examples

* [[generalized Calabi-Yau manifold]]

## Related concepts

* [[generalized tangent bundle]], [[generalized vielbein]]

* [[type II geometry]]

* [[exceptional generalized geometry]]

* [[Bn-geometry]]

* [[generalized contact geometry]]

## References

#### General

Generalized complex geometry was proposed by [[Nigel Hitchin]] as a formalism in [[differential geometry]] that would be suited to capture the phenomena that physicists encountered in the study of [[T-duality]].
It was later and is still developed by his students, notably Gualtieri and Cavalcanti.


A standard reference is the PhD thesis

* [[Marco Gualtieri]], _Generalized complex geometry_ ([arXiv:math/0401221](http://arxiv.org/abs/math/0401221))
 {#Gualtieri}

A survey set of slides with an eye towards  the description of the [[Kalb-Ramond field]] and [[bundle gerbe]]s is

* [[Nigel Hitchin]], _B-Fields, gerbes and generalized geometry_ Oxford Durham Symposium 2005 ([pdf](http://www.maths.dur.ac.uk/events/Meetings/LMS/2005/GCFTST/Talks/hitchin1.pdf)) 

* [[Nigel Hitchin]], _Lectures on generalized geometry_ ([arxiv/1008.0973](http://arxiv.org/abs/1008.0973))

#### As targets for $\sigma$-models

Generalized complex structures may serve as [[target spaces]] for [[sigma-models]]. Relations to the [[Poisson sigma-model]] and the [[Courant sigma-model]] are discussed in

* [[Alberto Cattaneo]], Jian Qiub, [[Maxim Zabzine]], _2D and 3D topological field theories for generalized complex geometry_, [euclid](http://projecteuclid.org/getRecord?id=euclid.atmp/1288619156) [MR2012a:81255](http://www.ams.org/mathscinet-getitem?mr=2721659) [pdf](http://www.math.uzh.ch/fileadmin/math/preprints/GC_BV.pdf)

#### Mirror symmetry

* Oren Ben-Bassat, _Mirror symmetry and generalized complex manifolds. I. The transform on vector bundles, spinors, and branes_, 
J. Geom. Phys. __56__ (2006), no. 4, 533–558 [math.AG/0405303](http://arxiv.org/abs/math/0405303) [MR2006k:53067](http://www.ams.org/mathscinet-getitem?mr=2199280) [doi](http://dx.doi.org/10.1016/j.geomphys.2005.03.004) 

#### Geometry of supergravity

Generalized complex geometry and variant of [[exceptional generalized complex geometry]] are natural for describing [[supergravity]] background compactifications in [[string theory]] with their [[T-duality]] and [[U-duality]] symmetries.

* Ian Ellwood, _NS-NS fluxes in Hitchin's generalized geometry_ ([arXiv:hep-th/0612100](http://arxiv.org/abs/hep-th/0612100))

* Paulo Pires Pacheco, [[Daniel Waldram]], _M-theory, exceptional generalised geometry and superpotentials_ ([arXiv:0804.1362](http://arxiv.org/abs/0804.1362))

* [[Mariana Graña]], [[Ruben Minasian]], Michela Petrini, [[Daniel Waldram]], _T-duality, generalized geometry and non-geometric backgrounds_,  J. High Energy Phys. 2009, no. 4, 075, 39 pp. [arXiv:0807.4527](http://xxx.lanl.gov/abs/0807.4527) [MR2010i:81323](http://www.ams.org/mathscinet-getitem?mr=2505954) [doi](http://dx.doi.org/10.1088/1126-6708/2009/04/075)

* David Andriot, Ruben Minasian, Michela Petrini, _Flux backgrounds from twists_,  J. High Energy Phys. 2009, no. 12, 028 [arXiv:0903.0633](http://arxiv.org/abs/0903.0633) [MR2011c:81201](http://www.ams.org/mathscinet-getitem?mr=2593014) [doi](http://dx.doi.org/10.1088/1126-6708/2009/12/028)


[[!redirects generalized complex structure]]
[[!redirects generalized complex structures]]
