
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Functional analysis
+-- {: .hide}
[[!include functional analysis - contents]]
=--
#### Monoidal categories
+-- {: .hide}
[[!include monoidal categories - contents]]
=--
=--
=--

# Tensor products of Banach spaces
* table of contents
{: toc}

## Idea

There are various [[norms]] that may be placed on the [[tensor product]] of the underlying [[vector spaces]] of two [[Banach spaces]]; the result is not usually [[complete space|complete]], but of course we may take its [[completion]].  One of these, the _projective tensor product_, makes [[Ban]] (the category of Banach spaces and [[short linear maps]]) into a [[closed symmetric monoidal category]], but there are others that still put useful structures on $Ban$.  If we start with [[Hilbert spaces]], then there is a choice of norm that will make the result into a Hilbert space; then [[Hilb]] also becomes a closed symmetric monoidal category.


## Definitions

Let $V$ and $W$ be [[Banach spaces]], and let $V \otimes W$ be their [[tensor product]] as [[vector spaces]].  To define a tensor product of $V$ and $W$ as Banach spaces, we will place a [[norm]] on $V \otimes W$, making a [[normed vector space]]; the only difference in the following definitions is which norm to use.  Then we take the completion $V {\displaystyle\hat{\otimes}} W$, which is a Banach space.

+-- {: .num_defn}
###### Definition (projective tensor product)

Every element of $V \otimes W$ may be written (in many different ways) as a formal [[linear combination]] of formal tensor products of elements of $V$ and $W$ (suppressing the symbol $\otimes$):
$$ \sum_i \alpha_i v_i w_i .$$
Let the __projective cross norm__ ${\|x\|_\pi}$ of an element $x$ of $V \otimes W$ be
$$ {\|x\|_\pi} \coloneqq \inf \{ \sum_i {|\alpha_i|} {\|v_i\|_V} {\|w_i\|_W} \;|\; x = \sum_i \alpha_i v_i w_i \} .$$
Then the __projective tensor product__ $V {\displaystyle\hat{\otimes}_\pi} W$ of $V$ and $W$ is the completion of $V \otimes W$ under the projective cross norm.
=--

+-- {: .num_defn}
###### Definition (injective tensor product)

If $\lambda$ and $\mu$ are [[linear functionals]] on $V$ and $W$ (respectively), then $\lambda \otimes \mu$ is a linear functional on $V \otimes W$.  Let the __injective cross norm__ ${\|x\|_\epsilon}$ of an element $x$ of $V \otimes W$ be
$$ {\|x\|_\epsilon} \coloneqq \sup \{ {|(\lambda \otimes \mu)x|} \;|\; {\|\lambda\|_{V^*}}, {\|\mu\|_{W^*}} \leq 1 \} .$$
Then the __injective tensor product__ $V {\displaystyle\hat{\otimes}_\epsilon} W$ of $V$ and $W$ is the completion of $V \otimes W$ under the injective cross norm.
=--

+-- {: .num_defn}
###### Definition (tensor product of Hilbert spaces)

If $V$ and $W$ are [[Hilbert spaces]], then their norms determine and are determined by their [[inner products]], so let us discuss inner products.  The elements of $V \otimes W$ are generated by elements of the form $v w$, so set
$$ \langle{v_1 w_1, v_2 w_2}\rangle \coloneqq \langle{v_1, v_2}\rangle \langle{w_1, w_2}\rangle $$
and extend by linearity.  We write the norm of an element $x$ of the [[inner product space]] $V \otimes W$ as ${\|x\|_\sigma}$.  Then the __tensor product__ $V {\displaystyle\hat{\otimes}_\sigma} W$ of the Hilbert spaces $V$ and $W$ is the completion of $V \otimes W$ under this norm (or inner product).
=--


## Cross norms

Besides the specific norms defined above, we can define axioms of a reasonable norm on $V \otimes W$.

+-- {: .num_defn}
###### Definition (cross norm)

A __cross norm__ on $V$ and $W$ is *any* [[norm]] $\chi$ on $V \otimes W$ such that:

*  ${\|v \otimes w\|_\chi} = {\|v\|_V} {\|w\|_W}$ for any elements $v$ and $w$ of $V$ and $W$ (respectively);
*  ${\|\lambda \otimes \mu\|_{\chi^*}} = {\|\lambda\|_{V^*}} {\|\mu\|_{W^*}}$ for any [[bounded linear functionals]] $\lambda$ and $\mu$ on $V$ and $W$ (respectively).
=--

+-- {: .num_defn}
###### Definition (uniform cross norm)

A __uniform cross norm__ is an operation that takes two Banach spaces and returns a norm on their algebraic tensor product, [[natural transformation|naturally]] in the two spaces.  Equivalently, it\'s a [[functor]] $\chi\colon Ban \times Ban \to NVect$ that makes the following diagram commute (or fills it with a [[natural isomorphism]]):
$$ \array { Ban \times Ban   & \overset{\chi}\rightarrow     & NVect \\
            \downarrow       &                               & \downarrow \\
            Vect \times Vect & \underset{\otimes}\rightarrow & Vect
} $$
=--

A uniform cross norm is obviously desirable from the [[nPOV]], but does it meet the analysts\' needs for a cross norm?  Yes:

+-- {: .num_prop}
###### Proposition

A uniform cross norm assigns a cross norm to any two Banach spaces.
=--

The specific cross norms from the previous section qualify as much as possible:

+-- {: .num_prop}
###### Proposition

The projective and injective cross norms are uniform cross norms (and hence are in fact cross norms).  The norm on the algebraic tensor product of two Hilbert spaces is also a cross norm.
=--

As far as I can tell, the Hilbert-space cross norm $\sigma$ doesn\'t apply to arbitrary Banach spaces, so it doesn\'t define a uniform cross norm as defined above; however, it does define a functor on $Hilb \times Hilb$, so it\'s as uniform as could be expected.

Looking only at the general theory of cross norms, the projective and injective cross norms appear naturally:

+-- {: .num_prop #topbot}
###### Proposition

If $\chi$ is any uniform cross norm, $V$ and $W$ are any Banach spaces, and $x$ is any element of $V \otimes W$, then
$$ {\|x\|_\epsilon} \leq {\|x\|_\chi} \leq {\|x\|_\pi} .$$
=--

That is, we have a [[poset]] of uniform cross norms, and the projective and injective cross norms are (respectively) the [[top]] and [[bottom]] of this poset.

Although $\sigma$ is not a uniform cross norm, it relates to $\epsilon$ and $\pi$ in the same way:

+-- {: .num_prop}
###### Proposition

If $V$ and $W$ are Hilbert spaces and $x$ is an element of $V \otimes W$, then
$$ {\|x\|_\epsilon} \leq {\|x\|_\sigma} \leq {\|x\|_\pi} .$$
=--

+-- {: .query}
Actually, this would all be simpler if Propostion \ref{topbot} applied to *arbitrary* cross norms and not just uniform ones.  Perhaps it does.  Or perhaps $\sigma$ extends to a uniform cross norm on all of $Ban$; that would also make things simpler.  I don\'t know.
=--

Of course, any cross norm $\chi$ on $V$ and $W$ allows us to form the Banach space $V {\displaystyle\hat{\otimes}_\chi} W$, which may reasonably be called a __tensor product__ of $V$ and $W$; that\'s why we care.


## Schmidt decomposition

The __Schmidt decomposition__ is a way of expressing a pure state in the tensor product of two Hilbert spaces in terms of states of the two components:

+-- {: .num_theorem}
###### Theorem [Nielsen and Chuang Theorem 2.7](#NielsenChuang)

Let $A$ and $B$ be finite-dimensional Hilbert spaces.  Let $|\psi\rangle$ be a [[pure state]] of $A \otimes B$.  Then there exist [[orthonormal family|orthonormal families]] $\{ |i_A \rangle \}_i$ in $A$ and $\{ |i_B \rangle \}_i$ in $B$, and non-negative real numbers $\lambda_i$, such that
\[ |\psi\rangle = \sum_i \lambda_i |i_A \rangle \otimes |i_B\rangle \]
and $\sum_i \lambda_i^2 = 1$.
=--

The numbers $\lambda_i$ are called the __Schmidt co-efficients__ of $|\psi\rangle$, and the families $\{ |i_A\rangle \}$ and $\{ |i_B\rangle \}$ the __Schmidt bases__ for $A$ and $B$.

+-- {: .num_defn}
###### Definition
The __Schmidt number__ of $|\psi\rangle$ is the number of non-zero Schmidt coefficients of $|\psi\rangle$.
=--


## Foundational issues

We need the [[Hahn–Banach theorem]] for $\epsilon$ to be a cross norm; but $\sigma$ and $\pi$ work regardless.  Possibly some of the other propositions rely on some other form of the [[axiom of choice]]; I haven\'t seen their proofs.


## References

* M. Nielsen and I. Chuang.  _Quantum Computation and Quantum Information_.  Cambridge University Press.  2000.  {#NielsenChuang}

Many facts taken from Wikipedia:

* [Topological tensor product](https://en.wikipedia.org/wiki/Topological_tensor_product) (which also discusses tensor products of [[locally convex spaces]]),
* [Tensor product of Hilbert spaces](https://en.wikipedia.org/wiki/Tensor_product_of_Hilbert_spaces).


[[!redirects tensor product of a Banach space]]
[[!redirects tensor products of a Banach space]]
[[!redirects tensor product of Banach spaces]]
[[!redirects tensor products of Banach spaces]]

[[!redirects tensor product of a Hilbert space]]
[[!redirects tensor products of a Hilbert space]]
[[!redirects tensor product of Hilbert spaces]]
[[!redirects tensor products of Hilbert spaces]]

[[!redirects projective tensor product]]
[[!redirects projective tensor products]]
[[!redirects projective tensor norm]]
[[!redirects projective tensor norms]]
[[!redirects projective cross norm]]
[[!redirects projective cross norms]]

[[!redirects injective tensor product]]
[[!redirects injective tensor products]]
[[!redirects injective tensor norm]]
[[!redirects injective tensor norms]]
[[!redirects injective cross norm]]
[[!redirects injective cross norms]]

[[!redirects cross norm]]
[[!redirects cross norms]]
[[!redirects reasonable cross norm]]
[[!redirects reasonable cross norms]]
[[!redirects uniform cross norm]]
[[!redirects uniform cross norms]]

[[!redirects Schmidt decomposition]]
[[!redirects Schmidt decompositions]]
[[!redirects Schmidt coefficient]]
[[!redirects Schmidt coefficients]]
[[!redirects Schmidt co-efficient]]
[[!redirects Schmidt co-efficients]]
[[!redirects Schmidt basis]]
[[!redirects Schmidt bases]]
[[!redirects Schmidt basises]]
[[!redirects Schmidt number]]
[[!redirects Schmidt numbers]]
