
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Group Theory
+-- {: .hide}
[[!include group theory - contents]]
=--
=--
=--

# Cyclic groups
* table of contents
{: toc}

## Definition

A __cyclic group__ is a [[quotient group]] of the [[free group]] on the [[singleton]].

Generally, we consider a cyclic group as a [[group]], that is without specifying which element comprises the generating singleton.  But see [Ring structure](#Ring) below.


## Examples

There is (up to [[isomorphism]]) one cyclic group for every [[natural number]] $n$, denoted

$$
  \mathbb{Z}_n \coloneqq \mathbb{Z}/n\mathbb{Z}
  \,.
$$

For $n \gt 0$, the [[order of a group|order]] ([[cardinality]]) of $\mathbb{Z}_n$ is $n$ (so [[finite set|finite]]); for $n = 0$, which is the group of [[integers]]

$$
  \mathbb{Z}_0 \coloneqq \mathbb{Z}
$$

the [[order of a group|order]] is [[countable set|countable]] but [[infinite set|infinite]].

If we identify the [[free group]] on the singleton with the additive group $\mathbb{Z}$ of [[integers]], then the infinite cyclic group is $\mathbb{Z}$ itself, while the finite cyclic group of order $n$ is $\mathbb{Z}/n$, that is $\mathbb{Z}$ modulo (the [[normal subgroup]] generated by) the integer $n$.  Of course, $\mathbb{Z}$ itself is also $\mathbb{Z}/0$.  One could also consider $\mathbb{Z}/n$ for negative $n$, but this is the same as $\mathbb{Z}/{|n|}$.

The cyclic group of order $n$ may also be identified with a [[subgroup]] of the multiplicative group of [[complex numbers]] (or [[algebraic numbers]]): the group of $n$th roots of $1$.  For $n = 0$, we may pick any non-zero complex number (or even something else) that is *not* a root of $1$ (but there is no standard choice) and take the subgroup generated by it.


## Notation

Besides '$\mathbb{Z}/n$', the cyclic group of order $n$ may also be denoted in other ways: some more complicated variation of '$\mathbb{Z}/n$' (to put 'the \[normal\] subgroup generated by' explicitly in the notation), or else the simplified form '$\mathbb{Z}_n$' (which however conflicts with notation for the $n$-[[adic integers]]).  When written multiplicatively, it may be denoted '$Z_n$' (note the font change) or '$C_n$'; either letter here stands for 'cyclic' in one language or another.  (It is a coincidence that the German words 'Zahl', which gives us '$\mathbb{Z}$', and 'zyklisch', which gives us '$Z$', begin with the same letter.)

Besides '$\mathbb{Z}$', the infinite cyclic group may also be denoted in other ways: some variation of '$(\mathbb{Z},+)$' to indicate that we are using *addition* of integers, or any of the above notations with either '$0$' or '$\infty$' in place of '$n$' (depending on whether we think of it as $\mathbb{Z}$ modulo $0$ or the cyclic group with order $\infty$).

When written additively, the notation for the elements of a cyclic group are usually just the notation for integers; for the finite cyclic group of order $n$, we use the natural number less than $n$.  In the finite case, we may also use brackets or some other notation to indicate [[equivalence classes]].  When written multiplicatively, any letter ('$e$', '$x$', '$a$', '$\xi$', etc) may be taken to stand for the generating element; then any other element is a power of this generator.  When thought of as a multiplicative group of complex numbers, one generator is $\mathrm{e}^{2\mathrm{i}\pi/n}$, and the notation may reflect that.

## Properties

### Ring structure
   {#Ring}

Let $A$ be a cyclic group, and let $x$ be a generator of $A$.  Then there is a unique [[ring]] structure on $A$ (making the original group the additive group of the ring) such that $x$ is the multiplicative identity $1$.

If we identify $A$ with the additive group $\mathbb{Z}/n$ and pick (the equivalence class of) the integer $1$ for $x$, then the resulting ring is precisely the [[quotient ring]] $\mathbb{Z}/n$.

In this way, a cyclic group equipped with the [[extra structure]] of a generator is the same thing (in the sense that their [[groupoids]] are [[equivalence of categories|equivalent]]) as a ring with the [[extra property]] that the underlying additive group is cyclic.

For $n \gt 0$, the number of ring structures on the cyclic group $\mathbb{Z}/n$, which is the same as the number of generators, is $\phi(n)$, the [[totient function|Euler totient]] of $n$; the generators are those $i$ that are [[relatively prime numbers|relatively prime]] to $n$.  While $\phi(1) = 1$, otherwise $\phi(n) \gt 1$ (another way to see that we have a structure and not just a property).  For $\mathbb{Z}$ itself, there are two ring structures, since $1$ and $-1$ are the generators (and these are relatively prime to $0$).

### Fundamental theorem of cyclic groups
  {#FundamentalTheoremOfCyclicGroups}

For $n \in \mathbb{N}$, there is precisely one [[subgroup]] of the cyclic group $\mathbb{Z}/n\mathbb{N}$ of [[order of a group|order]] $d \in \mathbb{N}$ for each factor of $d$ in $n$, and this is the subgroup generated by $n/d \in \mathbb{Z} \to \mathbb{Z}/n\mathbb{Z}$.

Moreover, the [[lattice of subgroups]] of $\mathbb{Z}/n\mathbb{Z}$ is equivalently the dual of the lattice of natural numbers $\leq n$ ordered by divisibility.

(e.g [Aluffi 09, pages 83-84](#Aluffi09))

This is a special case of the _[[fundamental theorem of finitely generated abelian groups]]_. See there for more.

### Group cohomology

For a discussion of the [[group cohomology]] of cyclic groups see at _[[projective resolution]]_ in the section _[Cohomology of cyclic groups](http://ncatlab.org/nlab/show/projective+resolution#CohomologyOfCyclicGroups)_.

Relevant for [[Dijkgraaf-Witten theory]] is the fact

$$
  H^3_{grp}(\mathbb{Z}/n\mathbb{Z}, U(1)) \simeq \mathbb{Z}/n\mathbb{Z}
  \,.
$$

### Relation to finite abelian groups

+-- {: .num_prop}
###### Proposition

Every [[finite abelian group]] is a [[direct sum of abelian groups]] over cyclic groups.

=--

See at _[[finite abelian group]]_ for details.

## Related concepts

* [[group of order 2]]

* [[binary cyclic group]]

* [[cyclic ring]]

* [[p-localization]]

* [[profinite completion of the integers]]

* [[cyclotomic field]]

* [[cyclotomic spectrum]]

## References

* {#Aluffi09} Paolo Aluffi, _Algebra: Chapter 0, Part 0_, 2009

*  _Cyclic groups_ [pdf](http://math.kennesaw.edu/~plaval/math4361/groups_cyclic.pdf)

*  {#Gallian10} Joseph A. Gallian, _Fundamental Theorem of Cyclic Groups_, Contemporary Abstract Algebra, p. 77, (2010)

Discussion of the cyclic group in the context of the [[classification of finite rotation groups]]:

* {#Klein1884} [[Felix Klein]], chapter I.3 of _Vorlesungen über das Ikosaeder und die Auflösung der Gleichungen vom fünften Grade_, 1884, translated as _Lectures on the Icosahedron and the Resolution of Equations of Degree Five_ by George Morrice 1888, [online version](https://archive.org/details/cu31924059413439)


[[!redirects cyclic group]]
[[!redirects cyclic groups]]

[[!redirects cyclic group of order 2]]
