
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Deduction and Induction
+-- {: .hide}
[[!include deduction and induction - contents]]
=--
#### Type theory
+-- {: .hide}
[[!include type theory - contents]]
=--
#### Foundations
+-- {: .hide}
[[!include foundations - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Idea
Formalization of mathematical reasoning can be presented in different forms. The framework of **natural deduction** describes a particular class of [[deductive systems]] which is supposed to be close to "natural" _[[deductive reasoning]]_ insofar it is based on the idea of _reasoning from assumptions_ in contrast to proof systems that reason from 'truths' in the tradition of Hilbertian axiomatics.  It is used particularly to present the [[syntax]] of formal [[logic]] and [[type theory]].

+-- {: .un_remark}
###### Remark
The phrase "natural deduction" is not always used to mean the same thing.  Some people use it semi-informally to refer to a "sort of reasoning" that involves making assumptions, perhaps formalized using hypothetical [[judgments]].  Other people take it to refer specifically to deductive systems which are presented using *introduction* and *elimination* rules, which is the meaning we adopt on this page.  There is significant overlap between the two meanings, but they are not identical.
=--


## Summary

### Introduction and elimination
 {#IntroductionAndElimination}

A system of *natural deduction* is a [[deductive system]] containing a class of [[judgments]] generated by some "constructor" operations, and for which each constructor comes with two relevant classes of rules:

* **Introduction rules**, which allow us to conclude a judgment built using the constructor from simpler judgments; and

* **Elimination rules**, which allow us to conclude some other judgment by using a judgment involving the constructor.

For instance, in a system of [[propositional logic]] whose judgments are the truth of [[propositions]], one such constructor might be the "conjunction" connective $\wedge$.  The introduction rule for $\wedge$ would be
$$ \frac{A \; true \qquad B\;true}{A\wedge B\; true}$$
while its elimination rules might be
$$ \frac{A\wedge B\; true}{A\;true} \qquad \frac{A\wedge B\;true}{B\;true}.$$
The introduction and elimination rules must fit together in an appropriate way, sometimes referred to as "harmony".

Similarly, in a system of [[type theory]], the relevant judgments are typing judgments of the form $a:A$, meaning that the [[term]] $a$ belongs to the [[type]] $A$.  In this case, an analogous constructor might be the cartesian [[product type]], whose rules are analogous, but keeping track of the specific terms involved (see [[propositions as types]]):
$$ \frac{a:A \qquad b:B}{(a,b):A\times B}$$
and
$$ \frac{p:A\times B}{\pi_1(p):A} \qquad \frac{p:A\times B}{\pi_2(p):B}.$$

### Formation and computation

In natural deduction systems for type theory, there are usually two other classes of rules:

* **[[type formation|Formation rules]]**, which declare on which basis a new [[type]] can be introduced; and

* **[[computation rule|Computation rules]]** or **conversion rules**, which constrain the result of combining term introduction with term elimination.

These two rules refer to different classes of judgments than the introduction and elimination rules: judgments that a certain thing is a type for the formation rules, and judgments that one term reduces to, or converts with, another, for the computation rules.

For instance, the cartesian product type would come with a formation rule
$$ \frac{A\;type \qquad B\;type}{A\times B\;type}$$
and computation rules such as [[beta-reduction]]
$$ \frac{a:A \qquad b:B}{\pi_1(a,b) \to_\beta a} \qquad \frac{a:A \qquad b:B}{\pi_2(a,b) \to_\beta b}$$
(and possibly [[eta-conversion]]).

Technically, the propositional logic system could also come with a formation rule involving a judgment "is a proposition":
$$ \frac{A\;prop \qquad B\;prop}{A\wedge B\;prop}$$
But it would not have a computation rule, as there are no terms inhabiting its propositions.  (It could, however, be embedded into a type theory via [[propositions as types]], where there would be terms inhabiting its propositions regarded as types).

More generally, natural deduction with computation rules gives a formulation of [[computation]].  See _[[computational trinitarianism]]_ for discussion of this unification of concepts.

On the other hand, in type theories that have a [[type of types]], there may be no need for a separate judgment "$A\;type$", as it can be replaced by a typing judgment "$A:Type$" that $A$ belongs to a type of types.

### Hypothetical reasoning

Natural deduction also generally involves *hypothetical judgments* or *[[deductive reasoning|reasoning]] from [[assumptions]]*.  For instance, the introduction rule for [[implication]] in a system of [[propositional logic]] says that if, *assuming* "$A$", we can derive "$B$", then we can derive "$A\Rightarrow B$".  This is sometimes written as
\[ \frac{\array{[A]\\ \vdots \\ B}}{A\Rightarrow B} \label{impintro} \]
(We now follow the common practice of writing the judgment "$A\;true$" as simply "$A$".)
Here the $\vdots$ indicate an arbitrary [[derivation]] tree, while the brackets around $A$ indicate that this assumption has been "discharged" and is no longer an assumption in the conclusion $A\Rightarrow B$.  To be precise, we should annotate each bracket somehow to indicate which rule discharged that assumption.

Another way to indicate hypothetical reasoning (which also allows it to fit once again within the general notion of [[deductive system]]) is to indicate in each judgment the hypotheses on which it depends.  Thus, we might write "$A\vdash B$" to mean a hypothetical judgment of $B$ assuming $A$.  With this notation, the introduction rule for $\Rightarrow$ can be written as:
$$\frac{A\vdash B}{\vdash A\Rightarrow B}.$$
The rule \eqref{impintro}, where $\vdots$ indicates an arbitrary [[derivation]], can then be written as
$$ \frac{\array{\frac{}{A\vdash A} \\ \vdots \\ A\vdash B}}{\vdash A\Rightarrow B}. $$
Here we have prefixed the entire derivation $\vdots$ in \eqref{impintro} by "$A\vdash$" to indicate that it is all performed with $A$ as an assumption, and the discharge of that assumption is indicated by removing this prefix from the final conclusion.  We also begin the deduction with the *axiom* $A\vdash A$ (the [[identity rule]]).

To be fully precise, we should now allow all rules to take place under arbitrary additional hypotheses; thus the introduction rule of $\Rightarrow$ should really be
$$\frac{\Gamma, A\vdash B}{\Gamma\vdash A\Rightarrow B}.$$
where $\Gamma$ denotes an arbitrary list of hypothesis truth judgments.
However, often this unchanged ambient context is unstated, but implicitly assumed to be present.

+-- {: .un_remark}
###### Remark
Hypothetical judgments of this sort are very similar to the [[sequents]] which appear in [[sequent calculus]], and are (as is evident) written with very similar notation.  However, the rules of natural deduction are different from the rules of sequent calculus, as are its formal properties.
=--

This treatment of hypothetical judgments applies also to type theories, where the individual judgments are typing judgments.  In this case, the assumed judgments on the left of the $\vdash$ are generally restricted to be of the form $x:A$ with $x$ a [[variable]] (rather than an arbitrary [[term]]), and these assumed judgments are referred to as the [[context]].  When the judgment on the right of the $\vdash$ may involve variables that occur to its left, one speaks of *generic judgments* rather than "hypothetical" ones.  Thus, a generic judgment is of the form
$$ (x : A) \;\vdash\; (b(x) : B) $$
to be read as 

&gt; In a context where we have a term $x$ of a type $A$, there is a term $b(x)$ of [[types in context|type]] $B$.

Thus, for instance, the introduction rule for the [[function type]] is
$$ \frac{(x:A) \;\vdash\; (b:B)}{\vdash (\lambda x.b:A\to B)}. $$

In natural deduction for [[dependent type theory]], we can also have type judgments with hypotheses, such as
$$ (x : A) \;\vdash\; B(x) \; type $$
to be read as

&gt; For each $x$ in $A$ there is a type $B(x)$.  Or: $B$ is a _[[type in context]]_ $A$, a _[[dependent type|type dependent]]_ on $A$.

In a type theory with a [[type of types]], this judgment could be written as $(x:A)\;\vdash\;(B(x):Type)$.

+-- {: .un_remark}
###### Remark
So far, we have been considering hypothetical judgments such as $A\vdash B$ and generic judgments such as $(x:A)\vdash (b(x):B)$ to be "atomic" judgments in a particular [[deductive system]].  In particular, the turnstile symbol $\vdash$ has been simply another symbol that we use to build judgments according to a particular syntax, analogous to the colon $:$.  As remarked at [[deductive system]], this usage of $\vdash$ is *a priori* completely unrelated to its use to indicate provability of theorems in a particular deductive system (such as a system of natural deduction), and therefore perhaps ought to be denoted by a different symbol.

However, it is also possible to incorporate some "knowledge" about the meaning of hypothetical and generic judgments into the deductive system, and thereby bring the two meanings of $\vdash$ back into alignment.  See [[logical framework]] for a development of this idea.
=--



## Properties

### Relation to category theory

The four classes of rules of natural deduction combined give alternative specifications of [[universal constructions]] in [[category theory]]. In [[categorical semantics]] one considers categories which are such that their [[objects]] are regarded as [[types]] and their [[generalized elements]] as [[terms]], then the rules of natural deductions describe the possible construction of [[morphisms]] in that category.

For instance, the connectives of type theory are presentations of [[functors]], but their action on morphisms is not explicitly defined, because [[representability determines functoriality| the action is definable from the introduction and elimination rules]].

(...)


### Decidability

(...)

## Related concepts

* [[logical framework]], [[metalanguage]]

* [[deduction calculus]]

* [[type theory]], [[meaning explanation]]

* [[sequent calculus]]

* [[calculus of constructions]]

## References

In a broad sense, the idea of natural deduction can be traced back to [[Aristotle]]'s **Prior Analytics** as classical work by J. Bacon, J. Corcoran and T. Smiley around 1970 has argued that his theory of [[syllogism]] can be viewed as a [[fragment]] of natural deduction. For more on this see e.g.

* J. Bacon, _Natural-deduction rules for syllogistic_ , JSL **31** (1966) pp.686-7.

* J. Corcoran, _Completeness of an ancient logic_ , JSL **37** (1972) pp.696-702.

* T. Smiley, _What is a syllogism_ , JPL **2** (1973) pp.136-154.

The next step to the modern conception was an observation by the Polish logician (and Aristotle scholar) J. Lukasiewicz in 1926 that the formalization of mathematical reasoning proposed by [[David Hilbert|D. Hilbert]] or *Principia Mathematica* fails to comply with the actual reasoning style of mathematicians. This was taken up by S. Jaskowski  who published a system of natural deduction in 1934:

* S. Jaskowski, _On the rules of suppositions in formal logic_ , Studia Logica **1** Warsaw 1934. ([pdf](http://www.logik.ch/daten/jaskowski.pdf))

At about the same time [[Gerhard Gentzen|G. Gentzen]] developed a system of natural deduction in his thesis[^Dummett] - a landmark of 20th century [[mathematical logic]] introducing proof systems for [[predicate logic]] (in both [[classical logic|classical]] and [[intuitionistic logic|intuitionistic]] versions) and the concept of [[cut-elimination]] - that was published as

* {#Gentzen} [[Gerhard Gentzen]], _Untersuchungen &#252;ber das logische Schlie&#223;en_, _Mathematische Zeitschrift_ **39**(1), Springer-Verlag 1934-35. &lt;http://dx.doi.org/10.1007/BF01201353&gt; (English translation _Investigations into Logical Deduction_ in Szabo)  

[^Dummett]: *It can be said of Gentzen that it was he who first showed how proof theory should be done*. (M. Dummett, _Frege- Philosophy of Language_ , Harvard UP 1981$^2$. p.434)
 
In order to prove the famous *[[Gentzen's Hauptsatz|Hauptsatz]]* for proof normalization Gentzen invented the [[sequent calculus]] though he sketched a similar result for natural deduction in his later work on the [[consistency]] of [[arithmetics]]. Normalization for systems of natural deduction was established by D. Prawitz in his thesis in 1965:

* D. Prawitz, _Natural Deduction - A Proof-theoretical Study_ , Dover reprint New York 2006[1965].

A standard textbook that describes proof systems in natural deduction format, sequent calculi or Hilbert-style systems is

* A. S. Troelstra, H. Schwichtenberg, _Basic Proof Theory_ , CUP 2000$^2$.

An introductory lecture using [[dependent type theory]] in [[intuitionistic logic]] is

* [[Per Martin-Löf]], _On the meaning of logical constants and the justifications of the logical laws_, leture series in Siena (1983) ([web](http://docenti.lett.unisi.it/files/4/1/1/6/martinlof4.pdf))

A formalization of the general [[logical framework]] of natural deduction is discussed in section 3 of 

* [[Frank Pfenning]], _Logical frameworks -- A brief introduction_ ([pdf](http://www.cs.cmu.edu/~fp/papers/mdorf01.pdf))

A good account is at

* Wikipedia, _[Natural deduction](http://en.wikipedia.org/wiki/Natural_deduction)_

The standard rules for type-formation, term introduction/elimination and computation in [[dependent type theory]] are listed for instance in [part I](http://www.math.unipa.it/~ngambino/Research/Lectures/lecture1.pdf)  of

* [[Nicola Gambino]], _Lectures on dependent type theory_ ([pdf](http://www.cs.le.ac.uk/events/mgs2009/courses/gambino/lecturenotes-gambino.pdf))


[[!redirects natural deduction]]
[[!redirects natural deductions]]


[[!redirects term introduction]]
[[!redirects term introduction rule]]
[[!redirects term introduction rules]]
[[!redirects introduction rule]]
[[!redirects introduction rules]]

[[!redirects term elimination]]
[[!redirects term elimination rule]]
[[!redirects term elimination rules]]
[[!redirects elimination rule]]
[[!redirects elimination rules]]

[[!redirects computation rule]]
[[!redirects computation rules]]
[[!redirects conversion rule]]
[[!redirects conversion rules]]

[[!redirects term constructor]]
[[!redirects term constructors]]


[[!redirects inference rule]]
[[!redirects inference rules]]