
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### $(0,1)$-Category theory
+--{: .hide}
[[!include (0,1)-category theory - contents]]
=--
#### Category theory
+-- {: .hide}
[[!include category theory - contents]]
=--
=--
=--



# Contents
* table of contents
{: toc}

## Idea 

A _partial order_ on a set is a way of ordering its elements to say that some elements precede others, but allowing for the possibility that two elements may be incomparable without being the same.  This is the fundamental notion in [[order theory]].

By regarding the ordering $\leq$ as the existence of a unique [[morphism]], preorders may be regarded as certain [[categories]] (namely, [[thin categories]]).  This category is sometimes called the _order category_ associated to a partial order; see [below](#AsACategoryWithExtraProperties) for details.


## Definitions

### As a set with extra structure

A poset may be understood as a [[set]] with [[extra structure]].

Given a [[set]] $S$, a __partial order__ on $S$ is a (binary) [[relation]] $\leq$ with the following properties:

* [[reflexive relation|reflexivity]]: $x \leq x$ always;

* [[transitive relation|transitivity]]: if $x \leq y \leq z$, then $x \leq z$;

* [[antisymmetric relation|antisymmetry]]: if $x \leq y \leq x$, then $x = y$.

A __poset__ is a set equipped with a partial order.


### As a preorder with antisymmetry

A poset is precisely a [[proset]] satisfying the extra condition that 
$x \leq y \leq x$ implies that $x = y$. 


### As a category with extra properties 
 {#AsACategoryWithExtraProperties}

A poset may be understood as a [[category]] with [[extra property]], sometimes called its _order category_.

A __poset__ is a [[category]] such that:

* for any pair of objects $x, y$, there is at most one morphism from $x$ to $y$

* if there is a morphism from $x$ to $y$ and a morphism from $y$ to $x$ (which by the above implies that $x$ and $y$ are [[isomorphic]]), then $x = y$.

Equivalently, this says that a poset is a [[skeletal category|skeletal]] [[thin category|thin]] category, or equivalently a skeletal [[category enriched]] over the [[cartesian monoidal category]] of [[truth values]] or equivalently a skeletal [[(0,1)-category]].

When we do this, we are soon led to contemplate a slight generalization of partial orders: namely [[preorder|preorders]]. The reason is that the antisymmetry law, saying that $x \le y$ and $y \le x$ imply $x = y$, violates the [[principle of equivalence]] in a certain sense.  (On the other hand, it does not violate it if taken as a *definition* of [[equality]].)


### Monotone functions 

The morphisms of partially ordered sets are [[monotone functions]]; a __monotone function__ $f$ from a poset $S$ to a poset $T$ is a [[function]] from $S$ to $T$ (seen as [[structured sets]]) that preserves $\leq$:
$$ x \leq y \;\Rightarrow\; f(x) \leq f(y) .$$
Equivalently, it is a [[functor]] from $S$ to $T$ (seen as certain categories).

In this way, posets form a [[category]] [[Pos]].


### Intervals 

A (closed bounded) **[[interval]]** in a poset $C$ is a set of the form
$$[x,y] = \{r\in C|x\le r\le y\}.$$

A poset is **[[locally finite poset|locally finite]]** if every closed bounded interval is finite.


### Kinds of posets 

A poset with a [[top element]] and [[bottom element]] is called __bounded__.  (But note that a *[[subset]]* of a poset may be bounded without being a bounded as a poset in its own right.)  More generally, it is __bounded above__ if it is has a top element and __bounded below__ if it has a bottom element.

A poset with all [[meets]] and [[joins]] is called a __[[lattice]]__; if it has only one or the other, it is still a __[[semilattice]]__.

A poset in which every finite set has an upper bound (but perhaps not a *least* upper bound, that is a join) is a __[[directed set]]__.

As remarked above, a poset in which each interval $[x,y]$ is a [[finite set]] is called __locally finite__ or a __[[causet]]__.

A poset with a bounding [[countable set|countable subset]] is called __$\sigma$-bounded__.  That is, the poset is $\sigma$-bounded above if there exists a sequence $(x_n)_{n=1}^{N}$ (where $N$ is a natural number or infinity) such that for every $y$ in the poset there is an $x_m$ with $y \leq x_m$.  (The poset is $\sigma$-bounded below if we have $x_m \leq y$ instead.)  Note that every bounded poset is $\sigma$-bounded, but not conversely.  Note that some authorities require $N = \infty$; this makes a difference only for the empty poset (we say it is $\sigma$-bounded, they say it is not).


### In higher category theory 

A poset can be understood as a [[(0,1)-category]]. This suggests an obvious [[vertical categorification]] of the notion of poset to that of [[n-poset]].


## Properties

### Locales from posets -- Alexandroff topology
{#LocalesFromPosets}

+-- {: .num_defn }
###### Definition

For $P$ a poset, write $Up(P)$ for the [[topological space]] whose underlying [[set]] is the underlying set of $P$ and whose [[open subset]]s are the _upward closed subsets_ of $P$: those subsets $U \subset P$ with the property that 

$$
  ((x \in U) and (x \leq y)) \Rightarrow (y \in U)
  \,.
$$ 

This is called the **[[Alexandroff topology]]** on $P$.

=--

+-- {: .num_prop #UpIfFFAndPreservesLimits}
###### Proposition

This construction naturally extends to a 
[[full and faithful functor]].

$Up : $ [[Poset]] $\to$ [[Top]] $\to$ [[Locale]].


=--

+-- {: .num_prop }
###### Proposition

For $P$ a poset, there is a [[natural equivalence]]

$$
  Sh(Up(P)) \simeq [P,Set]
$$

between the [[category of sheaves]] on the [[locale]] $Up(P)$ and the 
category of [[copresheaves]] on $P$.

=--

For more see [[Alexandroff topology]].


### Cauchy completion

Every poset is a [[Cauchy complete category]]. Posets are the Cauchy completions of [[prosets]]. ([Rosolini](#Rosolini))


## Related concepts

* [[preorder]]

* [[continuous poset]]

* [[Noetherian poset]]

* [[specialization topology]]

## References

* Richard P. Stanley, Enumerative [[combinatorics]], vol I [pdf](http://www-math.mit.edu/~rstan/ec/ec1.pdf)

[[Cauchy completion]] of prosets and posets is discussed in 

* G. Rosolini, _A note on Cauchy completeness for preorders_ ([pdf](http://www.disi.unige.it/person/RosoliniG/notccp.pdf))
 {#Rosolini}

Here are some references on [[directed homotopy theory]]:

* [[Marco Grandis]], _Directed homotopy theory, I. The fundamental category_ ([arXiv](http://arxiv.org/abs/math.AT/0111048))

* [[Tim Porter]], _Enriched categories and models for spaces of evolving states_, Theoretical Computer Science, 405, (2008), pp. 88--100.

* [[Tim Porter]], _Enriched categories and models for spaces of
dipaths. A discussion document and overview of some techniques_ ([pdf](http://drops.dagstuhl.de/opus/volltexte/2007/898/pdf/06341.PorterTimothy.Paper.898.pdf))


[[!redirects poset]]
[[!redirects posets]]
[[!redirects partial order]]
[[!redirects partial orders]]
[[!redirects partial ordering]]
[[!redirects partial orderings]]
[[!redirects partially ordered]]
[[!redirects partially ordered set]]
[[!redirects partially ordered sets]]
[[!redirects partially-ordered]]
[[!redirects partially-ordered set]]
[[!redirects partially-ordered sets]]

[[!redirects bounded poset]]
[[!redirects bounded posets]]

[[!redirects order category]]
[[!redirects order categories]]
