
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Gravity
+--{: .hide}
[[!include gravity contents]]
=--
#### String theory
+-- {: .hide}
[[!include string theory - contents]]
=--
=--
=--



#Contents#
* table of contents
{:toc}

## Black hole entropy

In ([[perturbative string theory|perturbative]]) [[string theory]] the [[Bekenstein-Hawking entropy]] associated to a macroscopic [[black hole]]  finds an explanation as follows:

The [[black hole]] [[spacetime]] is regarded as a [[non-perturbative QFT|strongly coupled]] [[condensate]] of string states ([[closed strings]], carrying [[gravity]]). One looks for a corresponding weakly-coupled background for closed strings in flat [[Minkowski space]] that is known to turn into the black hole spacetime as the string coupling is turned on. Such turn out to be certain [[D-brane]] configurations in Minkowski space: at weak coupling the D-brane does not back-react on the spacetime (since that back-reaction is mediated by closed string quanta) and so it just sits there, whereas at strong coupling it curves spacetime and may collapse to a configuration that looks like the prescribed black hole spacetime.

<img src="https://ncatlab.org/nlab/files/BlackBrane.png" />

> graphics grabbed from [Ibanez-Uranga 12](#IbanezUranga12)

Now, if the configuration has a sufficient amount of [[supersymmetry]] preserved ([[BPS state]]), then one argues ([Witten 95, section 2.3](#Witten95)) that certain observables are actually independent of the coupling constant ("[[protection from quantum corrections]]"), and accordingly these observables are the same for black holes as for the corresponding D-brane configurations in flat space, where they may be computed in string perturbation theory.

The best studied such configuration is that of [[D1-D5 brane bound states]]. For these configurations one may compute the number of [[BPS states]] (which are "protected"), hence the  [[entropy]], via the [[Witten genus]] ([Strominger-Vafa 96](#StromingerVafa96)), see at _[Witten genus -- Relation to BPS state counting](Witten+genus#RelationToBPSStateCounting)_. By the above reasoning this may then be compared to the [[Bekenstein-Hawking entropy]] of the corresponding (supersymmetric) black hole. And indeed the results match the semiclassical BH-entropy to leading order and in addition provide their higher order quantum corrections. See the _[References](#References)_ below.

The [[T-duality|T-dual]] version of the D1/D5-bound states are D0/D6-bound states, coming from the [[Kaluza-Klein monopole]] in [[11-dimensional supergravity]] (e.g. [Nelson 93](#Nelson93)).

## Related concepts

* [[black ring]]

* [[black brane]]

  * [[black hole]]

  * [[black string]]

  * [[black membrane]]

  * [[black fivebrane]]

* [[AdS/CFT correspondence]]

* gravitational entropy

  * [[Bekenstein-Hawking entropy]]

  * [[generalized second law of thermodynamics]]

  * [[black holes in string theory]]

  * [[holographic entanglement entropy]]

[[!include table of branes]]

## Related concepts

* [[5d supergravity]]

## References
 {#References}

### Introductions and Review

* [[Juan Maldacena]], _Black Holes in String Theory_, PhD thesis 1996 ([arXiv:hep-th/9607235](http://arxiv.org/abs/hep-th/9607235))

* [[Juan Maldacena]], _Black Holes and D-branes_, Nucl.Phys.Proc.Suppl. 61A (1998) 111-123; Nucl.Phys.Proc.Suppl. 62 (1998) 428-442 ([arXiv:hep-th/9705078](http://arxiv.org/abs/hep-th/9705078))



* [[Mike Duff]], chapter 5 of _[[The World in Eleven Dimensions]]: Supgergravity, Supermembranes and M-theory_, IoP 1999 ([publisher](https://www.crcpress.com/The-World-in-Eleven-Dimensions-Supergravity-supermembranes-and-M-theory/Duff/9780750306720))

* [[Kostas Skenderis]], _Black holes and branes in string theory_,  	Lect.Notes Phys. 541 (2000) 325-364 ([arXiv:hep-th/9901050](https://arxiv.org/abs/hep-th/9901050))


* [[Thomas Mohaupt]], _Black Hole Entropy, Special Geometry and Strings_, Fortsch.Phys. 49 (2001) 3-161 ([arXiv:hep-th/0007195](http://arxiv.org/abs/hep-th/0007195))

* Sumit R. Das, [[Samir Mathur]], _The Quantum Physics of Black Holes: Results from String Theory_ ([arXiv:gr-qc/0105063](http://arxiv.org/abs/gr-qc/0105063))

* Justin R. David, Gautam Mandal, Spenta R. Wadia, _Microscopic Formulation of Black Holes in String Theory_ ([arXiv:hep-th/0203048](http://arxiv.org/abs/hep-th/0203048))

* [[Thibault Damour]], _The entropy of black holes: a primer_ ([arXiv:hep-th/0401160](http://arxiv.org/abs/hep-th/0401160))

* [[Barton Zwiebach]], chapter 22 of _A first course in string theory_

* [[Per Kraus]], _Lectures on black holes and the AdS_3 / CFT_2 correspondence_ ([arXiv:hep-th/0609074](http://arxiv.org/abs/hep-th/0609074))

  _Stringy black holes in five dimensions_, 2007 ([pdf slides](http://hep.ps.uci.edu/~arajaram/Irvine.07.pdf))

* [[Xi Yin]], _Black Holes, Anti de Sitter space, and Topological
Strings_, 2006 ([pdf](http://www.people.fas.harvard.edu/~xiyin/Site/Research_files/allthesis.pdf))

* {#Sen07} [[Ashoke Sen]], _Black Hole Entropy Function, Attractors and Precision Counting of Microstates_, extensive lecture notes ([arXiv:0708.1270](http://arxiv.org/abs/0708.1270))

* Joao Gomes, _Quantum entropy of supersymmetric black holes_ ([arXiv:1111.2025](http://arxiv.org/abs/1111.2025))

* {#IbanezUranga12} [[Luis Ibáñez]], [[Angel Uranga]], section 6.2 of _[[String Theory and Particle Physics -- An Introduction to String Phenomenology]]_, Cambridge University Press 2012


See also 

* [String Theory Wiki](http://www.stringwiki.org), _[Black hole entropy](http://www.stringwiki.org/w/index.php?title=Black_Hole_Entropy)_



### Original articles

The argument that properties of [[BPS states]] are preserved as the coupling increases beyond [[perturbation theory]] and are not destroyed by [[non-perturbative effects]] originates in 

* {#Witten95} [[Edward Witten]], section 2.3 of _String Theory Dynamics In Various Dimensions_, Nucl.Phys.B443:85-126,1995 ([arXiv:hep-th/9503124](http://arxiv.org/abs/hep-th/9503124))


The original computations of stringy black hole entropy using this argument are due to

* [[Ashoke Sen]], _Extremal black holes and elementary string states_ ([arXiv:hep-th/9504147](http://arxiv.org/abs/hep-th/9504147))

* {#StromingerVafa96} [[Andrew Strominger]], [[Cumrun Vafa]], _Microscopic Origin of the Bekenstein-Hawking Entropy_ ([arXiv:hep-th/9601029](http://arxiv.org/abs/hep-th/9601029))

* Curtis Callan, [[Juan Maldacena]], _D-brane Approach to Black Hole Quantum Mechanics_ ([arXiv:hep-th/9602043](http://arxiv.org/abs/hep-th/9602043))

* [[Juan Maldacena]], [[Gregory Moore]], [[Andrew Strominger]], _Counting BPS Blackholes in Toroidal Type II String Theory_ ([arXiv:hep-th/9903163](http://arxiv.org/abs/hep-th/9903163))

* [[Davide Gaiotto]], [[Andrew Strominger]], X. Yin, _New Connections Between 4D and 5D Black Holes_, JHEP 0602:024,2006 ([arXiv:hep-th/0503217](http://arxiv.org/abs/hep-th/0503217))

See also

* [[Emil Martinec]], V. Sahakian, _Black Holes and Five-brane Thermodynamics_, Phys.Rev. D60 (1999) 064002 ([arXiv:hep-th/9901135](http://arxiv.org/abs/hep-th/9901135))

Discussion for [[M-theory]]/[[11-dimensional supergravity]] includes

* [[Juan Maldacena]], [[Andrew Strominger]], [[Edward Witten]], _Black Hole Entropy in M-Theory_, JHEP 9712:002,1997 ([arXiv:hep-th/9711053](http://arxiv.org/abs/hep-th/9711053))

* [[Gary Horowitz]] , M. Roberts, _Counting the microstates of a Kerr black hole in M theory_, Phys Rev Lett. 2007 Nov 30;99(22):221601. Epub 2007 Nov 30. ([web](https://www.ncbi.nlm.nih.gov/pubmed/18233277)), ([arXiv:0708.1346](https://arxiv.org/abs/0708.1346))

* [[Davide Gaiotto]], [[Andrew Strominger]], Xi Yin, _The M5-Brane Elliptic Genus: Modularity and BPS States_, JHEP 0708:070,2007 ([arXiv:hep-th/0607010](http://arxiv.org/abs/hep-th/0607010))

Discussion relating to the [[Kaluza-Klein monopole]] includes

* {#Nelson93} William Nelson, _Kaluza-Klein Black Holes in String Theory_, Phys.Rev.D49:5302-5306,1994 ([arXiv:hep-th/9312058](http://arxiv.org/abs/hep-th/9312058))

More recent developments include

* Alejandra Castro, Joshua L. Davis, [[Per Kraus]], Finn Larsen, _String Theory Effects on Five-Dimensional Black Hole Physics_ ([arXiv:0801.1863](http://arxiv.org/abs/0801.1863))


* Oleg Lunin, [[Samir Mathur]], _A toy black hole S-matrix in the D1-D5 CFT_ ([arXiv:1211.5830](http://arxiv.org/abs/1211.5830))



* Alejandra Castro, Joshua M. Lapan, Alexander Maloney, Maria J. Rodriguez, _Black Hole Monodromy and Conformal Field Theory_ ([arXiv:1303.0759](http://arxiv.org/abs/1303.0759))

### Relation to topological string amplitudes

Discussion of black hole microstates via the [[topological string]]'s [[Gopakumar-Vafa invariants]]:

* [[Rajesh Gopakumar]], [[Cumrun Vafa]], _M-Theory and Topological Strings--I_ ([arXiv:hep-th/9809187](https://arxiv.org/abs/hep-th/9809187))

* [[Rajesh Gopakumar]], [[Cumrun Vafa]], _M-Theory and Topological Strings--II_ ([arXiv:hep-th/9812127](https://arxiv.org/abs/hep-th/9812127))

 

[[!redirects black hole in string theory]]