
# Sequences
* table of contents
{: toc}

## Definitions

A __sequence__ is a [[function]] whose [[source|domain]] is a [[subset]] of the set $\mathbb{N}$ of [[natural numbers]] (or more generally a subset of the set $\mathbb{Z}$ of [[integers]]; cf. subsequences introduced below).  Often one means an __infinite sequence__, which is a sequence whose domain is infinite.  Sequences (especially finite ones) are often called __[[lists]]__ in computer science.  (In [[constructive mathematics]], the domain of a sequence must be a [[decidable subset]] of $\mathbb{Z}$.) 

Sequences may also be indicated by functions $\omega \to X$ where $\omega$ is the first countably infinite [[ordinal]]: the key piece of structure on $\mathbb{N}$ relevant for the study of sequences, particularly in analysis, is the order structure. 

Up to [[bijection]], the only possible sources are those of the form
$$ \{i\colon \mathbb{Z} \;|\; 0 \leq i \lt n\} $$
for $n = 0, 1, 2, \ldots, \infty$; other domains are used for notational convenience.

An alternative generalisation takes the domain to be a set of [[ordinal numbers]], without loss of generality the set
$$ \{i\colon \Ord \;|\; i \lt \alpha\} $$
for $\alpha$ some specific ordinal number (or the [[proper class]] $\Ord$ of all ordinal numbers, if one wishes to allow for a proper class). 

A _subsequence_ of a sequence $a = a_n: \mathbb{N} \to X$ is a composition 

$$\mathbb{N} \stackrel{i}{\to} \mathbb{N} \stackrel{a}{\to} X$$ 

where $i$ is an order-preserving monomorphism. The salient point is that $i$ be [[cofinal diagram|cofinal]] as an embedding. 


## Notation

One normally writes the value of the sequence $a$ at the argument $i$ as $a_i$ rather than $a(i)$.  Similarly, given a term $a[i]$ with the free variable $i$, one often defines a sequence whose values equal those terms as $(a[i])_{i \lt n}$, $\{a[i]\}_i$, or the like.  In fact, one even often says literally 'Let $(a_i)$ be a sequence.' even though 'Let $a$ be a sequence.' would be less of an abuse of notation.  This is all because notation for sequences arose before [[functions]] were considered in their full generality, and one distinguished a 'sequence' (whose domain was a set of integers) from a 'function' (whose domain was an interval in the real line or a region in the complex plane).  Early mathematicians also often conflated the sequence (the function itself) with its range (a subset of the function\'s [[target]]); hence the use of curly braces.  All of this applies in greater generality to [[families]] with index sets other than $\mathbb{N}$.


## Generalisations

### Nets

Infinite sequences are often used in topology, but for topology in general, one needs to generalise to [[nets]], also called _Moore--Smith sequences_.  Here one replaces the domain $\mathbb{N}$ by any arbitrary [[direction|directed set]].


### Sequential nets

Recall that [[weak countable choice]] is a rather weak version of the [[axiom of choice]] that is accepted even in most schools of [[constructive mathematics]]; it follows separately from both [[excluded middle]] and [[countable choice]].  However, when it fails (as it does in the [[internal language]] of some widely studied [[toposes]], such as the [[topos of sheaves]] over the [[real line]]), then some important results about sequences fail, including many standard results in [[topology]].  In this case, we may want a slight generalisation that we call _sequential nets_.

A __sequential net__ is a [[multi-valued function]] from $\mathbb{N}$ (or a [[decidable set|decidable]] [[subset]] thereof) to $X$, that is a [[span]] $\mathbb{N} \leftarrow A \rightarrow X$ where the map $A \to \mathbb{N}$ is a [[surjection]] (or has a decidable range).  Note that $A$ inherits the structure of a directed set via $A \to \mathbb{N}$, so that $A \to X$ is a net.  As a net, every sequential net is equivalent (in the sense of corresponding to the same [[filter]]) to some sequence, if you assume WCC.  Without WCC, however, this equivalence fails.

(Using a multi-valued function here is a special case of an alternative definition of [[net]] that uses only [[partially ordered]] directed sets; see [[net]].  In some [[foundations of mathematics]], we can get the same result by defining a sequential net to be a __presequence__: a [[prefunction]], which is like a function but need not preserve [[equality]], from a decidable subset of $\mathbb{N}$.)

Without WCC, many of the usual properties of [[metric spaces]] and other [[sequential spaces]] fail, but they continue to hold using sequential nets in the place of sequences.  For example, every (located Dedekind) [[real number]] may be represented as a sequential Cauchy net, even when they might not all be represented as Cauchy sequences; see [[Cauchy real number]].


## Sequence spaces

In [[functional analysis]], one considers [[topological vector spaces]] of infinite sequences; these are the [[sequence spaces]].  (Actually, these generalise quite nicely to [[net]] spaces.)

## Related concepts

* [[limit of a sequence]]

* [[sequentially compact space]]

Not all that related, but similar sounding:

* [[sequential limit]]

[[!redirects sequence]]
[[!redirects sequences]]
[[!redirects infinite sequence]]
[[!redirects infinite sequences]]

[[!redirects sequential net]]
[[!redirects sequential nets]]

[[!redirects presequence]]
[[!redirects presequences]]

[[!redirects pre-sequence]]
[[!redirects pre-sequences]]


[[!redirects subsequence]]
[[!redirects subsequences]]

[[!redirects sub-sequence]]
[[!redirects sub-sequences]]
