
# Uniform convergence spaces
* table of contents
{: toc}

## Idea

Uniform convergence spaces are simultaneously a generalisation of [[uniform spaces]] and a specialisation with [[extra structure]] of [[convergence spaces]].  That is, we have [[functors]]
$$ Unif \to Unif Conv \to Conv ,$$
both [[faithful functor|faithful]] and with $Unif \to Unif Conv$ also [[full functor|full]].  (Here we take the [[morphisms]] of $Unif Conv$ and $Unif$ to be the [[uniformly continuous maps]], while $Conv$ must use the [[continuous maps]].)


## Motivation

The [[uniform property|uniform properties]] of a [[metric space]] $X$ are determined entirely by the [[equivalence relation]] between [[infinite sequences]] through which sequences $a$ and $b$ are related iff the distance between them tends to zero:
$$ \lim_{n \to \infty} {\|a_n - b_n\|} = 0 .$$

An analogous holds for a [[uniform space]] $X$ if one generalises from sequences to [[nets]].  However, the relevant equivalence relation is not (directly) between two arbitrary nets but rather between two nets with the same [[directed set]] as [[domain]].  (This is because the limit above refers to a single index $n$; if we changed this to the limit as $m, n \to \infty$ of ${\|a_m - b_n\|}$, then we would get a [[partial equivalence relation]] that applies only to [[Cauchy sequences]], and this would recover only the [[Cauchy structure]] and not the entire [[uniform structure]].)

Rather than speak of two nets with the same domain, let us speak equivalently of a single net in the [[cartesian square]] $X \times X$.  Then for a more manifestly [[size issue|small]] definition, let us speak of a [[filter]] on $X \times X$.  So a uniform convergence structure on a [[set]] $X$ will be a collection of filters on $X \times X$.  We will require this collection to satisfy certain properties; if we imposed enough properties, we could recover a definition of uniform space (or even of [[metrisable]] [[uniform space]]), but some less stringent requirements yield the definition of uniform convergence space below.


## Definitions

Let $X$ be an [[abstract set]], and let $U$ be a collection of [[filters]] on the [[cartesian square]] $X \times X$, called the __asymptotic filters__.  We will consider various properties of such a structure below.

A collection that satisfies all of (1--6) below is a __uniform convergence structure__.  If it satisfies at least (2--6), then it is is a __[[base]]__ for a uniform convergence structure; if it satisfies at least (4--6), then it is a __[[subbase]]__ for a uniform convergence structure.  That said, we could start with a perfectly arbitrary collection and generate a subbase, then a base, then an entire structure.

If we use (6′) instead of (6), then this is a __pointwise uniform convergence structure__.  If we drop (4), then we have a __quasiuniform convergence structure__.  These also can have bases and subbases and be generated from an arbitrary collection of asymptotic filters.

A (pointwise) (quasi)-**uniform convergence space** is a set $X$ equipped with such a structure.

Here are the relevant properties:

1.  _Isotone_:  If $F \subseteq G$ (as filters on $X \times X$) and $F$ is asymptotic, then $G$ is asymptotic.

2.  _Proper_:  There is an asymptotic filter.  If (1) also holds, then we may equivalently say that the [[improper filter]] on $X \times X$ is asymptotic.  This is automatic if (6) holds but is independent of the other conditions; it *almost* follows from (6′), but only if $X$ is [[inhabited set|inhabited]].

3.  _Filtered_:  If $F$ and $G$ are asymptotic filters, then there is an asymptotic filter contained in both $F$ and $G$.  If (1) also holds, then we may equivalently say that the [[intersection]] $F \cap G$ is asymptotic.

4.  _Symmetric_:  If $F$ is an asymptotic filter, then there is an asymptotic filter $G$ with the property that, whenever $R \in G$, its [[inverse relation|inverse]] (as a [[binary relation]] on $X$) $R^{-1}$ belongs to $F$.  If (1) also holds, then we may equivalently say that the filter $\{ R^{-1} \;|\; R \in F \}$ is asymptotic.

5.  _Transitive_:  If $F$ and $G$ are asymptotic filters, then there is an asymptotic filter $H$ with the property that, whenever $R \in H$, there are a [[natural number]] $n$, an $n$-[[tuple]] $(S_1, \ldots, S_n) \in F^n$, and an $n$-tuple $(T_1, \ldots, T_n) \in G^n$ such that $R \supseteq (S_1 \circ T_1) \cap \cdots \cap (S_n \circ T_n)$ (where $\circ$ indicates [[composition]] of [[binary relations]] on $X$).  If (1) also holds, then we may equivalently say that the filter generated by $\{ S \circ T \;|\; S \in F,\; T \in G \}$ is asymptotic.

6.  _Reflexive_:  There is an asymptotic filter $F$ with the property that each $R \in F$ is [[reflexive relation|reflexive]] as a binary relation on $X$.  If (1) also holds, then we may equivalently say that the collection of all reflexive relations (which is a filter) is asymptotic.

Although (6) as given here is in the original definition and is the proper nullary analogue of the binary (5), a weaker version is now more popular:

*  (6′).  _Pointwise reflexive_:  For every point $a$ of $X$, there is an asymptotic filter $F$ with the property that each $R \in F$ satisfies $(a,a) \in R$ (so that $R$ is reflexive at $a$).  If (1) also holds, then we may equivalently say that the collection of all relations reflexive at $a$ (which is a filter, indeed the [[principal ultrafilter]] at $(a,a)$) is asymptotic.

One reason for this is apparently to render the [[category]] of uniform convergence spaces [[cartesian closed category|cartesian closed]].  So presumably there are uniform convergence spaces $X$ and $Y$ satisfying (6) such that the set of [[uniformly continuous maps]] from $X$ to $Y$ can be given only a pointwise uniform convergence structure.

For the purposes of [[constructive mathematics]], we can also consider another condition:

*  (7).  _Comparison_:  If $F$ is an asymptotic filter, then there is an asymptotic filter $G$ with the property that, whenever $R \in G$, there is some $S \in F$ such that $\neg{R} \cup S = X \times X$.  Assuming [[excluded middle]], we may take $G$ to be $F$ itself (and take $S$ to be $R$), rendering this condition trivial in [[classical mathematics]].

A (pointwise) (quasi)-uniform convergence structure/space that satisfies (7) may be called (quasi)-**uniformly regular space|uniformly regular** (although '(quasi)-uniformly [[locally decomposable space|locally decomposable]]' would be more proper, since there is no reason why such a space should be [[regular space|regular]], even in the symmetric case).

It is traditional to consider only _[[proper filter|proper]]_ asymptotic filters (or equivalently to consider only asymptotic [[nets]]), which allows one to leave out (2); but in that case (5) and (6) must be modified to apply only when the generated filters are proper: (5) applies only when each element of $F$ [[intersection|meets]] each element of $G$, and (6), if used, applies only when $X$ is [[inhabited set|inhabited]].  So really, it is simpler to include the improper filter among the asymptotic filters.

The conditions (1,2,3,4,5,6,7) correspond respectively to the conditions (6,4,5,2,3,1,0) at [[uniform space]] (as of 2013-02-22, in case the latter are ever renumbered).  However, (6′) has no direct analogue.


## Terminology warning

Among the terms defined (in boldface) above, I ([[Toby Bartels]]) invented 'asymptotic filter' and those involving 'pointwise' and 'quasi‑', because no appropriate terms appeared in the reference that I used.  Possibly other terms appear in the literature (besides the fact that 'pointwise' may simply be left out).  That said, my use of 'quasi‑' follows [[quasimetric]] and [[quasiuniform space]], so it at least is probably correct.  On the other hand, 'asymptotic' conflicts with the meaning of [[asymptotic function]] in [[complexity theory]] (which is weaker, and in fact says that functions are asymptotic when their [[logarithms]] are asymptotic in our sense), although it matches the meaning of [[asymptote]] in elementary [[analytic geometry]].  Finally, 'pointwise' was 'weak' in earlier versions of this page, until I changed it to have a more transparent meaning and avoid potential conflicts.  (People say 'weak uniform convergence' in various contexts, but nobody ever says 'pointwise uniform convergence'.)


## Subsidiary concepts

Let $X$ and $Y$ be pointwise uniform convergence spaces.  A [[function]] $f$ from $X$ to $Y$ is __[[uniformly continuous function|uniformly continuous]]__ if $f \times f\colon X \to Y$ takes asymptotic filters only to asymptotic filters.  Then $f$ is a __uniform homeomorphism__ if $f$ is a [[bijection]] whose [[inverse function|inverse]] is also uniformly continuous.  We take the uniformly continuous functions to be the [[morphisms]] of a [[category]] $Unif Conv$ whose [[objects]] are the uniform convergence spaces; then the uniform homeomorphisms are the [[isomorphisms]] of this category.

Now let $X$ and $Y$ be pointwise quasiuniform spaces.  The definitions above may be repeated with 'quasiuniform' instead of 'uniform'.  If we ever use 'uniform' with pointwise quasiuniform convergence spaces, this means to use the pointwise uniform convergence structure generated by the given pointwise quasiuniform convergence structure.  (The pointwise uniform convergence structure generated by a quasiuniform convergence structure will be a uniform convergence structure, so we may leave 'pointwise' out of this paragraph entirely if so desired.)

Let $X$ be a pointwise uniform convergence space.  A filter $F$ on $X$ is __[[Cauchy filter|Cauchy]]__ if it is [[proper filter|proper]] and $F \times F$ (which is a filter on $X \times X$) is asymptotic.  Then the Cauchy filters on $X$ form a Cauchy structure that makes $X$ into a [[Cauchy space]].  If $X$ is a pointwise quasiuniform convergence space, then we may use the same definition.  In any case, the result depends only on the generated uniform convergence structure.

Let $X$ be a pointwise uniform convergence space.  A filter $F$ on $X$ __[[convergence|converges]]__ to a point $a$ in $X$ if $F \times U_a$, where $U_a$ is the principal ultrafilter at $a$ (the collection of all subsets of $X$ to which $a$ belongs), is asymptotic; we may use $U_a \times F$ instead and get the same result.  Then this relation of convergence is a convergence structure that makes $X$ into a [[convergence space]], and this convergence space will be [[reciprocal space|reciprocal]] ($R_1$).  If $X$ is a pointwise quasiuniform convergence space, then we may use the same definition, but the result may no longer be reciprocal, and using $U_a \times F$ instead will give a different convergence structure (and where $U_a$ converges to $b$ one way, $U_b$ converges to $a$ the other way).  Nevertheless, the result depends only on the generated quasiuniform convergence structure.

The convergence space structure induced by the Cauchy structure induced by a pointwise uniform convergence space is the same as the convergence structure induced directly by the pointwise uniform convergence space.  This fails for (pointwise) quasiuniform convergence spaces, but it remains true that every convergent filter is Cauchy.  A pointwise qausiuniform convergence space is __[[complete space|complete]]__ if, conversely, every Cauchy filter converges to at least one point.  Also, the space is __[[Hausdorff space|Hausdorff]]__ if every Cauchy filter (and hence every filter) converges to at *most* one point.  The complete Hausdorff uniform convergence spaces form a [[reflective subcategory]] of $Unif Conv$, so every uniform convergence space has a __[[Hausdorff completion]]__.


## Examples

Let $X$ be a [[metric space]] and call an [[infinite sequence]] in $X \times X$ _asymptotic_ if, when viewed as a [[pairing|pair]] $(a,b)$ of infinite sequences in $X$, these sequences satisfy the relation given in the Motivation above:
$$ \lim_{n \to \infty} {\|a_n - b_n\|} = 0 .$$
The [[eventuality filters]] of the asymptotic sequences in $X \times X$ form a base for a uniform convergence structure.  The same holds even if $X$ is only a [[pseudometric space]] or an [[extended metric space]]; but if $X$ is only a [[quasimetric space]], then we get only a base for a quasiuniform convergence structure.

Now let $X$ be a [[uniform space]] and let a filter be _asymptotic_ if every [[entourage]] belongs to it.  Indeed, if $E$ is the collection of entourages, then $E$ is itself a filter on $X \times X$ and $\{E\}$ is already a base for this uniform convergence structure.  If $X$ is the underlying uniform space of a metric space, then this is the same uniform convergence structure as in the previous paragraph.  If $X$ is only a [[quasiuniform space]], then we get only a quasiuniform convergence structure.

Now let $X$ be a [[Cauchy space]] and let a filter $F$ on $X 
\times X$ be _subbasic asymptotic_ if $F = G \times G$ for some Cauchy filter $G$ on $X$.  Then the subbasic asymptotic filters form a subbase for a uniform convergence structure, and the Cauchy structure induced by this uniform convergence structure agrees with the original Cauchy structure on $X$.

Now let $X$ be a [[convergence space]] and let a filter $F$ on $X \times X$ be _subbasic asymptotic_ if $F = G \times G$ for some convergent filter $G$ on $X$.  Then the subbasic asymptotic filters form a subbase for a quasiuniform convergence structure, which is a (pointwise) uniform convergence structure iff $X$ is [[reciprocal space|reciprocal]] ($R_1$).  In any case, the convergence structure induced by this quasiuniform convergence structure agrees with the original convergence structure on $X$.

If $X$ is a [[group object]] in the category $Conv$ of convergence spaces (that is, $X$ is both a convergence space and a [[group]] such the group operations are [[continuous function|continuous]]), then there are two other ways to make $X$ into a uniform convergence space (left and right, which agree if $X$ is an [[abelian group]]), analogous to the ways in which a [[topological group]] becomes a [[uniform space]].  Specifically, let a [[net]] in $X \times X$ be _asymptotic_ if, when viewed as a [[pairing|pair]] $(a,b)$ of nets (with common domain) in $X$, these sequences satisfy a relation analogous to that for asymptotic sequences in a metric space above:
$$ \lim_{n \to \infty} a_n b_n^{-1} = 1 $$
(on one side) or
$$ \lim_{n \to \infty} a_n^{-1} b_n = 1 $$
(on the other side).  The [[eventuality filters]] of the asymptotic nets in $X \times X$ form a base for a uniform convergence structure; indeed, they are precisely the proper asymptotic filters.  The convergence structure induced by this uniform convergence structure agrees with the original convergence structure on $X$ (which must be reciprocal, for essentially the same reason that the topology of a topological group must be).  Probably one can get a quasiuniform convergence structure or four out of a [[monoid object]] in $Conv$, but I haven\'t thought that through.


## References

Pages 72--76 (in Part I) in

* Jan Harm van der Walt (2009); _Generalized solutions of systems of nonlinear partial differential equations_ (PhD thesis); [web](http://upetd.up.ac.za/thesis/available/etd-05242009-122628/).

(This dissertation is not really about uniform convergence spaces, but it has the advantage of being free online.)


[[!redirects uniform convergence space]]
[[!redirects uniform convergence spaces]]

[[!redirects uniform convergence structure]]
[[!redirects uniform convergence structures]]

[[!redirects pointwise uniform convergence space]]
[[!redirects pointwise uniform convergence spaces]]
[[!redirects weak uniform convergence space]]
[[!redirects weak uniform convergence spaces]]

[[!redirects pointwise uniform convergence structure]]
[[!redirects pointwise uniform convergence structures]]
[[!redirects weak uniform convergence structure]]
[[!redirects weak uniform convergence structures]]

[[!redirects quasiuniform convergence space]]
[[!redirects quasiuniform convergence spaces]]

[[!redirects quasiuniform convergence structure]]
[[!redirects quasiuniform convergence structures]]

[[!redirects pointwise quasiuniform convergence space]]
[[!redirects pointwise quasiuniform convergence spaces]]
[[!redirects weak quasiuniform convergence space]]
[[!redirects weak quasiuniform convergence spaces]]

[[!redirects pointwise quasiuniform convergence structure]]
[[!redirects pointwise quasiuniform convergence structures]]
[[!redirects weak quasiuniform convergence structure]]
[[!redirects weak quasiuniform convergence structures]]
