
> This entry is about the notion of limit in [[analysis]] and [[topology]]. For the notion of the same name in [[category theory]] see at _[[limit]]_.

+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Topology
+-- {: .hide}
[[!include topology - contents]]
=--
=--
=--

# Contents
* table of contents
{: toc}

## Idea

A _limit_ of a [[sequence]] (or [[net]]) of points $(x_i)$ in a [[topological space]] (or other [[convergence space]]) $X$ is a point $x$ such that the sequence eventually gets arbitrarily close to $x$.  We can also speak of a limit of a [[filter]] on $X$.

The notion is of particular and historical importance in [[analysis]], where it serves to define for instance the notion of [[derivative]].


## Definitions

The precise definition depends on what sort of space $X$ is.

+-- {: .num_defn #topological}
###### Definition

If $X$ a [[topological space]] and $I$ the set of [[natural numbers]] (or more generally any [[directed set]]) and $\nu = (x_i)_{i\in I}\colon I \to X$ is a [[sequence]] (or a [[net]]) of points in $X$, one says that a point $x \in X$ is a **limit** of $\nu$ or that $\nu$ **converges** to $x$ if for each [[neighbourhood]] $U$ in $X$ of $x$ there exists an $n \in I$ such that $x_i \in U$ for each $i \geq n$.
=--

An important special case (the original) is:

+-- {: .num_defn #real}
###### Definition

If $X$ the [[real line]] and $I$ the set of [[natural numbers]] (or more generally any [[directed set]]) and $\nu = (x_i)_{i\in I}\colon I \to X$ is a [[sequence]] (or a [[net]]) of [[real numbers]], one says that a point $x \in X$ is a **limit** of $\nu$ or that $\nu$ **converges** to $x$ if for each [[positive number]] $\epsilon$ there exists an $n \in I$ such that ${|x_i - x|} \lt \epsilon$ for each $i \geq n$.
=--

An important generalization (possibly the most general) is:

+-- {: .num_defn #convergence}
###### Definition

If $X$ a [[convergence space]] and $I$ the set of [[natural numbers]] (or more generally any [[directed set]]) and $\nu = (x_i)_{i\in I}\colon I \to X$ is a [[sequence]] (or a [[net]]) of points in $X$, one says that a point $x \in X$ is a **limit** of $\nu$ or that $\nu$ **converges** to $x$ if the [[eventuality filter]] of $\nu$ converges to $x$ (which is a primitive concept in convergence spaces).
=--

Other types of [[space]] for which we might put in definitions (or which might have definitions on their own pages) are ([[extended metric space|extended]]) ([[quasimetric space|quasi]])-([[pseudometric space|pseudo]])-[[metric spaces]], ([[quasiuniform space|quasi]])-[[uniform spaces]], [[pretopological spaces]], and (quasi)-[[uniform convergence spaces]].


### Notation

When one of the conditions above holds, we may write any of the following, where ‘$\to$’ is read as 'converges to':

* $\nu \to x$,
* $x_i \to_i x$,
* $x_i \to x$ (suppressing the index $i$ by abuse of notation).


Or we may write any of the following, were $\lim$ is read as 'the set of limits of':

* $x \in \lim \nu$,
* $x \in \lim_i x_i$,
* $x \in \lim x_i$ (suppressing the index $i$ by abuse of notation).

Of course, the right-hand side has a meaning by itself, as the set of limits itself (a [[subset]] of the [[underlying set]] of $X$, or a [[subspace]] of $X$ itself).


If $X$ is a [[Hausdorff space]], then there is at most one point $x$ with the property that the sequence (or net) $\nu$ converges to $x$.  Then we may write any of the following, were now $\lim$ is read as 'the limit of':

* $x = \lim \nu$,
* $x = \lim_i x_i$,
* $x = \lim x_i$ (suppressing the index $i$ by abuse of notation).

Now the right-hand side by itself is the possibly undefined [[term]] for the limit itself (if it exists).


### Limits of filters

More generally than [[sequences]], and equivalently to [[nets]], we may speak of limits of [[filters]] on $X$.  This concept is axiomatized directly in the concept of [[convergence space]]. In the case of a [[topological space]] $X$, a filter of subsets of $X$ converges to a point $x$ if every neighbourhood of $x$ is contained in the filter.

In the definitions above, equivalent nets (those with equal [[eventuality filters]]) always converge to the same point.  As every [[proper filter]] is the eventuality filter of some net, a proper filter converges to $x$ if any of these nets converges to $x$; the [[improper filter]] converges to every point.  (In [[constructive mathematics]], we may cover all filters by saying: $F$ converges to $x$ if, on the assumption that $F$ is proper, any of its nets converges to $x$.)

## Properties

### Relation to limits in the sense of category theory
 {#RelationToLimitsInCategoryTheory}

The [[limits]] of [[category theory]] are a great generalization of an analogy with the limits discussed here.  It turns out, however, that limits in [[topological spaces]] (at least) can be viewed as category-theoretic limits. For now, see [this math.sx answer](http://math.stackexchange.com/a/62800).


## Examples

* [[geometric series]]

## Related concepts

* [[filter]]

* [[convergence space]]

* [[series]]

* [[limit point]]

* [[radius of convergence]]

* [[uniform convergence]], [[pointwise convergence]]

* [[divergent series]]

## References

* Wikipedia, _[Limit (mathematics)](http://en.wikipedia.org/wiki/Limit_%28mathematics%29)_

Discussion of this history of the concept, with emphasis on its roots all the way back in [[Zeno's paradoxes of motion]] is in 

* {#Boyer49} Carl Benjamin Boyer, _The history of the Calculus and its conceptual development_, Dover 1949


category: analysis

[[!redirects convergence]]
[[!redirects convergences]]
[[!redirects convergencies]]

[[!redirects converges]]

[[!redirects convergence of a sequence]]
[[!redirects convergence of sequences]]
[[!redirects convergence of a net]]
[[!redirects convergence of nets]]
[[!redirects convergence of a filter]]
[[!redirects convergence of filters]]

[[!redirects convergent sequence]]
[[!redirects convergent sequences]]
[[!redirects convergent net]]
[[!redirects convergent nets]]
[[!redirects convergent filter]]
[[!redirects convergent filters]]

[[!redirects limit of a sequence]]
[[!redirects limits of a sequence]]
[[!redirects limits of sequences]]
[[!redirects limit of a net]]
[[!redirects limits of a net]]
[[!redirects limits of nets]]
[[!redirects limit of a filter]]
[[!redirects limits of a filter]]
[[!redirects limits of filters]]
