
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Locality and descent
+--{: .hide}
[[!include descent and locality - contents]]
=--
=--
=--

# Contents
* table of contents
{:toc}

## Idea

In general, [[localization]] is a process of adding formal inverses to an algebraic structure. The _localization_ of a [[category]] $C$ at a collection $W$ of its [[morphism]]s is -- if it exists -- the result of universally making all morphisms in $W$ into [[isomorphism]]s.

### Motivation

A classic example is the [[localization of a commutative ring]]: we can 'localize the ring $\mathbb{Z}$ away from the prime $2$' and obtain the ring $\mathbb{Z}[\frac{1}{2}]$, or localize it away from all primes and obtain its field of fractions: the field $\mathbb{Q}$ of [[rational number|rational numbers]].

The terminology is odd for historical and geometric reasons: localizing *at* a prime means inverting things *not* divisible by that prime, while inverting the prime itself is called localizing *away* from that prime.  The reason for this, as well as for the term 'localization', becomes more apparent when we consider examples of a more vividly geometric flavor.  

For example, the ring $\mathbb{R}[x]$ consists of [[polynomial]] functions on the real line.  If we pick a point $a \in \mathbb{R}$ and localize $\mathbb{R}[x]$ by putting in an inverse to the element $(x-a)$, the resulting ring consists of [[rational function]]s defined _everywhere_ on the real line _except_ possibly at the point $a$.  This is called **localization _away from_ $a$**, or localization away from the [[ideal]] $I$ generated by $(x-a)$.  

If on the other hand we put in an inverse to every element of $\mathbb{R}[x]$ that is _not_ in the ideal $I$, we obtain the ring of rational functions defined _somewhere_ on the real line _at least_ at the point $a$: namely, those without a factor of $(x-a)$ in the denominator.  This is called **localizing _at_ $a$**, or localizing at the ideal $I$.

Notice that what is literally 'localized' when localizing the ring is not the ring itself, but its [[spectrum of a commutative ring|spectrum]]: the spectrum becomes smaller.  The spectrum of $\mathbb{R}[x]$ is the whole real line.  When we localize away from $a$, the resulting ring has spectrum $\mathbb{R} - \{a\}$.  When we localize at $a$, the resulting ring has spectrum $\{a\}$.

The case of localizing $\mathbb{Z}$ can also be interpreted geometrically in a similar way, using [[scheme]] theory and [[arithmetic geometry]].

A ring is a very special case of a [[category]], namely a one-object [[Ab-enriched category]].  This article mainly treats the more general case of localizing an arbitrary category.  The localization of a category $C$ at a class of [[morphisms]] $W$ is the universal solution to making the morphisms in $W$ into [[isomorphisms]]; it is variously written $C[W^{-1}]$, $W^{-1}C$ or $L_W C$.  In some contexts, it also could be called the [[homotopy category]] of $C$ with respect to $W$.


## Definition

Let $C$ be a [[category]] and $W \subset Mor(C)$ a collection of [[morphisms]]. 


### General 

A **localization** of $C$ by $W$ (or "at $W$") is

* a (generally [[large category|large]], see below) [[category]] $C[W^{-1}]$;

* and a functor $Q : C \to C[W^{-1}]$;

* such that

  * for all $w \in W$, $Q(w)$ is an [[isomorphism]];

  * for any category $A$ and any [[functor]] $F : C \to A$ such that $F(w)$ is an [[isomorphism]] for all $w \in W$, there exists a functor $F_W : C[W^{-1}] \to A$ and a [[natural transformation|natural isomorphism]] $F \simeq F_W \circ Q$;

  * the map between [[functor category|functor categories]]
  $$(-)\circ Q : Funct(C[W^{-1}], A) \to Funct(C,A)$$ 
  is [[fully faithful functor|full and faithful]] for every category $A$.

Note:

* if $C[W^{-1}]$ exists, it is unique up to [[equivalence]].

* In 2-categorical language, $C[W^{-1}]$ is the [[coinverter]] of the canonical natural transformation $s\to t$, where $s,t:W\to C$ are the "source" and "target" functors and $W$ is considered as a full subcategory of the [[arrow category]] $C ^{\mathbf{2}}$.

* **size issues**: If $C$ is [[large category|large]], then the existence of $C[W^{-1}]$ may depend on [[foundations]], and it will not necessarily be [[locally small category|locally small]] even if $C$ is.  The tools of [[homotopy theory]], and in particular [[model category|model categories]], can be used to address this question (see also at _[[homotopy category of a model category]]_).  


### Reflective localization

A special class of localizations are _[[reflective localizations]]_, those where the functor $C \to L_W C$ has a [[full and faithful functor|full and faithful]] [[right adjoint]] $L_W C \hookrightarrow C$.

In such a case

$$
  L_W C 
    \stackrel{\overset{Q}{\leftarrow}}{\hookrightarrow}
  C
$$

this adjoint exhibits $L_W C$ as a [[reflective subcategory]] of $C$. 

One shows that $L_W C$ is -- up to [[equivalence of categories]] -- the full subcategory on the $W$-[[local object]]s, and this property precisely characterizes such reflective localizations.

More on this is at [[reflective subcategory]] and [[reflective sub-(∞,1)-category]], and also [[reflective factorization system]].

### Localizations of enriched categories

Given a symmetric closed monoidal category $V$, a $V$-enriched category $A$ with underlying ordinary category $A_0$ and a subcategory $\Sigma$ of $A_0$
containing the identities of $A_0$, H. Wolff defines the corresponding theory of localizations. See [[localization of an enriched category]].
 
## Construction 

There is a general construction of $C[W^{-1}]$, if it exists, which is however hard to use.   When the system $W$ has special properties, most notably when $W$ admits a [[calculus of fractions]] or a [[factorization system]], then there are more direct formulas for the [[hom-sets]] of $C[W^{-1}]$.


### General construction 

If $C$ is a category and $W$ is a set of arrows, we construct the localization of $C$. Let $W^{op}$ be the set in $C^{op}$ corresponding to $W$ (it isn't necessarily a category).

Let $G$ be the following [[quiver|directed graph]]: 

* the vertices of $G$ are the objects of $C$,
* the arrows of $G$ between two vertices $x,y$ are given by the disjoint union $C(x,y)\coprod W^{op}(x,y)$.

The arrows in $W^{op}(x,y)$ are written as $\overline{f}$ for $f\in W(y,x)$.

Let $\mathcal{P}G$ be the [[free functor|free]] category on $G$. The identity arrows are given by the empty path beginning and ending at a given object. We introduce a relation on the arrows of $\mathcal{P}G$ and quotient by the equivalence relation $\sim$ generated by it to get $C[W^{-1}]$.

The equivalence relation $\sim$ is generated by

* for all objects $x$ of $C$, 
$$(x;id_x;x) \sim (x;\emptyset;x)$$
* for all $f:x\to y$ and $g:y\to z$ in $C$, 
$$(x;f,g;z)\sim (x;g\circ f;z)$$
* for all $f:x\to y$ in $W$, 
$$(x;f,\overline{f};x)\sim (x;id_x;x)$$
and
$$(y;\overline{f},f;y)\sim (y;id_y;y)$$

(Continue to show the quotient by $\sim$ gives a category, that it is locally small, and that if $C$ is small, the quotient is small.)

+-- {: .query}
[[David Roberts]]: This could probably be described as the [[fundamental category]] of 2-dimensional [[simplicial complex]] with the directed space structure coming from the 1-skeleton, which will be the path category above. In that case, we could/should probably leave out the paths of zero length. 
=--


### Construction when there is a calculus of fractions 

If the class $W$ admits a [[calculus of fractions]], then there is a simpler description of $C[W^{-1}]$ in terms of [[span|spans]] instead of zig-zags.  The idea is that any morphism $f: x \to z$ in $C[W^{-1}]$ is built from a morphism $f_2 : y \to z$ in $C$ and a morphism $f_1 : y \to x$ in $W$:

$$  x \stackrel{f_1}{\longleftarrow} y \stackrel{f_2}{\longrightarrow} z $$

For more on this, see the entry [[calculus of fractions]].

Dorette Pronk has extended this idea to construct a [[bicategory of fractions|bicategories of fractions]]  where a class of 1-arrows is sent to [[equivalence|equivalences]].

### In abelian categories

Localization is especially well developed in abelian setup where several competing formalisms and input data are used. See [[localization of an abelian category]]. 

## Properties
 {#Properties}

* The localization of the [[product category]] of two [[categories with weak equivalences]] is (if it exists) the product of their localizations

  $$
    (\mathcal{C} \times \mathcal{D})[ (W_{\mathcal{C}} \times W_{\mathcal{D}})^{-1} ]
    \;\;
      \simeq
    \;\;
    ( \mathcal{C}[W_{\mathcal{C}}^{-1}] )
     \times
    ( \mathcal{D}[W_{\mathcal{D}}^{-1}] )
    \,.
  $$

  This is because localization is a [[reflector]] into the [[exponential ideal]] of minimal categories with weak equivalences.

## In higher category theory

The notion of localization of a category has analogs in [[higher category theory]].

For [[(∞,1)-categories]] and the special case of reflective embeddings this is discussed in

* [[localization of an (∞,1)-category]].

Every [[locally presentable (∞,1)-category]] is presented by a [[combinatorial model category|combinatorial]] [[model category]]. Accordingly, there is a model for the localization of $(\infty,1)$-categories in terms of these models. This is called

* left [[Bousfield localization of model categories]]

See also [[localization of a simplicial model category]].

## Related concepts

* [[localizing subcategory]], [[localizer]]

* [[monoidal localization]]

* [[simplicial localization]]

* [[localization of a simplicial model category]]

* [[localization of a ring]], [[localization of a commutative ring]]

  * [[localization of a module]]

* [[localization of model categories]]

  * [[localization of simplicial model categories]]

  * [[Bousfield localization of model categories]]

    * [[Bousfield localization of spectra]]

    * [[p-localization]]

* [[colocalization]]

## References

The classical reference to localization for categories is the book by Gabriel and Zisman:

* P. Gabriel, M. Zisman, _[[Calculus of fractions and homotopy theory]]_, Springer, New York, 1967. _Ergebnisse der Mathematik und ihrer Grenzgebiete_, Band 35. 
 
A more recent account of localization with a [[calculus of fractions]] is section 7 of

* [[M. Kashiwara]], [[P. Schapira]], _[[Categories and Sheaves]]_, Springer 2000. 

An excellent account emphasizing the interplay of the different notions (reflective subcategory, calculus of fractions, closure operator) can be found in ch. V of

* [[Francis Borceux|F. Borceux]], _Handbook of Categorical Algebra vol. 1_ , Cambridge UP 1994.[^borceux]

[^borceux]: See also vols.2,3 for examples of the theory in action in abelian categories, sheaf theory etc.

The pioneering work on abelian categories, with a large part on the localization in abelian categories is

* [[Pierre Gabriel]], [[Des catégories abéliennes]], Bulletin de la Société Mathématique de France, 90 (1962), p. 323-448, [numdam](http://www.numdam.org/item?id=BSMF_1962__90__323_0)

A __terminological discussion__ prompted by question in which sense "localization" is a descriptive term or not is archived ion $n$Forum [here](https://nforum.ncatlab.org/discussion/481/localization/?Focus=23461#Comment_23461).

A formal implementation of Gabriel-Zisman localization in [[ZFC]], which in turn is implemented in the [[proof assistant]] [[Coq]] is in 

* {#Simpson05} [[Carlos Simpson]], _Explaining Gabriel-Zisman localization to the computer_ ([arXiv:math/0506471](http://arxiv.org/abs/math/0506471), [web](http://math.unice.fr/~carlos/themes/verif.html))

A [[HoTT]]-[[Coq]]-formalization of left-exact [[reflective sub-(∞,1)-categories]] ([[localization of an (∞,1)-category]]) in [[homotopy type theory]] is in 

* {#Shulman} [[Mike Shulman]], _[HoTT/Coq/Subcategories/LexReflectiveSubcategory.v](https://github.com/mikeshulman/HoTT/blob/master/Coq/Subcategories/LexReflectiveSubcategory.v)_
 
An original account of [[localization of commutative rings]] and of [[p-localization|p-local]] [[homotopy theory]] is 

* {#Sullivan70} [[Dennis Sullivan]], _Localization, Periodicity and Galois Symmetry_ (The 1970 MIT notes) edited by [[Andrew Ranicki]], K-Monographs in Mathematics, Dordrecht: Springer ([pdf](http://www.maths.ed.ac.uk/~aar/surgery/gtop.pdf)) 




[[!redirects localization]]
[[!redirects localizations]]
[[!redirects localisation]]
[[!redirects localisations]]

[[!redirects localization of a category]]
[[!redirects localizations of a category]]
[[!redirects localizations of categories]]


[[!redirects localization functor]]
[[!redirects localization functors]]
[[!redirects localisation functor]]
[[!redirects localisation functors]]