
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
###Context###
#### Category theory
+--{: .hide}
[[!include category theory - contents]]
=--
#### Compact objects
+--{: .hide}
[[!include compact object - contents]]
=--
=--
=--



# Contents
* table of contents
{:toc}

## Idea 

An accessible [[category]] is a possibly [[large category]] which is however essentially determined by a [[small category]], in a certain way.  

## Definition 

+-- {: .num_defn }
###### Definition 

A [[locally small category]] $C$ is **$\kappa$-accessible** for a [[regular cardinal]] $\kappa$ if:

1.  the category has $\kappa$-[[directed colimits]] (or, equivalently, $\kappa$-filtered colimits), and

1.  there is a [[set]] of $\kappa$-[[compact objects]] that generate the category under $\kappa$-directed colimits.

Then $C$ is an **accessible category** if there exists a $\kappa$ so that it is $\kappa$-accessible.

=--

+-- {: .num_remark }
###### Remark

Unlike for [[locally presentable categories]], it does not follow that if $C$ is $\kappa$-accessible and $\kappa\lt \lambda$ then $C$ is also $\lambda$-accessible.  It is true, however, that for any accessible category, there are arbitrarily large cardinals $\lambda$ such that $C$ is $\lambda$-accessible.

=--

+-- {: .num_prop }
###### Proposition

Equivalent characterizations include that $C$ is accessible iff:

* it is the category of [[models]] (in [[Set]]) of some small [[sketch]].

* it is of the form $Ind_\kappa(S)$ for $S$ small, i.e. the $\kappa$-[[ind-object|ind-completion]] of a small category, for some $\kappa$.

* it is of the form $\kappa\,Flat(S)$ for $S$ small and some $\kappa$, i.e. the category of $\kappa$-[[flat functor|flat]] functors from some small category to $Set$.

* it is the category of models (in $Set$) of a suitable type of logical theory.

=--

The relevant notion of [[functor]] between accessible categories is 

+-- {: .num_defn }
###### Definition 

A [[functor]] $F\colon C\to D$ between accessible categories is 
an **[[accessible functor]]**  if there exists a $\kappa$ such that $C$ and $D$ are both $\kappa$-accessible and $F$ preserves $\kappa$-[[filtered colimits]].

=--

## Properties 
 {#Properties}

### Stability under various constructions

+-- {: .num_prop}
###### Proposition 

If $\mathcal{C}$ is an accessible category and $K$ is a [[small category]], then the [[category of presheaves]] $Func(K^{op}, \mathcal{C})$ is again accessible.

=--

([Lurie, prop. 5.4.4.3](#Lurie))

+-- {: .num_prop #StabilityUnderInverseImage}
###### Proposition 
**(preservation of accessibility under inverse images)**

Let $F : C \to D$ be a [[functor]] between [[locally presentable categories]] which preserves $\kappa$-[[filtered category|filtered]] [[colimits]], and let $D_0 \subset D$ be an accessible subcategory. Then the inverse image $f^{-1}(D_0) \subset C$ is a $\kappa$-accessible subcategory.

=--


This appears as [[Higher Topos Theory|HTT, corollary A.2.6.5]].



+-- {: .num_prop}
###### Proposition 
**(accessibility of fibrations and weak equivalences in a combinatorial model category)**

Let $C$ be a [[combinatorial model category]], $Arr(C)$ its [[arrow category]], $W \subset Arr(C)$ the [[full subcategory]] on the weak equivalences and $F \subset Arr(C)$ the full subcategory on the fibrations. Then $F$, $W$ and $F \cap W$ are accessible subcategories of $Arr(C)$.

=--

This appears as [[Higher Topos Theory|HTT, corollary A.2.6.6]].



+-- {: .num_prop #Limits}
###### Proposition 
**(closure under limits)**

The [[2-category]] $Acc$ of accessible categories, accessible functors, and natural transformations has all small [[2-limits]].

=--

This can be found in [Makkai-Paré](#MakkaiPare).  Some special cases are proven in [Adámek-Rosický](#AdamekRosicky).



+-- {: .num_prop}
###### Proposition 
**(directed unions)**

The [[2-category]] $Acc$ has [[directed colimits]] of systems of [[fully faithful functors]].  If there is a proper class of [[strongly compact cardinals]], then it has directed colimits of systems of [[faithful functors]].

=--

See ([Paré-Rosický](#ParéRosický)).

### Adjoint functor theorem

+-- {: .num_prop}
###### Proposition 
**(adjoint functors)**

Every accessible functor satisfies the [[solution set condition]], and every left or right adjoint between accessible categories is accessible.  Therefore, the [[adjoint functor theorem]] takes an especially pleasing form for accessible categories: a functor is a left (resp. right) adjoint iff it is accessible and preserves all small colimits (resp. limits).

=--

### Idempotence completeness

+-- {: .num_prop}
###### Proposition 

A [[small category]] is accessible precisely when it is [[idempotent complete category|idempotent complete]].  

=--

[Makkai-Paré](#MakkaiPare) say that this means accessibility is an "almost pure smallness condition."


### Categories of models over a theory

+-- {: .num_prop }
###### Proposition

A [[geometric theory]] $T$ is a [[theory of presheaf type]] precisely if its category $Mod(T,Set)$ of [[models]] in [[Set]] is a finitely accessible category, and if and only if it is [[sketch|sketchable]].

=--


See also at _[categorical model theory](model+theory#CategoricalModelTheory)_.

## Examples

### Functor categories

See at _[Functor category -- Accessibility](functor+category#LocalPresentability)_.

## Related concepts

* [[class-accessible category]]

[[!include locally presentable categories - table]]



## References 

The term _accessible category_ is due to

* {#MakkaiPare89}  [[Michael Makkai]], [[Robert Paré]], _Accessible categories: The foundations of categorical model theory_ Contemporary Mathematics 104. American Mathematical
Society, Rhode Island, 1989.1989. 
{#MakkaiPare}

The standard textbook on the theory of accessible categories is

* [[Jiří Adámek]], [[Jiří Rosický]], _[[Locally presentable and accessible categories]]_, Cambridge University Press, (1994)
 {#AdamekRosicky}

See also

* [[Robert Paré]], [[Jiří Rosický]], _Colimits of accessible categories_ ([arXiv:1110.0767](http://arxiv.org/abs/1110.0767))
 {#ParéRosický}

and 

* [[Jiří Adámek]], [[Francis Borceux]], [[Stephen Lack]], [[Jiří Rosický]], _A classification of accessible categories,_ Journal of Pure and Applied Algebra 175:7-30, 2002. [abstract](http://maths.mq.edu.au/~slack/papers/acc.html)

which further stratifies the accessible categories in terms of [[sound doctrines]].

A discussion of [[accessible (∞,1)-categories]] is in [section 5.4, p. 341](http://arxiv.org/PS_cache/math/pdf/0608/0608040v4.pdf#page=341)
of

* [[Jacob Lurie]], _[[Higher Topos Theory]]_ 

Accessible categories in the context of [categorical model theory](model+theory#CategoricalModelTheory) are further discussed in


* [[Tibor Beke]], [[Jiří Rosický]], _Abstract elementary classes and accessible categories_, 2011   ([pdf](http://www.math.muni.cz/~rosicky/papers/elem7.pdf))


[[!redirects accessible categories]]