
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Analysis
+-- {: .hide}
[[!include analysis - contents]]
=--
#### Topology
+-- {: .hide}
[[!include topology - contents]]
=--
=--
=--

# Limit points
* table of contents
{: toc}

## Idea

Given a [[space]] $S$, a [[subspace]] $A$ of $S$, and a [[concrete point]] $x$ in $S$, $x$ is a _limit point_ of $A$ if $x$ can be approximated by the contents of $A$.

There are several variations on this idea, and the term 'limit point' itself is ambiguous (sometimes meaning Definition \ref{adherent}, sometimes Definition \ref{accumulation}.


## Definitions

The classical definitions apply when $S$ is a [[topological space]].  Then $A$ may be thought of as a [[subset]] of (the [[underlying set]] of) $S$, and $x$ as an [[element]].  In order to apply the definitions in [[constructive mathematics]], there needs to be an [[inequality relation]] $\ne$ on the points of $S$; in [[classical mathematics]], this is taken to be the [[denial inequality]], as usual.  (We need not assume that $\ne$ is an [[apartness relation]] nor any compatibility between $\ne$ and the topology, at least for the definitions; although it\'s quite possible that some classical theorems will require such assumptions.)

For the most general definitions, let $\kappa$ be a collection of [[cardinal numbers]].  (We might want $\kappa$ to have some closure properties akin to those of an [[arity class]], but the definition there is not quite what we want.)  Recall that a _$\kappa$-[[arity|ary]] [[indexed subset]]_ of $S$ is a [[function]] $B\colon I \to S$ such that the [[cardinality]] of $I$ belongs to the class $\kappa$; a point $y$ is _in_ $B$ (as an indexed subset) if $y$ belongs to the [[range]] of $B$ (as a function), and $y$ is _out_ of $B$ if $y$ is inequal ($\ne$) to every point in $B$.

+-- {: .num_defn #general}
###### Definitions

The point $x$ is a __$\kappa$-adherent point__ of the subspace $A$ if, for each [[neighbourhood]] $U$ of $x$, for each $\kappa$-ary indexed subset $B$ of the [[intersection]] $U \cap A$, there is an element $y$ of $U \cap A$ that is out of $B$.  Slightly more strongly, $x$ is a __$\kappa$-accumulation point__ (or __$\kappa$-cluster point__)  of $A$ if, for each neighbourhood $U$ of $x$, for each $\kappa$-ary indexed subset $B$ of $U \cap A$, there is an element $y \ne x$ of $U \cap A$ that is out of $B$.  (Alternatively, take $U$ to be a [[punctured neighborhood]], but that won\'t work constructively in general.)
=--

Every $\kappa$-accumulation point is a $\kappa$-adherent point; the converse holds if every $k \in \kappa$ satisfies $k + 1 \in \kappa$ (and then one usually says 'accumulation' rather than 'adherent').  Also, if $\kappa \subseteq \lambda$, then every $\lambda$-(adherent/accumulation) point is a $\kappa$-(adherent/accumulation) point.

It immediately follows that the following classical special cases are in order of increasing strength:

*  Using $\kappa = 1 = \{0\}$:

   +-- {: .num_defn #adherent}
   ###### Definition

   The point $x$ is an __adherent point__ of the subspace $A$ if, for every neighbourhood $U$ of $x$, the intersection $U \cap A$ is [[inhabited subset|inhabited]] (nonempty).
   =--

*  Using $\kappa = 1$ again:

   +-- {: .num_defn #accumulation}
   ###### Definition

   The point $x$ is an __accumulation point__ of the subspace $A$ if, for every punctured neighbourhood $U$ of $x$, the intersection $U \cap A$ is inhabited.
   =--

*  Using $\kappa = \omega = \{0, 1, 2, \ldots\}$:

   +-- {: .num_defn #omega}
   ###### Definition

   The point $x$ is an __$\omega$-accumulation point__ of the subspace $A$ if, for every neighbourhood $U$ of $x$, the intersection $U \cap A$ is [[infinite set|infinite]].
   =--

*  Using $\kappa = \omega_1 = \{0, 1, 2, \ldots, \aleph_0\}$:

   +-- {: .num_defn #condensation}
   ###### Definition

   The point $x$ is a __condensation point__ of the subspace $A$ if, for every neighbourhood $U$ of $x$, the intersection $U \cap A$ is [[uncountable set|uncountable]].
   =--


## Properties

The subspace $A$ is [[closed subspace|closed]] iff every adherent point of $A$ belongs to $A$ and iff every accumulation point of $A$ belongs to $A$.  (Thus one may say that $A$ is closed iff every limit point of $A$ belongs to $A$ without ambiguity.)

More generally, the [[topological closure|closure]] of $A$ is the set of all adherent points of $A$.  Classically (using [[excluded middle]], or more generally if $S$ has [[decidable equality]]), the closure of $A$ is the [[union]] of $A$ and its set of accumulation points.

Classically, a point in $A$ that is not an accumulation point of $A$ is precisely an [[isolated point]].  (Constructively, each of these is stronger than the negation of the other.)

A justification for the terminology 'limit point' for an accumulation point is that the concept of [[limit of a fuction]] approaching a point really only makes sense approaching an accumulation point.  (This is for essentially the same reason that every function is continuous at an isolated point.)  More precisely, every answer whatsoever satisfies the definition of $\lim_c f$ if $c$ is a non-accumulation point of $dom f$ (because the [[improper filter]] converges everywhere).


## Related concepts

* [[limit of a sequence]]

## References

* Wikipedia, _[Limit point](https://en.wikipedia.org/wiki/Limit_point)_


[[!redirects limit point]]
[[!redirects limit points]]

[[!redirects adherent point]]
[[!redirects adherent points]]

[[!redirects accumulation point]]
[[!redirects accumulation points]]

[[!redirects cluster point]]
[[!redirects cluster points]]

[[!redirects ω-accumulation point]]
[[!redirects ω-accumulation points]]
[[!redirects ωaccumulation point]]
[[!redirects ωaccumulation points]]
[[!redirects omega-accumulation point]]
[[!redirects omega-accumulation points]]

[[!redirects condensation point]]
[[!redirects condensation points]]
