
+-- {: .rightHandSide}
+-- {: .toc .clickDown tabindex="0"}
### Context
#### Philosophy
+-- {: .hide}
[[!include philosophy - contents]]
=--
=--
=--

This page collects material related to

* [[Bertrand Russell]],

  _Logic As the Essence of Philosophy_

  1914

  ([web](http://www.readbookonline.net/read/62308/109598/))

on [[formal logic]] as a tool in [[philosophy]], criticizing the "old old logic",  [[Aristotle's logic]] of [[syllogism]], [[Hegel]]'s [[metaphysics|metaphysical]] "[[objective logic]]" ([I]({#OnHegelsLogicI}), [II]({#OnHegelsLogicII}), [III]({#OnHegelsLogicIII})), and championing ([I](#ConclusionAndOutlook)) the "new logic" (modern [[predicate logic]]) initiated by [[Peano]] and [[Frege]] ([I](#EnterPeanoFrege)).

***

> The topics we discussed in our first lecture, and the topics we shall discuss later, all reduce themselves, in so far as they are genuinely philosophical, to problems of logic. This is not due to any accident, but to the fact that every philosophical problem, when it is subjected to the necessary analysis and purification, is found either to be not really philosophical at all, or else to be, in the sense in which we are using the word, logical. But as the word "logic" is never used in the same sense by two different philosophers, some explanation of what I mean by the word is indispensable at the outset.

> Logic, in the Middle Ages, and down to the present day in teaching, meant no more than a scholastic collection of technical terms and rules of syllogistic inference. Aristotle had spoken, and it was the part of humbler men merely to repeat the lesson after him. The trivial nonsense embodied in this tradition is still set in examinations, and defended by eminent authorities as an excellent "propædeutic," i.e. a training in those habits of solemn humbug which are so great a help in later life. But it is not this that I mean to praise in saying that all philosophy is logic. Ever since the beginning of the seventeenth century, all vigorous minds that have concerned themselves with inference have abandoned the mediæval tradition, and in one way or other have widened the scope of logic.

> The first extension was the introduction of the inductive method by Bacon and Galileo--by the former in a theoretical and largely mistaken form, by the latter in actual use in establishing the foundations of modern physics and astronomy. This is probably the only extension of the old logic which has become familiar to the general educated public. But induction, important as it is when regarded as a method of investigation, does not seem to remain when its work is done: in the final form of a perfected science, it would seem that everything ought to be deductive. If induction remains at all, which is a difficult question, it will remain merely as one of the principles according to which deductions are effected. Thus the ultimate result of the introduction of the inductive method seems not the creation of a new kind of non-deductive reasoning, but rather the widening of the scope of deduction by pointing out a way of deducing which is certainly not syllogistic, and does not fit into the mediæval scheme.

> The question of the scope and validity of induction is of great difficulty, and of great importance to our knowledge. Take such a question as, "Will the sun rise to-morrow?" Our first instinctive feeling is that we have abundant reason for saying that it will, because it has risen on so many previous mornings. Now, I do not myself know whether this does afford a ground or not, but I am willing to suppose that it does. The question which then arises is: What is the principle of inference by which we pass from past sunrises to future ones? The answer given by Mill is that the inference depends upon the law of causation. Let us suppose this to be true; then what is the reason for believing in the law of causation? There are broadly three possible answers: (1) that it is itself known a priori; (2) that it is a postulate; (3) that it is an empirical generalisation from past instances in which it has been found to hold. The theory that causation is known a priori cannot be definitely refuted, but it can be rendered very unplausible by the mere process of formulating the law exactly, and thereby showing that it is immensely more complicated and less obvious than is generally supposed. The theory that causation is a postulate, i.e. that it is something which we choose to assert although we know that it is very likely false, is also incapable of refutation; but it is plainly also incapable of justifying any use of the law in inference. We are thus brought to the theory that the law is an empirical generalisation, which is the view held by Mill.

> But if so, how are empirical generalisations to be justified? The evidence in their favour cannot be empirical, since we wish to argue from what has been observed to what has not been observed, which can only be done by means of some known relation of the observed and the unobserved; but the unobserved, by definition, is not known empirically, and therefore its relation to the observed, if known at all, must be known independently of empirical evidence. Let us see what Mill says on this subject.

> According to Mill, the law of causation is proved by an admittedly fallible process called "induction by simple enumeration." This process, he says, "consists in ascribing the nature of general truths to all propositions which are true in every instance that we happen to know of."[8] As regards its fallibility, he asserts that "the precariousness of the method of simple enumeration is in an inverse ratio to the largeness of the generalisation. The process is delusive and insufficient, exactly in proportion as the subject-matter of the observation is special and limited in extent. As the sphere widens, this unscientific method becomes less and less liable to mislead; and the most universal class of truths, the law of causation for instance, and the principles of number and of geometry, are duly and satisfactorily proved by that method alone, nor are they susceptible of any other proof."[9]

>[8] Logic, book iii., chapter iii., § 2.
>[9] Book iii., chapter xxi., § 3.

> In the above statement, there are two obvious lacunæ: (1) How is the method of simple enumeration itself justified? (2) What logical principle, if any, covers the same ground as this method, without being liable to its failures? Let us take the second question first.

> A method of proof which, when used as directed, gives sometimes truth and sometimes falsehood--as the method of simple enumeration does--is obviously not a valid method, for validity demands invariable truth. Thus, if simple enumeration is to be rendered valid, it must not be stated as Mill states it. We shall have to say, at most, that the data render the result probable. Causation holds, we shall say, in every instance we have been able to test; therefore it probably holds in untested instances. There are terrible difficulties in the notion of probability, but we may ignore them at present. We thus have what at least may be a logical principle, since it is without exception. If a proposition is true in every instance that we happen to know of, and if the instances are very numerous, then, we shall say, it becomes very probable, on the data, that it will be true in any further instance. This is not refuted by the fact that what we declare to be probable does not always happen, for an event may be probable on the data and yet not occur. It is, however, obviously capable of further analysis, and of more exact statement. We shall have to say something like this: that every instance of a proposition[10] being true increases the probability of its being true in a fresh instance, and that a sufficient number of favourable instances will, in the absence of instances to the contrary, make the probability of the truth of a fresh instance approach indefinitely near to certainty. Some such principle as this is required if the method of simple enumeration is to be valid.

> [10] Or rather a propositional function.

> But this brings us to our other question, namely, how is our principle known to be true? Obviously, since it is required to justify induction, it cannot be proved by induction; since it goes beyond the empirical data, it cannot be proved by them alone; since it is required to justify all inferences from empirical data to what goes beyond them, it cannot itself be even rendered in any degree probable by such data. Hence, if it is known, it is not known by experience, but independently of experience. I do not say that any such principle is known: I only say that it is required to justify the inferences from experience which empiricists allow, and that it cannot itself be justified empirically.[11]

> [11] The subject of causality and induction will be discussed again in Lecture VIII.

> A similar conclusion can be proved by similar arguments concerning any other logical principle. Thus logical knowledge is not derivable from experience alone, and the empiricist's philosophy can therefore not be accepted in its entirety, in spite of its excellence in many matters which lie outside logic.

> {#OnHegelsLogicI} Hegel and his followers widened the scope of logic in quite a different way--a way which I believe to be fallacious, but which requires discussion if only to show how their conception of logic differs from the conception which I wish to advocate. In their writings, logic is practically identical with metaphysics. In broad outline, the way this came about is as follows. Hegel believed that, by means of a priori reasoning, it could be shown that the world must have various important and interesting characteristics, since any world without these characteristics would be impossible and self-contradictory. Thus what he calls "logic" is an investigation of the nature of the universe, in so far as this can be inferred merely from the principle that the universe must be logically self-consistent. I do not myself believe that from this principle alone anything of importance can be inferred as regards the existing universe. But, however that may be, I should not regard Hegel's reasoning, even if it were valid, as properly belonging to logic: it would rather be an application of logic to the actual world. Logic itself would be concerned rather with such questions as what self-consistency is, which Hegel, so far as I know, does not discuss. And though he criticises the traditional logic, and professes to replace it by an improved logic of his own, there is some sense in which the traditional logic, with all its faults, is uncritically and unconsciously assumed throughout his reasoning. It is not in the direction advocated by him, it seems to me, that the reform of logic is to be sought, but by a more fundamental, more patient, and less ambitious investigation into the presuppositions which his system shares with those of most other philosophers.

> {#OnHegelsLogicII} The way in which, as it seems to me, Hegel's system assumes the ordinary logic which it subsequently criticises, is exemplified by the general conception of "categories" with which he operates throughout. This conception is, I think, essentially a product of logical confusion, but it seems in some way to stand for the conception of "qualities of Reality as a whole." Mr Bradley has worked out a theory according to which, in all judgment, we are ascribing a predicate to Reality as a whole; and this theory is derived from Hegel. Now the traditional logic holds that every proposition ascribes a predicate to a subject, and from this it easily follows that there can be only one subject, the Absolute, for if there were two, the proposition that there were two would not ascribe a predicate to either. Thus Hegel's doctrine, that philosophical propositions must be of the form, "the Absolute is such-and-such," depends upon the traditional belief in the universality of the subject-predicate form. This belief, being traditional, scarcely self-conscious, and not supposed to be important, operates underground, and is assumed in arguments which, like the refutation of relations, appear at first sight such as to establish its truth. This is the most important respect in which Hegel uncritically assumes the traditional logic. Other less important respects--though important enough to be the source of such essentially Hegelian conceptions as the "concrete universal" and the "union of identity in difference"--will be found where he explicitly deals with formal logic.[12]

> {#OnHegelsLogicIII} [12] See the translation by H. S. Macran, Hegel's Doctrine of Formal Logic, Oxford, 1912. Hegel's argument in this portion of his "Logic" depends throughout upon confusing the "is" of predication, as in "Socrates is mortal," with the "is" of identity, as in "Socrates is the philosopher who drank the hemlock." Owing to this confusion, he thinks that "Socrates" and "mortal" must be identical. Seeing that they are different, he does not infer, as others would, that there is a mistake somewhere, but that they exhibit "identity in difference." Again, Socrates is particular, "mortal" is universal. Therefore, he says, since Socrates is mortal, it follows that the particular is the universal--taking the "is" to be throughout expressive of identity. But to say "the particular is the universal" is self-contradictory. Again Hegel does not suspect a mistake but proceeds to synthesise particular and universal in the individual, or concrete universal. This is an example of how, for want of care at the start, vast and imposing systems of philosophy are built upon stupid and trivial confusions, which, but for the almost incredible fact that they are unintentional, one would be tempted to characterise as puns.

> There is quite another direction in which a large technical development of logic has taken place: I mean the direction of what is called logistic or mathematical logic. This kind of logic is mathematical in two different senses: it is itself a branch of mathematics, and it is the logic which is specially applicable to other more traditional branches of mathematics. Historically, it began as merely a branch of mathematics: its special applicability to other branches is a more recent development. In both respects, it is the fulfilment of a hope which Leibniz cherished throughout his life, and pursued with all the ardour of his amazing intellectual energy. Much of his work on this subject has been published recently, since his discoveries have been remade by others; but none was published by him, because his results persisted in contradicting certain points in the traditional doctrine of the syllogism. We now know that on these points the traditional doctrine is wrong, but respect for Aristotle prevented Leibniz from realising that this was possible.[13]

>[13] Cf. Couturat, La Logique de Leibniz, pp. 361, 386.

> {#EnterPeanoFrege} The modern development of mathematical logic dates from Boole's Laws of Thought (1854). But in him and his successors, before Peano and Frege, the only thing really achieved, apart from certain details, was the invention of a mathematical symbolism for deducing consequences from the premisses which the newer methods shared with those of Aristotle. This subject has considerable interest as an independent branch of mathematics, but it has very little to do with real logic. The first serious advance in real logic since the time of the Greeks was made independently by Peano and Frege--both mathematicians. They both arrived at their logical results by an analysis of mathematics. Traditional logic regarded the two propositions, "Socrates is mortal" and "All men are mortal," as being of the same form;[14] Peano and Frege showed that they are utterly different in form. The philosophical importance of logic may be illustrated by the fact that this confusion--which is still committed by most writers--obscured not only the whole study of the forms of judgment and inference, but also the relations of things to their qualities, of concrete existence to abstract concepts, and of the world of sense to the world of Platonic ideas. Peano and Frege, who pointed out the error, did so for technical reasons, and applied their logic mainly to technical developments; but the philosophical importance of the advance which they made is impossible to exaggerate.

> [14] It was often recognised that there was some difference between them, but it was not recognised that the difference is fundamental, and of very great importance.
Mathematical logic, even in its most modern form, is not directly of philosophical importance except in its beginnings. After the beginnings, it belongs rather to mathematics than to philosophy. Of its beginnings, which are the only part of it that can properly be called philosophical logic, I shall speak shortly. But even the later developments, though not directly philosophical, will be found of great indirect use in philosophising. They enable us to deal easily with more abstract conceptions than merely verbal reasoning can enumerate; they suggest fruitful hypotheses which otherwise could hardly be thought of; and they enable us to see quickly what is the smallest store of materials with which a given logical or scientific edifice can be constructed. Not only Frege's theory of number, which we shall deal with in Lecture VII., but the whole theory of physical concepts which will be outlined in our next two lectures, is inspired by mathematical logic, and could never have been imagined without it.

> In both these cases, and in many others, we shall appeal to a certain principle called "the principle of abstraction." This principle, which might equally well be called "the principle which dispenses with abstraction," and is one which clears away incredible accumulations of metaphysical lumber, was directly suggested by mathematical logic, and could hardly have been proved or practically used without its help. The principle will be explained in our fourth lecture, but its use may be briefly indicated in advance. When a group of objects have that kind of similarity which we are inclined to attribute to possession of a common quality, the principle in question shows that membership of the group will serve all the purposes of the supposed common quality, and that therefore, unless some common quality is actually known, the group or class of similar objects may be used to replace the common quality, which need not be assumed to exist. In this and other ways, the indirect uses of even the later parts of mathematical logic are very great; but it is now time to turn our attention to its philosophical foundations.

> In every proposition and in every inference there is, besides the particular subject-matter concerned, a certain form, a way in which the constituents of the proposition or inference are put together. If I say, "Socrates is mortal," "Jones is angry," "The sun is hot," there is something in common in these three cases, something indicated by the word "is." What is in common is the form of the proposition, not an actual constituent. If I say a number of things about Socrates--that he was an Athenian, that he married Xantippe, that he drank the hemlock--there is a common constituent, namely Socrates, in all the propositions I enunciate, but they have diverse forms. If, on the other hand, I take any one of these propositions and replace its constituents, one at a time, by other constituents, the form remains constant, but no constituent remains. Take (say) the series of propositions, "Socrates drank the hemlock," "Coleridge drank the hemlock," "Coleridge drank opium," "Coleridge ate opium." The form remains unchanged throughout this series, but all the constituents are altered. Thus form is not another constituent, but is the way the constituents are put together. It is forms, in this sense, that are the proper object of philosophical logic.

> It is obvious that the knowledge of logical forms is something quite different from knowledge of existing things. The form of "Socrates drank the hemlock" is not an existing thing like Socrates or the hemlock, nor does it even have that close relation to existing things that drinking has. It is something altogether more abstract and remote. We might understand all the separate words of a sentence without understanding the sentence: if a sentence is long and complicated, this is apt to happen. In such a case we have knowledge of the constituents, but not of the form. We may also have knowledge of the form without having knowledge of the constituents. If I say, "Rorarius drank the hemlock," those among you who have never heard of Rorarius (supposing there are any) will understand the form, without having knowledge of all the constituents. In order to understand a sentence, it is necessary to have knowledge both of the constituents and of the particular instance of the form. It is in this way that a sentence conveys information, since it tells us that certain known objects are related according to a certain known form. Thus some kind of knowledge of logical forms, though with most people it is not explicit, is involved in all understanding of discourse. It is the business of philosophical logic to extract this knowledge from its concrete integuments, and to render it explicit and pure.

> In all inference, form alone is essential: the particular subject-matter is irrelevant except as securing the truth of the premisses. This is one reason for the great importance of logical form. When I say, "Socrates was a man, all men are mortal, therefore Socrates was mortal," the connection of premisses and conclusion does not in any way depend upon its being Socrates and man and mortality that I am mentioning. The general form of the inference may be expressed in some such words as, "If a thing has a certain property, and whatever has this property has a certain other property, then the thing in question also has that other property." Here no particular things or properties are mentioned: the proposition is absolutely general. All inferences, when stated fully, are instances of propositions having this kind of generality. If they seem to depend upon the subject-matter otherwise than as regards the truth of the premisses, that is because the premisses have not been all explicitly stated. In logic, it is a waste of time to deal with inferences concerning particular cases: we deal throughout with completely general and purely formal implications, leaving it to other sciences to discover when the hypotheses are verified and when they are not.

> But the forms of propositions giving rise to inferences are not the simplest forms: they are always hypothetical, stating that if one proposition is true, then so is another. Before considering inference, therefore, logic must consider those simpler forms which inference presupposes. Here the traditional logic failed completely: it believed that there was only one form of simple proposition (i.e. of proposition not stating a relation between two or more other propositions), namely, the form which ascribes a predicate to a subject. This is the appropriate form in assigning the qualities of a given thing--we may say "this thing is round, and red, and so on." Grammar favours this form, but philosophically it is so far from universal that it is not even very common. If we say "this thing is bigger than that," we are not assigning a mere quality of "this," but a relation of "this" and "that." We might express the same fact by saying "that thing is smaller than this," where grammatically the subject is changed. Thus propositions stating that two things have a certain relation have a different form from subject-predicate propositions, and the failure to perceive this difference or to allow for it has been the source of many errors in traditional metaphysics.

> The belief or unconscious conviction that all propositions are of the subject-predicate form--in other words, that every fact consists in some thing having some quality--has rendered most philosophers incapable of giving any account of the world of science and daily life. If they had been honestly anxious to give such an account, they would probably have discovered their error very quickly; but most of them were less anxious to understand the world of science and daily life, than to convict it of unreality in the interests of a super-sensible "real" world. Belief in the unreality of the world of sense arises with irresistible force in certain moods--moods which, I imagine, have some simple physiological basis, but are none the less powerfully persuasive. The conviction born of these moods is the source of most mysticism and of most metaphysics. When the emotional intensity of such a mood subsides, a man who is in the habit of reasoning will search for logical reasons in favour of the belief which he finds in himself. But since the belief already exists, he will be very hospitable to any reason that suggests itself. The paradoxes apparently proved by his logic are really the paradoxes of mysticism, and are the goal which he feels his logic must reach if it is to be in accordance with insight. It is in this way that logic has been pursued by those of the great philosophers who were mystics--notably Plato, Spinoza, and Hegel. But since they usually took for granted the supposed insight of the mystic emotion, their logical doctrines were presented with a certain dryness, and were believed by their disciples to be quite independent of the sudden illumination from which they sprang. Nevertheless their origin clung to them, and they remained--to borrow a useful word from Mr Santayana--"malicious" in regard to the world of science and common sense. It is only so that we can account for the complacency with which philosophers have accepted the inconsistency of their doctrines with all the common and scientific facts which seem best established and most worthy of belief.

> The logic of mysticism shows, as is natural, the defects which are inherent in anything malicious. While the mystic mood is dominant, the need of logic is not felt; as the mood fades, the impulse to logic reasserts itself, but with a desire to retain the vanishing insight, or at least to prove that it was insight, and that what seems to contradict it is illusion. The logic which thus arises is not quite disinterested or candid, and is inspired by a certain hatred of the daily world to which it is to be applied. Such an attitude naturally does not tend to the best results. Everyone knows that to read an author simply in order to refute him is not the way to understand him; and to read the book of Nature with a conviction that it is all illusion is just as unlikely to lead to understanding. If our logic is to find the common world intelligible, it must not be hostile, but must be inspired by a genuine acceptance such as is not usually to be found among metaphysicians.

> Traditional logic, since it holds that all propositions have the subject-predicate form, is unable to admit the reality of relations: all relations, it maintains, must be reduced to properties of the apparently related terms. There are many ways of refuting this opinion; one of the easiest is derived from the consideration of what are called "asymmetrical" relations. In order to explain this, I will first explain two independent ways of classifying relations.

> Some relations, when they hold between A and B, also hold between B and A. Such, for example, is the relation "brother or sister." If A is a brother or sister of B, then B is a brother or sister of A. Such again is any kind of similarity, say similarity of colour. Any kind of dissimilarity is also of this kind: if the colour of A is unlike the colour of B, then the colour of B is unlike the colour of A. Relations of this sort are called symmetrical. Thus a relation is symmetrical if, whenever it holds between A and B, it also holds between B and A.

> All relations that are not symmetrical are called non-symmetrical. Thus "brother" is non-symmetrical, because, if A is a brother of B, it may happen that B is a sister of A.

> A relation is called asymmetrical when, if it holds between A and B, it never holds between B and A. Thus husband, father, grandfather, etc., are asymmetrical relations. So are before, after, greater, above, to the right of, etc. All the relations that give rise to series are of this kind.

> Classification into symmetrical, asymmetrical, and merely non-symmetrical relations is the first of the two classifications we had to consider. The second is into transitive, intransitive, and merely non-transitive relations, which are defined as follows.

> A relation is said to be transitive, if, whenever it holds between A and B and also between B and C, it holds between A and C. Thus before, after, greater, above are transitive. All relations giving rise to series are transitive, but so are many others. The transitive relations just mentioned were asymmetrical, but many transitive relations are symmetrical--for instance, equality in any respect, exact identity of colour, being equally numerous (as applied to collections), and so on.

> A relation is said to be non-transitive whenever it is not transitive. Thus "brother" is non-transitive, because a brother of one's brother may be oneself. All kinds of dissimilarity are non-transitive.

> A relation is said to be intransitive when, if A has the relation to B, and B to C, A never has it to C. Thus "father" is intransitive. So is such a relation as "one inch taller" or "one year later."

> Let us now, in the light of this classification, return to the question whether all relations can be reduced to predications.

> In the case of symmetrical relations--i.e. relations which, if they hold between A and B, also hold between B and A--some kind of plausibility can be given to this doctrine. A symmetrical relation which is transitive, such as equality, can be regarded as expressing possession of some common property, while one which is not transitive, such as inequality, can be regarded as expressing possession of different properties. But when we come to asymmetrical relations, such as before and after, greater and less, etc., the attempt to reduce them to properties becomes obviously impossible. When, for example, two things are merely known to be unequal, without our knowing which is greater, we may say that the inequality results from their having different magnitudes, because inequality is a symmetrical relation; but to say that when one thing is greater than another, and not merely unequal to it, that means that they have different magnitudes, is formally incapable of explaining the facts. For if the other thing had been greater than the one, the magnitudes would also have been different, though the fact to be explained would not have been the same. Thus mere difference of magnitude is not all that is involved, since, if it were, there would be no difference between one thing being greater than another, and the other being greater than the one. We shall have to say that the one magnitude is greater than the other, and thus we shall have failed to get rid of the relation "greater." In short, both possession of the same property and possession of different properties are symmetrical relations, and therefore cannot account for the existence of asymmetrical relations.

> Asymmetrical relations are involved in all series--in space and time, greater and less, whole and part, and many others of the most important characteristics of the actual world. All these aspects, therefore, the logic which reduces everything to subjects and predicates is compelled to condemn as error and mere appearance. To those whose logic is not malicious, such a wholesale condemnation appears impossible. And in fact there is no reason except prejudice, so far as I can discover, for denying the reality of relations. When once their reality is admitted, all logical grounds for supposing the world of sense to be illusory disappear. If this is to be supposed, it must be frankly and simply on the ground of mystic insight unsupported by argument. It is impossible to argue against what professes to be insight, so long as it does not argue in its own favour. As logicians, therefore, we may admit the possibility of the mystic's world, while yet, so long as we do not have his insight, we must continue to study the everyday world with which we are familiar. But when he contends that our world is impossible, then our logic is ready to repel his attack. And the first step in creating the logic which is to perform this service is the recognition of the reality of relations.

> Relations which have two terms are only one kind of relations. A relation may have three terms, or four, or any number. Relations of two terms, being the simplest, have received more attention than the others, and have generally been alone considered by philosophers, both those who accepted and those who denied the reality of relations. But other relations have their importance, and are indispensable in the solution of certain problems. Jealousy, for example, is a relation between three people. Professor Royce mentions the relation "giving": when A gives B to C, that is a relation of three terms.[15] When a man says to his wife: "My dear, I wish you could induce Angelina to accept Edwin," his wish constitutes a relation between four people, himself, his wife, Angelina, and Edwin. Thus such relations are by no means recondite or rare. But in order to explain exactly how they differ from relations of two terms, we must embark upon a classification of the logical forms of facts, which is the first business of logic, and the business in which the traditional logic has been most deficient.

> [15] Encyclopædia of the Philosophical Sciences, vol. i. p. 97.

> The existing world consists of many things with many qualities and relations. A complete description of the existing world would require not only a catalogue of the things, but also a mention of all their qualities and relations. We should have to know not only this, that, and the other thing, but also which was red, which yellow, which was earlier than which, which was between which two others, and so on. When I speak of a "fact," I do not mean one of the simple things in the world; I mean that a certain thing has a certain quality, or that certain things have a certain relation. Thus, for example, I should not call Napoleon a fact, but I should call it a fact that he was ambitious, or that he married Josephine. Now a fact, in this sense, is never simple, but always has two or more constituents. When it simply assigns a quality to a thing, it has only two constituents, the thing and the quality. When it consists of a relation between two things, it has three constituents, the things and the relation. When it consists of a relation between three things, it has four constituents, and so on. The constituents of facts, in the sense in which we are using the word "fact," are not other facts, but are things and qualities or relations. When we say that there are relations of more than two terms, we mean that there are single facts consisting of a single relation and more than two things. I do not mean that one relation of two terms may hold between A and B, and also between A and C, as, for example, a man is the son of his father and also the son of his mother. This constitutes two distinct facts: if we choose to treat it as one fact, it is a fact which has facts for its constituents. But the facts I am speaking of have no facts among their constituents, but only things and relations. For example, when A is jealous of B on account of C, there is only one fact, involving three people; there are not two instances of jealousy, but only one. It is in such cases that I speak of a relation of three terms, where the simplest possible fact in which the relation occurs is one involving three things in addition to the relation. And the same applies to relations of four terms or five or any other number. All such relations must be admitted in our inventory of the logical forms of facts: two facts involving the same number of things have the same form, and two which involve different numbers of things have different forms.

> Given any fact, there is an assertion which expresses the fact. The fact itself is objective, and independent of our thought or opinion about it; but the assertion is something which involves thought, and may be either true or false. An assertion may be positive or negative: we may assert that Charles I. was executed, or that he did not die in his bed. A negative assertion may be said to be a denial. Given a form of words which must be either true or false, such as "Charles I. died in his bed," we may either assert or deny this form of words: in the one case we have a positive assertion, in the other a negative one. A form of words which must be either true or false I shall call a proposition. Thus a proposition is the same as what may be significantly asserted or denied. A proposition which expresses what we have called a fact, i.e. which, when asserted, asserts that a certain thing has a certain quality, or that certain things have a certain relation, will be called an atomic proposition, because, as we shall see immediately, there are other propositions into which atomic propositions enter in a way analogous to that in which atoms enter into molecules. Atomic propositions, although, like facts, they may have any one of an infinite number of forms, are only one kind of propositions. All other kinds are more complicated. In order to preserve the parallelism in language as regards facts and propositions, we shall give the name "atomic facts" to the facts we have hitherto been considering. Thus atomic facts are what determine whether atomic propositions are to be asserted or denied.

> Whether an atomic proposition, such as "this is red," or "this is before that," is to be asserted or denied can only be known empirically. Perhaps one atomic fact may sometimes be capable of being inferred from another, though this seems very doubtful; but in any case it cannot be inferred from premisses no one of which is an atomic fact. It follows that, if atomic facts are to be known at all, some at least must be known without inference. The atomic facts which we come to know in this way are the facts of sense-perception; at any rate, the facts of sense-perception are those which we most obviously and certainly come to know in this way. If we knew all atomic facts, and also knew that there were none except those we knew, we should, theoretically, be able to infer all truths of whatever form.[16] Thus logic would then supply us with the whole of the apparatus required. But in the first acquisition of knowledge concerning atomic facts, logic is useless. In pure logic, no atomic fact is ever mentioned: we confine ourselves wholly to forms, without asking ourselves what objects can fill the forms. Thus pure logic is independent of atomic facts; but conversely, they are, in a sense, independent of logic. Pure logic and atomic facts are the two poles, the wholly a priori and the wholly empirical. But between the two lies a vast intermediate region, which we must now briefly explore.

> [16] This perhaps requires modification in order to include such facts as beliefs and wishes, since such facts apparently contain propositions as components. Such facts, though not strictly atomic, must be supposed included if the statement in the text is to be true.
"Molecular" propositions are such as contain conjunctions--if, or, and, unless, etc.--and such words are the marks of a molecular proposition. Consider such an assertion as, "If it rains, I shall bring my umbrella." This assertion is just as capable of truth or falsehood as the assertion of an atomic proposition, but it is obvious that either the corresponding fact, or the nature of the correspondence with fact, must be quite different from what it is in the case of an atomic proposition. Whether it rains, and whether I bring my umbrella, are each severally matters of atomic fact, ascertainable by observation. But the connection of the two involved in saying that if the one happens, then the other will happen, is something radically different from either of the two separately. It does not require for its truth that it should actually rain, or that I should actually bring my umbrella; even if the weather is cloudless, it may still be true that I should have brought my umbrella if the weather had been different. Thus we have here a connection of two propositions, which does not depend upon whether they are to be asserted or denied, but only upon the second being inferable from the first. Such propositions, therefore, have a form which is different from that of any atomic proposition.

> Such propositions are important to logic, because all inference depends upon them. If I have told you that if it rains I shall bring my umbrella, and if you see that there is a steady downpour, you can infer that I shall bring my umbrella. There can be no inference except where propositions are connected in some such way, so that from the truth or falsehood of the one something follows as to the truth or falsehood of the other. It seems to be the case that we can sometimes know molecular propositions, as in the above instance of the umbrella, when we do not know whether the component atomic propositions are true or false. The practical utility of inference rests upon this fact.

> The next kind of propositions we have to consider are general propositions, such as "all men are mortal," "all equilateral triangles are equiangular." And with these belong propositions in which the word "some" occurs, such as "some men are philosophers" or "some philosophers are not wise." These are the denials of general propositions, namely (in the above instances), of "all men are non-philosophers" and "all philosophers are wise." We will call propositions containing the word "some" negative general propositions, and those containing the word "all" positive general propositions. These propositions, it will be seen, begin to have the appearance of the propositions in logical text-books. But their peculiarity and complexity are not known to the text-books, and the problems which they raise are only discussed in the most superficial manner.

> When we were discussing atomic facts, we saw that we should be able, theoretically, to infer all other truths by logic if we knew all atomic facts and also knew that there were no other atomic facts besides those we knew. The knowledge that there are no other atomic facts is positive general knowledge; it is the knowledge that "all atomic facts are known to me," or at least "all atomic facts are in this collection"--however the collection may be given. It is easy to see that general propositions, such as "all men are mortal," cannot be known by inference from atomic facts alone. If we could know each individual man, and know that he was mortal, that would not enable us to know that all men are mortal, unless we knew that those were all the men there are, which is a general proposition. If we knew every other existing thing throughout the universe, and knew that each separate thing was not an immortal man, that would not give us our result unless we knew that we had explored the whole universe, i.e. unless we knew "all things belong to this collection of things I have examined." Thus general truths cannot be inferred from particular truths alone, but must, if they are to be known, be either self-evident, or inferred from premisses of which at least one is a general truth. But all empirical evidence is of particular truths. Hence, if there is any knowledge of general truths at all, there must be some knowledge of general truths which is independent of empirical evidence, i.e. does not depend upon the data of sense.

> The above conclusion, of which we had an instance in the case of the inductive principle, is important, since it affords a refutation of the older empiricists. They believed that all our knowledge is derived from the senses and dependent upon them. We see that, if this view is to be maintained, we must refuse to admit that we know any general propositions. It is perfectly possible logically that this should be the case, but it does not appear to be so in fact, and indeed no one would dream of maintaining such a view except a theorist at the last extremity. We must therefore admit that there is general knowledge not derived from sense, and that some of this knowledge is not obtained by inference but is primitive.

> Such general knowledge is to be found in logic. Whether there is any such knowledge not derived from logic, I do not know; but in logic, at any rate, we have such knowledge. It will be remembered that we excluded from pure logic such propositions as, "Socrates is a man, all men are mortal, therefore Socrates is mortal," because Socrates and man and mortal are empirical terms, only to be understood through particular experience. The corresponding proposition in pure logic is: "If anything has a certain property, and whatever has this property has a certain other property, then the thing in question has the other property." This proposition is absolutely general: it applies to all things and all properties. And it is quite self-evident. Thus in such propositions of pure logic we have the self-evident general propositions of which we were in search.

> A proposition such as, "If Socrates is a man, and all men are mortal, then Socrates is mortal," is true in virtue of its form alone. Its truth, in this hypothetical form, does not depend upon whether Socrates actually is a man, nor upon whether in fact all men are mortal; thus it is equally true when we substitute other terms for Socrates and man and mortal. The general truth of which it is an instance is purely formal, and belongs to logic. Since it does not mention any particular thing, or even any particular quality or relation, it is wholly independent of the accidental facts of the existent world, and can be known, theoretically, without any experience of particular things or their qualities and relations.

> Logic, we may say, consists of two parts. The first part investigates what propositions are and what forms they may have; this part enumerates the different kinds of atomic propositions, of molecular propositions, of general propositions, and so on. The second part consists of certain supremely general propositions, which assert the truth of all propositions of certain forms. This second part merges into pure mathematics, whose propositions all turn out, on analysis, to be such general formal truths. The first part, which merely enumerates forms, is the more difficult, and philosophically the more important; and it is the recent progress in this first part, more than anything else, that has rendered a truly scientific discussion of many philosophical problems possible.

> The problem of the nature of judgment or belief may be taken as an example of a problem whose solution depends upon an adequate inventory of logical forms. We have already seen how the supposed universality of the subject-predicate form made it impossible to give a right analysis of serial order, and therefore made space and time unintelligible. But in this case it was only necessary to admit relations of two terms. The case of judgment demands the admission of more complicated forms. If all judgments were true, we might suppose that a judgment consisted in apprehension of a fact, and that the apprehension was a relation of a mind to the fact. From poverty in the logical inventory, this view has often been held. But it leads to absolutely insoluble difficulties in the case of error. Suppose I believe that Charles I. died in his bed. There is no objective fact "Charles I.'s death in his bed" to which I can have a relation of apprehension. Charles I. and death and his bed are objective, but they are not, except in my thought, put together as my false belief supposes. It is therefore necessary, in analysing a belief, to look for some other logical form than a two-term relation. Failure to realise this necessity has, in my opinion, vitiated almost everything that has hitherto been written on the theory of knowledge, making the problem of error insoluble and the difference between belief and perception inexplicable.

> {#ConclusionAndOutlook} Modern logic, as I hope is now evident, has the effect of enlarging our abstract imagination, and providing an infinite number of possible hypotheses to be applied in the analysis of any complex fact. In this respect it is the exact opposite of the logic practised by the classical tradition. In that logic, hypotheses which seem primâ facie possible are professedly proved impossible, and it is decreed in advance that reality must have a certain special character. In modern logic, on the contrary, while the primâ facie hypotheses as a rule remain admissible, others, which only logic would have suggested, are added to our stock, and are very often found to be indispensable if a right analysis of the facts is to be obtained. The old logic put thought in fetters, while the new logic gives it wings. It has, in my opinion, introduced the same kind of advance into philosophy as Galileo introduced into physics, making it possible at last to see what kinds of problems may be capable of solution, and what kinds must be abandoned as beyond human powers. And where a solution appears possible, the new logic provides a method which enables us to obtain results that do not merely embody personal idiosyncrasies, but must command the assent of all who are competent to form an opinion. _ 


category: reference